/*
 * GdkDragDrop methods tests
 * Testing GdkDragDrop methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;


/*
 * Name: gdk_drag_begin
 * Params: GdkWindow *window, GList *targets
 * Returns: GdkDragContext*
 * Assertion: Starts a drag and creates a new drag context for it. This function is called by the drag source.
 * Params Values: the source window for this drag, the list of offered targets.
 * Expected: a newly created GdkDragContext.  
 */
static void test_purpose_1()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {}
    #define NTARGETS 0
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_begin
 * Params: GdkWindow *window, GList *targets
 * Returns: GdkDragContext*
 * Assertion: Starts a drag and creates a new drag context for it. This function is called by the drag source.
 * Params Values: the source window for this drag, the list of offered targets.
 * Expected: a newly created GdkDragContext.  
 */
static void test_purpose_2()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0}
    #define NTARGETS 1
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_begin
 * Params: GdkWindow *window, GList *targets
 * Returns: GdkDragContext*
 * Assertion: Starts a drag and creates a new drag context for it. This function is called by the drag source.
 * Params Values: the source window for this drag, the list of offered targets.
 * Expected: a newly created GdkDragContext.  
 */
static void test_purpose_3()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1}
    #define NTARGETS 2
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_begin
 * Params: GdkWindow *window, GList *targets
 * Returns: GdkDragContext*
 * Assertion: Starts a drag and creates a new drag context for it. This function is called by the drag source.
 * Params Values: the source window for this drag, the list of offered targets.
 * Expected: a newly created GdkDragContext.  
 */
static void test_purpose_4()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1, 2}
    #define NTARGETS 3
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_begin
 * Params: GdkWindow *window, GList *targets
 * Returns: GdkDragContext*
 * Assertion: Starts a drag and creates a new drag context for it. This function is called by the drag source.
 * Params Values: the source window for this drag, the list of offered targets.
 * Expected: a newly created GdkDragContext.  
 */
static void test_purpose_5()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1, 2, 3}
    #define NTARGETS 4
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_begin
 * Params: GdkWindow *window, GList *targets
 * Returns: GdkDragContext*
 * Assertion: Starts a drag and creates a new drag context for it. This function is called by the drag source.
 * Params Values: the source window for this drag, the list of offered targets.
 * Expected: a newly created GdkDragContext.  
 */
static void test_purpose_6()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1, 2, 3, 4}
    #define NTARGETS 5
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drop_finish
 * Params: GdkDragContext *context, gboolean success, guint32 time_
 * Returns: void
 * Assertion: Ends the drag operation after a drop. This function is called by the drag destination.
 * Params Values: a GtkDragContext, TRUE if the data was successfully received, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_7()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {}
    #define NTARGETS 0
    #define SUCCESS TRUE
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drop_finish (drag_context, SUCCESS, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef SUCCESS
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drop_finish
 * Params: GdkDragContext *context, gboolean success, guint32 time_
 * Returns: void
 * Assertion: Ends the drag operation after a drop. This function is called by the drag destination.
 * Params Values: a GtkDragContext, TRUE if the data was successfully received, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_8()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0}
    #define NTARGETS 1
    #define SUCCESS TRUE
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drop_finish (drag_context, SUCCESS, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef SUCCESS
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drop_finish
 * Params: GdkDragContext *context, gboolean success, guint32 time_
 * Returns: void
 * Assertion: Ends the drag operation after a drop. This function is called by the drag destination.
 * Params Values: a GtkDragContext, TRUE if the data was successfully received, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_9()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1}
    #define NTARGETS 2
    #define SUCCESS TRUE
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drop_finish (drag_context, SUCCESS, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef SUCCESS
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drop_finish
 * Params: GdkDragContext *context, gboolean success, guint32 time_
 * Returns: void
 * Assertion: Ends the drag operation after a drop. This function is called by the drag destination.
 * Params Values: a GtkDragContext, TRUE if the data was successfully received, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_10()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1, 2}
    #define NTARGETS 3
    #define SUCCESS FALSE
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drop_finish (drag_context, SUCCESS, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef SUCCESS
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drop_finish
 * Params: GdkDragContext *context, gboolean success, guint32 time_
 * Returns: void
 * Assertion: Ends the drag operation after a drop. This function is called by the drag destination.
 * Params Values: a GtkDragContext, TRUE if the data was successfully received, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_11()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1, 2, 3}
    #define NTARGETS 4
    #define SUCCESS FALSE
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drop_finish (drag_context, SUCCESS, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef SUCCESS
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drop_finish
 * Params: GdkDragContext *context, gboolean success, guint32 time_
 * Returns: void
 * Assertion: Ends the drag operation after a drop. This function is called by the drag destination.
 * Params Values: a GtkDragContext, TRUE if the data was successfully received, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_12()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1, 2, 3, 4}
    #define NTARGETS 5
    #define SUCCESS FALSE
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drop_finish (drag_context, SUCCESS, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef SUCCESS
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_drop
 * Params: GdkDragContext *context, guint32 time_
 * Returns: void
 * Assertion: Drops on the current destination. This function is called by the drag source.
 * Params Values: a GtkDragContext, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_13()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {}
    #define NTARGETS 0
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drag_drop (drag_context, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_drop
 * Params: GdkDragContext *context, guint32 time_
 * Returns: void
 * Assertion: Drops on the current destination. This function is called by the drag source.
 * Params Values: a GtkDragContext, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_14()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0}
    #define NTARGETS 1
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drag_drop (drag_context, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_drop
 * Params: GdkDragContext *context, guint32 time_
 * Returns: void
 * Assertion: Drops on the current destination. This function is called by the drag source.
 * Params Values: a GtkDragContext, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_15()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1}
    #define NTARGETS 2
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drag_drop (drag_context, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_drop
 * Params: GdkDragContext *context, guint32 time_
 * Returns: void
 * Assertion: Drops on the current destination. This function is called by the drag source.
 * Params Values: a GtkDragContext, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_16()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1, 2}
    #define NTARGETS 3
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drag_drop (drag_context, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_drop
 * Params: GdkDragContext *context, guint32 time_
 * Returns: void
 * Assertion: Drops on the current destination. This function is called by the drag source.
 * Params Values: a GtkDragContext, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_17()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1, 2, 3}
    #define NTARGETS 4
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drag_drop (drag_context, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_drop
 * Params: GdkDragContext *context, guint32 time_
 * Returns: void
 * Assertion: Drops on the current destination. This function is called by the drag source.
 * Params Values: a GtkDragContext, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_18()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1, 2, 3, 4}
    #define NTARGETS 5
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drag_drop (drag_context, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_status
 * Params: GdkDragContext *context, GdkDragAction action, guint32 time_
 * Returns: void
 * Assertion: Selects one of the actions offered by the drag source. This function is called by the drag destination in response to gdk_drag_motion() called by the drag source.
 * Params Values: a GtkDragContext, the selected action which will be taken when a drop happens, or 0 to indicate that a drop will not be accepted, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_19()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {}
    #define NTARGETS 0
    #define ACTION 0
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drag_status (drag_context, ACTION, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef ACTION
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_status
 * Params: GdkDragContext *context, GdkDragAction action, guint32 time_
 * Returns: void
 * Assertion: Selects one of the actions offered by the drag source. This function is called by the drag destination in response to gdk_drag_motion() called by the drag source.
 * Params Values: a GtkDragContext, the selected action which will be taken when a drop happens, or 0 to indicate that a drop will not be accepted, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_20()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0}
    #define NTARGETS 1
    #define ACTION GDK_ACTION_DEFAULT
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drag_status (drag_context, ACTION, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef ACTION
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_status
 * Params: GdkDragContext *context, GdkDragAction action, guint32 time_
 * Returns: void
 * Assertion: Selects one of the actions offered by the drag source. This function is called by the drag destination in response to gdk_drag_motion() called by the drag source.
 * Params Values: a GtkDragContext, the selected action which will be taken when a drop happens, or 0 to indicate that a drop will not be accepted, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_21()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1}
    #define NTARGETS 2
    #define ACTION GDK_ACTION_COPY
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drag_status (drag_context, ACTION, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef ACTION
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_status
 * Params: GdkDragContext *context, GdkDragAction action, guint32 time_
 * Returns: void
 * Assertion: Selects one of the actions offered by the drag source. This function is called by the drag destination in response to gdk_drag_motion() called by the drag source.
 * Params Values: a GtkDragContext, the selected action which will be taken when a drop happens, or 0 to indicate that a drop will not be accepted, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_22()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1, 2}
    #define NTARGETS 3
    #define ACTION GDK_ACTION_MOVE
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drag_status (drag_context, ACTION, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef ACTION
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_status
 * Params: GdkDragContext *context, GdkDragAction action, guint32 time_
 * Returns: void
 * Assertion: Selects one of the actions offered by the drag source. This function is called by the drag destination in response to gdk_drag_motion() called by the drag source.
 * Params Values: a GtkDragContext, the selected action which will be taken when a drop happens, or 0 to indicate that a drop will not be accepted, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_23()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1, 2, 3}
    #define NTARGETS 4
    #define ACTION GDK_ACTION_LINK
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drag_status (drag_context, ACTION, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef ACTION
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_status
 * Params: GdkDragContext *context, GdkDragAction action, guint32 time_
 * Returns: void
 * Assertion: Selects one of the actions offered by the drag source. This function is called by the drag destination in response to gdk_drag_motion() called by the drag source.
 * Params Values: a GtkDragContext, the selected action which will be taken when a drop happens, or 0 to indicate that a drop will not be accepted, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_24()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1, 2, 3, 4}
    #define NTARGETS 5
    #define ACTION GDK_ACTION_PRIVATE
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drag_status (drag_context, ACTION, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef ACTION
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drag_status
 * Params: GdkDragContext *context, GdkDragAction action, guint32 time_
 * Returns: void
 * Assertion: Selects one of the actions offered by the drag source. This function is called by the drag destination in response to gdk_drag_motion() called by the drag source.
 * Params Values: a GtkDragContext, the selected action which will be taken when a drop happens, or 0 to indicate that a drop will not be accepted, the timestamp for this operation.
 * Expected: void  
 */
static void test_purpose_25()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    #define TARGETS {0, 1, 2, 3, 4, 5}
    #define NTARGETS 6
    #define ACTION GDK_ACTION_ASK
    #define TIME GDK_CURRENT_TIME
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint data[] = TARGETS;
    GList *targets = NULL;
    GdkDragContext *drag_context;
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (NTARGETS != 0)
        for (i = 0; i < NTARGETS; i++)
            targets = g_list_prepend (targets, GINT_TO_POINTER (data[i]));
    
    drag_context = gdk_drag_begin (window, targets);
    
    if (!drag_context)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_DRAG_CONTEXT (drag_context))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    g_list_free (targets);
    
    gdk_drag_status (drag_context, ACTION, TIME);
    
    g_object_unref (drag_context);
    
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    #undef TARGETS
    #undef NTARGETS
    #undef ACTION
    #undef TIME
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkDragDrop ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {NULL,0}
};
