/*
 * GdkDrawPrimitives methods tests
 * Testing GdkDrawPrimitives methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
static GdkWindow *create_new_gdk_window()
{
    GdkWindowAttr parent_attributes = {"Lsb_Test", 0, 1, 2, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    return gdk_window_new(NULL, &parent_attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
}

/*
 * Name: gdk_draw_rectangle
 * Params: GdkDrawable *drawable, GdkGC *gc, gboolean filled, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a rectangular outline or filled rectangle, using the foreground color and other attributes of the GdkGC.
 *            A rectangle drawn filled is 1 pixel smaller in both dimensions than a rectangle outlined. Calling gdk_draw_rectangle (window, gc, TRUE, 0, 0, 20, 20) results in a filled rectangle 20 pixels wide and 20 pixels high. Calling gdk_draw_rectangle (window, gc, FALSE, 0, 0, 20, 20) results in an outlined rectangle with corners at (0, 0), (0, 20), (20, 20), and (20, 0), which makes it 21 pixels wide and 21 pixels high.
 *            drawable :    a GdkDrawable (a GdkWindow or a GdkPixmap).
 *            gc :    a GdkGC.
 *            filled :    TRUE if the rectangle should be filled.
 *            x : the x coordinate of the left edge of the rectangle.
 *            y : the y coordinate of the top edge of the rectangle.
 *            width : the width of the rectangle.
 *            height :    the height of the rectangle.
 * Params Values: GdkDrawable *drawable, GdkGC *gc, gboolean filled, gint x, gint y, gint width, gint height
 * Expected: void  
 */
static void test_purpose_1()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_window_show(gdk_window);
    gdk_draw_rectangle(gdk_window, gdk_gc, TRUE, 0, 0, 100, 100);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_draw_line
 * Params: GdkDrawable *drawable, GdkGC *gc, gint x1_, gint y1_, gint x2_, gint y2_
 * Returns: void
 * Assertion: Draws a line, using the foreground color and other attributes of the GdkGC.
 *            drawable :    a GdkDrawable (a GdkWindow or a GdkPixmap).
 *            gc :    a GdkGC.
 *            x1_ :     the x coordinate of the start point.
 *            y1_ :   the y coordinate of the start point.
 *            x2_ :   the x coordinate of the end point.
 *            y2_ :   the y coordinate of the end point.
 * Params Values: GdkDrawable *drawable, GdkGC *gc, gboolean filled, gint x1_, gint y1_, gint x2_, gint y2_
 * Expected: void  
 */
static void test_purpose_2()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_window_show(gdk_window);
    gdk_draw_line(gdk_window, gdk_gc, 0, 0, 100, 100);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_draw_lines
 * Params: GdkDrawable *drawable, GdkGC *gc, GdkPoint *points, gint npoints
 * Returns: void
 * Assertion: Draws a series of lines connecting the given points. The way in which joins between lines are draw is determined by the GdkCapStyle value in the GdkGC. This can be set with gdk_gc_set_line_attributes().
 *            drawable :    a GdkDrawable (a GdkWindow or a GdkPixmap).
 *            gc : a GdkGC.
 *            points : an array of GdkPoint structures specifying the endpoints of the
 *            npoints :    the size of the points array.
 * Params Values: GdkDrawable *drawable, GdkGC *gc, GdkPoint *points, gint npoints
 * Expected: void  
 */
static void test_purpose_3()
{
    gint i;
    GdkPoint points[5];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_window_show(gdk_window);
    for (i = 0; i < 5; i++){
        points[i].x = i * 10;
        points[i].y = i * 20;
    }
    gdk_draw_lines(gdk_window, gdk_gc, points, 5);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_draw_point
 * Params: GdkDrawable *drawable, GdkGC *gc, gint x, gint y
 * Returns: void
 * Assertion: Draws a point, using the foreground color and other attributes of the GdkGC.
 *            drawable :   a GdkDrawable (a GdkWindow or a GdkPixmap).
 *            gc : a GdkGC.
 *            x :  the x coordinate of the point.
 *            y :  the y coordinate of the point.
 * Params Values: GdkDrawable *drawable, GdkGC *gc, gint x, gint y
 * Expected: void  
 */
static void test_purpose_4()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_window_show(gdk_window);
    gdk_draw_point(gdk_window, gdk_gc, 100, 100);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_draw_points
 * Params: GdkDrawable *drawable, GdkGC *gc, GdkPoint *points, gint npoints
 * Returns: void
 * Assertion: Draws a number of points, using the foreground color and other attributes of the GdkGC
 *            drawable :    a GdkDrawable (a GdkWindow or a GdkPixmap).
 *            gc : a GdkGC.
 *            points : an array of GdkPoint structures specifying the endpoints of the
 *            npoints :  the number of points to be drawn.
 * Params Values: GdkDrawable *drawable, GdkGC *gc, GdkPoint *points, gint npoints
 * Expected: void  
 */
static void test_purpose_5()
{
    gint i;
    GdkPoint points[5];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_window_show(gdk_window);
    for (i = 0; i < 5; i++){
        points[i].x = i * 10;
        points[i].y = i * 20;
    }
    gdk_draw_points(gdk_window, gdk_gc, points, 5);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_draw_polygon
 * Params: GdkDrawable *drawable, GdkGC *gc, gboolean filled, GdkPoint *points, gint npoints
 * Returns: void
 * Assertion: Draws an outlined or filled polygon.
 *            drawable :    a GdkDrawable (a GdkWindow or a GdkPixmap).
 *            gc : a GdkGC.
 *            filled :  TRUE if the polygon should be filled. The polygon is closed automatically, connecting the last point to the first point if necessary.
 *            points : an array of GdkPoint structures specifying the endpoints of the
 *            npoints : the number of points.
 * Params Values: GdkDrawable *drawable, GdkGC *gc, gboolean filled, GdkPoint *points, gint npoints
 * Expected: void  
 */
static void test_purpose_6()
{
    gint i;
    GdkPoint points[5];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_window_show(gdk_window);
    for (i = 0; i < 5; i++){
        points[i].x = i * 10;
        points[i].y = i * 20;
    }
    gdk_draw_polygon(gdk_window, gdk_gc, TRUE, points, 5);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_draw_arc
 * Params: GdkDrawable *drawable, GdkGC *gc, gboolean filled, gint x, gint y, gint width, gint height, gint angle1, gint angle2
 * Returns: void
 * Assertion: Draws an arc or a filled 'pie slice'. The arc is defined by the bounding rectangle of the entire ellipse, and the start and end angles of the part of the ellipse to be drawn.
 *            drawable :    a GdkDrawable (a GdkWindow or a GdkPixmap).
 *            gc : a GdkGC.
 *            filled :  TRUE if the polygon should be filled. The polygon is closed automatically, connecting the last point to the first point if necessary.
 *            x :   the x coordinate of the left edge of the bounding rectangle.
 *            y :  the y coordinate of the top edge of the bounding rectangle.
 *            width :  the width of the bounding rectangle.
 *            height : the height of the bounding rectangle.
 *            angle1 : the start angle of the arc, relative to the 3 o'clock position, counter-clockwise, in 1/64ths of a degree.
 *            angle2 : the end angle of the arc, relative to angle1, in 1/64ths of a degree.
 * Params Values: GdkDrawable *drawable, GdkGC *gc, gboolean filled, gint x, gint y, gint width, gint height, gint angle1, gint angle2
 * Expected: void  
 */
static void test_purpose_7()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_window_show(gdk_window);
    gdk_draw_arc(gdk_window, gdk_gc, TRUE, 0, 0, 100, 100, 64, 64*10);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drawable_get_size
 * Params: GdkDrawable *drawable, gint *width, gint *height
 * Returns: void
 * Assertion: Fills *width and *height with the size of drawable. width or height can be NULL if you only want the other one.
 *            On the X11 platform, if drawable is a GdkWindow, the returned size is the size reported in the most-recently-processed configure event, rather than the current size on the X server.
 *            drawable :    a GdkDrawable
 *            width :  location to store drawable's width, or NULL
 *            height : location to store drawable's height, or NULL
 * Params Values: GdkDrawable *drawable, gint *width, gint *height
 * Expected: void  
 */
static void test_purpose_8()
{
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_drawable_get_size(gdk_window, &width, &height);
    if ((width != 100) || (height != 100))
        TEST_FAIL("gdk_drawable_get_size: failed", NULL);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drawable_get_depth
 * Params: GdkDrawable *drawable
 * Returns: gint
 * Assertion: Obtains the bit depth of the drawable, that is, the number of bits that make up a pixel in the drawable's visual. Examples are 8 bits per pixel, 24 bits per pixel, etc.
 *            drawable :    a GdkDrawable
 *            Returns :    number of bits per pixel
 * Params Values: GdkDrawable *drawable
 * Expected: gint  
 */
static void test_purpose_9()
{
    gint depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_window_show(gdk_window);
    depth = gdk_drawable_get_depth(gdk_window);
    if (depth <= 0)
        TEST_FAIL("gdk_drawable_get_depth: failed", NULL);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_draw_segments
 * Params: gdk_draw_segments, GdkGC *gc, GdkSegment *segs, gint nsegs
 * Returns: void
 * Assertion: Draws a number of unconnected lines.
 *            drawable :   a GdkDrawable (a GdkWindow or a GdkPixmap).
 *            gc : a GdkGC.
 *            segs :   an array of GdkSegment structures specifying the start and end points of the lines to be drawn.
 *            nsegs :  the number of line segments to draw, i.e. the size of the segs array.
 * Params Values: GdkDrawable *drawable
 * Expected: void  
 */
static void test_purpose_10()
{
    gint i;
    GdkSegment segs[5];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_window_show(gdk_window);
    for (i = 0; i < 5; i++){
        segs[i].x1 = i * 10;
        segs[i].y1 = i * 10;
        segs[i].x2 = i * 20;
        segs[i].y2 = i * 20;
    }
    gdk_draw_segments(gdk_window, gdk_gc, segs, 5);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_draw_drawable
 * Params: GdkDrawable *drawable, GdkGC *gc, GdkDrawable *src, gint xsrc, gint ysrc, gint xdest, gint ydest, gint width, gint height
 * Returns: void
 * Assertion: Copies the width x height region of src at coordinates (xsrc, ysrc) to coordinates (xdest, ydest) in drawable. width and/or height may be given as -1, in which case the entire src drawable will be copied.
 *            Most fields in gc are not used for this operation, but notably the clip mask or clip region will be honored.
 *            The source and destination drawables must have the same visual and colormap, or errors will result. (On X11, failure to match visual/colormap results in a BadMatch error from the X server.) A common cause of this problem is an attempt to draw a bitmap to a color drawable. The way to draw a bitmap is to set the bitmap as a clip mask on your GdkGC, then use gdk_draw_rectangle() to draw a rectangle clipped to the bitmap.
 *            drawable :    a GdkDrawable
 *            gc : a GdkGC sharing the drawable's visual and colormap
 *            src :    the source GdkDrawable, which may be the same as drawable
 *            xsrc :   X position in src of rectangle to draw
 *            ysrc :   Y position in src of rectangle to draw
 *            xdest :  X position in drawable where the rectangle should be drawn
 *            ydest :  Y position in drawable where the rectangle should be drawn
 *            width :  width of rectangle to draw, or -1 for entire src width
 *            height : height of rectangle to draw, or -1 for entire src height
 * Params Values: GdkDrawable *drawable, GdkGC *gc, GdkDrawable *src, gint xsrc, gint ysrc, gint xdest, gint ydest, gint width, gint height
 * Expected: void  
 */
static void test_purpose_11()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    GdkWindowAttr parent_attributes = {"Lsb_Test_Src", 0, 1, 2, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    GdkWindow *gdk_src = gdk_window_new(NULL, &parent_attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    gdk_window_show(gdk_window);
    gdk_window_show(gdk_src);
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_draw_drawable(gdk_window, gdk_gc, gdk_src, 0, 0, 50, 50, -1, -1);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    gdk_window_destroy(gdk_src);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drawable_get_colormap
 * Params: GdkDrawable *drawable
 * Returns: GdkColormap*
 * Assertion: Gets the colormap for drawable, if one is set; returns NULL otherwise.
 *            drawable :   a GdkDrawable
 *            Returns :    the colormap, or NULL
 * Params Values: GdkDrawable *drawable
 * Expected: void  
 */
static void test_purpose_12()
{
    GdkColormap *gdk_color;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    gdk_window_show(gdk_window);
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_color = gdk_drawable_get_colormap(gdk_window);
    if (gdk_color == NULL)
        TEST_FAIL("gdk_drawable_get_colormap: failed", NULL);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drawable_set_colormap
 * Params: GdkDrawable *drawable, GdkColormap *colormap
 * Returns: void
 * Assertion: Sets the colormap associated with drawable. Normally this will happen automatically when the drawable is created; you only need to use this function if the drawable-creating function did not have a way to determine the colormap, and you then use drawable operations that require a colormap. The colormap for all drawables and graphics contexts you intend to use together should match. i.e. when using a GdkGC to draw to a drawable, or copying one drawable to another, the colormaps should match.
 *            drawable :    a GdkDrawable
 *            colormap :   a GdkColormap
 * Params Values: GdkDrawable *drawable, GdkColormap *colormap
 * Expected: void  
 */
static void test_purpose_13()
{
    GdkVisual *pvisual;
    GdkColormap *gdk_color;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    gdk_window_show(gdk_window);
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    pvisual = gdk_visual_get_system();
    gdk_color = gdk_colormap_new(pvisual, TRUE);
    gdk_drawable_set_colormap(gdk_window, gdk_color);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drawable_get_visual
 * Params: GdkDrawable *drawable
 * Returns: GdkVisual*
 * Assertion: Gets the GdkVisual describing the pixel format of drawable.
 *            drawable :   a GdkDrawable
 *            Returns :    a GdkVisual
 * Params Values: GdkDrawable *drawable
 * Expected: GdkVisual*  
 */
static void test_purpose_14()
{
    GdkVisual *pvisual;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    gdk_window_show(gdk_window);
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    pvisual = gdk_drawable_get_visual(gdk_window);
    if (pvisual == NULL)
        TEST_FAIL("gdk_drawable_get_visual: failed", NULL);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drawable_get_screen
 * Params: GdkDrawable *drawable
 * Returns: GdkScreen*
 * Assertion: Gets the GdkScreen associated with a GdkDrawable.
 *            drawable :   a GdkDrawable
 *            Returns :    the GdkScreen associated with drawable
 * Params Values: GdkDrawable *drawable
 * Expected: GdkScreen*  
 */
static void test_purpose_15()
{
    GdkScreen* gdk_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    gdk_window_show(gdk_window);
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_screen = gdk_drawable_get_screen(gdk_window);
    if (gdk_screen == NULL)
        TEST_FAIL("gdk_drawable_get_screen: failed", NULL);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_drawable_get_display
 * Params: GdkDrawable *drawable
 * Returns: GdkDisplay*
 * Assertion: Gets the GdkDisplay associated with a GdkDrawable.
 *            drawable :   a GdkDrawable
 *            Returns :    the GdkDisplay associated with drawable
 * Params Values: GdkDrawable *drawable
 * Expected: GdkDisplay*  
 */
static void test_purpose_16()
{
    GdkDisplay* gdk_display;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    gdk_window_show(gdk_window);
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_display = gdk_drawable_get_display(gdk_window);
    if (gdk_display == NULL)
        TEST_FAIL("gdk_drawable_get_display: failed", NULL);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_draw_pixbuf
 * Params: GdkDrawable *drawable, GdkGC *gc, GdkPixbuf *pixbuf, gint src_x, gint src_y, gint dest_x, gint dest_y, gint width, gint height, GdkRgbDither dither, gint x_dither, gint y_dither
 * Returns: void
 * Assertion: Renders a rectangular portion of a pixbuf to a drawable. The destination drawable must have a colormap. All windows have a colormap, however, pixmaps only have colormap by default if they were created with a non-NULL window argument. Otherwise a colormap must be set on them with gdk_drawable_set_colormap()
 *            On older X servers, rendering pixbufs with an alpha channel involves round trips to the X server, and may be somewhat slow.
 *            The clip mask of gc is ignored, but clip rectangles and clip regions work fine.
 *            drawable :    Destination drawable.
 *            gc : a GdkGC, used for clipping, or NULL
 *            pixbuf : a GdkPixbuf
 *            src_x :  Source X coordinate within pixbuf.
 *            src_y :  Source Y coordinates within pixbuf.
 *            dest_x : Destination X coordinate within drawable.
 *            dest_y : Destination Y coordinate within drawable.
 *            width :  Width of region to render, in pixels, or -1 to use pixbuf width.
 *            height : Height of region to render, in pixels, or -1 to use pixbuf height.
 *            dither : Dithering mode for GdkRGB.
 *            x_dither :   X offset for dither.
 *            y_dither :   Y offset for dither.
 * Params Values: GdkDrawable *drawable, GdkGC *gc, GdkPixbuf *pixbuf, gint src_x, gint src_y, gint dest_x, gint dest_y, gint width, gint height, GdkRgbDither dither, gint x_dither, gint y_dither
 * Expected: void  
 */
static void test_purpose_17()
{
    GdkPixbuf* gdk_pixbuf;;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    gdk_window_show(gdk_window);
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    gdk_pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, FALSE, 8, 100, 100);
    gdk_draw_pixbuf(gdk_window, gdk_gc, gdk_pixbuf, 0, 0, 0, 0, -1, -1, GDK_RGB_DITHER_NONE, 0, 0);
    g_object_unref(gdk_pixbuf);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_draw_image
 * Params: GdkDrawable *drawable, GdkGC *gc, GdkImage *image, gint xsrc, gint ysrc, gint xdest, gint ydest, gint width, gint height, GdkRgbDither dither, gint x_dither, gint y_dither
 * Returns: void
 * Assertion: Draws a GdkImage onto a drawable. The depth of the GdkImage must match the depth of the GdkDrawable.
 *            drawable :    a GdkDrawable (a GdkWindow or a GdkPixmap).
 *            gc : a GdkGC.
 *            image :  the GdkImage to draw.
 *            xsrc :   the left edge of the source rectangle within image.
 *            ysrc :   the top of the source rectangle within image.
 *            xdest :  the x coordinate of the destination within drawable.
 *            ydest :  the y coordinate of the destination within drawable.
 *            width :  the width of the area to be copied, or -1 to make the area extend to the right edge of image.
 *            height : the height of the area to be copied, or -1 to make the area extend to the bottom edge of image.
 * Params Values: GdkDrawable *drawable, GdkGC *gc, GdkImage *image, gint xsrc, gint ysrc, gint xdest, gint ydest, gint width, gint height, GdkRgbDither dither, gint x_dither, gint y_dither
 * Expected: void  
 */
static void test_purpose_18()
{
    GdkImage* gdk_image;
    GdkVisual *pvisual;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GdkWindow *gdk_window = create_new_gdk_window();
    gdk_window_show(gdk_window);
    GdkGC* gdk_gc = gdk_gc_new(gdk_window);
    pvisual = gdk_drawable_get_visual(gdk_window);
    gdk_image = gdk_image_new(GDK_IMAGE_NORMAL, pvisual, 100, 100);
    gdk_draw_image(gdk_window, gdk_gc, gdk_image, 0, 0, 0, 0, -1, -1);
    g_object_unref(gdk_image);
    g_object_unref(gdk_gc);
    gdk_window_destroy(gdk_window);
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkDrawPrimitives ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {NULL,0}
};
