/*
 * GdkXWinSysInterface methods tests
 * Testing GdkXWinSysInterface methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
#include <X11/X.h>
#include <X11/Xlibint.h>
#include <gdk/gdkx.h>
struct _GdkDrawableImplX11
{
  GdkDrawable parent_instance;

  void *wrapper;

  void *colormap;

  Window xid;
  void *screen;

  void *xft_draw;
};

/*
 * Name: gdk_x11_image_get_ximage
 * Params: GdkImage *
 * Return: XImage *
 * Assertion: Returns the X image belonging to a GdkImage.
 * Expected: an XImage* belonging to image  
 */
static void test_purpose_1()
{
    
    GdkImage * image = NULL;
    XImage * ximage = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    image = gdk_image_new(GDK_IMAGE_FASTEST,gdk_visual_get_system(),100,100);
    if(image == NULL){
    	TEST_FAIL("gdk_x11_image_get_ximage: image is NULL",NULL);
    	return;
    }
    if(GDK_IS_IMAGE(image) != TRUE){
    	TEST_FAIL("gdk_x11_image_get_ximage: image is NOT a GdkImage object",NULL);
    	return;
    }
    ximage = (XImage *)gdk_x11_image_get_ximage(image);
    if(ximage == NULL){
    	TEST_FAIL("gdk_x11_image_get_ximage: ximage is NULL",NULL);
    	return;
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_x11_gc_get_xdisplay
 * Params: GdkGC *
 * Return: Display *
 * Assertion: Returns the display of a GdkGC.
 * Expected: an Xlib Display*.  
 */
static void test_purpose_2()
{
    GdkGC * gdkgc = NULL;
    Display * display = NULL;
    GdkPixmap * pixmap = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixmap = gdk_pixmap_new(NULL,100,100,32);
    if(pixmap == NULL){
    	TEST_FAIL("gdk_x11_gc_get_xdisplay: pixmap is NULL",NULL);
    	return;
    }
    gdkgc = gdk_gc_new((GdkDrawable *)pixmap);
    if(gdkgc == NULL){
    	TEST_FAIL("gdk_x11_gc_get_xdisplay: gdkgc is NULL",NULL);
    	return;
    };
    display = (Display *)gdk_x11_gc_get_xdisplay(gdkgc);
    if(display == NULL){
    	TEST_FAIL("gdk_x11_gc_get_xdisplay: display is NULL",NULL);
    	return;
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_x11_lookup_display
 * Params: Display *
 * Return: GdkDisplay *
 * Assertion: Find the GdkDisplay corresponding to display, if any exists.
 * Expected: the GdkDisplay, if found, otherwise NULL.  
 */
static void test_purpose_3()
{
    GdkGC * gdkgc = NULL;
    Display * display = NULL;
    GdkDisplay * gdkdisplay = NULL;
    GdkPixmap * pixmap = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixmap = gdk_pixmap_new(NULL,100,100,32);
    if(pixmap == NULL){
    	TEST_FAIL("gdk_x11_lookup_xdisplay: pixmap is NULL",NULL);
    	return;
    }
    gdkgc = gdk_gc_new((GdkDrawable *)pixmap);
    if(gdkgc == NULL){
    	TEST_FAIL("gdk_x11_lookup_xdisplay: gdkgc is NULL",NULL);
    	return;
    };
    display = (Display *)gdk_x11_gc_get_xdisplay(gdkgc);
    if(display == NULL){
    	TEST_FAIL("gdk_x11_lookup_xdisplay: display is NULL",NULL);
    	return;
    }
    
    gdkdisplay = (GdkDisplay *)gdk_x11_lookup_xdisplay(display);
    if(gdkdisplay == NULL){
    	TEST_FAIL("gdk_x11_lookup_xdisplay: gdkdisplay is NULL",NULL);
    	return;
    }
    if(GDK_IS_DISPLAY(gdkdisplay) != TRUE){
    	TEST_FAIL("gdk_x11_lookup_xdisplay: gdkdisplay is NOT a GdkDisplay object",NULL);
    	return;
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_x11_get_xatom_by_name
 * Params: const gchar *
 * Return: Atom
 * Assertion: Returns the X atom for GDK's default display corresponding to atom_name. This function caches the result, so if called repeatedly it is much faster than XInternAtom(), which is a round trip to the server each time.
 * Expected: a X atom for GDK's default display.  
 */
static void test_purpose_4()
{
    #define ATOM_NAME	"PRIMARY"
    #define EXPECTED	1
    Atom ret ;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_x11_get_xatom_by_name(ATOM_NAME);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_x11_get_xatom_by_name: return value doesnt match the expected ",NULL);
    	return;
    }
    #undef ATOM_NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_x11_get_xatom_by_name
 * Params: const gchar *
 * Return: Atom
 * Assertion: Returns the X atom for GDK's default display corresponding to atom_name. This function caches the result, so if called repeatedly it is much faster than XInternAtom(), which is a round trip to the server each time.
 * Expected: a X atom for GDK's default display.  
 */
static void test_purpose_5()
{
    #define ATOM_NAME	"ATOM"
    #define EXPECTED	4
    Atom ret ;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_x11_get_xatom_by_name(ATOM_NAME);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_x11_get_xatom_by_name: return value doesnt match the expected ",NULL);
    	return;
    }
    #undef ATOM_NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_x11_get_xatom_by_name
 * Params: const gchar *
 * Return: Atom
 * Assertion: Returns the X atom for GDK's default display corresponding to atom_name. This function caches the result, so if called repeatedly it is much faster than XInternAtom(), which is a round trip to the server each time.
 * Expected: a X atom for GDK's default display.  
 */
static void test_purpose_6()
{
    #define ATOM_NAME	"CUT_BUFFER1"
    #define EXPECTED	10
    Atom ret ;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ret = gdk_x11_get_xatom_by_name(ATOM_NAME);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_x11_get_xatom_by_name: return value doesnt match the expected ",NULL);
    	return;
    }
    #undef ATOM_NAME
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_foreign_new
 * Params: GdkNativeWindow
 * Return: GdkWindow *
 * Assertion: Wraps a native window for the default display in a GdkWindow. This may fail if the window has been destroyed.
 * Expected: the newly-created GdkWindow wrapper for the native window or NULL if the window has been destroyed.  
 */
static void test_purpose_7()
{
    GdkWindow * window = NULL;
    GdkWindow * win_test = NULL;
    GdkWindowAttr attr_test = {"foo_test", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    XID xid;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    	win_test = gdk_window_new (NULL, &attr_test, GDK_WA_X | GDK_WA_Y);
    	if(win_test == NULL){
    		TEST_FAIL("gdk_window_forigne_new: win_test is NULL",NULL);
    		return;
    	}
    	xid = gdk_x11_drawable_get_xid((GdkDrawable *)win_test);
    	window = gdk_window_foreign_new(xid);
    	if(window == NULL){
    		TEST_FAIL("gdk_window_forigne_new: window is NULL",NULL);
    		return;
    	}
    	if(GDK_IS_DRAWABLE(window) == FALSE){
    		TEST_FAIL("gdk_window_forigne_new: doesnt a window object",NULL);
    		return;
    	};
    
    	gdk_window_destroy(win_test);	
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_x11_gc_get_xgc
 * Params: GdkGC *
 * Return: GC
 * Assertion: Returns the X GC of a GdkGC.
 * Expected: an Xlib GC.  
 */
static void test_purpose_8()
{
    GdkGC * gdkgc = NULL;
    GC gc = NULL;
    GdkPixmap * pixmap = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixmap = gdk_pixmap_new(NULL,100,100,32);
    if(pixmap == NULL){
    	TEST_FAIL("gdk_x11_gc_get_xgc: pixmap is NULL",NULL);
    	return;
    }
    gdkgc = gdk_gc_new((GdkDrawable *)pixmap);
    if(gdkgc == NULL){
    	TEST_FAIL("gdk_x11_gc_get_xgc: gdkgc is NULL",NULL);
    	return;
    };
    gc = (GC)gdk_x11_gc_get_xgc(gdkgc);
    if(gc == NULL){
    	TEST_FAIL("gdk_x11_gc_get_xgc: gc is NULL",NULL);
    	return;
    }
    g_object_unref(pixmap);
    g_object_unref(gdkgc);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_to_xatom
 * Params: GdkAtom 
 * Return: Atom
 * Assertion: Converts from a GdkAtom to the X atom for the default GDK display with the same string value.
 * Expected: the X atom corresponding to atom.  
 */
static void test_purpose_9()
{
    #define TEST_VALUE	1
    GdkAtom atom;
    Atom xatom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    atom = _GDK_MAKE_ATOM(TEST_VALUE);
    xatom = gdk_x11_atom_to_xatom(atom);
    if(xatom != TEST_VALUE){
    	TEST_FAIL("gdk_x11_atom_to_xatom: return value doesnt match expected value",NULL);
    	return;
    }
    #undef TEST_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_to_xatom
 * Params: GdkAtom 
 * Return: Atom
 * Assertion: Converts from a GdkAtom to the X atom for the default GDK display with the same string value.
 * Expected: the X atom corresponding to atom.  
 */
static void test_purpose_10()
{
    #define TEST_VALUE	10
    GdkAtom atom;
    Atom xatom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    atom = _GDK_MAKE_ATOM(TEST_VALUE);
    xatom = gdk_x11_atom_to_xatom(atom);
    if(xatom != TEST_VALUE){
    	TEST_FAIL("gdk_x11_atom_to_xatom: return value doesnt match expected value",NULL);
    	return;
    }
    #undef TEST_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_atom_to_xatom
 * Params: GdkAtom 
 * Return: Atom
 * Assertion: Converts from a GdkAtom to the X atom for the default GDK display with the same string value.
 * Expected: the X atom corresponding to atom.  
 */
static void test_purpose_11()
{
    #define TEST_VALUE	59
    GdkAtom atom;
    Atom xatom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    atom = _GDK_MAKE_ATOM(TEST_VALUE);
    xatom = gdk_x11_atom_to_xatom(atom);
    if(xatom != TEST_VALUE){
    	TEST_FAIL("gdk_x11_atom_to_xatom: return value doesnt match expected value",NULL);
    	return;
    }
    #undef TEST_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_xatom_to_atom
 * Params: Atom 
 * Return: GdkAtom
 * Assertion: Convert from an X atom for the default display to the corresponding GdkAtom.
 * Expected: the corresponding GdkAtom.  
 */
static void test_purpose_12()
{
    #define TEST_VALUE	1
    GdkAtom atom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    atom = _GDK_MAKE_ATOM(TEST_VALUE);
    atom = (GdkAtom)gdk_x11_xatom_to_atom((Atom)TEST_VALUE);
    if(atom != _GDK_MAKE_ATOM(TEST_VALUE)){
    	TEST_FAIL("gdk_x11_xatom_to_atom: return value doesnt match expected value",NULL);
    	return;
    }
    #undef TEST_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_xatom_to_atom
 * Params: Atom 
 * Return: GdkAtom
 * Assertion: Convert from an X atom for the default display to the corresponding GdkAtom.
 * Expected: the corresponding GdkAtom.  
 */
static void test_purpose_13()
{
    #define TEST_VALUE	10
    GdkAtom atom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    atom = _GDK_MAKE_ATOM(TEST_VALUE);
    atom = (GdkAtom)gdk_x11_xatom_to_atom((Atom)TEST_VALUE);
    if(atom != _GDK_MAKE_ATOM(TEST_VALUE)){
    	TEST_FAIL("gdk_x11_xatom_to_atom: return value doesnt match expected value",NULL);
    	return;
    }
    #undef TEST_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_xatom_to_atom
 * Params: Atom 
 * Return: GdkAtom
 * Assertion: Convert from an X atom for the default display to the corresponding GdkAtom.
 * Expected: the corresponding GdkAtom.  
 */
static void test_purpose_14()
{
    #define TEST_VALUE	59
    GdkAtom atom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    atom = _GDK_MAKE_ATOM(TEST_VALUE);
    atom = (GdkAtom)gdk_x11_xatom_to_atom((Atom)TEST_VALUE);
    if(atom != _GDK_MAKE_ATOM(TEST_VALUE)){
    	TEST_FAIL("gdk_x11_xatom_to_atom: return value doesnt match expected value",NULL);
    	return;
    }
    #undef TEST_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_lookup
 * Params: GdkNativeWindow anid
 * Return: GdkWindow *
 * Assertion: Looks up the GdkWindow that wraps the given native window handle.
 * Expected: the GdkWindow wrapper for the native window, or NULL if there is none.  
 */
static void test_purpose_15()
{
    GdkWindow * window = NULL;
    GdkWindow * win_test = NULL;
    GdkWindowAttr attr_test = {"foo_test", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    	win_test = gdk_window_new (NULL, &attr_test, GDK_WA_X | GDK_WA_Y);
    	if(win_test == NULL){
    		TEST_FAIL("gdk_window_lookup: win_test is NULL",NULL);
    		return;
    	}
    	window = gdk_window_lookup(gdk_x11_drawable_get_xid((GdkDrawable *)win_test));
    	if(window == NULL){
    		TEST_FAIL("gdk_window_lookup: window is NULL",NULL);
    		return;
    	}
    	if(GDK_IS_DRAWABLE(window) == FALSE){
    		TEST_FAIL("gdk_window_lookup: doesnt a window object",NULL);
    		return;
    	};
    	if(window != win_test){
    		TEST_FAIL("gdk_window_lookup: the return window doesnt the right window",NULL);
    		return;	
    	}
    	window = gdk_window_lookup(0);
    	if(window != NULL){
    		TEST_FAIL("gdk_window_lookup: window shoud be NULL",NULL);
    		return;
    	}
    	gdk_window_destroy(win_test);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_x11_drawable_get_xid
 * Params: GdkDrawable *
 * Return: XID
 * Assertion: Returns the X resource (window or pixmap) belonging to a GdkDrawable.
 * Expected: the ID of drawable's X resource.  
 */
static void test_purpose_16()
{
    #define TYPE_PIXMAP	1
    #define TYPE_BITMAP	2
    #define TYPE_WINDOW	3
    #define DRAWABLE_TYPE	TYPE_PIXMAP
    
    GdkBitmap * bitmap = NULL;
    GdkPixmap * pixmap = NULL;
    GdkWindow * window = NULL;
    XID xid;
    
    gchar data[400];
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if(DRAWABLE_TYPE == TYPE_PIXMAP){//for pixmap
    	pixmap = gdk_pixmap_new(NULL,100,100,32);
    	if(pixmap == NULL){
    		TEST_FAIL("gdk_xll_drawable_get_xid: pixmap is NULL",NULL);
    		return;
    	}
    	xid = gdk_x11_drawable_get_xid((GdkDrawable *)pixmap);
    	if(xid != ((struct _GdkDrawableImplX11 *)(((GdkPixmapObject *)pixmap)->impl))->xid){
    		TEST_FAIL("gdk_xll_drawable_get_xid: xid doesnt match raw xid",NULL);
    		return;
    	}
    	g_object_unref(pixmap);
    }
    if(DRAWABLE_TYPE == TYPE_BITMAP){//for bitmap
    	bitmap = gdk_bitmap_create_from_data(NULL,data,10,10);
    	if(bitmap == NULL){
    		TEST_FAIL("gdk_xll_drawable_get_xid: bitmap is NULL",NULL);
    		return;
    	}
    	xid = gdk_x11_drawable_get_xid((GdkDrawable *)bitmap);
    	if(xid != ((struct _GdkDrawableImplX11 *)(((GdkPixmapObject *)bitmap)->impl))->xid){
    		TEST_FAIL("gdk_xll_drawable_get_xid: xid doesnt match raw xid",NULL);
    		return;
    	}
    	g_object_unref(bitmap);
    };
    if(DRAWABLE_TYPE == TYPE_WINDOW){//for window
    	window = gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y);
    	if(window == NULL){
    		TEST_FAIL("gdk_xll_drawable_get_xid: window is NULL",NULL);
    		return;
    	}
    	xid = gdk_x11_drawable_get_xid((GdkDrawable *)window);
    	if(xid != ((struct _GdkDrawableImplX11 *)(((GdkPixmapObject *)window)->impl))->xid){
    		TEST_FAIL("gdk_xll_drawable_get_xid: xid doesnt match raw xid",NULL);
    		return;
    	}
    	gdk_window_destroy(window);
    };
    #undef DRAWABLE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_x11_drawable_get_xid
 * Params: GdkDrawable *
 * Return: XID
 * Assertion: Returns the X resource (window or pixmap) belonging to a GdkDrawable.
 * Expected: the ID of drawable's X resource.  
 */
static void test_purpose_17()
{
    #define TYPE_PIXMAP	1
    #define TYPE_BITMAP	2
    #define TYPE_WINDOW	3
    #define DRAWABLE_TYPE	TYPE_BITMAP
    
    GdkBitmap * bitmap = NULL;
    GdkPixmap * pixmap = NULL;
    GdkWindow * window = NULL;
    XID xid;
    
    gchar data[400];
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if(DRAWABLE_TYPE == TYPE_PIXMAP){//for pixmap
    	pixmap = gdk_pixmap_new(NULL,100,100,32);
    	if(pixmap == NULL){
    		TEST_FAIL("gdk_xll_drawable_get_xid: pixmap is NULL",NULL);
    		return;
    	}
    	xid = gdk_x11_drawable_get_xid((GdkDrawable *)pixmap);
    	if(xid != ((struct _GdkDrawableImplX11 *)(((GdkPixmapObject *)pixmap)->impl))->xid){
    		TEST_FAIL("gdk_xll_drawable_get_xid: xid doesnt match raw xid",NULL);
    		return;
    	}
    	g_object_unref(pixmap);
    }
    if(DRAWABLE_TYPE == TYPE_BITMAP){//for bitmap
    	bitmap = gdk_bitmap_create_from_data(NULL,data,10,10);
    	if(bitmap == NULL){
    		TEST_FAIL("gdk_xll_drawable_get_xid: bitmap is NULL",NULL);
    		return;
    	}
    	xid = gdk_x11_drawable_get_xid((GdkDrawable *)bitmap);
    	if(xid != ((struct _GdkDrawableImplX11 *)(((GdkPixmapObject *)bitmap)->impl))->xid){
    		TEST_FAIL("gdk_xll_drawable_get_xid: xid doesnt match raw xid",NULL);
    		return;
    	}
    	g_object_unref(bitmap);
    };
    if(DRAWABLE_TYPE == TYPE_WINDOW){//for window
    	window = gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y);
    	if(window == NULL){
    		TEST_FAIL("gdk_xll_drawable_get_xid: window is NULL",NULL);
    		return;
    	}
    	xid = gdk_x11_drawable_get_xid((GdkDrawable *)window);
    	if(xid != ((struct _GdkDrawableImplX11 *)(((GdkPixmapObject *)window)->impl))->xid){
    		TEST_FAIL("gdk_xll_drawable_get_xid: xid doesnt match raw xid",NULL);
    		return;
    	}
    	gdk_window_destroy(window);
    };
    #undef DRAWABLE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_x11_drawable_get_xid
 * Params: GdkDrawable *
 * Return: XID
 * Assertion: Returns the X resource (window or pixmap) belonging to a GdkDrawable.
 * Expected: the ID of drawable's X resource.  
 */
static void test_purpose_18()
{
    #define TYPE_PIXMAP	1
    #define TYPE_BITMAP	2
    #define TYPE_WINDOW	3
    #define DRAWABLE_TYPE	TYPE_WINDOW
    
    GdkBitmap * bitmap = NULL;
    GdkPixmap * pixmap = NULL;
    GdkWindow * window = NULL;
    XID xid;
    
    gchar data[400];
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    if(DRAWABLE_TYPE == TYPE_PIXMAP){//for pixmap
    	pixmap = gdk_pixmap_new(NULL,100,100,32);
    	if(pixmap == NULL){
    		TEST_FAIL("gdk_xll_drawable_get_xid: pixmap is NULL",NULL);
    		return;
    	}
    	xid = gdk_x11_drawable_get_xid((GdkDrawable *)pixmap);
    	if(xid != ((struct _GdkDrawableImplX11 *)(((GdkPixmapObject *)pixmap)->impl))->xid){
    		TEST_FAIL("gdk_xll_drawable_get_xid: xid doesnt match raw xid",NULL);
    		return;
    	}
    	g_object_unref(pixmap);
    }
    if(DRAWABLE_TYPE == TYPE_BITMAP){//for bitmap
    	bitmap = gdk_bitmap_create_from_data(NULL,data,10,10);
    	if(bitmap == NULL){
    		TEST_FAIL("gdk_xll_drawable_get_xid: bitmap is NULL",NULL);
    		return;
    	}
    	xid = gdk_x11_drawable_get_xid((GdkDrawable *)bitmap);
    	if(xid != ((struct _GdkDrawableImplX11 *)(((GdkPixmapObject *)bitmap)->impl))->xid){
    		TEST_FAIL("gdk_xll_drawable_get_xid: xid doesnt match raw xid",NULL);
    		return;
    	}
    	g_object_unref(bitmap);
    };
    if(DRAWABLE_TYPE == TYPE_WINDOW){//for window
    	window = gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y);
    	if(window == NULL){
    		TEST_FAIL("gdk_xll_drawable_get_xid: window is NULL",NULL);
    		return;
    	}
    	xid = gdk_x11_drawable_get_xid((GdkDrawable *)window);
    	if(xid != ((struct _GdkDrawableImplX11 *)(((GdkPixmapObject *)window)->impl))->xid){
    		TEST_FAIL("gdk_xll_drawable_get_xid: xid doesnt match raw xid",NULL);
    		return;
    	}
    	gdk_window_destroy(window);
    };
    #undef DRAWABLE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_x11_get_server_time
 * Params: GdkWindow *
 * Return: guint32
 * Assertion: Routine to get the current X server time stamp.
 * Expected: the time stamp of the X server  
 */
static void test_purpose_19()
{
    guint32 srv_time = 0;
    GdkWindow * win_test = NULL;
    GdkWindowAttr attr_test = {"foo_test", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    win_test = gdk_window_new (NULL, &attr_test, 0);
    gdk_window_set_events (win_test, GDK_PROPERTY_CHANGE_MASK);
    if(win_test == NULL){
    	TEST_FAIL("gdk_x11_get_server_time: win_test is NULL",NULL);
    	return;
    }
    gdk_window_show (win_test);
    srv_time = gdk_x11_get_server_time(win_test);
    if(srv_time == 0){
    	TEST_FAIL("gdk_x11_get_server_time: the server time is 0",NULL);
    	return;
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixmap_foreign_new
 * Params: GdkNativeWindow
 * Return: GdkWindow *
 * Assertion: Wraps a native window for the default display in a GdkWindow. This may fail if the window has been destroyed.
 * Expected: the newly-created GdkWindow wrapper for the native window or NULL if the window has been destroyed.  
 */
static void test_purpose_20()
{
    GdkWindow * window = NULL;
    GdkWindow * win_test = NULL;
    GdkWindowAttr attr_test = {"foo_test", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    XID xid;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    	win_test = gdk_window_new (NULL, &attr_test, GDK_WA_X | GDK_WA_Y);
    	if(win_test == NULL){
    		TEST_FAIL("gdk_pixmap_forigne_new: win_test is NULL",NULL);
    		return;
    	}
    	xid = gdk_x11_drawable_get_xid((GdkDrawable *)win_test);
    	window = gdk_pixmap_foreign_new(xid);
    	if(window == NULL){
    		TEST_FAIL("gdk_pixmap_forigne_new: window is NULL",NULL);
    		return;
    	}
    	if(GDK_IS_DRAWABLE(window) == FALSE){
    		TEST_FAIL("gdk_pixmap_forigne_new: doesnt a window object",NULL);
    		return;
    	};
    
    	gdk_window_destroy(win_test);	
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkXWinSysInterface ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {NULL,0}
};
