/*
 * Graphics_Contexts methods tests
 * Testing Graphics_Contexts methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: 0, system colormap, newly created GdkGCValues*, GDK_GC_FOREGROUND
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_1()
{
    #define DEPTH 0
    #define MASK GDK_GC_FOREGROUND
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: 1, system colormap, newly created GdkGCValues*, GDK_GC_BACKGROUND
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_2()
{
    #define DEPTH 1
    #define MASK GDK_GC_BACKGROUND
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: 2, system colormap, newly created GdkGCValues*, GDK_GC_STIPPLE  
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_3()
{
    #define DEPTH 2
    #define MASK GDK_GC_STIPPLE  
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: 10, system colormap, newly created GdkGCValues*, GDK_GC_FUNCTION 
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_4()
{
    #define DEPTH 10
    #define MASK GDK_GC_FUNCTION 
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: 100, system colormap, newly created GdkGCValues*, GDK_GC_FILL 
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_5()
{
    #define DEPTH 100
    #define MASK GDK_GC_FILL 
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: -100, system colormap, newly created GdkGCValues*, GDK_GC_TILE 
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_6()
{
    #define DEPTH -100
    #define MASK GDK_GC_TILE 
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: G_MININT, system colormap, newly created GdkGCValues*, GDK_GC_CLIP_MASK
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_7()
{
    #define DEPTH G_MININT
    #define MASK GDK_GC_CLIP_MASK
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: G_MAXINT, system colormap, newly created GdkGCValues*, GDK_GC_SUBWINDOW
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_8()
{
    #define DEPTH G_MAXINT
    #define MASK GDK_GC_SUBWINDOW
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: 0, system colormap, newly created GdkGCValues*, GDK_GC_TS_X_ORIGIN
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_9()
{
    #define DEPTH 0
    #define MASK GDK_GC_TS_X_ORIGIN
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: 1, system colormap, newly created GdkGCValues*, GDK_GC_TS_Y_ORIGIN
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_10()
{
    #define DEPTH 1
    #define MASK GDK_GC_TS_Y_ORIGIN
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: 2, system colormap, newly created GdkGCValues*, GDK_GC_CLIP_X_ORIGIN
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_11()
{
    #define DEPTH 2
    #define MASK GDK_GC_CLIP_X_ORIGIN
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: 10, system colormap, newly created GdkGCValues*, GDK_GC_EXPOSURES
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_12()
{
    #define DEPTH 10
    #define MASK GDK_GC_EXPOSURES
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: 100, system colormap, newly created GdkGCValues*, GDK_GC_LINE_WIDTH
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_13()
{
    #define DEPTH 100
    #define MASK GDK_GC_LINE_WIDTH
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: -100, system colormap, newly created GdkGCValues*, GDK_GC_LINE_STYLE 
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_14()
{
    #define DEPTH -100
    #define MASK GDK_GC_LINE_STYLE 
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: G_MININT, system colormap, newly created GdkGCValues*, GDK_GC_CAP_STYLE
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_15()
{
    #define DEPTH G_MININT
    #define MASK GDK_GC_CAP_STYLE
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_gc_get
 * Params: gint depth, GdkColormap *colormap, GdkGCValues *values, GdkValuesMask values_mask
 * Returns: GdkGC*
 * Assertion: Gets a GdkGC with the given depth, colormap and GdkGCValues. 
 * Params Values: G_MAXINT, system colormap, newly created GdkGCValues*, GDK_GC_JOIN_STYLE
 * Expected: GdkGC*
 * 
 * Name: gtk_gc_release
 * Params: GdkGC *gc
 * Returns: void
 * Assertion: Releases a GdkGC allocated using gtk_gc_get().
 * Params Values: newly created GdkGC*
 * Expected: void  
 */
static void test_purpose_16()
{
    #define DEPTH G_MAXINT
    #define MASK GDK_GC_JOIN_STYLE
    
    GdkColormap* colormap; 
    GdkPixmap* pixmap;
    GdkGC* gc;
    GdkGC* real_gc;
    GdkGCValues values;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    pixmap = gdk_pixmap_new (NULL, 1, 1, 1);
    gc = gdk_gc_new (pixmap);
    gdk_gc_get_values (gc, &values);
    
    real_gc = gtk_gc_get (DEPTH, colormap, &values, MASK);
    gtk_gc_release (real_gc);
    
    #undef DEPTH 
    #undef MASK
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for Graphics_Contexts ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {NULL,0}
};
