/*
 * GtkCellEditable methods tests
 * Testing GtkCellEditable methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

static gint result;

void  
global_signal ()
{
    result++;
}  


/*
 * Name: gtk_cell_editable_start_editing
 * Params: GtkCellEditable *cell_editable, GdkEvent *event
 * Returns: void
 * Assertion: Begins editing on a cell_editable.
 * Params Values: GtkCellEditable *cell_editable, GdkEvent *event
 * Expected: void
 * 
 * Name: gtk_cell_editable_start_editing
 * Params: GtkCellEditable *cell_editable, GdkEvent *event
 * Returns: void
 * Assertion: event is the GdkEvent that began the editing process.
 * Params Values: GtkCellEditable *cell_editable, GdkEvent *event
 * Expected: void
 * 
 * Name: gtk_cell_editable_start_editing
 * Params: GtkCellEditable *cell_editable, GdkEvent *event
 * Returns: void
 * Assertion: It may be NULL, in the instance that editing was initiated through programatic means.
 * Params Values: GtkCellEditable *cell_editable, GdkEvent *event
 * Expected: void  
 */
static void test_purpose_1()
{
    #define WIDGET gtk_entry_new ()
    #define EVENT NULL
    
    GtkCellEditable* cell;
    GdkEvent event;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = GTK_CELL_EDITABLE (WIDGET);
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!EVENT)
    {
        gtk_cell_editable_start_editing (cell, NULL);
    
    } else {
    
        gtk_cell_editable_start_editing (cell, &event);
    }
    
    #undef WIDGET
    #undef EVENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_cell_editable_start_editing
 * Params: GtkCellEditable *cell_editable, GdkEvent *event
 * Returns: void
 * Assertion: Begins editing on a cell_editable.
 * Params Values: GtkCellEditable *cell_editable, GdkEvent *event
 * Expected: void
 * 
 * Name: gtk_cell_editable_start_editing
 * Params: GtkCellEditable *cell_editable, GdkEvent *event
 * Returns: void
 * Assertion: event is the GdkEvent that began the editing process.
 * Params Values: GtkCellEditable *cell_editable, GdkEvent *event
 * Expected: void
 * 
 * Name: gtk_cell_editable_start_editing
 * Params: GtkCellEditable *cell_editable, GdkEvent *event
 * Returns: void
 * Assertion: It may be NULL, in the instance that editing was initiated through programatic means.
 * Params Values: GtkCellEditable *cell_editable, GdkEvent *event
 * Expected: void  
 */
static void test_purpose_2()
{
    #define WIDGET gtk_entry_new ()
    #define EVENT 1
    
    GtkCellEditable* cell;
    GdkEvent event;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = GTK_CELL_EDITABLE (WIDGET);
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!EVENT)
    {
        gtk_cell_editable_start_editing (cell, NULL);
    
    } else {
    
        gtk_cell_editable_start_editing (cell, &event);
    }
    
    #undef WIDGET
    #undef EVENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_cell_editable_editing_done
 * Params: GtkCellEditable *cell_editable
 * Returns: void
 * Assertion: Emits the "editing_done" signal. 
 * Params Values: GtkCellEditable *cell_editable
 * Expected: void  
 */
static void test_purpose_3()
{
    #define WIDGET gtk_entry_new ()
    
    GtkCellEditable* cell;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = 0;
    cell = GTK_CELL_EDITABLE (WIDGET);
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (cell), "editing-done", GTK_SIGNAL_FUNC (global_signal), NULL);
    
    gtk_cell_editable_editing_done (cell);
    
    if (!result)
    {
        TEST_FAIL ("'editing-done' signal not catched", NULL);
    }
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_cell_editable_editing_done
 * Params: GtkCellEditable *cell_editable
 * Returns: void
 * Assertion: Emits the "editing_done" signal. 
 * Params Values: GtkCellEditable *cell_editable
 * Expected: void  
 */
static void test_purpose_4()
{
    #define WIDGET gtk_entry_new ()
    
    GtkCellEditable* cell;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = 0;
    cell = GTK_CELL_EDITABLE (WIDGET);
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (cell), "editing-done", GTK_SIGNAL_FUNC (global_signal), NULL);
    
    gtk_cell_editable_editing_done (cell);
    
    if (!result)
    {
        TEST_FAIL ("'editing-done' signal not catched", NULL);
    }
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_cell_editable_remove_widget
 * Params: GtkCellEditable *cell_editable
 * Returns: void
 * Assertion: Emits the "remove_widget" signal. 
 * Params Values: GtkCellEditable *cell_editable
 * Expected: void  
 */
static void test_purpose_5()
{
    #define WIDGET gtk_entry_new ()
    
    GtkCellEditable* cell;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = 0;
    cell = GTK_CELL_EDITABLE (WIDGET);
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (cell), "remove-widget", GTK_SIGNAL_FUNC (global_signal), NULL);
    
    gtk_cell_editable_remove_widget (cell);
    
    if (!result)
    {
        TEST_FAIL ("'remove_widget' signal not catched", NULL);
    }
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_cell_editable_remove_widget
 * Params: GtkCellEditable *cell_editable
 * Returns: void
 * Assertion: Emits the "remove_widget" signal. 
 * Params Values: GtkCellEditable *cell_editable
 * Expected: void  
 */
static void test_purpose_6()
{
    #define WIDGET gtk_entry_new ()
    
    GtkCellEditable* cell;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = 0;
    cell = GTK_CELL_EDITABLE (WIDGET);
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (cell), "remove-widget", GTK_SIGNAL_FUNC (global_signal), NULL);
    
    gtk_cell_editable_remove_widget (cell);
    
    if (!result)
    {
        TEST_FAIL ("'remove_widget' signal not catched", NULL);
    }
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkCellEditable ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {NULL,0}
};
