/*
 * GtkCellRenderer methods tests
 * Testing GtkCellRenderer methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name:  gtk_cell_renderer_get_size 
 * Params: GtkCellRenderer *cell, GtkWidget *widget, GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the cell.
 * Params Values: newly created GtkCellRenderer*, newly created GtkWidget*, The area a cell will be allocated, or NULL, location to return x offset of cell relative to cell_area, or NULL, location to return y offset of cell relative to cell_area, or NULL, location to return width needed to render a cell, or NULL, location to return height needed to render a cell, or NULL
 * 
 * Expected: void
 * Name:  gtk_cell_renderer_get_size 
 * Params: GtkCellRenderer *cell, GtkWidget *widget, GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: If cell_area is not NULL, fills in the x and y offsets (if set) of the cell relative to this location.
 * Params Values: newly created GtkCellRenderer*, newly created GtkWidget*, The area a cell will be allocated, or NULL, location to return x offset of cell relative to cell_area, or NULL, location to return y offset of cell relative to cell_area, or NULL, location to return width needed to render a cell, or NULL, location to return height needed to render a cell, or NULL
 * Expected: void  
 */
static void test_purpose_1()
{
    #define CELL gtk_cell_renderer_text_new ()
    #define WIDGET gtk_button_new ()
    #define X_OFFSET 1
    #define Y_OFFSET 1
    #define WIDTH 1
    #define HEIGHT 1
    #define CELL_AREA 1
    
    GtkCellRenderer* cell;
    GtkWidget* widget;
    GdkRectangle cell_area;
    gint x_offset;
    gint y_offset;
    // force initialization to silence gcc/valgrind
    gint width = 0;
    gint height = 0;
    GdkRectangle* pcell_area;
    gint* px_offset;
    gint* py_offset;
    gint* pwidth;
    gint* pheight;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    widget = WIDGET;
    pcell_area = CELL_AREA ? &cell_area : NULL;
    px_offset = X_OFFSET ? &x_offset : NULL;
    py_offset = Y_OFFSET ? &y_offset : NULL;
    pwidth = WIDTH ? &width : NULL;
    pheight = HEIGHT ? &height : NULL;
    
    gtk_cell_renderer_get_size (cell, widget, pcell_area, px_offset, py_offset, 
                                pwidth, pheight);
    
    gtk_object_destroy (GTK_OBJECT(widget));
    
    #undef CELL
    #undef WIDGET
    #undef X_OFFSET
    #undef Y_OFFSET
    #undef WIDTH
    #undef HEIGHT
    #undef CELL_AREA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_get_size 
 * Params: GtkCellRenderer *cell, GtkWidget *widget, GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the cell.
 * Params Values: newly created GtkCellRenderer*, newly created GtkWidget*, The area a cell will be allocated, or NULL, location to return x offset of cell relative to cell_area, or NULL, location to return y offset of cell relative to cell_area, or NULL, location to return width needed to render a cell, or NULL, location to return height needed to render a cell, or NULL
 * 
 * Expected: void
 * Name:  gtk_cell_renderer_get_size 
 * Params: GtkCellRenderer *cell, GtkWidget *widget, GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: If cell_area is not NULL, fills in the x and y offsets (if set) of the cell relative to this location.
 * Params Values: newly created GtkCellRenderer*, newly created GtkWidget*, The area a cell will be allocated, or NULL, location to return x offset of cell relative to cell_area, or NULL, location to return y offset of cell relative to cell_area, or NULL, location to return width needed to render a cell, or NULL, location to return height needed to render a cell, or NULL
 * Expected: void  
 */
static void test_purpose_2()
{
    #define CELL gtk_cell_renderer_pixbuf_new ()
    #define WIDGET gtk_label_new ("Label text")
    #define X_OFFSET NULL
    #define Y_OFFSET NULL
    #define WIDTH NULL
    #define HEIGHT NULL
    #define CELL_AREA NULL
    
    GtkCellRenderer* cell;
    GtkWidget* widget;
    GdkRectangle cell_area;
    gint x_offset;
    gint y_offset;
    // force initialization to silence gcc/valgrind
    gint width = 0;
    gint height = 0;
    GdkRectangle* pcell_area;
    gint* px_offset;
    gint* py_offset;
    gint* pwidth;
    gint* pheight;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    widget = WIDGET;
    pcell_area = CELL_AREA ? &cell_area : NULL;
    px_offset = X_OFFSET ? &x_offset : NULL;
    py_offset = Y_OFFSET ? &y_offset : NULL;
    pwidth = WIDTH ? &width : NULL;
    pheight = HEIGHT ? &height : NULL;
    
    gtk_cell_renderer_get_size (cell, widget, pcell_area, px_offset, py_offset, 
                                pwidth, pheight);
    
    gtk_object_destroy (GTK_OBJECT(widget));
    
    #undef CELL
    #undef WIDGET
    #undef X_OFFSET
    #undef Y_OFFSET
    #undef WIDTH
    #undef HEIGHT
    #undef CELL_AREA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_get_size 
 * Params: GtkCellRenderer *cell, GtkWidget *widget, GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the width and height needed to render the cell.
 * Params Values: newly created GtkCellRenderer*, newly created GtkWidget*, The area a cell will be allocated, or NULL, location to return x offset of cell relative to cell_area, or NULL, location to return y offset of cell relative to cell_area, or NULL, location to return width needed to render a cell, or NULL, location to return height needed to render a cell, or NULL
 * 
 * Expected: void
 * Name:  gtk_cell_renderer_get_size 
 * Params: GtkCellRenderer *cell, GtkWidget *widget, GdkRectangle *cell_area, gint *x_offset, gint *y_offset, gint *width, gint *height
 * Returns: void
 * Assertion: If cell_area is not NULL, fills in the x and y offsets (if set) of the cell relative to this location.
 * Params Values: newly created GtkCellRenderer*, newly created GtkWidget*, The area a cell will be allocated, or NULL, location to return x offset of cell relative to cell_area, or NULL, location to return y offset of cell relative to cell_area, or NULL, location to return width needed to render a cell, or NULL, location to return height needed to render a cell, or NULL
 * Expected: void  
 */
static void test_purpose_3()
{
    #define CELL gtk_cell_renderer_toggle_new ()
    #define WIDGET gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_NONE)
    #define X_OFFSET NULL
    #define Y_OFFSET 1
    #define WIDTH NULL
    #define HEIGHT 1
    #define CELL_AREA 1
    
    GtkCellRenderer* cell;
    GtkWidget* widget;
    GdkRectangle cell_area;
    gint x_offset;
    gint y_offset;
    // force initialization to silence gcc/valgrind
    gint width = 0;
    gint height = 0;
    GdkRectangle* pcell_area;
    gint* px_offset;
    gint* py_offset;
    gint* pwidth;
    gint* pheight;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    widget = WIDGET;
    pcell_area = CELL_AREA ? &cell_area : NULL;
    px_offset = X_OFFSET ? &x_offset : NULL;
    py_offset = Y_OFFSET ? &y_offset : NULL;
    pwidth = WIDTH ? &width : NULL;
    pheight = HEIGHT ? &height : NULL;
    
    gtk_cell_renderer_get_size (cell, widget, pcell_area, px_offset, py_offset, 
                                pwidth, pheight);
    
    gtk_object_destroy (GTK_OBJECT(widget));
    
    #undef CELL
    #undef WIDGET
    #undef X_OFFSET
    #undef Y_OFFSET
    #undef WIDTH
    #undef HEIGHT
    #undef CELL_AREA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_render 
 * Params: GtkCellRenderer *cell, GdkWindow *window, GtkWidget *widget, GdkRectangle *background_area, GdkRectangle *cell_area, GdkRectangle *expose_area, GtkCellRendererState flags
 * Returns: void
 * Assertion: Invokes the virtual render function of the GtkCellRenderer. 
 * Params Values: newly created GtkCellRenderer, GdkWindow*, the widget owning window, entire cell area, area normally rendered by a cell renderer, area that actually needs updating, GTK_CELL_RENDERER_SELECTED 
 * Expected: void  
 */
static void test_purpose_4()
{
    #define CELL gtk_cell_renderer_text_new ()
    #define CELL_FLAGS GTK_CELL_RENDERER_SELECTED
    
    GtkCellRenderer* cell;
    GtkWidget* window;
    GtkWidget* widget;
    GdkRectangle background_area;
    GdkRectangle cell_area;
    GdkRectangle expose_area;
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    gtk_tree_store_append (tree_store, &iter, NULL);
    widget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (tree_store));
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_realize (widget);
    
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &cell_area);
    gtk_tree_view_get_background_area (GTK_TREE_VIEW (widget), 
                                       gtk_tree_path_new_from_string  ("0"),
                                       gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                       &background_area);
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &expose_area);
    
    gtk_cell_renderer_render (cell, widget->window, widget, &background_area, &cell_area, &expose_area, CELL_FLAGS);
    
    #undef CELL
    #undef CELL_FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_render 
 * Params: GtkCellRenderer *cell, GdkWindow *window, GtkWidget *widget, GdkRectangle *background_area, GdkRectangle *cell_area, GdkRectangle *expose_area, GtkCellRendererState flags
 * Returns: void
 * Assertion: Invokes the virtual render function of the GtkCellRenderer. 
 * Params Values: newly created GtkCellRenderer, GdkWindow*, the widget owning window, entire cell area, area normally rendered by a cell renderer, area that actually needs updating, GTK_CELL_RENDERER_PRELIT 
 * Expected: void  
 */
static void test_purpose_5()
{
    #define CELL gtk_cell_renderer_pixbuf_new ()
    #define CELL_FLAGS GTK_CELL_RENDERER_PRELIT
    
    GtkCellRenderer* cell;
    GtkWidget* window;
    GtkWidget* widget;
    GdkRectangle background_area;
    GdkRectangle cell_area;
    GdkRectangle expose_area;
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    gtk_tree_store_append (tree_store, &iter, NULL);
    widget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (tree_store));
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_realize (widget);
    
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &cell_area);
    gtk_tree_view_get_background_area (GTK_TREE_VIEW (widget), 
                                       gtk_tree_path_new_from_string  ("0"),
                                       gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                       &background_area);
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &expose_area);
    
    gtk_cell_renderer_render (cell, widget->window, widget, &background_area, &cell_area, &expose_area, CELL_FLAGS);
    
    #undef CELL
    #undef CELL_FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_render 
 * Params: GtkCellRenderer *cell, GdkWindow *window, GtkWidget *widget, GdkRectangle *background_area, GdkRectangle *cell_area, GdkRectangle *expose_area, GtkCellRendererState flags
 * Returns: void
 * Assertion: Invokes the virtual render function of the GtkCellRenderer. 
 * Params Values: newly created GtkCellRenderer, GdkWindow*, the widget owning window, entire cell area, area normally rendered by a cell renderer, area that actually needs updating, GTK_CELL_RENDERER_INSENSITIVE  
 * Expected: void  
 */
static void test_purpose_6()
{
    #define CELL gtk_cell_renderer_toggle_new ()
    #define CELL_FLAGS GTK_CELL_RENDERER_INSENSITIVE 
    
    GtkCellRenderer* cell;
    GtkWidget* window;
    GtkWidget* widget;
    GdkRectangle background_area;
    GdkRectangle cell_area;
    GdkRectangle expose_area;
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    gtk_tree_store_append (tree_store, &iter, NULL);
    widget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (tree_store));
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_realize (widget);
    
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &cell_area);
    gtk_tree_view_get_background_area (GTK_TREE_VIEW (widget), 
                                       gtk_tree_path_new_from_string  ("0"),
                                       gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                       &background_area);
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &expose_area);
    
    gtk_cell_renderer_render (cell, widget->window, widget, &background_area, &cell_area, &expose_area, CELL_FLAGS);
    
    #undef CELL
    #undef CELL_FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_render 
 * Params: GtkCellRenderer *cell, GdkWindow *window, GtkWidget *widget, GdkRectangle *background_area, GdkRectangle *cell_area, GdkRectangle *expose_area, GtkCellRendererState flags
 * Returns: void
 * Assertion: Invokes the virtual render function of the GtkCellRenderer. 
 * Params Values: newly created GtkCellRenderer, GdkWindow*, the widget owning window, entire cell area, area normally rendered by a cell renderer, area that actually needs updating, GTK_CELL_RENDERER_SORTED 
 * Expected: void  
 */
static void test_purpose_7()
{
    #define CELL gtk_cell_renderer_toggle_new ()
    #define CELL_FLAGS GTK_CELL_RENDERER_SORTED
    
    GtkCellRenderer* cell;
    GtkWidget* window;
    GtkWidget* widget;
    GdkRectangle background_area;
    GdkRectangle cell_area;
    GdkRectangle expose_area;
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    gtk_tree_store_append (tree_store, &iter, NULL);
    widget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (tree_store));
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_realize (widget);
    
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &cell_area);
    gtk_tree_view_get_background_area (GTK_TREE_VIEW (widget), 
                                       gtk_tree_path_new_from_string  ("0"),
                                       gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                       &background_area);
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &expose_area);
    
    gtk_cell_renderer_render (cell, widget->window, widget, &background_area, &cell_area, &expose_area, CELL_FLAGS);
    
    #undef CELL
    #undef CELL_FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_activate
 * Params: GtkCellRenderer *cell, GdkEvent *event, GtkWidget *widget, const gchar *path, GdkRectangle *background_area, GdkRectangle *cell_area, GtkCellRendererState flags
 * Returns: gboolean
 * Assertion: Passes an activate event to the cell renderer for possible processing.
 * Params Values: newly created GtkCellRenderer, GdkEvent*, the widget owning window, entire cell area, area normally rendered by a cell renderer, GTK_CELL_RENDERER_SELECTED 
 * Expected: TRUE if the event was consumed/handled  
 */
static void test_purpose_8()
{
    #define CELL gtk_cell_renderer_text_new ()
    #define CELL_FLAGS GTK_CELL_RENDERER_SELECTED
    
    GtkCellRenderer* cell;
    GtkWidget* window;
    GtkWidget* widget;
    GdkRectangle background_area;
    GdkRectangle cell_area;
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GdkEvent event;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    gtk_tree_store_append (tree_store, &iter, NULL);
    widget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (tree_store));
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_realize (widget);
    
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &cell_area);
    gtk_tree_view_get_background_area (GTK_TREE_VIEW (widget), 
                                       gtk_tree_path_new_from_string  ("0"),
                                       gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                       &background_area);
    
    gtk_cell_renderer_activate (cell, &event, widget, "0", &background_area, &cell_area, CELL_FLAGS);
    
    #undef CELL
    #undef CELL_FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_activate
 * Params: GtkCellRenderer *cell, GdkEvent *event, GtkWidget *widget, const gchar *path, GdkRectangle *background_area, GdkRectangle *cell_area, GtkCellRendererState flags
 * Returns: gboolean
 * Assertion: Passes an activate event to the cell renderer for possible processing.
 * Params Values: newly created GtkCellRenderer, GdkEvent*, the widget owning window, entire cell area, area normally rendered by a cell renderer, GTK_CELL_RENDERER_PRELIT 
 * Expected: TRUE if the event was consumed/handled  
 */
static void test_purpose_9()
{
    #define CELL gtk_cell_renderer_pixbuf_new ()
    #define CELL_FLAGS GTK_CELL_RENDERER_PRELIT
    
    GtkCellRenderer* cell;
    GtkWidget* window;
    GtkWidget* widget;
    GdkRectangle background_area;
    GdkRectangle cell_area;
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GdkEvent event;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    gtk_tree_store_append (tree_store, &iter, NULL);
    widget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (tree_store));
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_realize (widget);
    
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &cell_area);
    gtk_tree_view_get_background_area (GTK_TREE_VIEW (widget), 
                                       gtk_tree_path_new_from_string  ("0"),
                                       gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                       &background_area);
    
    gtk_cell_renderer_activate (cell, &event, widget, "0", &background_area, &cell_area, CELL_FLAGS);
    
    #undef CELL
    #undef CELL_FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_activate
 * Params: GtkCellRenderer *cell, GdkEvent *event, GtkWidget *widget, const gchar *path, GdkRectangle *background_area, GdkRectangle *cell_area, GtkCellRendererState flags
 * Returns: gboolean
 * Assertion: Passes an activate event to the cell renderer for possible processing.
 * Params Values: newly created GtkCellRenderer, GdkEvent*, the widget owning window, entire cell area, area normally rendered by a cell renderer, GTK_CELL_RENDERER_INSENSITIVE  
 * Expected: TRUE if the event was consumed/handled  
 */
static void test_purpose_10()
{
    #define CELL gtk_cell_renderer_toggle_new ()
    #define CELL_FLAGS GTK_CELL_RENDERER_INSENSITIVE 
    
    GtkCellRenderer* cell;
    GtkWidget* window;
    GtkWidget* widget;
    GdkRectangle background_area;
    GdkRectangle cell_area;
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GdkEvent event;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    gtk_tree_store_append (tree_store, &iter, NULL);
    widget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (tree_store));
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_realize (widget);
    
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &cell_area);
    gtk_tree_view_get_background_area (GTK_TREE_VIEW (widget), 
                                       gtk_tree_path_new_from_string  ("0"),
                                       gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                       &background_area);
    
    gtk_cell_renderer_activate (cell, &event, widget, "0", &background_area, &cell_area, CELL_FLAGS);
    
    #undef CELL
    #undef CELL_FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_activate
 * Params: GtkCellRenderer *cell, GdkEvent *event, GtkWidget *widget, const gchar *path, GdkRectangle *background_area, GdkRectangle *cell_area, GtkCellRendererState flags
 * Returns: gboolean
 * Assertion: Passes an activate event to the cell renderer for possible processing.
 * Params Values: newly created GtkCellRenderer, GdkEvent*, the widget owning window, entire cell area, area normally rendered by a cell renderer, GTK_CELL_RENDERER_SORTED 
 * Expected: TRUE if the event was consumed/handled  
 */
static void test_purpose_11()
{
    #define CELL gtk_cell_renderer_toggle_new ()
    #define CELL_FLAGS GTK_CELL_RENDERER_SORTED
    
    GtkCellRenderer* cell;
    GtkWidget* window;
    GtkWidget* widget;
    GdkRectangle background_area;
    GdkRectangle cell_area;
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GdkEvent event;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    gtk_tree_store_append (tree_store, &iter, NULL);
    widget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (tree_store));
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_realize (widget);
    
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &cell_area);
    gtk_tree_view_get_background_area (GTK_TREE_VIEW (widget), 
                                       gtk_tree_path_new_from_string  ("0"),
                                       gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                       &background_area);
    
    gtk_cell_renderer_activate (cell, &event, widget, "0", &background_area, &cell_area, CELL_FLAGS);
    
    #undef CELL
    #undef CELL_FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_start_editing
 * Params: GtkCellRenderer *cell, GdkEvent *event, GtkWidget *widget, const gchar *path, GdkRectangle *background_area, GdkRectangle *cell_area, GtkCellRendererState flags
 * Returns: GtkCellEditable*
 * Assertion: Passes an activate event to the cell renderer for possible processing.
 * Params Values: newly created GtkCellRenderer, GdkEvent*, the widget owning window, entire cell area, area normally rendered by a cell renderer, GTK_CELL_RENDERER_SELECTED 
 * Expected: A new GtkCellEditable, or NULL.  
 */
static void test_purpose_12()
{
    #define CELL gtk_cell_renderer_text_new ()
    #define CELL_FLAGS GTK_CELL_RENDERER_SELECTED
    
    GtkCellRenderer* cell;
    GtkWidget* window;
    GtkWidget* widget;
    GdkRectangle background_area;
    GdkRectangle cell_area;
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GdkEvent event;
    GtkCellEditable* cell_editable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    gtk_tree_store_append (tree_store, &iter, NULL);
    widget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (tree_store));
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_realize (widget);
    
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &cell_area);
    gtk_tree_view_get_background_area (GTK_TREE_VIEW (widget), 
                                       gtk_tree_path_new_from_string  ("0"),
                                       gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                       &background_area);
    
    cell_editable = gtk_cell_renderer_start_editing (cell, &event, widget, "0", &background_area, &cell_area, CELL_FLAGS);
    
    #undef CELL
    #undef CELL_FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_start_editing
 * Params: GtkCellRenderer *cell, GdkEvent *event, GtkWidget *widget, const gchar *path, GdkRectangle *background_area, GdkRectangle *cell_area, GtkCellRendererState flags
 * Returns: GtkCellEditable*
 * Assertion: Passes an activate event to the cell renderer for possible processing.
 * Params Values: newly created GtkCellRenderer, GdkEvent*, the widget owning window, entire cell area, area normally rendered by a cell renderer, GTK_CELL_RENDERER_PRELIT 
 * Expected: A new GtkCellEditable, or NULL.  
 */
static void test_purpose_13()
{
    #define CELL gtk_cell_renderer_pixbuf_new ()
    #define CELL_FLAGS GTK_CELL_RENDERER_PRELIT
    
    GtkCellRenderer* cell;
    GtkWidget* window;
    GtkWidget* widget;
    GdkRectangle background_area;
    GdkRectangle cell_area;
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GdkEvent event;
    GtkCellEditable* cell_editable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    gtk_tree_store_append (tree_store, &iter, NULL);
    widget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (tree_store));
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_realize (widget);
    
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &cell_area);
    gtk_tree_view_get_background_area (GTK_TREE_VIEW (widget), 
                                       gtk_tree_path_new_from_string  ("0"),
                                       gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                       &background_area);
    
    cell_editable = gtk_cell_renderer_start_editing (cell, &event, widget, "0", &background_area, &cell_area, CELL_FLAGS);
    
    #undef CELL
    #undef CELL_FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_start_editing
 * Params: GtkCellRenderer *cell, GdkEvent *event, GtkWidget *widget, const gchar *path, GdkRectangle *background_area, GdkRectangle *cell_area, GtkCellRendererState flags
 * Returns: GtkCellEditable*
 * Assertion: Passes an activate event to the cell renderer for possible processing.
 * Params Values: newly created GtkCellRenderer, GdkEvent*, the widget owning window, entire cell area, area normally rendered by a cell renderer, GTK_CELL_RENDERER_INSENSITIVE  
 * Expected: A new GtkCellEditable, or NULL.  
 */
static void test_purpose_14()
{
    #define CELL gtk_cell_renderer_toggle_new ()
    #define CELL_FLAGS GTK_CELL_RENDERER_INSENSITIVE 
    
    GtkCellRenderer* cell;
    GtkWidget* window;
    GtkWidget* widget;
    GdkRectangle background_area;
    GdkRectangle cell_area;
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GdkEvent event;
    GtkCellEditable* cell_editable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    gtk_tree_store_append (tree_store, &iter, NULL);
    widget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (tree_store));
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_realize (widget);
    
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &cell_area);
    gtk_tree_view_get_background_area (GTK_TREE_VIEW (widget), 
                                       gtk_tree_path_new_from_string  ("0"),
                                       gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                       &background_area);
    
    cell_editable = gtk_cell_renderer_start_editing (cell, &event, widget, "0", &background_area, &cell_area, CELL_FLAGS);
    
    #undef CELL
    #undef CELL_FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_start_editing
 * Params: GtkCellRenderer *cell, GdkEvent *event, GtkWidget *widget, const gchar *path, GdkRectangle *background_area, GdkRectangle *cell_area, GtkCellRendererState flags
 * Returns: GtkCellEditable*
 * Assertion: Passes an activate event to the cell renderer for possible processing.
 * Params Values: newly created GtkCellRenderer, GdkEvent*, the widget owning window, entire cell area, area normally rendered by a cell renderer, GTK_CELL_RENDERER_SORTED 
 * Expected: A new GtkCellEditable, or NULL.  
 */
static void test_purpose_15()
{
    #define CELL gtk_cell_renderer_toggle_new ()
    #define CELL_FLAGS GTK_CELL_RENDERER_SORTED
    
    GtkCellRenderer* cell;
    GtkWidget* window;
    GtkWidget* widget;
    GdkRectangle background_area;
    GdkRectangle cell_area;
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GdkEvent event;
    GtkCellEditable* cell_editable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = CELL;
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    gtk_tree_store_append (tree_store, &iter, NULL);
    widget = gtk_tree_view_new_with_model (GTK_TREE_MODEL (tree_store));
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_realize (widget);
    
    gtk_tree_view_get_cell_area (GTK_TREE_VIEW (widget), 
                                 gtk_tree_path_new_from_string  ("0"),
                                 gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                 &cell_area);
    gtk_tree_view_get_background_area (GTK_TREE_VIEW (widget), 
                                       gtk_tree_path_new_from_string  ("0"),
                                       gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 0),
                                       &background_area);
    
    cell_editable = gtk_cell_renderer_start_editing (cell, &event, widget, "0", &background_area, &cell_area, CELL_FLAGS);
    
    #undef CELL
    #undef CELL_FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_set_fixed_size 
 * Params: GtkCellRenderer *cell, gint width, gint height
 * Returns: void
 * Assertion: Sets the renderer size to be explicit, independent of the properties set.
 * Params Values: newly created GtkCellRenderer, gtk_cell_renderer_text_new (), 0
 * Expected: void
 * 
 * Name:  gtk_cell_renderer_get_fixed_size 
 * Params: GtkCellRenderer *cell, gint *width, gint *height
 * Returns: void
 * Assertion: Fills in width and height with the appropriate size of cell.
 * Params Values: newly created GtkCellRenderer, location to fill in with the fixed width of the widget, or NULL, location to fill in with the fixed height of the widget, or NULL
 * Expected: void  
 */
static void test_purpose_16()
{
    #define CELL gtk_cell_renderer_text_new ()
    #define WIDTH 0
    #define HEIGHT 0
    #define PWIDTH 1
    #define PHEIGHT 1
    
    GtkCellRenderer* cell;
    // force initialization to silence gcc/valgrind
    gint width = 0;
    gint height = 0;
    gint* pwidth;
    gint* pheight;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = gtk_cell_renderer_text_new ();
    
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_cell_renderer_set_fixed_size (cell, WIDTH, HEIGHT);
    pwidth = PWIDTH ? &width : NULL;
    pheight = PHEIGHT ? &height : NULL;
    gtk_cell_renderer_get_fixed_size (cell, pwidth, pheight);
    
    if (width != WIDTH && pwidth)
    {
        TEST_FAIL ("width = %i, should be %i", width, WIDTH); 
    }
    
    if (height != HEIGHT && pheight)
    {
        TEST_FAIL ("height = %i, should be %i", height, HEIGHT); 
    }
    
    gtk_object_destroy (GTK_OBJECT(cell));
    
    #undef CELL
    #undef WIDTH
    #undef HEIGHT
    #undef PWIDTH
    #undef PHEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_set_fixed_size 
 * Params: GtkCellRenderer *cell, gint width, gint height
 * Returns: void
 * Assertion: Sets the renderer size to be explicit, independent of the properties set.
 * Params Values: newly created GtkCellRenderer, gtk_cell_renderer_pixbuf_new (), -1
 * Expected: void
 * 
 * Name:  gtk_cell_renderer_get_fixed_size 
 * Params: GtkCellRenderer *cell, gint *width, gint *height
 * Returns: void
 * Assertion: Fills in width and height with the appropriate size of cell.
 * Params Values: newly created GtkCellRenderer, location to fill in with the fixed width of the widget, or NULL, location to fill in with the fixed height of the widget, or NULL
 * Expected: void  
 */
static void test_purpose_17()
{
    #define CELL gtk_cell_renderer_pixbuf_new ()
    #define WIDTH -1
    #define HEIGHT -1
    #define PWIDTH NULL
    #define PHEIGHT NULL
    
    GtkCellRenderer* cell;
    // force initialization to silence gcc/valgrind
    gint width = 0;
    gint height = 0;
    gint* pwidth;
    gint* pheight;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = gtk_cell_renderer_text_new ();
    
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_cell_renderer_set_fixed_size (cell, WIDTH, HEIGHT);
    pwidth = PWIDTH ? &width : NULL;
    pheight = PHEIGHT ? &height : NULL;
    gtk_cell_renderer_get_fixed_size (cell, pwidth, pheight);
    
    if (width != WIDTH && pwidth)
    {
        TEST_FAIL ("width = %i, should be %i", width, WIDTH); 
    }
    
    if (height != HEIGHT && pheight)
    {
        TEST_FAIL ("height = %i, should be %i", height, HEIGHT); 
    }
    
    gtk_object_destroy (GTK_OBJECT(cell));
    
    #undef CELL
    #undef WIDTH
    #undef HEIGHT
    #undef PWIDTH
    #undef PHEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_cell_renderer_set_fixed_size 
 * Params: GtkCellRenderer *cell, gint width, gint height
 * Returns: void
 * Assertion: Sets the renderer size to be explicit, independent of the properties set.
 * Params Values: newly created GtkCellRenderer, gtk_cell_renderer_toggle_new (), G_MAXINT
 * Expected: void
 * 
 * Name:  gtk_cell_renderer_get_fixed_size 
 * Params: GtkCellRenderer *cell, gint *width, gint *height
 * Returns: void
 * Assertion: Fills in width and height with the appropriate size of cell.
 * Params Values: newly created GtkCellRenderer, location to fill in with the fixed width of the widget, or NULL, location to fill in with the fixed height of the widget, or NULL
 * Expected: void  
 */
static void test_purpose_18()
{
    #define CELL gtk_cell_renderer_toggle_new ()
    #define WIDTH G_MAXINT
    #define HEIGHT G_MAXINT
    #define PWIDTH NULL
    #define PHEIGHT 1
    
    GtkCellRenderer* cell;
    // force initialization to silence gcc/valgrind
    gint width = 0;
    gint height = 0;
    gint* pwidth;
    gint* pheight;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cell = gtk_cell_renderer_text_new ();
    
    if (!cell)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CELL_RENDERER (cell))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_cell_renderer_set_fixed_size (cell, WIDTH, HEIGHT);
    pwidth = PWIDTH ? &width : NULL;
    pheight = PHEIGHT ? &height : NULL;
    gtk_cell_renderer_get_fixed_size (cell, pwidth, pheight);
    
    if (width != WIDTH && pwidth)
    {
        TEST_FAIL ("width = %i, should be %i", width, WIDTH); 
    }
    
    if (height != HEIGHT && pheight)
    {
        TEST_FAIL ("height = %i, should be %i", height, HEIGHT); 
    }
    
    gtk_object_destroy (GTK_OBJECT(cell));
    
    #undef CELL
    #undef WIDTH
    #undef HEIGHT
    #undef PWIDTH
    #undef PHEIGHT
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkCellRenderer ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {NULL,0}
};
