/*
 * GtkEntry methods tests
 * Testing GtkEntry methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
#include "librobot.h"

GtkWidget* couple_of_widgets[2];

void
global_copy_paste (GtkWidget *widget, gpointer user_data)
{
    G_CONST_RETURN gchar* text;
    int i;
    GtkEntry* entry;
    gboolean res;

    if (!GTK_WIDGET_REALIZED (widget))
    {
        return;
    }

    res = robot_focus_in_event (couple_of_widgets[0]);
    robot_key_press_event (couple_of_widgets[0], GDK_Home, 0);
    for (i = 0; i < 6; i++)
    {
        robot_key_press_event (couple_of_widgets[0], GDK_Right, GDK_SHIFT_MASK);
    }
    robot_key_release_event (couple_of_widgets[0], GDK_Right, GDK_SHIFT_MASK);
    robot_key_press_event (couple_of_widgets[0], GDK_c, GDK_CONTROL_MASK);
    robot_key_release_event (couple_of_widgets[0], GDK_c, GDK_CONTROL_MASK);
    res = robot_focus_out_event (couple_of_widgets[0]);
    res = robot_focus_in_event (couple_of_widgets[1]);

    g_usleep (0.5 * 1000000);

    robot_key_press_event (couple_of_widgets[1], GDK_v, GDK_CONTROL_MASK);
    robot_key_release_event (couple_of_widgets[1], GDK_v, GDK_CONTROL_MASK);
    gdk_window_process_all_updates();

    g_usleep (0.5 * 1000000);
}

/*
 * Name: gtk_entry_new
 * Params: void
 * Returns: GtkEntry*
 * Assertion: Creates a new GtkEntry widget.
 * Params Values: void
 * Expected: GtkEntry*  
 */
static void test_purpose_1()
{
    gint text_position;
    gboolean editable;
    gint max_length;
    gboolean visibility;
    guint invisible_char;
    gboolean activates_default;
    gint width_chars;
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "editable", &editable, NULL);
    if (editable != TRUE)
    {
        TEST_FAIL ("editable is %d, should be %d", editable, TRUE);
    }
    
    g_object_get (GTK_OBJECT (widget), "max-length", &max_length, NULL);
    if (max_length != 0)
    {
        TEST_FAIL("max length is %i, should be %d", max_length, 0);
    }
    
    g_object_get (GTK_OBJECT (widget), "visibility", &visibility, NULL);
    if (visibility != TRUE)
    {
        TEST_FAIL("visibility is %d, should be %d", visibility, TRUE);
    }
    
    g_object_get (GTK_OBJECT (widget), "invisible-char", &invisible_char, NULL);
    if (invisible_char == '\0')
    {
        TEST_FAIL("invisible char is %c, should be not zero.", invisible_char);
    }
    
    g_object_get (GTK_OBJECT (widget), "activates-default", &activates_default, NULL);
    if (activates_default != FALSE)
    {
        TEST_FAIL("activates_default is %d, should be %d", FALSE);
    }
    
    g_object_get (GTK_OBJECT (widget), "width-chars", &width_chars, NULL);
    if (width_chars != -1)
    {
        TEST_FAIL("width_chars is %d, should be %d", width_chars, -1);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_text
 * Params: GtkEntry *entry, const gchar *text
 * Returns: void
 * Assertion: Sets the text in the widget to the given value, replacing the current contents.
 * Params Values: GtkEntry *entry, ""
 * Expected: void
 * 
 * Name: gtk_entry_get_text
 * Params: GtkEntry *entry
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the contents of the entry widget.
 * Params Values: GtkEntry *entry
 * Expected: ""  
 */
static void test_purpose_2()
{
    #define TEXT ""
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    real_text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strcmp (real_text, TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", real_text, TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_text
 * Params: GtkEntry *entry, const gchar *text
 * Returns: void
 * Assertion: Sets the text in the widget to the given value, replacing the current contents.
 * Params Values: GtkEntry *entry, " "
 * Expected: void
 * 
 * Name: gtk_entry_get_text
 * Params: GtkEntry *entry
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the contents of the entry widget.
 * Params Values: GtkEntry *entry
 * Expected: " "  
 */
static void test_purpose_3()
{
    #define TEXT " "
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    real_text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strcmp (real_text, TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", real_text, TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_text
 * Params: GtkEntry *entry, const gchar *text
 * Returns: void
 * Assertion: Sets the text in the widget to the given value, replacing the current contents.
 * Params Values: GtkEntry *entry, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void
 * 
 * Name: gtk_entry_get_text
 * Params: GtkEntry *entry
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the contents of the entry widget.
 * Params Values: GtkEntry *entry
 * Expected: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"  
 */
static void test_purpose_4()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    real_text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strcmp (real_text, TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", real_text, TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_text
 * Params: GtkEntry *entry, const gchar *text
 * Returns: void
 * Assertion: Sets the text in the widget to the given value, replacing the current contents.
 * Params Values: GtkEntry *entry, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void
 * 
 * Name: gtk_entry_get_text
 * Params: GtkEntry *entry
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the contents of the entry widget.
 * Params Values: GtkEntry *entry
 * Expected: "!@#$%^&*()_+|~=\";:'?<>`/"  
 */
static void test_purpose_5()
{
    #define TEXT "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    real_text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strcmp (real_text, TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", real_text, TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_text
 * Params: GtkEntry *entry, const gchar *text
 * Returns: void
 * Assertion: Sets the text in the widget to the given value, replacing the current contents.
 * Params Values: GtkEntry *entry, "_a_b"
 * Expected: void
 * 
 * Name: gtk_entry_get_text
 * Params: GtkEntry *entry
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the contents of the entry widget.
 * Params Values: GtkEntry *entry
 * Expected: "_a_b"  
 */
static void test_purpose_6()
{
    #define TEXT "_a_b"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    real_text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strcmp (real_text, TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", real_text, TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_text
 * Params: GtkEntry *entry, const gchar *text
 * Returns: void
 * Assertion: Sets the text in the widget to the given value, replacing the current contents.
 * Params Values: GtkEntry *entry, "\n\t\""
 * Expected: void
 * 
 * Name: gtk_entry_get_text
 * Params: GtkEntry *entry
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the contents of the entry widget.
 * Params Values: GtkEntry *entry
 * Expected: "\n\t\""  
 */
static void test_purpose_7()
{
    #define TEXT "\n\t\""
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    real_text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strcmp (real_text, TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", real_text, TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_text
 * Params: GtkEntry *entry, const gchar *text
 * Returns: void
 * Assertion: Sets the text in the widget to the given value, replacing the current contents.
 * Params Values: GtkEntry *entry, "_\n\t\""
 * Expected: void
 * 
 * Name: gtk_entry_get_text
 * Params: GtkEntry *entry
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the contents of the entry widget.
 * Params Values: GtkEntry *entry
 * Expected: "_\n\t\""  
 */
static void test_purpose_8()
{
    #define TEXT "_\n\t\""
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    real_text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strcmp (real_text, TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", real_text, TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_text
 * Params: GtkEntry *entry, const gchar *text
 * Returns: void
 * Assertion: Sets the text in the widget to the given value, replacing the current contents.
 * Params Values: GtkEntry *entry, "\b"
 * Expected: void
 * 
 * Name: gtk_entry_get_text
 * Params: GtkEntry *entry
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the contents of the entry widget.
 * Params Values: GtkEntry *entry
 * Expected: "\b"  
 */
static void test_purpose_9()
{
    #define TEXT "\b"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    real_text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strcmp (real_text, TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", real_text, TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_text
 * Params: GtkEntry *entry, const gchar *text
 * Returns: void
 * Assertion: Sets the text in the widget to the given value, replacing the current contents.
 * Params Values: GtkEntry *entry, "_\b"
 * Expected: void
 * 
 * Name: gtk_entry_get_text
 * Params: GtkEntry *entry
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the contents of the entry widget.
 * Params Values: GtkEntry *entry
 * Expected: "_\b"  
 */
static void test_purpose_10()
{
    #define TEXT "_\b"
    
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    real_text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strcmp (real_text, TEXT))
    {
        TEST_FAIL("Text =  %s, should be %s\n", real_text, TEXT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_visibility
 * Params: GtkEntry *entry, gboolean visible
 * Returns: void
 * Assertion: Sets whether the contents of the entry are visible or not.
 * Params Values: GtkEntry *entry, TRUE
 * Expected: void  
 */
static void test_purpose_11()
{
    #define TEXT ""
    #define VISIBLE TRUE
    
    GtkWidget *widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    gtk_entry_set_visibility (GTK_ENTRY (widget), VISIBLE);
    
    g_object_get (GTK_OBJECT (widget), "visibility", &visible, NULL);
    if (visible != VISIBLE)
    {
        TEST_FAIL("visibility = %i, should be %i", visible, VISIBLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_visibility
 * Params: GtkEntry *entry, gboolean visible
 * Returns: void
 * Assertion: Sets whether the contents of the entry are visible or not.
 * Params Values: GtkEntry *entry, FALSE
 * Expected: void  
 */
static void test_purpose_12()
{
    #define TEXT " "
    #define VISIBLE FALSE
    
    GtkWidget *widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    gtk_entry_set_visibility (GTK_ENTRY (widget), VISIBLE);
    
    g_object_get (GTK_OBJECT (widget), "visibility", &visible, NULL);
    if (visible != VISIBLE)
    {
        TEST_FAIL("visibility = %i, should be %i", visible, VISIBLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_visibility
 * Params: GtkEntry *entry, gboolean visible
 * Returns: void
 * Assertion: Sets whether the contents of the entry are visible or not.
 * Params Values: GtkEntry *entry, TRUE
 * Expected: void  
 */
static void test_purpose_13()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define VISIBLE TRUE
    
    GtkWidget *widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    gtk_entry_set_visibility (GTK_ENTRY (widget), VISIBLE);
    
    g_object_get (GTK_OBJECT (widget), "visibility", &visible, NULL);
    if (visible != VISIBLE)
    {
        TEST_FAIL("visibility = %i, should be %i", visible, VISIBLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_visibility
 * Params: GtkEntry *entry, gboolean visible
 * Returns: void
 * Assertion: Sets whether the contents of the entry are visible or not.
 * Params Values: GtkEntry *entry, FALSE
 * Expected: void  
 */
static void test_purpose_14()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define VISIBLE FALSE
    
    GtkWidget *widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    gtk_entry_set_visibility (GTK_ENTRY (widget), VISIBLE);
    
    g_object_get (GTK_OBJECT (widget), "visibility", &visible, NULL);
    if (visible != VISIBLE)
    {
        TEST_FAIL("visibility = %i, should be %i", visible, VISIBLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_visibility
 * Params: GtkEntry *entry, gboolean visible
 * Returns: void
 * Assertion: The default invisible char is the asterisk '*', but it can be changed with gtk_entry_set_invisible_char().
 * Params Values: GtkEntry *entry, <%1%>
 * Expected: void  
 */
static void test_purpose_15()
{
    #define CHAR '*'
    
    GtkWidget *widget;
    gunichar ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_invisible_char (GTK_ENTRY (widget), CHAR);
    ch = gtk_entry_get_invisible_char (GTK_ENTRY (widget));
    if (ch != CHAR)
    {
        TEST_FAIL("invisible_char = '%c', should be '%c'", ch, CHAR);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHAR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_visibility
 * Params: GtkEntry *entry, gboolean visible
 * Returns: void
 * Assertion: The default invisible char is the asterisk '*', but it can be changed with gtk_entry_set_invisible_char().
 * Params Values: GtkEntry *entry, <%1%>
 * Expected: void  
 */
static void test_purpose_16()
{
    #define CHAR 'q'
    
    GtkWidget *widget;
    gunichar ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_invisible_char (GTK_ENTRY (widget), CHAR);
    ch = gtk_entry_get_invisible_char (GTK_ENTRY (widget));
    if (ch != CHAR)
    {
        TEST_FAIL("invisible_char = '%c', should be '%c'", ch, CHAR);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHAR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_visibility
 * Params: GtkEntry *entry, gboolean visible
 * Returns: void
 * Assertion: The default invisible char is the asterisk '*', but it can be changed with gtk_entry_set_invisible_char().
 * Params Values: GtkEntry *entry, <%1%>
 * Expected: void  
 */
static void test_purpose_17()
{
    #define CHAR '\n'
    
    GtkWidget *widget;
    gunichar ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_invisible_char (GTK_ENTRY (widget), CHAR);
    ch = gtk_entry_get_invisible_char (GTK_ENTRY (widget));
    if (ch != CHAR)
    {
        TEST_FAIL("invisible_char = '%c', should be '%c'", ch, CHAR);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHAR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_visibility
 * Params: GtkEntry *entry, gboolean visible
 * Returns: void
 * Assertion: The default invisible char is the asterisk '*', but it can be changed with gtk_entry_set_invisible_char().
 * Params Values: GtkEntry *entry, <%1%>
 * Expected: void  
 */
static void test_purpose_18()
{
    #define CHAR '&'
    
    GtkWidget *widget;
    gunichar ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_invisible_char (GTK_ENTRY (widget), CHAR);
    ch = gtk_entry_get_invisible_char (GTK_ENTRY (widget));
    if (ch != CHAR)
    {
        TEST_FAIL("invisible_char = '%c', should be '%c'", ch, CHAR);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHAR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_visibility
 * Params: GtkEntry *entry, gboolean visible
 * Returns: void
 * Assertion: The default invisible char is the asterisk '*', but it can be changed with gtk_entry_set_invisible_char().
 * Params Values: GtkEntry *entry, <%1%>
 * Expected: void  
 */
static void test_purpose_19()
{
    #define CHAR '?'
    
    GtkWidget *widget;
    gunichar ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_invisible_char (GTK_ENTRY (widget), CHAR);
    ch = gtk_entry_get_invisible_char (GTK_ENTRY (widget));
    if (ch != CHAR)
    {
        TEST_FAIL("invisible_char = '%c', should be '%c'", ch, CHAR);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHAR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_get_visibility
 * Params: GtkEntry *entry
 * Returns: gboolean
 * Assertion: Retrieves whether the text in entry is visible.
 * Params Values: GtkEntry *entry
 * Expected: TRUE  
 */
static void test_purpose_20()
{
    #define TEXT ""
    #define VISIBLE TRUE
    
    GtkWidget *widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    g_object_set (GTK_OBJECT (widget), "visibility", VISIBLE, NULL);
    
    visible = gtk_entry_get_visibility (GTK_ENTRY (widget));
    if (visible != VISIBLE)
    {
        TEST_FAIL("visibility = %i, should be %i", visible, VISIBLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_get_visibility
 * Params: GtkEntry *entry
 * Returns: gboolean
 * Assertion: Retrieves whether the text in entry is visible.
 * Params Values: GtkEntry *entry
 * Expected: FALSE  
 */
static void test_purpose_21()
{
    #define TEXT " "
    #define VISIBLE FALSE
    
    GtkWidget *widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    g_object_set (GTK_OBJECT (widget), "visibility", VISIBLE, NULL);
    
    visible = gtk_entry_get_visibility (GTK_ENTRY (widget));
    if (visible != VISIBLE)
    {
        TEST_FAIL("visibility = %i, should be %i", visible, VISIBLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_get_visibility
 * Params: GtkEntry *entry
 * Returns: gboolean
 * Assertion: Retrieves whether the text in entry is visible.
 * Params Values: GtkEntry *entry
 * Expected: TRUE  
 */
static void test_purpose_22()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define VISIBLE TRUE
    
    GtkWidget *widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    g_object_set (GTK_OBJECT (widget), "visibility", VISIBLE, NULL);
    
    visible = gtk_entry_get_visibility (GTK_ENTRY (widget));
    if (visible != VISIBLE)
    {
        TEST_FAIL("visibility = %i, should be %i", visible, VISIBLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_get_visibility
 * Params: GtkEntry *entry
 * Returns: gboolean
 * Assertion: Retrieves whether the text in entry is visible.
 * Params Values: GtkEntry *entry
 * Expected: FALSE  
 */
static void test_purpose_23()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define VISIBLE FALSE
    
    GtkWidget *widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    
    g_object_set (GTK_OBJECT (widget), "visibility", VISIBLE, NULL);
    
    visible = gtk_entry_get_visibility (GTK_ENTRY (widget));
    if (visible != VISIBLE)
    {
        TEST_FAIL("visibility = %i, should be %i", visible, VISIBLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_get_invisible_char
 * Params: GtkEntry *entry
 * Returns: gunichar
 * Assertion: Retrieves the character displayed in place of the real characters for entries with visisbility set to false.
 * Params Values: GtkEntry *entry, '*'
 * Expected: void  
 */
static void test_purpose_24()
{
    #define CHAR '*'
    
    GtkWidget *widget;
    gunichar ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "invisible-char", CHAR, NULL);
    ch = gtk_entry_get_invisible_char (GTK_ENTRY (widget));
    
    if (ch != CHAR)
    {
        TEST_FAIL("invisible_char = '%c', should be '%c'", ch, CHAR);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHAR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_get_invisible_char
 * Params: GtkEntry *entry
 * Returns: gunichar
 * Assertion: Retrieves the character displayed in place of the real characters for entries with visisbility set to false.
 * Params Values: GtkEntry *entry, '+'
 * Expected: void  
 */
static void test_purpose_25()
{
    #define CHAR '+'
    
    GtkWidget *widget;
    gunichar ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "invisible-char", CHAR, NULL);
    ch = gtk_entry_get_invisible_char (GTK_ENTRY (widget));
    
    if (ch != CHAR)
    {
        TEST_FAIL("invisible_char = '%c', should be '%c'", ch, CHAR);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHAR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_get_invisible_char
 * Params: GtkEntry *entry
 * Returns: gunichar
 * Assertion: Retrieves the character displayed in place of the real characters for entries with visisbility set to false.
 * Params Values: GtkEntry *entry, '\r'
 * Expected: void  
 */
static void test_purpose_26()
{
    #define CHAR '\r'
    
    GtkWidget *widget;
    gunichar ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "invisible-char", CHAR, NULL);
    ch = gtk_entry_get_invisible_char (GTK_ENTRY (widget));
    
    if (ch != CHAR)
    {
        TEST_FAIL("invisible_char = '%c', should be '%c'", ch, CHAR);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHAR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_get_invisible_char
 * Params: GtkEntry *entry
 * Returns: gunichar
 * Assertion: Retrieves the character displayed in place of the real characters for entries with visisbility set to false.
 * Params Values: GtkEntry *entry, '\n'
 * Expected: void  
 */
static void test_purpose_27()
{
    #define CHAR '\n'
    
    GtkWidget *widget;
    gunichar ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "invisible-char", CHAR, NULL);
    ch = gtk_entry_get_invisible_char (GTK_ENTRY (widget));
    
    if (ch != CHAR)
    {
        TEST_FAIL("invisible_char = '%c', should be '%c'", ch, CHAR);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHAR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_max_length
 * Params: GtkEntry *entry, gint length
 * Returns: void
 * Assertion: Sets the maximum allowed length of the contents of the widget.
 * Params Values: GtkEntry *entry, 0
 * Expected: void  
 */
static void test_purpose_28()
{
    #define LENGTH 0
    
    GtkWidget *widget;
    gint length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_max_length (GTK_ENTRY (widget), LENGTH);
    
    g_object_get (GTK_OBJECT (widget), "max-length", &length, NULL);
    if (LENGTH != length)
    {
        TEST_FAIL("max length = %i, should be %i", length, LENGTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_max_length
 * Params: GtkEntry *entry, gint length
 * Returns: void
 * Assertion: Sets the maximum allowed length of the contents of the widget.
 * Params Values: GtkEntry *entry, 1
 * Expected: void  
 */
static void test_purpose_29()
{
    #define LENGTH 1
    
    GtkWidget *widget;
    gint length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_max_length (GTK_ENTRY (widget), LENGTH);
    
    g_object_get (GTK_OBJECT (widget), "max-length", &length, NULL);
    if (LENGTH != length)
    {
        TEST_FAIL("max length = %i, should be %i", length, LENGTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_max_length
 * Params: GtkEntry *entry, gint length
 * Returns: void
 * Assertion: Sets the maximum allowed length of the contents of the widget.
 * Params Values: GtkEntry *entry, 65535
 * Expected: void  
 */
static void test_purpose_30()
{
    #define LENGTH 65535
    
    GtkWidget *widget;
    gint length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_max_length (GTK_ENTRY (widget), LENGTH);
    
    g_object_get (GTK_OBJECT (widget), "max-length", &length, NULL);
    if (LENGTH != length)
    {
        TEST_FAIL("max length = %i, should be %i", length, LENGTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_max_length
 * Params: GtkEntry *entry, gint length
 * Returns: void
 * Assertion: If the current contents are longer than the given length, then they will be truncated to fit.
 * Params Values: GtkEntry *entry with text "qw", 1
 * Expected: void  
 */
static void test_purpose_31()
{
    #define TEXT "qw"
    #define TEXT2 "qw"
    #define LENGTH 1
    
    GtkWidget *widget;
    gint length;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    gtk_entry_set_max_length (GTK_ENTRY (widget), LENGTH);
    
    text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strlen (text) > LENGTH)
    {
        TEST_FAIL ("1: strlen (text) = %d, max-length = %d", strlen (text), LENGTH);
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT2);
    text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strlen (text) > LENGTH)
    {
        TEST_FAIL ("2: strlen (text) = %d, max-length = %d", strlen (text), LENGTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef TEXT2
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_max_length
 * Params: GtkEntry *entry, gint length
 * Returns: void
 * Assertion: If the current contents are longer than the given length, then they will be truncated to fit.
 * Params Values: GtkEntry *entry with text "qwtriyhjjljhl;;jkl'kl;gfjfgjgfj", 15
 * Expected: void  
 */
static void test_purpose_32()
{
    #define TEXT "qwtriyhjjljhl;;jkl'kl;gfjfgjgfj"
    #define TEXT2 ""
    #define LENGTH 15
    
    GtkWidget *widget;
    gint length;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    gtk_entry_set_max_length (GTK_ENTRY (widget), LENGTH);
    
    text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strlen (text) > LENGTH)
    {
        TEST_FAIL ("1: strlen (text) = %d, max-length = %d", strlen (text), LENGTH);
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT2);
    text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strlen (text) > LENGTH)
    {
        TEST_FAIL ("2: strlen (text) = %d, max-length = %d", strlen (text), LENGTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef TEXT2
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_max_length
 * Params: GtkEntry *entry, gint length
 * Returns: void
 * Assertion: If the current contents are longer than the given length, then they will be truncated to fit.
 * Params Values: GtkEntry *entry with text "", 15
 * Expected: void  
 */
static void test_purpose_33()
{
    #define TEXT ""
    #define TEXT2 "qwtriyhjjljhl;;jkl'kl;gfjfgjgfj"
    #define LENGTH 15
    
    GtkWidget *widget;
    gint length;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    gtk_entry_set_max_length (GTK_ENTRY (widget), LENGTH);
    
    text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strlen (text) > LENGTH)
    {
        TEST_FAIL ("1: strlen (text) = %d, max-length = %d", strlen (text), LENGTH);
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT2);
    text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strlen (text) > LENGTH)
    {
        TEST_FAIL ("2: strlen (text) = %d, max-length = %d", strlen (text), LENGTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef TEXT2
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_max_length
 * Params: GtkEntry *entry, gint length
 * Returns: void
 * Assertion: If the current contents are longer than the given length, then they will be truncated to fit.
 * Params Values: GtkEntry *entry with text "qwtriyhjjljhl;;jkl'kl;gfjfgjgfj", 15
 * Expected: void  
 */
static void test_purpose_34()
{
    #define TEXT "qwtriyhjjljhl;;jkl'kl;gfjfgjgfj"
    #define TEXT2 "qwtriyhjjljhl;;jkl'kl;gfjfgjgfj"
    #define LENGTH 15
    
    GtkWidget *widget;
    gint length;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    gtk_entry_set_max_length (GTK_ENTRY (widget), LENGTH);
    
    text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strlen (text) > LENGTH)
    {
        TEST_FAIL ("1: strlen (text) = %d, max-length = %d", strlen (text), LENGTH);
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT2);
    text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strlen (text) > LENGTH)
    {
        TEST_FAIL ("2: strlen (text) = %d, max-length = %d", strlen (text), LENGTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef TEXT2
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_max_length
 * Params: GtkEntry *entry, gint length
 * Returns: void
 * Assertion: If the current contents are longer than the given length, then they will be truncated to fit.
 * Params Values: GtkEntry *entry with text "setddf", 65535
 * Expected: void  
 */
static void test_purpose_35()
{
    #define TEXT "setddf"
    #define TEXT2 "setddf"
    #define LENGTH 65535
    
    GtkWidget *widget;
    gint length;
    G_CONST_RETURN gchar* text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT);
    gtk_entry_set_max_length (GTK_ENTRY (widget), LENGTH);
    
    text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strlen (text) > LENGTH)
    {
        TEST_FAIL ("1: strlen (text) = %d, max-length = %d", strlen (text), LENGTH);
    }
    
    gtk_entry_set_text (GTK_ENTRY (widget), TEXT2);
    text = gtk_entry_get_text (GTK_ENTRY (widget));
    if (strlen (text) > LENGTH)
    {
        TEST_FAIL ("2: strlen (text) = %d, max-length = %d", strlen (text), LENGTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef TEXT2
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_get_max_length
 * Params: GtkEntry *entry
 * Returns: gint
 * Assertion: Retrieves the maximum allowed length of the text in entry.
 * Params Values: GtkEntry *entry
 * Expected: 0  
 */
static void test_purpose_36()
{
    #define LENGTH 0
    
    GtkWidget *widget;
    gint length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "max-length", LENGTH, NULL);
    
    length = gtk_entry_get_max_length (GTK_ENTRY (widget));
    if (length != LENGTH)
    {
        TEST_FAIL("max length = %i, should be %i", length, LENGTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_get_max_length
 * Params: GtkEntry *entry
 * Returns: gint
 * Assertion: Retrieves the maximum allowed length of the text in entry.
 * Params Values: GtkEntry *entry
 * Expected: 1  
 */
static void test_purpose_37()
{
    #define LENGTH 1
    
    GtkWidget *widget;
    gint length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "max-length", LENGTH, NULL);
    
    length = gtk_entry_get_max_length (GTK_ENTRY (widget));
    if (length != LENGTH)
    {
        TEST_FAIL("max length = %i, should be %i", length, LENGTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_get_max_length
 * Params: GtkEntry *entry
 * Returns: gint
 * Assertion: Retrieves the maximum allowed length of the text in entry.
 * Params Values: GtkEntry *entry
 * Expected: 65535  
 */
static void test_purpose_38()
{
    #define LENGTH 65535
    
    GtkWidget *widget;
    gint length;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    g_object_set (GTK_OBJECT (widget), "max-length", LENGTH, NULL);
    
    length = gtk_entry_get_max_length (GTK_ENTRY (widget));
    if (length != LENGTH)
    {
        TEST_FAIL("max length = %i, should be %i", length, LENGTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_activates_default
 * Params: GtkEntry *entry, gboolean setting
 * Returns: void
 * Assertion: If setting is TRUE, pressing Enter in the entry will activate the default widget for the window containing the entry.
 * Params Values: GtkEntry *entry, FALSE
 * Expected: void
 * 
 * Name: gtk_entry_get_activates_default
 * Params: GtkEntry *entry
 * Returns: gboolean
 * Assertion: Retrieves the value set by gtk_entry_set_activates_default().
 * Params Values: GtkEntry *entry
 * Expected: gboolean  
 */
static void test_purpose_39()
{
    #define SETTING FALSE
    
    GtkWidget *widget;
    gboolean setting;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_activates_default (GTK_ENTRY (widget), SETTING);
    if (gtk_entry_get_activates_default (GTK_ENTRY (widget)) != SETTING )
    {
        TEST_FAIL("activetes default = %i, should be %i\n", gtk_entry_get_activates_default (GTK_ENTRY (widget)), SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_activates_default
 * Params: GtkEntry *entry, gboolean setting
 * Returns: void
 * Assertion: If setting is TRUE, pressing Enter in the entry will activate the default widget for the window containing the entry.
 * Params Values: GtkEntry *entry, TRUE
 * Expected: void
 * 
 * Name: gtk_entry_get_activates_default
 * Params: GtkEntry *entry
 * Returns: gboolean
 * Assertion: Retrieves the value set by gtk_entry_set_activates_default().
 * Params Values: GtkEntry *entry
 * Expected: gboolean  
 */
static void test_purpose_40()
{
    #define SETTING TRUE
    
    GtkWidget *widget;
    gboolean setting;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_activates_default (GTK_ENTRY (widget), SETTING);
    if (gtk_entry_get_activates_default (GTK_ENTRY (widget)) != SETTING )
    {
        TEST_FAIL("activetes default = %i, should be %i\n", gtk_entry_get_activates_default (GTK_ENTRY (widget)), SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_has_frame
 * Params: GtkEntry *entry, gboolean setting
 * Returns: void
 * Assertion: Sets whether the entry has a beveled frame around it.
 * Params Values: GtkEntry *entry, FALSE
 * Expected: void
 * 
 * Name: gtk_entry_get_has_frame
 * Params: GtkEntry *entry
 * Returns: gboolean
 * Assertion: Gets the value set by gtk_entry_set_has_frame().
 * Params Values: GtkEntry *entry
 * Expected: gboolean  
 */
static void test_purpose_41()
{
    #define SETTING FALSE
    
    GtkWidget *widget;
    gboolean setting;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_has_frame (GTK_ENTRY (widget), SETTING);
    if (gtk_entry_get_has_frame (GTK_ENTRY (widget)) != SETTING )
    {
        TEST_FAIL("has frame = %i, should be %i\n", gtk_entry_get_has_frame (GTK_ENTRY (widget)), SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_has_frame
 * Params: GtkEntry *entry, gboolean setting
 * Returns: void
 * Assertion: Sets whether the entry has a beveled frame around it.
 * Params Values: GtkEntry *entry, TRUE
 * Expected: void
 * 
 * Name: gtk_entry_get_has_frame
 * Params: GtkEntry *entry
 * Returns: gboolean
 * Assertion: Gets the value set by gtk_entry_set_has_frame().
 * Params Values: GtkEntry *entry
 * Expected: gboolean  
 */
static void test_purpose_42()
{
    #define SETTING TRUE
    
    GtkWidget *widget;
    gboolean setting;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_has_frame (GTK_ENTRY (widget), SETTING);
    if (gtk_entry_get_has_frame (GTK_ENTRY (widget)) != SETTING )
    {
        TEST_FAIL("has frame = %i, should be %i\n", gtk_entry_get_has_frame (GTK_ENTRY (widget)), SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_width_chars
 * Params: GtkEntry *entry, gint n_chars
 * Returns: void
 * Assertion: Changes the size request of the entry to be about the right size for n_chars characters.
 * Params Values: GtkEntry *entry, 0
 * Expected: void
 * 
 * Name: gtk_entry_get_width_chars
 * Params: GtkEntry *entry
 * Returns: gint n_chars
 * Assertion: Gets the value set by gtk_entry_set_width_chars().
 * Params Values: GtkEntry *entry
 * Expected: 0  
 */
static void test_purpose_43()
{
    #define SETTING 0
    
    GtkWidget *widget;
    gint n_chars;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_width_chars (GTK_ENTRY (widget), SETTING);
    if (gtk_entry_get_width_chars (GTK_ENTRY (widget)) != SETTING )
    {
        TEST_FAIL("has frame = %i, should be %i\n", gtk_entry_get_width_chars (GTK_ENTRY (widget)), SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_width_chars
 * Params: GtkEntry *entry, gint n_chars
 * Returns: void
 * Assertion: Changes the size request of the entry to be about the right size for n_chars characters.
 * Params Values: GtkEntry *entry, 10
 * Expected: void
 * 
 * Name: gtk_entry_get_width_chars
 * Params: GtkEntry *entry
 * Returns: gint n_chars
 * Assertion: Gets the value set by gtk_entry_set_width_chars().
 * Params Values: GtkEntry *entry
 * Expected: 10  
 */
static void test_purpose_44()
{
    #define SETTING 10
    
    GtkWidget *widget;
    gint n_chars;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_width_chars (GTK_ENTRY (widget), SETTING);
    if (gtk_entry_get_width_chars (GTK_ENTRY (widget)) != SETTING )
    {
        TEST_FAIL("has frame = %i, should be %i\n", gtk_entry_get_width_chars (GTK_ENTRY (widget)), SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_width_chars
 * Params: GtkEntry *entry, gint n_chars
 * Returns: void
 * Assertion: Changes the size request of the entry to be about the right size for n_chars characters.
 * Params Values: GtkEntry *entry, 1000
 * Expected: void
 * 
 * Name: gtk_entry_get_width_chars
 * Params: GtkEntry *entry
 * Returns: gint n_chars
 * Assertion: Gets the value set by gtk_entry_set_width_chars().
 * Params Values: GtkEntry *entry
 * Expected: 1000  
 */
static void test_purpose_45()
{
    #define SETTING 1000
    
    GtkWidget *widget;
    gint n_chars;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_width_chars (GTK_ENTRY (widget), SETTING);
    if (gtk_entry_get_width_chars (GTK_ENTRY (widget)) != SETTING )
    {
        TEST_FAIL("has frame = %i, should be %i\n", gtk_entry_get_width_chars (GTK_ENTRY (widget)), SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_width_chars
 * Params: GtkEntry *entry, gint n_chars
 * Returns: void
 * Assertion: Changes the size request of the entry to be about the right size for n_chars characters.
 * Params Values: GtkEntry *entry, -1
 * Expected: void
 * 
 * Name: gtk_entry_get_width_chars
 * Params: GtkEntry *entry
 * Returns: gint n_chars
 * Assertion: Gets the value set by gtk_entry_set_width_chars().
 * Params Values: GtkEntry *entry
 * Expected: -1  
 */
static void test_purpose_46()
{
    #define SETTING -1
    
    GtkWidget *widget;
    gint n_chars;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_set_width_chars (GTK_ENTRY (widget), SETTING);
    if (gtk_entry_get_width_chars (GTK_ENTRY (widget)) != SETTING )
    {
        TEST_FAIL("has frame = %i, should be %i\n", gtk_entry_get_width_chars (GTK_ENTRY (widget)), SETTING);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_width_chars
 * Params: GtkEntry *entry, gint n_chars
 * Returns: void
 * Assertion: If n_chars is -1, the size reverts to the default entry size.
 * Params Values: GtkEntry *entry, 0
 * Expected: void  
 */
static void test_purpose_47()
{
    #define SETTING 0
    
    GtkWidget *widget;
    gint n_chars;
    gint default_width_chars;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    default_width_chars = gtk_entry_get_width_chars (GTK_ENTRY (widget));
    gtk_entry_set_width_chars (GTK_ENTRY (widget), SETTING);
    gtk_entry_set_width_chars (GTK_ENTRY (widget), -1);
    
    if (gtk_entry_get_width_chars (GTK_ENTRY (widget)) != default_width_chars)
    {
        TEST_FAIL("has frame = %i, should be %i\n", gtk_entry_get_width_chars (GTK_ENTRY (widget)), default_width_chars);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_width_chars
 * Params: GtkEntry *entry, gint n_chars
 * Returns: void
 * Assertion: If n_chars is -1, the size reverts to the default entry size.
 * Params Values: GtkEntry *entry, 49
 * Expected: void  
 */
static void test_purpose_48()
{
    #define SETTING 49
    
    GtkWidget *widget;
    gint n_chars;
    gint default_width_chars;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    default_width_chars = gtk_entry_get_width_chars (GTK_ENTRY (widget));
    gtk_entry_set_width_chars (GTK_ENTRY (widget), SETTING);
    gtk_entry_set_width_chars (GTK_ENTRY (widget), -1);
    
    if (gtk_entry_get_width_chars (GTK_ENTRY (widget)) != default_width_chars)
    {
        TEST_FAIL("has frame = %i, should be %i\n", gtk_entry_get_width_chars (GTK_ENTRY (widget)), default_width_chars);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_set_width_chars
 * Params: GtkEntry *entry, gint n_chars
 * Returns: void
 * Assertion: If n_chars is -1, the size reverts to the default entry size.
 * Params Values: GtkEntry *entry, 65535
 * Expected: void  
 */
static void test_purpose_49()
{
    #define SETTING 65535
    
    GtkWidget *widget;
    gint n_chars;
    gint default_width_chars;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    default_width_chars = gtk_entry_get_width_chars (GTK_ENTRY (widget));
    gtk_entry_set_width_chars (GTK_ENTRY (widget), SETTING);
    gtk_entry_set_width_chars (GTK_ENTRY (widget), -1);
    
    if (gtk_entry_get_width_chars (GTK_ENTRY (widget)) != default_width_chars)
    {
        TEST_FAIL("has frame = %i, should be %i\n", gtk_entry_get_width_chars (GTK_ENTRY (widget)), default_width_chars);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_get_layout
 * Params: GtkEntry *entry
 * Returns: PangoLayout*
 * Assertion: Gets the PangoLayout used to display the entry.
 * Params Values: GtkEntry *entry
 * Expected: PangoLayout*  
 */
static void test_purpose_50()
{
    GtkWidget *widget;
    PangoLayout* layout;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    layout = gtk_entry_get_layout (GTK_ENTRY (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_entry_get_layout_offsets
 * Params: GtkEntry *entry, gint *x, gint *y
 * Returns: void
 * Assertion: Obtains the position of the PangoLayout used to render text in the entry, in widget coordinates.
 * Params Values: GtkEntry *entry, gint *x, gint *y
 * Expected: void  
 */
static void test_purpose_51()
{
    GtkWidget *widget;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_entry_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_ENTRY (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_entry_get_layout_offsets (GTK_ENTRY (widget), &x, &y);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkEntry ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {NULL,0}
};
