/*
 * GtkToolbar methods tests
 * Testing GtkToolbar methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
global_gtk_signal_func()
{
    return;
}

/*
 * Name: gtk_toolbar_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Creates a new toolbar.
 * Params Values: void
 * Expected: GtkToolBar*  
 */
static void test_purpose_1()
{
    GtkOrientation orientation;
    GtkToolbarStyle style;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (G_OBJECT (widget), "orientation", &orientation, NULL);
    if (orientation != GTK_ORIENTATION_HORIZONTAL)
    {
        TEST_FAIL("default orientation value is %d, should be %d", 
                  orientation, GTK_ORIENTATION_HORIZONTAL);
    }
    
    g_object_get (G_OBJECT (widget), "toolbar-style", &style, NULL);
    if (style != GTK_TOOLBAR_BOTH)
    {
        TEST_FAIL("default toolbar-style is %d, should be %d", 
                  style, GTK_TOOLBAR_BOTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_set_orientation
 * Params: GtkToolbar *toolbar, GtkOrientation orientation
 * Returns: void
 * Assertion: Sets whether a toolbar should appear horizontally or vertically.
 * Params Values: newly created GtkToolbar*, GTK_ORIENTATION_HORIZONTAL
 * Expected: void  
 */
static void test_purpose_2()
{
    #define ORIENTATION GTK_ORIENTATION_HORIZONTAL
    
    GtkWidget *widget;
    GtkOrientation orientation;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_toolbar_set_orientation (GTK_TOOLBAR (widget), ORIENTATION);
    
    
    g_object_get (G_OBJECT (widget), "orientation", &orientation, NULL);
    if (ORIENTATION != orientation)
    {
        TEST_FAIL("toolbar orientation = %i, should be %i", orientation, ORIENTATION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ORIENTATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_set_orientation
 * Params: GtkToolbar *toolbar, GtkOrientation orientation
 * Returns: void
 * Assertion: Sets whether a toolbar should appear horizontally or vertically.
 * Params Values: newly created GtkToolbar*, GTK_ORIENTATION_VERTICAL
 * Expected: void  
 */
static void test_purpose_3()
{
    #define ORIENTATION GTK_ORIENTATION_VERTICAL
    
    GtkWidget *widget;
    GtkOrientation orientation;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_toolbar_set_orientation (GTK_TOOLBAR (widget), ORIENTATION);
    
    
    g_object_get (G_OBJECT (widget), "orientation", &orientation, NULL);
    if (ORIENTATION != orientation)
    {
        TEST_FAIL("toolbar orientation = %i, should be %i", orientation, ORIENTATION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ORIENTATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_get_orientation
 * Params: GtkToolbar *toolbar
 * Returns: GtkOrientation orientation
 * Assertion: Retrieves the current orientation of the toolbar.
 * Params Values: newly created GtkToolbar*
 * Expected: GTK_ORIENTATION_HORIZONTAL  
 */
static void test_purpose_4()
{
    #define ORIENTATION GTK_ORIENTATION_HORIZONTAL
    
    GtkWidget *widget;
    GtkOrientation orientation;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (widget), "orientation", ORIENTATION, NULL);
    orientation = gtk_toolbar_get_orientation (GTK_TOOLBAR (widget));
    if (ORIENTATION != orientation)
    {
        TEST_FAIL("toolbar orientation = %i, should be %i", orientation, ORIENTATION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ORIENTATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_get_orientation
 * Params: GtkToolbar *toolbar
 * Returns: GtkOrientation orientation
 * Assertion: Retrieves the current orientation of the toolbar.
 * Params Values: newly created GtkToolbar*
 * Expected: GTK_ORIENTATION_VERTICAL  
 */
static void test_purpose_5()
{
    #define ORIENTATION GTK_ORIENTATION_VERTICAL
    
    GtkWidget *widget;
    GtkOrientation orientation;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (widget), "orientation", ORIENTATION, NULL);
    orientation = gtk_toolbar_get_orientation (GTK_TOOLBAR (widget));
    if (ORIENTATION != orientation)
    {
        TEST_FAIL("toolbar orientation = %i, should be %i", orientation, ORIENTATION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef ORIENTATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_set_style
 * Params: GtkToolbar *toolbar, GtkToolbarStyle style
 * Returns: void
 * Assertion: Alters the view of toolbar to display either icons only, text only, or both.
 * Params Values: newly created GtkToolbar*, GTK_TOOLBAR_ICONS
 * Expected: void  
 */
static void test_purpose_6()
{
    #define STYLE GTK_TOOLBAR_ICONS
    
    GtkWidget *widget;
    GtkToolbarStyle style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_toolbar_set_style (GTK_TOOLBAR (widget), STYLE);
    
    
    g_object_get (G_OBJECT (widget), "toolbar-style", &style, NULL);
    if (STYLE != style)
    {
        TEST_FAIL("toolbar style = %i, should be %i", style, STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_set_style
 * Params: GtkToolbar *toolbar, GtkToolbarStyle style
 * Returns: void
 * Assertion: Alters the view of toolbar to display either icons only, text only, or both.
 * Params Values: newly created GtkToolbar*, GTK_TOOLBAR_TEXT
 * Expected: void  
 */
static void test_purpose_7()
{
    #define STYLE GTK_TOOLBAR_TEXT
    
    GtkWidget *widget;
    GtkToolbarStyle style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_toolbar_set_style (GTK_TOOLBAR (widget), STYLE);
    
    
    g_object_get (G_OBJECT (widget), "toolbar-style", &style, NULL);
    if (STYLE != style)
    {
        TEST_FAIL("toolbar style = %i, should be %i", style, STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_set_style
 * Params: GtkToolbar *toolbar, GtkToolbarStyle style
 * Returns: void
 * Assertion: Alters the view of toolbar to display either icons only, text only, or both.
 * Params Values: newly created GtkToolbar*, GTK_TOOLBAR_BOTH
 * Expected: void  
 */
static void test_purpose_8()
{
    #define STYLE GTK_TOOLBAR_BOTH
    
    GtkWidget *widget;
    GtkToolbarStyle style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_toolbar_set_style (GTK_TOOLBAR (widget), STYLE);
    
    
    g_object_get (G_OBJECT (widget), "toolbar-style", &style, NULL);
    if (STYLE != style)
    {
        TEST_FAIL("toolbar style = %i, should be %i", style, STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_set_style
 * Params: GtkToolbar *toolbar, GtkToolbarStyle style
 * Returns: void
 * Assertion: Alters the view of toolbar to display either icons only, text only, or both.
 * Params Values: newly created GtkToolbar*, GTK_TOOLBAR_BOTH_HORIZ
 * Expected: void  
 */
static void test_purpose_9()
{
    #define STYLE GTK_TOOLBAR_BOTH_HORIZ
    
    GtkWidget *widget;
    GtkToolbarStyle style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_toolbar_set_style (GTK_TOOLBAR (widget), STYLE);
    
    
    g_object_get (G_OBJECT (widget), "toolbar-style", &style, NULL);
    if (STYLE != style)
    {
        TEST_FAIL("toolbar style = %i, should be %i", style, STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_get_style
 * Params: GtkToolbar *toolbar
 * Returns: GtkToolbarStyle style
 * Assertion: Retrieves whether the toolbar has text, icons, or both .
 * Params Values: newly created GtkToolbar*
 * Expected: GTK_TOOLBAR_ICONS  
 */
static void test_purpose_10()
{
    #define STYLE GTK_TOOLBAR_ICONS
    
    GtkWidget *widget;
    GtkToolbarStyle style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (widget), "toolbar-style", STYLE, NULL);
    
    style = gtk_toolbar_get_style (GTK_TOOLBAR (widget));
    if (STYLE != style)
    {
        TEST_FAIL("toolbar style = %i, should be %i", style, STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_get_style
 * Params: GtkToolbar *toolbar
 * Returns: GtkToolbarStyle style
 * Assertion: Retrieves whether the toolbar has text, icons, or both .
 * Params Values: newly created GtkToolbar*
 * Expected: GTK_TOOLBAR_TEXT  
 */
static void test_purpose_11()
{
    #define STYLE GTK_TOOLBAR_TEXT
    
    GtkWidget *widget;
    GtkToolbarStyle style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (widget), "toolbar-style", STYLE, NULL);
    
    style = gtk_toolbar_get_style (GTK_TOOLBAR (widget));
    if (STYLE != style)
    {
        TEST_FAIL("toolbar style = %i, should be %i", style, STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_get_style
 * Params: GtkToolbar *toolbar
 * Returns: GtkToolbarStyle style
 * Assertion: Retrieves whether the toolbar has text, icons, or both .
 * Params Values: newly created GtkToolbar*
 * Expected: GTK_TOOLBAR_BOTH  
 */
static void test_purpose_12()
{
    #define STYLE GTK_TOOLBAR_BOTH
    
    GtkWidget *widget;
    GtkToolbarStyle style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (widget), "toolbar-style", STYLE, NULL);
    
    style = gtk_toolbar_get_style (GTK_TOOLBAR (widget));
    if (STYLE != style)
    {
        TEST_FAIL("toolbar style = %i, should be %i", style, STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_get_style
 * Params: GtkToolbar *toolbar
 * Returns: GtkToolbarStyle style
 * Assertion: Retrieves whether the toolbar has text, icons, or both .
 * Params Values: newly created GtkToolbar*
 * Expected: GTK_TOOLBAR_BOTH_HORIZ  
 */
static void test_purpose_13()
{
    #define STYLE GTK_TOOLBAR_BOTH_HORIZ
    
    GtkWidget *widget;
    GtkToolbarStyle style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set (G_OBJECT (widget), "toolbar-style", STYLE, NULL);
    
    style = gtk_toolbar_get_style (GTK_TOOLBAR (widget));
    if (STYLE != style)
    {
        TEST_FAIL("toolbar style = %i, should be %i", style, STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_unset_style
 * Params: GtkToolbar *toolbar
 * Returns: void
 * Assertion: Unsets a toolbar style set with gtk_toolbar_set_style(), so that user preferences will be used to determine the
 * toolbar style.
 * Params Values: newly created GtkToolbar*
 * Expected: void  
 */
static void test_purpose_14()
{
    #define STYLE GTK_TOOLBAR_ICONS
    
    GtkWidget *widget;
    GtkToolbarStyle style;
    GtkToolbarStyle default_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    default_style = gtk_toolbar_get_style (GTK_TOOLBAR (widget));
    
    gtk_toolbar_set_style (GTK_TOOLBAR (widget), STYLE);
    gtk_toolbar_unset_style (GTK_TOOLBAR (widget));
    
    style = gtk_toolbar_get_style (GTK_TOOLBAR (widget));
    if (style != default_style)
    {
        TEST_FAIL ("style is %d, default style is %d", style, default_style);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_unset_style
 * Params: GtkToolbar *toolbar
 * Returns: void
 * Assertion: Unsets a toolbar style set with gtk_toolbar_set_style(), so that user preferences will be used to determine the
 * toolbar style.
 * Params Values: newly created GtkToolbar*
 * Expected: void  
 */
static void test_purpose_15()
{
    #define STYLE GTK_TOOLBAR_TEXT
    
    GtkWidget *widget;
    GtkToolbarStyle style;
    GtkToolbarStyle default_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    default_style = gtk_toolbar_get_style (GTK_TOOLBAR (widget));
    
    gtk_toolbar_set_style (GTK_TOOLBAR (widget), STYLE);
    gtk_toolbar_unset_style (GTK_TOOLBAR (widget));
    
    style = gtk_toolbar_get_style (GTK_TOOLBAR (widget));
    if (style != default_style)
    {
        TEST_FAIL ("style is %d, default style is %d", style, default_style);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_unset_style
 * Params: GtkToolbar *toolbar
 * Returns: void
 * Assertion: Unsets a toolbar style set with gtk_toolbar_set_style(), so that user preferences will be used to determine the
 * toolbar style.
 * Params Values: newly created GtkToolbar*
 * Expected: void  
 */
static void test_purpose_16()
{
    #define STYLE GTK_TOOLBAR_BOTH
    
    GtkWidget *widget;
    GtkToolbarStyle style;
    GtkToolbarStyle default_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    default_style = gtk_toolbar_get_style (GTK_TOOLBAR (widget));
    
    gtk_toolbar_set_style (GTK_TOOLBAR (widget), STYLE);
    gtk_toolbar_unset_style (GTK_TOOLBAR (widget));
    
    style = gtk_toolbar_get_style (GTK_TOOLBAR (widget));
    if (style != default_style)
    {
        TEST_FAIL ("style is %d, default style is %d", style, default_style);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_toolbar_unset_style
 * Params: GtkToolbar *toolbar
 * Returns: void
 * Assertion: Unsets a toolbar style set with gtk_toolbar_set_style(), so that user preferences will be used to determine the
 * toolbar style.
 * Params Values: newly created GtkToolbar*
 * Expected: void  
 */
static void test_purpose_17()
{
    #define STYLE GTK_TOOLBAR_BOTH_HORIZ
    
    GtkWidget *widget;
    GtkToolbarStyle style;
    GtkToolbarStyle default_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_toolbar_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TOOLBAR (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    default_style = gtk_toolbar_get_style (GTK_TOOLBAR (widget));
    
    gtk_toolbar_set_style (GTK_TOOLBAR (widget), STYLE);
    gtk_toolbar_unset_style (GTK_TOOLBAR (widget));
    
    style = gtk_toolbar_get_style (GTK_TOOLBAR (widget));
    if (style != default_style)
    {
        TEST_FAIL ("style is %d, default style is %d", style, default_style);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkToolbar ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {NULL,0}
};
