/*
 * KeyDataList methods tests
 * Testing KeyDataList methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: g_datalist_id_get_data
 * Params: GData **datalist, GQuark key_id
 * Returns: gpointer
 * Assertion: Retrieves the data element corresponding to key_id.
 * 	   datalist : a datalist.
 * 	   key_id : the GQuark identifying a data element.
 * 	   Returns : the data element, or NULL if it is not found. 
 * Params Values: GData **datalist, GQuark key_id
 * Expected: 1  
 */
static void test_purpose_1()
{
    #define RETI    1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GData *gdata = NULL;
    gchar str[] = "Hello";
    gchar str1[] = "LSB";
    gpointer p;
    
    g_datalist_init(&gdata);
    GQuark qs = g_quark_from_string(str);
    GQuark qs1 = g_quark_from_string(str1);
    g_datalist_id_set_data_full(&gdata, qs, GINT_TO_POINTER(1), NULL);
    g_datalist_id_set_data_full(&gdata, qs1, GINT_TO_POINTER(2), NULL);
    if (RETI != NULL){
        p = g_datalist_id_get_data(&gdata, qs);
        if (RETI != GPOINTER_TO_INT(p)){
            TEST_FAIL("g_datalist_id_get_data: failed", NULL);
        }
    }
    else{
        p = g_datalist_id_get_data(&gdata, 12);
        if (p != NULL){
            TEST_FAIL("g_datalist_id_get_data: failed", NULL);
        }
    }
    g_datalist_clear(&gdata);
    #undef RETI
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_datalist_id_get_data
 * Params: GData **datalist, GQuark key_id
 * Returns: gpointer
 * Assertion: Retrieves the data element corresponding to key_id.
 * 	   datalist : a datalist.
 * 	   key_id : the GQuark identifying a data element.
 * 	   Returns : the data element, or NULL if it is not found. 
 * Params Values: GData **datalist, GQuark key_id
 * Expected: NULL  
 */
static void test_purpose_2()
{
    #define RETI    NULL
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GData *gdata = NULL;
    gchar str[] = "Hello";
    gchar str1[] = "LSB";
    gpointer p;
    
    g_datalist_init(&gdata);
    GQuark qs = g_quark_from_string(str);
    GQuark qs1 = g_quark_from_string(str1);
    g_datalist_id_set_data_full(&gdata, qs, GINT_TO_POINTER(1), NULL);
    g_datalist_id_set_data_full(&gdata, qs1, GINT_TO_POINTER(2), NULL);
    if (RETI != NULL){
        p = g_datalist_id_get_data(&gdata, qs);
        if (RETI != GPOINTER_TO_INT(p)){
            TEST_FAIL("g_datalist_id_get_data: failed", NULL);
        }
    }
    else{
        p = g_datalist_id_get_data(&gdata, 12);
        if (p != NULL){
            TEST_FAIL("g_datalist_id_get_data: failed", NULL);
        }
    }
    g_datalist_clear(&gdata);
    #undef RETI
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_datalist_clear
 * Params: GData **datalist
 * Returns: void
 * Assertion: Frees all the data elements of the datalist. The data elements' destroy functions are called if they have been set. 
 * 	   datalist : a datalist.
 * Params Values: GData **datalist, GQuark key_id
 * Expected: NULL  
 */
static void test_purpose_3()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GData *gdata = NULL;
    gchar str[] = "Hello";
    gchar str1[] = "LSB";
    
    g_datalist_init(&gdata);
    GQuark qs = g_quark_from_string(str);
    GQuark qs1 = g_quark_from_string(str1);
    g_datalist_id_set_data_full(&gdata, qs, GINT_TO_POINTER(1), NULL);
    g_datalist_id_set_data_full(&gdata, qs1, GINT_TO_POINTER(2), NULL);
    g_datalist_clear(&gdata);
    if (gdata != NULL){
        TEST_FAIL("g_datalist_clear: failed", NULL);
    }
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for KeyDataList ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {NULL,0}
};
