/*
 * Resource_Files methods tests
 * Testing Resource_Files methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_rc_parse
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Parses a given resource file.
 * Params Values: gchar*
 * Expected: void
 * 
 * Name: gtk_rc_get_style_by_paths
 * Params: GtkSettings *context,const char *widget_path,const char *class_path,GType type
 * Returns: GtkStyle*
 * Assertion: Creates up a GtkStyle from styles defined in a RC file by providing the raw components used in matching.
 * Params Values: GtkSettings *context,const char *widget_path,const char *class_path,GType type (widget is 'gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_IN) ')
 * Expected: GtkStyle*  
 */
static void test_purpose_1()
{
    #define WIDGET gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_IN) 
    #define CORRECT_RESULT_IS_NULL TRUE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    gtk_rc_parse (rc_filename);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    if (widget)
    {
        /******* VISUALISATION *******/
        TEST_VISUALIZE (widget);
        /******* -------------  *******/  
        gtk_widget_path (widget, &path_len, &path, NULL);
        gtk_widget_class_path (widget, &class_path_len, &class_path, NULL);
        style = gtk_rc_get_style_by_paths (gtk_widget_get_settings (widget), path, class_path,  G_OBJECT_TYPE (widget));
    } else {
        style = gtk_rc_get_style_by_paths (gtk_settings_get_default(), path, class_path,  G_TYPE_NONE);
    }
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    
    #undef WIDGET
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_parse
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Parses a given resource file.
 * Params Values: gchar*
 * Expected: void
 * 
 * Name: gtk_rc_get_style_by_paths
 * Params: GtkSettings *context,const char *widget_path,const char *class_path,GType type
 * Returns: GtkStyle*
 * Assertion: Creates up a GtkStyle from styles defined in a RC file by providing the raw components used in matching.
 * Params Values: GtkSettings *context,const char *widget_path,const char *class_path,GType type (widget is 'gtk_button_new () ')
 * Expected: GtkStyle*  
 */
static void test_purpose_2()
{
    #define WIDGET gtk_button_new () 
    #define CORRECT_RESULT_IS_NULL FALSE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    gtk_rc_parse (rc_filename);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    if (widget)
    {
        /******* VISUALISATION *******/
        TEST_VISUALIZE (widget);
        /******* -------------  *******/  
        gtk_widget_path (widget, &path_len, &path, NULL);
        gtk_widget_class_path (widget, &class_path_len, &class_path, NULL);
        style = gtk_rc_get_style_by_paths (gtk_widget_get_settings (widget), path, class_path,  G_OBJECT_TYPE (widget));
    } else {
        style = gtk_rc_get_style_by_paths (gtk_settings_get_default(), path, class_path,  G_TYPE_NONE);
    }
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    
    #undef WIDGET
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_parse
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Parses a given resource file.
 * Params Values: gchar*
 * Expected: void
 * 
 * Name: gtk_rc_get_style_by_paths
 * Params: GtkSettings *context,const char *widget_path,const char *class_path,GType type
 * Returns: GtkStyle*
 * Assertion: Creates up a GtkStyle from styles defined in a RC file by providing the raw components used in matching.
 * Params Values: GtkSettings *context,const char *widget_path,const char *class_path,GType type (widget is 'gtk_label_new ("Label") ')
 * Expected: GtkStyle*  
 */
static void test_purpose_3()
{
    #define WIDGET gtk_label_new ("Label") 
    #define CORRECT_RESULT_IS_NULL TRUE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    gtk_rc_parse (rc_filename);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    if (widget)
    {
        /******* VISUALISATION *******/
        TEST_VISUALIZE (widget);
        /******* -------------  *******/  
        gtk_widget_path (widget, &path_len, &path, NULL);
        gtk_widget_class_path (widget, &class_path_len, &class_path, NULL);
        style = gtk_rc_get_style_by_paths (gtk_widget_get_settings (widget), path, class_path,  G_OBJECT_TYPE (widget));
    } else {
        style = gtk_rc_get_style_by_paths (gtk_settings_get_default(), path, class_path,  G_TYPE_NONE);
    }
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    
    #undef WIDGET
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_parse
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Parses a given resource file.
 * Params Values: gchar*
 * Expected: void
 * 
 * Name: gtk_rc_get_style_by_paths
 * Params: GtkSettings *context,const char *widget_path,const char *class_path,GType type
 * Returns: GtkStyle*
 * Assertion: Creates up a GtkStyle from styles defined in a RC file by providing the raw components used in matching.
 * Params Values: GtkSettings *context,const char *widget_path,const char *class_path,GType type (widget is 'gtk_window_new (GTK_WINDOW_TOPLEVEL) ')
 * Expected: GtkStyle*  
 */
static void test_purpose_4()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL) 
    #define CORRECT_RESULT_IS_NULL FALSE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    gtk_rc_parse (rc_filename);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    if (widget)
    {
        /******* VISUALISATION *******/
        TEST_VISUALIZE (widget);
        /******* -------------  *******/  
        gtk_widget_path (widget, &path_len, &path, NULL);
        gtk_widget_class_path (widget, &class_path_len, &class_path, NULL);
        style = gtk_rc_get_style_by_paths (gtk_widget_get_settings (widget), path, class_path,  G_OBJECT_TYPE (widget));
    } else {
        style = gtk_rc_get_style_by_paths (gtk_settings_get_default(), path, class_path,  G_TYPE_NONE);
    }
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    
    #undef WIDGET
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_parse
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Parses a given resource file.
 * Params Values: gchar*
 * Expected: void
 * 
 * Name: gtk_rc_get_style_by_paths
 * Params: GtkSettings *context,const char *widget_path,const char *class_path,GType type
 * Returns: GtkStyle*
 * Assertion: Creates up a GtkStyle from styles defined in a RC file by providing the raw components used in matching.
 * Params Values: GtkSettings *context,const char *widget_path,const char *class_path,GType type (widget is 'NULL ')
 * Expected: GtkStyle*  
 */
static void test_purpose_5()
{
    #define WIDGET NULL 
    #define CORRECT_RESULT_IS_NULL TRUE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    gtk_rc_parse (rc_filename);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    if (widget)
    {
        /******* VISUALISATION *******/
        TEST_VISUALIZE (widget);
        /******* -------------  *******/  
        gtk_widget_path (widget, &path_len, &path, NULL);
        gtk_widget_class_path (widget, &class_path_len, &class_path, NULL);
        style = gtk_rc_get_style_by_paths (gtk_widget_get_settings (widget), path, class_path,  G_OBJECT_TYPE (widget));
    } else {
        style = gtk_rc_get_style_by_paths (gtk_settings_get_default(), path, class_path,  G_TYPE_NONE);
    }
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    
    #undef WIDGET
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_get_style
 * Params: GtkWidget *widget
 * Returns: GtkStyle*
 * Assertion: Finds all matching RC styles for a given widget, composites them together, and then creates a GtkStyle representing the composite appearance. 
 * Params Values: GtkWidget*
 * Expected: GtkStyle*  
 */
static void test_purpose_6()
{
    #define WIDGET gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_IN) 
    #define CORRECT_RESULT_IS_NULL TRUE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* rc_str;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    rc_str = read_file_to_string (fopen (rc_filename, "r"));
    if (!rc_str)
    {
        TEST_FAIL ("rc_str is NULL", NULL);
        return;
    }
    
    gtk_rc_parse_string (rc_str);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    style = gtk_rc_get_style(widget);
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    free (rc_str);
    
    #undef WIDGET
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_get_style
 * Params: GtkWidget *widget
 * Returns: GtkStyle*
 * Assertion: Finds all matching RC styles for a given widget, composites them together, and then creates a GtkStyle representing the composite appearance. 
 * Params Values: GtkWidget*
 * Expected: GtkStyle*  
 */
static void test_purpose_7()
{
    #define WIDGET gtk_button_new () 
    #define CORRECT_RESULT_IS_NULL FALSE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* rc_str;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    rc_str = read_file_to_string (fopen (rc_filename, "r"));
    if (!rc_str)
    {
        TEST_FAIL ("rc_str is NULL", NULL);
        return;
    }
    
    gtk_rc_parse_string (rc_str);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    style = gtk_rc_get_style(widget);
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    free (rc_str);
    
    #undef WIDGET
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_get_style
 * Params: GtkWidget *widget
 * Returns: GtkStyle*
 * Assertion: Finds all matching RC styles for a given widget, composites them together, and then creates a GtkStyle representing the composite appearance. 
 * Params Values: GtkWidget*
 * Expected: GtkStyle*  
 */
static void test_purpose_8()
{
    #define WIDGET gtk_label_new ("Label") 
    #define CORRECT_RESULT_IS_NULL TRUE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* rc_str;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    rc_str = read_file_to_string (fopen (rc_filename, "r"));
    if (!rc_str)
    {
        TEST_FAIL ("rc_str is NULL", NULL);
        return;
    }
    
    gtk_rc_parse_string (rc_str);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    style = gtk_rc_get_style(widget);
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    free (rc_str);
    
    #undef WIDGET
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_get_style
 * Params: GtkWidget *widget
 * Returns: GtkStyle*
 * Assertion: Finds all matching RC styles for a given widget, composites them together, and then creates a GtkStyle representing the composite appearance. 
 * Params Values: GtkWidget*
 * Expected: GtkStyle*  
 */
static void test_purpose_9()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL) 
    #define CORRECT_RESULT_IS_NULL FALSE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* rc_str;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    rc_str = read_file_to_string (fopen (rc_filename, "r"));
    if (!rc_str)
    {
        TEST_FAIL ("rc_str is NULL", NULL);
        return;
    }
    
    gtk_rc_parse_string (rc_str);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    style = gtk_rc_get_style(widget);
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    free (rc_str);
    
    #undef WIDGET
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_parse_string
 * Params: const gchar *rc_string
 * Returns: void
 * Assertion: Parses resource information directly from a string.
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_10()
{
    #define WIDGET gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_IN) 
    #define STR_TO_PARSE NULL
    #define CORRECT_RESULT_IS_NULL TRUE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* rc_str;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    if (STR_TO_PARSE == NULL)
    {
        rc_filename = strcat (rc_filename, tet_root);
        rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
        
        rc_str = read_file_to_string (fopen (rc_filename, "r"));
        if (!rc_str)
        {
            TEST_FAIL ("rc_str is NULL", NULL);
            return;
        }
    } else {
        rc_str = strdup (STR_TO_PARSE);
    }
    
    
    gtk_rc_parse_string (rc_str);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    style = gtk_rc_get_style(widget);
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    free (rc_str);
    
    #undef WIDGET
    #undef STR_TO_PARSE
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_parse_string
 * Params: const gchar *rc_string
 * Returns: void
 * Assertion: Parses resource information directly from a string.
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_11()
{
    #define WIDGET gtk_button_new () 
    #define STR_TO_PARSE NULL
    #define CORRECT_RESULT_IS_NULL FALSE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* rc_str;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    if (STR_TO_PARSE == NULL)
    {
        rc_filename = strcat (rc_filename, tet_root);
        rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
        
        rc_str = read_file_to_string (fopen (rc_filename, "r"));
        if (!rc_str)
        {
            TEST_FAIL ("rc_str is NULL", NULL);
            return;
        }
    } else {
        rc_str = strdup (STR_TO_PARSE);
    }
    
    
    gtk_rc_parse_string (rc_str);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    style = gtk_rc_get_style(widget);
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    free (rc_str);
    
    #undef WIDGET
    #undef STR_TO_PARSE
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_parse_string
 * Params: const gchar *rc_string
 * Returns: void
 * Assertion: Parses resource information directly from a string.
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_12()
{
    #define WIDGET gtk_label_new ("Label") 
    #define STR_TO_PARSE NULL
    #define CORRECT_RESULT_IS_NULL TRUE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* rc_str;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    if (STR_TO_PARSE == NULL)
    {
        rc_filename = strcat (rc_filename, tet_root);
        rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
        
        rc_str = read_file_to_string (fopen (rc_filename, "r"));
        if (!rc_str)
        {
            TEST_FAIL ("rc_str is NULL", NULL);
            return;
        }
    } else {
        rc_str = strdup (STR_TO_PARSE);
    }
    
    
    gtk_rc_parse_string (rc_str);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    style = gtk_rc_get_style(widget);
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    free (rc_str);
    
    #undef WIDGET
    #undef STR_TO_PARSE
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_parse_string
 * Params: const gchar *rc_string
 * Returns: void
 * Assertion: Parses resource information directly from a string.
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_13()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL) 
    #define STR_TO_PARSE NULL
    #define CORRECT_RESULT_IS_NULL FALSE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* rc_str;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    if (STR_TO_PARSE == NULL)
    {
        rc_filename = strcat (rc_filename, tet_root);
        rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
        
        rc_str = read_file_to_string (fopen (rc_filename, "r"));
        if (!rc_str)
        {
            TEST_FAIL ("rc_str is NULL", NULL);
            return;
        }
    } else {
        rc_str = strdup (STR_TO_PARSE);
    }
    
    
    gtk_rc_parse_string (rc_str);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    style = gtk_rc_get_style(widget);
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    free (rc_str);
    
    #undef WIDGET
    #undef STR_TO_PARSE
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_parse_string
 * Params: const gchar *rc_string
 * Returns: void
 * Assertion: Parses resource information directly from a string.
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_14()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL) 
    #define STR_TO_PARSE "style \"window\"\n{\n  fg[NORMAL] = { 1.0, 0, 0 }\n}"
    #define CORRECT_RESULT_IS_NULL TRUE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* rc_str;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    if (STR_TO_PARSE == NULL)
    {
        rc_filename = strcat (rc_filename, tet_root);
        rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
        
        rc_str = read_file_to_string (fopen (rc_filename, "r"));
        if (!rc_str)
        {
            TEST_FAIL ("rc_str is NULL", NULL);
            return;
        }
    } else {
        rc_str = strdup (STR_TO_PARSE);
    }
    
    
    gtk_rc_parse_string (rc_str);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    style = gtk_rc_get_style(widget);
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    free (rc_str);
    
    #undef WIDGET
    #undef STR_TO_PARSE
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_parse_string
 * Params: const gchar *rc_string
 * Returns: void
 * Assertion: Parses resource information directly from a string.
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_15()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL) 
    #define STR_TO_PARSE "widget_class \"GtkWindow\" style \"window\""
    #define CORRECT_RESULT_IS_NULL TRUE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* rc_str;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    if (STR_TO_PARSE == NULL)
    {
        rc_filename = strcat (rc_filename, tet_root);
        rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
        
        rc_str = read_file_to_string (fopen (rc_filename, "r"));
        if (!rc_str)
        {
            TEST_FAIL ("rc_str is NULL", NULL);
            return;
        }
    } else {
        rc_str = strdup (STR_TO_PARSE);
    }
    
    
    gtk_rc_parse_string (rc_str);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    style = gtk_rc_get_style(widget);
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    free (rc_str);
    
    #undef WIDGET
    #undef STR_TO_PARSE
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_parse_string
 * Params: const gchar *rc_string
 * Returns: void
 * Assertion: Parses resource information directly from a string.
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_16()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL) 
    #define STR_TO_PARSE "widget \"main window.*GtkButton*\" style \"main_button\""
    #define CORRECT_RESULT_IS_NULL TRUE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* rc_str;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    if (STR_TO_PARSE == NULL)
    {
        rc_filename = strcat (rc_filename, tet_root);
        rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
        
        rc_str = read_file_to_string (fopen (rc_filename, "r"));
        if (!rc_str)
        {
            TEST_FAIL ("rc_str is NULL", NULL);
            return;
        }
    } else {
        rc_str = strdup (STR_TO_PARSE);
    }
    
    
    gtk_rc_parse_string (rc_str);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    style = gtk_rc_get_style(widget);
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    free (rc_str);
    
    #undef WIDGET
    #undef STR_TO_PARSE
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_parse_string
 * Params: const gchar *rc_string
 * Returns: void
 * Assertion: Parses resource information directly from a string.
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_17()
{
    #define WIDGET gtk_label_new ("Label") 
    #define STR_TO_PARSE "style \"window\"\n{\n  fg[NORMAL] = { 1.0, 0, 0 }\n}"
    #define CORRECT_RESULT_IS_NULL TRUE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* rc_str;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    if (STR_TO_PARSE == NULL)
    {
        rc_filename = strcat (rc_filename, tet_root);
        rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
        
        rc_str = read_file_to_string (fopen (rc_filename, "r"));
        if (!rc_str)
        {
            TEST_FAIL ("rc_str is NULL", NULL);
            return;
        }
    } else {
        rc_str = strdup (STR_TO_PARSE);
    }
    
    
    gtk_rc_parse_string (rc_str);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    style = gtk_rc_get_style(widget);
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    free (rc_str);
    
    #undef WIDGET
    #undef STR_TO_PARSE
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_parse_string
 * Params: const gchar *rc_string
 * Returns: void
 * Assertion: Parses resource information directly from a string.
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_18()
{
    #define WIDGET gtk_label_new ("Label") 
    #define STR_TO_PARSE "widget_class \"GtkWindow\" style \"window\""
    #define CORRECT_RESULT_IS_NULL TRUE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* rc_str;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    if (STR_TO_PARSE == NULL)
    {
        rc_filename = strcat (rc_filename, tet_root);
        rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
        
        rc_str = read_file_to_string (fopen (rc_filename, "r"));
        if (!rc_str)
        {
            TEST_FAIL ("rc_str is NULL", NULL);
            return;
        }
    } else {
        rc_str = strdup (STR_TO_PARSE);
    }
    
    
    gtk_rc_parse_string (rc_str);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    style = gtk_rc_get_style(widget);
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    free (rc_str);
    
    #undef WIDGET
    #undef STR_TO_PARSE
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_parse_string
 * Params: const gchar *rc_string
 * Returns: void
 * Assertion: Parses resource information directly from a string.
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_19()
{
    #define WIDGET gtk_label_new ("Label") 
    #define STR_TO_PARSE "widget \"main window.*GtkButton*\" style \"main_button\""
    #define CORRECT_RESULT_IS_NULL TRUE
    
    GtkWidget* widget;
    GtkStyle* style;
    gchar* path;
    gchar* class_path;
    gchar* rc_str;
    gchar* tet_root = calloc (sizeof (char), 1024);
    gchar* rc_filename = calloc (sizeof (char), 1024);
    guint path_len = 1023;
    guint class_path_len = 1023;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    if (STR_TO_PARSE == NULL)
    {
        rc_filename = strcat (rc_filename, tet_root);
        rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
        
        rc_str = read_file_to_string (fopen (rc_filename, "r"));
        if (!rc_str)
        {
            TEST_FAIL ("rc_str is NULL", NULL);
            return;
        }
    } else {
        rc_str = strdup (STR_TO_PARSE);
    }
    
    
    gtk_rc_parse_string (rc_str);
    
    path = calloc (sizeof (gchar), path_len + 1);
    class_path = calloc (sizeof (gchar), class_path_len + 1);
    
    widget = WIDGET;
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    style = gtk_rc_get_style(widget);
    
    if (CORRECT_RESULT_IS_NULL == FALSE && style == NULL)
    {
        TEST_FAIL ("style is NULL but shouldn't be (path = '%s', class_path = '%s')", path, class_path);
    } 
    
    if (widget)
    {
        gtk_widget_destroy (widget);
    }
      
    free (path);
    free (class_path);
    free (rc_str);
    
    #undef WIDGET
    #undef STR_TO_PARSE
    #undef CORRECT_RESULT_IS_NULL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_reparse_all
 * Params: void
 * Returns: void
 * Assertion: If the modification time on any previously read file for the default GtkSettings has changed, discard all style information and then reread all previously read RC files.
 * Params Values: void
 * Expected: void  
 */
static void test_purpose_20()
{
    #define DO_TOUCH TRUE
    
    gboolean res;
    gchar* rc_filename = calloc (sizeof (char), 1024);
    gchar* tet_root = calloc (sizeof (char), 1024);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    gtk_rc_parse (rc_filename);
    if (DO_TOUCH)
    {
        gchar* exec_data[4];
        gchar* command = strdup ("/bin/bash");
        gchar* exec_cmd = "touch ";
        gchar* s 
            = calloc (sizeof (char), strlen (exec_cmd) + strlen (rc_filename) + 1);
    
        sprintf (s, "%s%s", exec_cmd, rc_filename);
        exec_data[0] = command;
        exec_data[1] = "-c";
        exec_data[2] = s;
        exec_data[3] = NULL;
        res = exec_program (command, exec_data);
        if (res == -1)
        {
            TEST_FAIL ("can't run command '%s %s %s', errno = '%d'; see <errno.h> for details", exec_data[0], exec_data[1], exec_data[0], errno);
        }
    
        g_usleep (2*1000000);
    
        free (s);
        free (command);
    }
    
    res = gtk_rc_reparse_all();
    if (res != DO_TOUCH)
    {
        TEST_FAIL ("res = %d, DO_TOUCH = %d, they should be equal", res, DO_TOUCH);
    }
      
    free (rc_filename);
    
    #undef DO_TOUCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_reparse_all
 * Params: void
 * Returns: void
 * Assertion: If the modification time on any previously read file for the default GtkSettings has changed, discard all style information and then reread all previously read RC files.
 * Params Values: void
 * Expected: void  
 */
static void test_purpose_21()
{
    #define DO_TOUCH FALSE
    
    gboolean res;
    gchar* rc_filename = calloc (sizeof (char), 1024);
    gchar* tet_root = calloc (sizeof (char), 1024);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    gtk_rc_parse (rc_filename);
    if (DO_TOUCH)
    {
        gchar* exec_data[4];
        gchar* command = strdup ("/bin/bash");
        gchar* exec_cmd = "touch ";
        gchar* s 
            = calloc (sizeof (char), strlen (exec_cmd) + strlen (rc_filename) + 1);
    
        sprintf (s, "%s%s", exec_cmd, rc_filename);
        exec_data[0] = command;
        exec_data[1] = "-c";
        exec_data[2] = s;
        exec_data[3] = NULL;
        res = exec_program (command, exec_data);
        if (res == -1)
        {
            TEST_FAIL ("can't run command '%s %s %s', errno = '%d'; see <errno.h> for details", exec_data[0], exec_data[1], exec_data[0], errno);
        }
    
        g_usleep (2*1000000);
    
        free (s);
        free (command);
    }
    
    res = gtk_rc_reparse_all();
    if (res != DO_TOUCH)
    {
        TEST_FAIL ("res = %d, DO_TOUCH = %d, they should be equal", res, DO_TOUCH);
    }
      
    free (rc_filename);
    
    #undef DO_TOUCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_reparse_all_for_settings
 * Params: GtkSettings *setting,gboolean force_load
 * Returns: void
 * Assertion: If the modification time on any previously read file for the given GtkSettings has changed, discard all style information and then reread all previously read RC files.
 * Params Values: GtkSettings*,gboolean
 * Expected: void  
 */
static void test_purpose_22()
{
    #define DO_TOUCH TRUE
    #define DO_FORCE TRUE
    #define CORRECT_RES TRUE
    
    gboolean res;
    GtkSettings* settings;
    gchar* rc_filename = calloc (sizeof (char), 1024);
    gchar* tet_root = calloc (sizeof (char), 1024);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    settings = gtk_settings_get_default ();
    
    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    gtk_rc_parse (rc_filename);
    if (DO_TOUCH)
    {
        gchar* exec_data[4];
        gchar* command = strdup ("/bin/bash");
        gchar* exec_cmd = "touch ";
        gchar* s 
            = calloc (sizeof (char), strlen (exec_cmd) + strlen (rc_filename) + 1);
    
        sprintf (s, "%s%s", exec_cmd, rc_filename);
        exec_data[0] = command;
        exec_data[1] = "-c";
        exec_data[2] = s;
        exec_data[3] = NULL;
        res = exec_program (command, exec_data);
        if (res == -1)
        {
            TEST_FAIL ("can't run command '%s %s %s', errno = '%d'; see <errno.h> for details", exec_data[0], exec_data[1], exec_data[0], errno);
        }
    
        g_usleep (2*1000000);
    
        free (s);
        free (command);
    }
    
    res = gtk_rc_reparse_all_for_settings (settings, DO_FORCE);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d (DO_TOUCH = %d, DO_FORCE = %d)", 
                   res, CORRECT_RES, DO_TOUCH, DO_FORCE);
    }
      
    free (rc_filename);
    
    #undef DO_TOUCH
    #undef DO_FORCE
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_reparse_all_for_settings
 * Params: GtkSettings *setting,gboolean force_load
 * Returns: void
 * Assertion: If the modification time on any previously read file for the given GtkSettings has changed, discard all style information and then reread all previously read RC files.
 * Params Values: GtkSettings*,gboolean
 * Expected: void  
 */
static void test_purpose_23()
{
    #define DO_TOUCH TRUE
    #define DO_FORCE FALSE
    #define CORRECT_RES TRUE
    
    gboolean res;
    GtkSettings* settings;
    gchar* rc_filename = calloc (sizeof (char), 1024);
    gchar* tet_root = calloc (sizeof (char), 1024);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    settings = gtk_settings_get_default ();
    
    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    gtk_rc_parse (rc_filename);
    if (DO_TOUCH)
    {
        gchar* exec_data[4];
        gchar* command = strdup ("/bin/bash");
        gchar* exec_cmd = "touch ";
        gchar* s 
            = calloc (sizeof (char), strlen (exec_cmd) + strlen (rc_filename) + 1);
    
        sprintf (s, "%s%s", exec_cmd, rc_filename);
        exec_data[0] = command;
        exec_data[1] = "-c";
        exec_data[2] = s;
        exec_data[3] = NULL;
        res = exec_program (command, exec_data);
        if (res == -1)
        {
            TEST_FAIL ("can't run command '%s %s %s', errno = '%d'; see <errno.h> for details", exec_data[0], exec_data[1], exec_data[0], errno);
        }
    
        g_usleep (2*1000000);
    
        free (s);
        free (command);
    }
    
    res = gtk_rc_reparse_all_for_settings (settings, DO_FORCE);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d (DO_TOUCH = %d, DO_FORCE = %d)", 
                   res, CORRECT_RES, DO_TOUCH, DO_FORCE);
    }
      
    free (rc_filename);
    
    #undef DO_TOUCH
    #undef DO_FORCE
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_reparse_all_for_settings
 * Params: GtkSettings *setting,gboolean force_load
 * Returns: void
 * Assertion: If the modification time on any previously read file for the given GtkSettings has changed, discard all style information and then reread all previously read RC files.
 * Params Values: GtkSettings*,gboolean
 * Expected: void  
 */
static void test_purpose_24()
{
    #define DO_TOUCH FALSE
    #define DO_FORCE TRUE
    #define CORRECT_RES TRUE
    
    gboolean res;
    GtkSettings* settings;
    gchar* rc_filename = calloc (sizeof (char), 1024);
    gchar* tet_root = calloc (sizeof (char), 1024);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    settings = gtk_settings_get_default ();
    
    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    gtk_rc_parse (rc_filename);
    if (DO_TOUCH)
    {
        gchar* exec_data[4];
        gchar* command = strdup ("/bin/bash");
        gchar* exec_cmd = "touch ";
        gchar* s 
            = calloc (sizeof (char), strlen (exec_cmd) + strlen (rc_filename) + 1);
    
        sprintf (s, "%s%s", exec_cmd, rc_filename);
        exec_data[0] = command;
        exec_data[1] = "-c";
        exec_data[2] = s;
        exec_data[3] = NULL;
        res = exec_program (command, exec_data);
        if (res == -1)
        {
            TEST_FAIL ("can't run command '%s %s %s', errno = '%d'; see <errno.h> for details", exec_data[0], exec_data[1], exec_data[0], errno);
        }
    
        g_usleep (2*1000000);
    
        free (s);
        free (command);
    }
    
    res = gtk_rc_reparse_all_for_settings (settings, DO_FORCE);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d (DO_TOUCH = %d, DO_FORCE = %d)", 
                   res, CORRECT_RES, DO_TOUCH, DO_FORCE);
    }
      
    free (rc_filename);
    
    #undef DO_TOUCH
    #undef DO_FORCE
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_reparse_all_for_settings
 * Params: GtkSettings *setting,gboolean force_load
 * Returns: void
 * Assertion: If the modification time on any previously read file for the given GtkSettings has changed, discard all style information and then reread all previously read RC files.
 * Params Values: GtkSettings*,gboolean
 * Expected: void  
 */
static void test_purpose_25()
{
    #define DO_TOUCH FALSE
    #define DO_FORCE FALSE
    #define CORRECT_RES FALSE
    
    gboolean res;
    GtkSettings* settings;
    gchar* rc_filename = calloc (sizeof (char), 1024);
    gchar* tet_root = calloc (sizeof (char), 1024);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    settings = gtk_settings_get_default ();
    
    tet_root = getenv ("TET_ROOT");
    
    rc_filename = strcat (rc_filename, tet_root);
    rc_filename = strcat (rc_filename, "/gtkvts/src/tests/functions/Resource_Files/rc_example.rc");
    
    gtk_rc_parse (rc_filename);
    if (DO_TOUCH)
    {
        gchar* exec_data[4];
        gchar* command = strdup ("/bin/bash");
        gchar* exec_cmd = "touch ";
        gchar* s 
            = calloc (sizeof (char), strlen (exec_cmd) + strlen (rc_filename) + 1);
    
        sprintf (s, "%s%s", exec_cmd, rc_filename);
        exec_data[0] = command;
        exec_data[1] = "-c";
        exec_data[2] = s;
        exec_data[3] = NULL;
        res = exec_program (command, exec_data);
        if (res == -1)
        {
            TEST_FAIL ("can't run command '%s %s %s', errno = '%d'; see <errno.h> for details", exec_data[0], exec_data[1], exec_data[0], errno);
        }
    
        g_usleep (2*1000000);
    
        free (s);
        free (command);
    }
    
    res = gtk_rc_reparse_all_for_settings (settings, DO_FORCE);
    if (res != CORRECT_RES)
    {
        TEST_FAIL ("res = %d, should be %d (DO_TOUCH = %d, DO_FORCE = %d)", 
                   res, CORRECT_RES, DO_TOUCH, DO_FORCE);
    }
      
    free (rc_filename);
    
    #undef DO_TOUCH
    #undef DO_FORCE
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_add_default_file
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Adds a file to the list of files to be parsed at the end of gtk_init().
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_26()
{
    #define NAME ""
    
    const gchar* name = NAME;
    gchar* real_name;
    gchar** str;
    gint i = 0;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    gtk_rc_add_default_file (name);
    
    str = gtk_rc_get_default_files ();
    
    while (str [i] != NULL) i++;
    real_name = str[i-1];
    if (strcmp (real_name,NAME))
    {
        TEST_FAIL ("Filename is '%s',should be '%s' ",real_name,NAME);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_add_default_file
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Adds a file to the list of files to be parsed at the end of gtk_init().
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_27()
{
    #define NAME " "
    
    const gchar* name = NAME;
    gchar* real_name;
    gchar** str;
    gint i = 0;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    gtk_rc_add_default_file (name);
    
    str = gtk_rc_get_default_files ();
    
    while (str [i] != NULL) i++;
    real_name = str[i-1];
    if (strcmp (real_name,NAME))
    {
        TEST_FAIL ("Filename is '%s',should be '%s' ",real_name,NAME);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_add_default_file
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Adds a file to the list of files to be parsed at the end of gtk_init().
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_28()
{
    #define NAME "   "
    
    const gchar* name = NAME;
    gchar* real_name;
    gchar** str;
    gint i = 0;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    gtk_rc_add_default_file (name);
    
    str = gtk_rc_get_default_files ();
    
    while (str [i] != NULL) i++;
    real_name = str[i-1];
    if (strcmp (real_name,NAME))
    {
        TEST_FAIL ("Filename is '%s',should be '%s' ",real_name,NAME);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_add_default_file
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Adds a file to the list of files to be parsed at the end of gtk_init().
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_29()
{
    #define NAME "Label String"
    
    const gchar* name = NAME;
    gchar* real_name;
    gchar** str;
    gint i = 0;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    gtk_rc_add_default_file (name);
    
    str = gtk_rc_get_default_files ();
    
    while (str [i] != NULL) i++;
    real_name = str[i-1];
    if (strcmp (real_name,NAME))
    {
        TEST_FAIL ("Filename is '%s',should be '%s' ",real_name,NAME);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_add_default_file
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Adds a file to the list of files to be parsed at the end of gtk_init().
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_30()
{
    #define NAME "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    const gchar* name = NAME;
    gchar* real_name;
    gchar** str;
    gint i = 0;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    gtk_rc_add_default_file (name);
    
    str = gtk_rc_get_default_files ();
    
    while (str [i] != NULL) i++;
    real_name = str[i-1];
    if (strcmp (real_name,NAME))
    {
        TEST_FAIL ("Filename is '%s',should be '%s' ",real_name,NAME);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_add_default_file
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Adds a file to the list of files to be parsed at the end of gtk_init().
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_31()
{
    #define NAME "!@#$%^&*()_+|~=\";:'?<>`/"
    
    const gchar* name = NAME;
    gchar* real_name;
    gchar** str;
    gint i = 0;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    gtk_rc_add_default_file (name);
    
    str = gtk_rc_get_default_files ();
    
    while (str [i] != NULL) i++;
    real_name = str[i-1];
    if (strcmp (real_name,NAME))
    {
        TEST_FAIL ("Filename is '%s',should be '%s' ",real_name,NAME);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_add_default_file
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Adds a file to the list of files to be parsed at the end of gtk_init().
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_32()
{
    #define NAME "_a_b"
    
    const gchar* name = NAME;
    gchar* real_name;
    gchar** str;
    gint i = 0;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    gtk_rc_add_default_file (name);
    
    str = gtk_rc_get_default_files ();
    
    while (str [i] != NULL) i++;
    real_name = str[i-1];
    if (strcmp (real_name,NAME))
    {
        TEST_FAIL ("Filename is '%s',should be '%s' ",real_name,NAME);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_add_default_file
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Adds a file to the list of files to be parsed at the end of gtk_init().
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_33()
{
    #define NAME "\n\t\""
    
    const gchar* name = NAME;
    gchar* real_name;
    gchar** str;
    gint i = 0;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    gtk_rc_add_default_file (name);
    
    str = gtk_rc_get_default_files ();
    
    while (str [i] != NULL) i++;
    real_name = str[i-1];
    if (strcmp (real_name,NAME))
    {
        TEST_FAIL ("Filename is '%s',should be '%s' ",real_name,NAME);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_add_default_file
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Adds a file to the list of files to be parsed at the end of gtk_init().
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_34()
{
    #define NAME "_\n\t\""
    
    const gchar* name = NAME;
    gchar* real_name;
    gchar** str;
    gint i = 0;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    gtk_rc_add_default_file (name);
    
    str = gtk_rc_get_default_files ();
    
    while (str [i] != NULL) i++;
    real_name = str[i-1];
    if (strcmp (real_name,NAME))
    {
        TEST_FAIL ("Filename is '%s',should be '%s' ",real_name,NAME);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_add_default_file
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Adds a file to the list of files to be parsed at the end of gtk_init().
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_35()
{
    #define NAME "\b"
    
    const gchar* name = NAME;
    gchar* real_name;
    gchar** str;
    gint i = 0;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    gtk_rc_add_default_file (name);
    
    str = gtk_rc_get_default_files ();
    
    while (str [i] != NULL) i++;
    real_name = str[i-1];
    if (strcmp (real_name,NAME))
    {
        TEST_FAIL ("Filename is '%s',should be '%s' ",real_name,NAME);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_add_default_file
 * Params: const gchar *filename
 * Returns: void
 * Assertion: Adds a file to the list of files to be parsed at the end of gtk_init().
 * Params Values: gchar*
 * Expected: void  
 */
static void test_purpose_36()
{
    #define NAME "_\b"
    
    const gchar* name = NAME;
    gchar* real_name;
    gchar** str;
    gint i = 0;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    gtk_rc_add_default_file (name);
    
    str = gtk_rc_get_default_files ();
    
    while (str [i] != NULL) i++;
    real_name = str[i-1];
    if (strcmp (real_name,NAME))
    {
        TEST_FAIL ("Filename is '%s',should be '%s' ",real_name,NAME);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_set_default_files 
 * Params: gchar **filenames
 * Returns: void
 * Assertion: Sets the list of files that GTK+ will read at the end of gtk_init()
 * Params Values: gchar**
 * Expected: void
 * 
 * Name: gtk_rc_get_default_files 
 * Params: void
 * Returns: gchar**
 * Assertion: Retrieves the current list of RC files that will be parsed at the end of gtk_init()
 * Params Values:void 
 * Expected: gchar**  
 */
static void test_purpose_37()
{
    
    gchar** name;
    gchar **set_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    name = gtk_rc_get_default_files ();
    if (name)
    {
        set_name = g_strdupv(gtk_rc_get_default_files ());
        gtk_rc_set_default_files (set_name);
        
        name = gtk_rc_get_default_files ();
        if (name[0] == NULL)
        {
            TEST_FAIL ("List of files is not NULL",NULL);
        }
    }
    g_strfreev(set_name);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_find_module_in_path 
 * Params: const gchar *module_file
 * Returns: gchar*
 * Assertion: Searches for a theme engine in the GTK+ search path.
 * Params Values: gchar*
 * Expected: gchar*  
 */
static void test_purpose_38()
{
    #define NAME "gnome-logo-icon.png"
    
    gchar* module = NULL;
    gchar* file_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    module = (gchar*) g_module_build_path (gtk_rc_get_theme_dir (), NAME);
    
    file_name = gtk_rc_find_module_in_path (module);
    
    if (!file_name)
    {
        TEST_FAIL ("file_name is NULL", NULL);
        return;
    }
    
    if (file_name)
    {
        g_free (file_name);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_get_im_module_path 
 * Params: void
 * Returns: gchar*
 * Assertion:Obtains the path in which to look for IM modules.
 * Params Values: void
 * Expected: gchar*  
 */
static void test_purpose_39()
{
    gchar* path;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_rc_get_im_module_path ();
    
    if (!path)
    {
        TEST_FAIL ("im module path = %s", path);
    }
    if (path)
    {
        g_free (path);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_get_im_module_file
 * Params: void
 * Returns: gchar*
 * Assertion: Obtains the path to the IM modules file.
 * Params Values: void
 * Expected: gchar*  
 */
static void test_purpose_40()
{
    gchar* file;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    file = gtk_rc_get_im_module_file ();
    if (!file)
    {
        TEST_FAIL ("im module file = %s", file);
    }
    
    if (file)
    {
        g_free (file);
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_style_new 
 * Params: void
 * Returns: GtkRcStyle*
 * Assertion: Creates a new GtkRcStyle with no fields set and a reference count of 1.
 * Params Values:void 
 * Expected: GtkRcStyle*  
 */
static void test_purpose_41()
{
    GtkRcStyle* widget;
    gint ref;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_rc_style_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_RC_STYLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    ref = G_OBJECT (widget)->ref_count;
    
    if (ref != 1)
    {
        TEST_FAIL ("reference count is %d, should be 1", ref);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_style_copy 
 * Params: GtkRcStyle *orig
 * Returns: GtkRcStyle*
 * Assertion: Makes a copy of the specified GtkRcStyle.
 * Params Values: GtkRcStyle*
 * Expected: GtkRcStyle*  
 */
static void test_purpose_42()
{
    GtkRcStyle* copy_widget;
    GtkRcStyle* widget;
    GtkRcStyle copy1;
    GtkRcStyle copy2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_rc_style_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_RC_STYLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    copy_widget = gtk_rc_style_copy (widget);
    
    copy1 = *widget;
    copy2 = *copy_widget;
    
    if ((copy1.name != copy2.name) ||
        (copy1.bg_pixmap_name[5] != copy2.bg_pixmap_name[5]) ||
        (copy1.font_desc != copy2.font_desc) ||
        (copy1.xthickness != copy2.xthickness) ||
        (copy1.ythickness != copy2.ythickness) 
        )
    {
        TEST_FAIL ("GtkRcStyle is not copied",NULL);
    }
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_style_ref
 * Params: GtkRcStyle *rc_style
 * Returns: void
 * Assertion: Increments the reference count of a GtkRcStyle.
 * Params Values: GtkRcStyle*
 * Expected: void  
 */
static void test_purpose_43()
{
    GtkRcStyle* widget;
    gint ref;
    gint new_ref;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_rc_style_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_RC_STYLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    ref = G_OBJECT (widget)->ref_count;
    
    gtk_rc_style_ref (widget);
    
    new_ref = G_OBJECT (widget)->ref_count;
    
    if (new_ref != ref + 1)
    {
        TEST_FAIL ("reference count is %d,should be %d",new_ref,ref+1);
    }
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_rc_style_unref
 * Params: GtkRcStyle *rc_style
 * Returns: void
 * Assertion: Decrements the reference count of a GtkRcStyle and frees if the result is 0.
 * Params Values: GtkRcStyle*
 * Expected: void  
 */
static void test_purpose_44()
{
    GtkRcStyle* widget;
    gint ref;
    gint new_ref;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_rc_style_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_RC_STYLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_rc_style_ref (widget);
    ref = G_OBJECT (widget)->ref_count;
    gtk_rc_style_unref (widget);
    new_ref = G_OBJECT (widget)->ref_count;
    if (new_ref != ref - 1)
    {
        TEST_FAIL ("reference count is %d,should be %d",new_ref,ref-1);
    }
    
    ref = G_OBJECT (widget)->ref_count;
    if (ref == 0)
    {
        gtk_rc_style_unref (widget);
        new_ref = G_OBJECT (widget)->ref_count;
        if (new_ref != 0)
        {
            TEST_FAIL ("reference count is %d,should be %d",new_ref,0);
        }
    }
    
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for Resource_Files ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {NULL,0}
};
