/*
 * StringChunk methods tests
 * Testing StringChunk methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: g_string_chunk_new
 * Params: gsize size
 * Returns: GStringChunk*
 * Assertion: Creates a new GStringChunk.
 *            size : the default size of the blocks of memory which are allocated to store the strings. If a particular string is larger than this default size, a larger block of memory will be allocated for it.
 *            Returns : a new GStringChunk.
 * Params Values: Default size = 10
 * Expected: GStringChunk*  
 */
static void test_purpose_1()
{
    #define SIZE    10
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GStringChunk *strchunk = NULL;
    strchunk = g_string_chunk_new(SIZE);
    if (strchunk == NULL){
        TEST_FAIL("g_string_chunk_new: new failed", NULL);
    }
    g_string_chunk_free(strchunk);
    
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_chunk_insert
 * Params: GStringChunk *chunk, const gchar *string
 * Returns: gchar*
 * Assertion: Adds a copy of string to the GStringChunk. It returns a pointer to the new copy of the string in the GStringChunk. The characters in the string can be changed, if necessary, though you should not change anything after the end of the string.
 * Unlike g_string_chunk_insert_const(), this function does not check for duplicates. Also strings added with g_string_chunk_insert() will not be searched by g_string_chunk_insert_const() when looking for duplicates.
 * chunk :	a GStringChunk.
 *            string : the string to add.
 *            Returns : a pointer to the copy of string within the GStringChunk. 
 * Params Values: string = "Hello, LSB"
 * Expected: "Hello, LSB"  
 */
static void test_purpose_2()
{
    #define STRING    "Hello, LSB"
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GStringChunk *strchunk = NULL;
    gchar *str;
    strchunk = g_string_chunk_new(1);
    if (strchunk == NULL){
        TEST_FAIL("g_string_chunk_insert: new chunk failed", NULL);
        return;
    }
    str = g_string_chunk_insert(strchunk, STRING);
    if (g_ascii_strcasecmp(str, STRING) != 0){
        TEST_FAIL("g_string_chunk_insert: insert failed", NULL);
    }
    g_string_chunk_free(strchunk);
    
    #undef STRING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_chunk_insert_len
 * Params: GStringChunk *chunk, const gchar *string, gssize len
 * Returns: gchar*
 * Assertion: Adds a copy of the first len bytes of string to the GStringChunk. The copy is nul-terminated.
 * The characters in the string can be changed, if necessary, though you should not change anything after the end of the string.
 *            chunk : a GStringChunk
 *            string : bytes to insert
 *            len : number of bytes of string to insert, or -1 to insert a nul-terminated string.
 *            Returns : a pointer to the copy of string within the GStringChunk
 * Params Values: string = "Hello, LSB", size = 5
 * Expected: gchar*  
 */
static void test_purpose_3()
{
    #define STRING    "Hello, LSB"
    #define SIZE      5
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GStringChunk *strchunk = NULL;
    gchar *str;
    
    strchunk = g_string_chunk_new(1);
    if (strchunk == NULL){
        TEST_FAIL("g_string_chunk_insert_len: new failed", NULL);
        return;
    }
    str = g_string_chunk_insert_len(strchunk, STRING, SIZE);
    if (g_ascii_strncasecmp(str, STRING, SIZE) != 0){
        TEST_FAIL("g_string_chunk_insert_len: insert failed", NULL);
    }
    g_string_chunk_free(strchunk);
    
    #undef STRING
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_string_chunk_insert_len
 * Params: GStringChunk *chunk, const gchar *string, gssize len
 * Returns: gchar*
 * Assertion: Adds a copy of the first len bytes of string to the GStringChunk. The copy is nul-terminated.
 * The characters in the string can be changed, if necessary, though you should not change anything after the end of the string.
 *            chunk : a GStringChunk
 *            string : bytes to insert
 *            len : number of bytes of string to insert, or -1 to insert a nul-terminated string.
 *            Returns : a pointer to the copy of string within the GStringChunk
 * Params Values: string = "Hello, LSB", size = -1
 * Expected: gchar*  
 */
static void test_purpose_4()
{
    #define STRING    "Hello, LSB"
    #define SIZE      -1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GStringChunk *strchunk = NULL;
    gchar *str;
    
    strchunk = g_string_chunk_new(1);
    if (strchunk == NULL){
        TEST_FAIL("g_string_chunk_insert_len: new failed", NULL);
        return;
    }
    str = g_string_chunk_insert_len(strchunk, STRING, SIZE);
    if (g_ascii_strncasecmp(str, STRING, SIZE) != 0){
        TEST_FAIL("g_string_chunk_insert_len: insert failed", NULL);
    }
    g_string_chunk_free(strchunk);
    
    #undef STRING
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for StringChunk ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {NULL,0}
};
