/*
 * atk_tcs methods tests
 * Testing atk_tcs methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
int struc_cmp (char *str1,char *str2)
{
    int i,l;
    if ((l = sizeof(str1)) != sizeof(str2))
        return 0;
    for (i = 0;i < l;i++)
        if (str1[i] != str2[i])
            return 0;
    return 1;
}

/*AtkAction interface functions implementation.*/
const char * get_name(AtkAction *action,gint i)
{
    const char *return_val;

    if (!ATK_IS_ACTION(action))
        return NULL;

    switch (i)
    {
    case 0:
        return_val = "Action1";
        break;
    case 1:
        return_val = "Action2";
        break;
    case 2:
        return_val = "Action3";
        break;
    default:
        return_val = NULL;
    }

    return return_val;
}

gint get_n_actions(AtkAction *action)
{ 
    if (!ATK_IS_ACTION(action))
        return 0;
    return 3;
} 

/*Focus tracker function to test atk_focus_tracker_notify().*/
void func_focus_tracker(AtkObject *object)
{
    if (object == NULL)
        return;
    atk_object_set_name(object,"My AtkObject");
    return;
}


/*
 * Name: atk_action_get_name
 * Params: AtkAction *action, gint i
 * Returns: a name string, or NULL if action does not implement this interface.
 * Assertion: Returns the name of the specified action of the object.
 * Params Values: action 
 * Expected: Get name of an action.
 *   
 */
static void test_purpose_1()
{
    #define ACTION action
    
    AtkAction *action;
    GObject *action_obj;
    const char *name;
    GType type = 0;
    gint num,i;
    AtkActionIface *iface;
    
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    type = atk_no_op_object_get_type();
    
    /*Create a new GObject.*/
    action_obj = g_object_new(type,NULL);
    
    /*action_obj = g_object_new(ATK_TYPE_OBJECT,NULL);*/
    
    if (action_obj == NULL)
    {
        TEST_FAIL("Action Object is not created!\n",NULL);
    }
    
    /*Create a new AtkAction object.*/
    action = ATK_ACTION(action_obj);
    
    iface = ATK_ACTION_GET_IFACE(action);
    
    /*Get interface functions' implementation.*/
    iface->get_name = get_name;
    iface->get_n_actions = get_n_actions;
    
    num = atk_action_get_n_actions(action);
    
    for(i = 0;i < num;i++)
    {
        name = atk_action_get_name(ACTION,i);
        if (ACTION == action)
        {    
            switch (i)
            {
            case 0: 
            if (strcmp(name,"Action1"))
            {
                TEST_FAIL("Action name got error!\n",NULL);
            }
            break;
            case 1: 
            if (strcmp(name,"Action2"))
            {
                TEST_FAIL("Action name got error!\n",NULL);
            }
            break;
            case 2: 
            if (strcmp(name,"Action3"))
            {
                TEST_FAIL("Action name got error!\n",NULL);
            }
            break;
            default: 
                TEST_FAIL("Number of actions got error!\n",NULL);
           }
        }
    }
    
    #undef ACTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_action_get_n_actions
 * Params: AtkAction *action
 * Returns: the number of actions, or 0 if action does not implement this interface.
 * Assertion: Gets the number of accessible actions available on the object. If there are more than one, the first one is considered the "default" action of the object.
 * Params Values: action 
 * Expected: Get the number of actions.
 *   
 */
static void test_purpose_2()
{
    #define ACTION action
    
    AtkAction *action;
    GObject *action_obj;
    gint num;
    GType type = 0;
    AtkActionIface *iface;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    type = atk_no_op_object_get_type();
    
    /*Create a new GObject.*/
    action_obj = g_object_new(type,NULL);
    
    if (action_obj == NULL)
    {
        TEST_FAIL("Action Object is not created!\n",NULL);
    }
    
    /*Create a new AtkAction object.*/
    action = ATK_ACTION(action_obj);
    
    iface = ATK_ACTION_GET_IFACE(action);
    if (iface->get_n_actions == NULL)
    {
        iface->get_n_actions = get_n_actions;
    /*    g_printf("Interface get_n_actions is NULL.\n");*/
    }
    
    /*Get the number of actions.*/
    num = atk_action_get_n_actions(ACTION);
    
    if (ACTION == action)
    {    
        if (num != 3)
        {
            TEST_FAIL("Number of actions got error!\n",NULL);
        }
    }
    
    #undef ACTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_no_op_object_new
 * Params: GObject *obj
 * Returns: a default (non-functioning stub) AtkObject
 * Assertion: Provides a default (non-functioning stub) AtkObject. Application maintainers should not use this method.
 * Params Values: obj 
 * Expected: an AtkObject
 *   
 */
static void test_purpose_3()
{
    #define OBJ obj 
    
    AtkObject *accessible = NULL;
    GObject *obj;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible = atk_no_op_object_new(OBJ);
    
    /*check that the AtkObject is created.*/
    if (accessible == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    g_object_unref(obj);
    
    #undef OBJ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_object_set_role
 * Params: AtkObject *accessible, AtkRole role
 * Returns: void
 * Assertion: Sets the role of the accessible.
 * Params Values: accessible,ATK_ROLE_ACCEL_LABEL 
 * Expected: Role of the accessible is ATK_ROLE_ACCEL_LABEL
 *   
 */
static void test_purpose_4()
{
    #define ACCESSIBLE accessible
    #define ROLE ATK_ROLE_ACCEL_LABEL
    
    AtkObject *accessible = NULL;
    GObject *obj;
    AtkRole role;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible = atk_no_op_object_new(obj);
    
    /*check that the AtkObject is created.*/
    if (accessible == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Set role of accessible.*/
    atk_object_set_role(ACCESSIBLE,ROLE);
    
    /*Get role of the accessible.*/
    role = atk_object_get_role(ACCESSIBLE);
    
    /*g_printf("Role of the accessible is %d.\n ",role);*/
    
    /*Check whether the name is the name set.*/
    if (role != ROLE)
    {
        TEST_FAIL("Role of the accessible is not set correctly!\n",NULL);
    }
    
    g_object_unref(obj);
    
    #undef ACCESSIBLE
    #undef ROLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_object_set_role
 * Params: AtkObject *accessible, AtkRole role
 * Returns: void
 * Assertion: Sets the role of the accessible.
 * Params Values: accessible,ATK_ROLE_ARROW 
 * Expected: Role of the accessible is ATK_ROLE_ARROW
 *   
 */
static void test_purpose_5()
{
    #define ACCESSIBLE accessible
    #define ROLE ATK_ROLE_ARROW
    
    AtkObject *accessible = NULL;
    GObject *obj;
    AtkRole role;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible = atk_no_op_object_new(obj);
    
    /*check that the AtkObject is created.*/
    if (accessible == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Set role of accessible.*/
    atk_object_set_role(ACCESSIBLE,ROLE);
    
    /*Get role of the accessible.*/
    role = atk_object_get_role(ACCESSIBLE);
    
    /*g_printf("Role of the accessible is %d.\n ",role);*/
    
    /*Check whether the name is the name set.*/
    if (role != ROLE)
    {
        TEST_FAIL("Role of the accessible is not set correctly!\n",NULL);
    }
    
    g_object_unref(obj);
    
    #undef ACCESSIBLE
    #undef ROLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_object_set_role
 * Params: AtkObject *accessible, AtkRole role
 * Returns: void
 * Assertion: Sets the role of the accessible.
 * Params Values: accessible,ATK_ROLE_DIAL 
 * Expected: Role of the accessible is ATK_ROLE_DIAL
 *   
 */
static void test_purpose_6()
{
    #define ACCESSIBLE accessible
    #define ROLE ATK_ROLE_DIAL
    
    AtkObject *accessible = NULL;
    GObject *obj;
    AtkRole role;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible = atk_no_op_object_new(obj);
    
    /*check that the AtkObject is created.*/
    if (accessible == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Set role of accessible.*/
    atk_object_set_role(ACCESSIBLE,ROLE);
    
    /*Get role of the accessible.*/
    role = atk_object_get_role(ACCESSIBLE);
    
    /*g_printf("Role of the accessible is %d.\n ",role);*/
    
    /*Check whether the name is the name set.*/
    if (role != ROLE)
    {
        TEST_FAIL("Role of the accessible is not set correctly!\n",NULL);
    }
    
    g_object_unref(obj);
    
    #undef ACCESSIBLE
    #undef ROLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_object_set_role
 * Params: AtkObject *accessible, AtkRole role
 * Returns: void
 * Assertion: Sets the role of the accessible.
 * Params Values: accessible,ATK_ROLE_EMBEDDED 
 * Expected: Role of the accessible is ATK_ROLE_EMBEDDED
 *   
 */
static void test_purpose_7()
{
    #define ACCESSIBLE accessible
    #define ROLE ATK_ROLE_EMBEDDED
    
    AtkObject *accessible = NULL;
    GObject *obj;
    AtkRole role;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible = atk_no_op_object_new(obj);
    
    /*check that the AtkObject is created.*/
    if (accessible == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Set role of accessible.*/
    atk_object_set_role(ACCESSIBLE,ROLE);
    
    /*Get role of the accessible.*/
    role = atk_object_get_role(ACCESSIBLE);
    
    /*g_printf("Role of the accessible is %d.\n ",role);*/
    
    /*Check whether the name is the name set.*/
    if (role != ROLE)
    {
        TEST_FAIL("Role of the accessible is not set correctly!\n",NULL);
    }
    
    g_object_unref(obj);
    
    #undef ACCESSIBLE
    #undef ROLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_object_set_name
 * Params: AtkObject *accessible, const gchar *name
 * Returns: void
 * Assertion: Sets the accessible name of the accessible.
 * Params Values: accessible,"Accessible one"  
 * Expected: name of the accessible is "Accessible one" 
 *   
 */
static void test_purpose_8()
{
    #define ACCESSIBLE accessible
    #define NAME "Accessible one" 
    
    AtkObject *accessible = NULL;
    GObject *obj;
    const char *name;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible = atk_no_op_object_new(obj);
    
    /*check that the AtkObject is created.*/
    if (accessible == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Set name of accessible.*/
    atk_object_set_name(ACCESSIBLE,NAME);
    
    /*Get name of the accessible.*/
    name = atk_object_get_name(ACCESSIBLE);
    
    /*g_printf("Name of the accessible is %s.\n ",name);*/
    
    /*Check whether the name is the name set.*/
    if (strcmp(name,NAME))
    {
        TEST_FAIL("Name of the accessible is not set correctly!\n",NULL);
    }
    
    g_object_unref(obj);
    
    #undef ACCESSIBLE
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_object_set_name
 * Params: AtkObject *accessible, const gchar *name
 * Returns: void
 * Assertion: Sets the accessible name of the accessible.
 * Params Values: accessible," " 
 * Expected: name of the accessible is " "
 *   
 */
static void test_purpose_9()
{
    #define ACCESSIBLE accessible
    #define NAME " "
    
    AtkObject *accessible = NULL;
    GObject *obj;
    const char *name;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible = atk_no_op_object_new(obj);
    
    /*check that the AtkObject is created.*/
    if (accessible == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Set name of accessible.*/
    atk_object_set_name(ACCESSIBLE,NAME);
    
    /*Get name of the accessible.*/
    name = atk_object_get_name(ACCESSIBLE);
    
    /*g_printf("Name of the accessible is %s.\n ",name);*/
    
    /*Check whether the name is the name set.*/
    if (strcmp(name,NAME))
    {
        TEST_FAIL("Name of the accessible is not set correctly!\n",NULL);
    }
    
    g_object_unref(obj);
    
    #undef ACCESSIBLE
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_object_set_name
 * Params: AtkObject *accessible, const gchar *name
 * Returns: void
 * Assertion: Sets the accessible name of the accessible.
 * Params Values: accessible,"" 
 * Expected: name of the accessible is ""
 *   
 */
static void test_purpose_10()
{
    #define ACCESSIBLE accessible
    #define NAME ""
    
    AtkObject *accessible = NULL;
    GObject *obj;
    const char *name;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible = atk_no_op_object_new(obj);
    
    /*check that the AtkObject is created.*/
    if (accessible == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Set name of accessible.*/
    atk_object_set_name(ACCESSIBLE,NAME);
    
    /*Get name of the accessible.*/
    name = atk_object_get_name(ACCESSIBLE);
    
    /*g_printf("Name of the accessible is %s.\n ",name);*/
    
    /*Check whether the name is the name set.*/
    if (strcmp(name,NAME))
    {
        TEST_FAIL("Name of the accessible is not set correctly!\n",NULL);
    }
    
    g_object_unref(obj);
    
    #undef ACCESSIBLE
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_object_initialize
 * Params: AtkObject *accessible, gpointer data
 * Returns: void
 * Assertion: This function is called when implementing subclasses of AtkObject. It does initialization required for the new object. It is intended that this function should called only in the ..._new() functions used to create an instance of a subclass of AtkObject.
 * Params Values: accessible,obj 
 * Expected: Dose initialization for accessible
 *   
 */
static void test_purpose_11()
{
    #define ATK_OBJ accessible
    #define OBJ obj
    
    AtkObject *accessible;
    AtkAction *action;
    GObject *obj;
    GObject *action_obj;
    
    /*
    *AtkObjectClass *klass;
    */
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    action_obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    if (action_obj == NULL)
    {
        TEST_FAIL("Action Object is not created!\n",NULL);
    }
       
    /*Create a new AtkAction object.*/
    accessible = ATK_ACTION(action_obj);
    
    /*
    *klass = ATK_OBJECT_GET_CLASS(accessible);
    *if (klass->initialize == NULL)
    *{
    *    g_printf("Initialize is NULL");
    *}
    */
    
    atk_object_initialize(ATK_OBJ,OBJ);
    
    /*Check whether the object is initialized.*/
    if (accessible == NULL)
    {
        TEST_FAIL("Action accessible is not created!\n",NULL);
    }
    
    g_object_unref(obj);
    g_object_unref(action_obj);
    
    #undef ATK_OBJ
    #undef OBJ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_role_register
 * Params: const gchar *name
 * Returns: an AtkRole for the new role.
 * Assertion: Registers the role specified by name.
 * Params Values: "my new role" 
 * Expected: name of the new registered role is "my new role"
 *   
 */
static void test_purpose_12()
{
    #define NAME "my new role"
    
    AtkRole role;
    AtkRole role_get;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Register a new AtkRole.*/
    role = atk_role_register(NAME);
    
    /*Get the new registered role.*/
    role_get = atk_role_for_name(NAME);
    
    /*Check whether the role is registered correctly.*/
    if (role != role_get)
    {
        TEST_FAIL("Role is not correctly registered!\n",NULL);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_role_register
 * Params: const gchar *name
 * Returns: an AtkRole for the new role.
 * Assertion: Registers the role specified by name.
 * Params Values: " " 
 * Expected: name of the new registered role is " "
 *   
 */
static void test_purpose_13()
{
    #define NAME " "
    
    AtkRole role;
    AtkRole role_get;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Register a new AtkRole.*/
    role = atk_role_register(NAME);
    
    /*Get the new registered role.*/
    role_get = atk_role_for_name(NAME);
    
    /*Check whether the role is registered correctly.*/
    if (role != role_get)
    {
        TEST_FAIL("Role is not correctly registered!\n",NULL);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_role_register
 * Params: const gchar *name
 * Returns: an AtkRole for the new role.
 * Assertion: Registers the role specified by name.
 * Params Values: "" 
 * Expected: name of the new registered role is ""
 *   
 */
static void test_purpose_14()
{
    #define NAME ""
    
    AtkRole role;
    AtkRole role_get;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Register a new AtkRole.*/
    role = atk_role_register(NAME);
    
    /*Get the new registered role.*/
    role_get = atk_role_for_name(NAME);
    
    /*Check whether the role is registered correctly.*/
    if (role != role_get)
    {
        TEST_FAIL("Role is not correctly registered!\n",NULL);
    }
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_object_set_parent
 * Params: AtkObject *accessible, AtkObject *parent
 * Returns: void
 * Assertion: Sets the accessible parent of the accessible.
 * Params Values: accessible,parent  
 * Expected: Parent of accessible is parent 
 *   
 */
static void test_purpose_15()
{
    #define ACCESSIBLE accessible
    #define PARENT parent 
    
    AtkObject *accessible = NULL;
    AtkObject *parent;
    AtkObject *parent_get;
    GObject *obj;
    GObject *obj_par;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj_par = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject,serves as the parent object.*/
    parent = atk_no_op_object_new(obj_par);
    
    /*Create the child AtkObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    accessible = atk_no_op_object_new(obj);
    
    /*Check that the AtkObject is created.*/
    if (accessible == NULL || parent == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Set name of accessible.*/
    atk_object_set_parent(ACCESSIBLE,PARENT);
    
    /*Get name of the accessible.*/
    parent_get = atk_object_get_parent(ACCESSIBLE);
    
    /*Check whether the name is the name set.*/
    if (!struc_cmp((char *)parent,(char *)parent_get))
    {
        TEST_FAIL("Parent of the accessible is not gotten correctly!\n",NULL);
    }
    
    g_object_unref(obj);
    g_object_unref(obj_par);
    
    #undef ACCESSIBLE
    #undef PARENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_role_for_name
 * Params: const gchar *name
 * Returns: the AtkRole enumerated type corresponding to the specified name, or ATK_ROLE_INVALID if no matching role is found.
 * Assertion: Get the AtkRole type corresponding to a rolew name.
 * Params Values: ATK_ROLE_ALERT,name  
 * Expected: Get an AtkRole corresponding to name name ,or ATK_ROLE_INVALID if no matching role is found.
 *   
 */
static void test_purpose_16()
{
    #define ROLE ATK_ROLE_ALERT
    #define NAME name 
    
    AtkObject *accessible = NULL;
    GObject *obj;
    AtkRole role;
    const char *name;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible = atk_no_op_object_new(obj);
    
    /*check that the AtkObject is created.*/
    if (accessible == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Set role of accessible.*/
    atk_object_set_role(accessible,ROLE);
    
    /*Get name of the role.*/
    name = atk_role_get_name(ROLE);
    
    /*Get role corresponding to name.*/
    role = atk_role_for_name(NAME);
    
    /*Check whether the role is correct.*/
    if (strcmp(name,NAME))
    {
        if (role != ATK_ROLE_INVALID)
            {
                TEST_FAIL("Role of the accessible is not gotten correctly!",NULL);
            }
    }
    else
        if (role != ROLE)
           {
                TEST_FAIL("Role of the accessible is not gotten correctly!\n",NULL);
           }
    
    g_object_unref(obj);
    
    #undef ROLE
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_role_for_name
 * Params: const gchar *name
 * Returns: the AtkRole enumerated type corresponding to the specified name, or ATK_ROLE_INVALID if no matching role is found.
 * Assertion: Get the AtkRole type corresponding to a rolew name.
 * Params Values: ATK_ROLE_ARROW,name 
 * Expected: Get an AtkRole corresponding to name name,or ATK_ROLE_INVALID if no matching role is found.
 *   
 */
static void test_purpose_17()
{
    #define ROLE ATK_ROLE_ARROW
    #define NAME name
    
    AtkObject *accessible = NULL;
    GObject *obj;
    AtkRole role;
    const char *name;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible = atk_no_op_object_new(obj);
    
    /*check that the AtkObject is created.*/
    if (accessible == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Set role of accessible.*/
    atk_object_set_role(accessible,ROLE);
    
    /*Get name of the role.*/
    name = atk_role_get_name(ROLE);
    
    /*Get role corresponding to name.*/
    role = atk_role_for_name(NAME);
    
    /*Check whether the role is correct.*/
    if (strcmp(name,NAME))
    {
        if (role != ATK_ROLE_INVALID)
            {
                TEST_FAIL("Role of the accessible is not gotten correctly!",NULL);
            }
    }
    else
        if (role != ROLE)
           {
                TEST_FAIL("Role of the accessible is not gotten correctly!\n",NULL);
           }
    
    g_object_unref(obj);
    
    #undef ROLE
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_role_for_name
 * Params: const gchar *name
 * Returns: the AtkRole enumerated type corresponding to the specified name, or ATK_ROLE_INVALID if no matching role is found.
 * Assertion: Get the AtkRole type corresponding to a rolew name.
 * Params Values: ATK_ROLE_FRAME,name 
 * Expected: Get an AtkRole corresponding to name name,or ATK_ROLE_INVALID if no matching role is found.
 *   
 */
static void test_purpose_18()
{
    #define ROLE ATK_ROLE_FRAME
    #define NAME name
    
    AtkObject *accessible = NULL;
    GObject *obj;
    AtkRole role;
    const char *name;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible = atk_no_op_object_new(obj);
    
    /*check that the AtkObject is created.*/
    if (accessible == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Set role of accessible.*/
    atk_object_set_role(accessible,ROLE);
    
    /*Get name of the role.*/
    name = atk_role_get_name(ROLE);
    
    /*Get role corresponding to name.*/
    role = atk_role_for_name(NAME);
    
    /*Check whether the role is correct.*/
    if (strcmp(name,NAME))
    {
        if (role != ATK_ROLE_INVALID)
            {
                TEST_FAIL("Role of the accessible is not gotten correctly!",NULL);
            }
    }
    else
        if (role != ROLE)
           {
                TEST_FAIL("Role of the accessible is not gotten correctly!\n",NULL);
           }
    
    g_object_unref(obj);
    
    #undef ROLE
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_role_for_name
 * Params: const gchar *name
 * Returns: the AtkRole enumerated type corresponding to the specified name, or ATK_ROLE_INVALID if no matching role is found.
 * Assertion: Get the AtkRole type corresponding to a rolew name.
 * Params Values: ATK_ROLE_FRAME,"invalid name" 
 * Expected: Get an AtkRole corresponding to name "invalid name",or ATK_ROLE_INVALID if no matching role is found.
 *   
 */
static void test_purpose_19()
{
    #define ROLE ATK_ROLE_FRAME
    #define NAME "invalid name"
    
    AtkObject *accessible = NULL;
    GObject *obj;
    AtkRole role;
    const char *name;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible = atk_no_op_object_new(obj);
    
    /*check that the AtkObject is created.*/
    if (accessible == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Set role of accessible.*/
    atk_object_set_role(accessible,ROLE);
    
    /*Get name of the role.*/
    name = atk_role_get_name(ROLE);
    
    /*Get role corresponding to name.*/
    role = atk_role_for_name(NAME);
    
    /*Check whether the role is correct.*/
    if (strcmp(name,NAME))
    {
        if (role != ATK_ROLE_INVALID)
            {
                TEST_FAIL("Role of the accessible is not gotten correctly!",NULL);
            }
    }
    else
        if (role != ROLE)
           {
                TEST_FAIL("Role of the accessible is not gotten correctly!\n",NULL);
           }
    
    g_object_unref(obj);
    
    #undef ROLE
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_registry_get_factory
 * Params: AtkRegistry *registry, GType type
 * Returns: an AtkObjectFactory appropriate for creating AtkObjects appropriate for type.
 * Assertion: Gets an AtkObjectFactory appropriate for creating AtkObjects appropriate for type.
 * Params Values: registry,ATK_TYPE_NO_OP_OBJECT  
 * Expected: Get an AtkObjectFactory appropriate for creating appropriate for ATK_TYPE_NO_OP_OBJECT 
 *   
 */
static void test_purpose_20()
{
    #define REGISTRY registry
    #define GTYPE ATK_TYPE_NO_OP_OBJECT 
    
    AtkRegistry *registry = NULL;
    AtkObjectFactory *factory = NULL;
    AtkObjectFactory *factory_get;
    gpointer factory_pointer;
    GType factory_type;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Get default implementation of the AtkObjectFactory/type registry.*/
    registry = atk_get_default_registry();
    
    if (registry == NULL)
    {
        TEST_FAIL("Registry is not gotten correctly!\n",NULL);
    }
    
    /*Get AtkObjectFactory appropriate for GTYPE.*/
    factory_get = atk_registry_get_factory(REGISTRY,GTYPE);
    
    factory_type = atk_registry_get_factory_type (REGISTRY, GTYPE);
    
    if (factory_type == G_TYPE_INVALID)
    {
     /* Factory type has not been specified for this object type */
        static AtkObjectFactory* default_factory = NULL;
    
        default_factory = atk_no_op_object_factory_new ();
    
        factory = default_factory;
    }
    else
    {
    /* ask second hashtable for instance of factory type */
        factory_pointer =
        g_hash_table_lookup (registry->factory_singleton_cache,
        (gpointer) factory_type);
    
        if (factory_pointer == NULL)
        {
            factory_pointer = g_type_create_instance (factory_type);
    
            factory = ATK_OBJECT_FACTORY (factory_pointer);
        }
    }
    
    /*Check whether the factory gotten is correct.*/
    if (!struc_cmp((char *)factory,(char *)factory_get))
    {
        TEST_FAIL("Factory is not gotten correctly!\n",NULL);
    }
    
    #undef REGISTRY
    #undef GTYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_registry_get_factory
 * Params: AtkRegistry *registry, GType type
 * Returns: an AtkObjectFactory appropriate for creating AtkObjects appropriate for type.
 * Assertion: Gets an AtkObjectFactory appropriate for creating AtkObjects appropriate for type.
 * Params Values: registry,ATK_TYPE_OBJECT 
 * Expected: Get an AtkObjectFactory appropriate for creating appropriate for ATK_TYPE_OBJECT
 *   
 */
static void test_purpose_21()
{
    #define REGISTRY registry
    #define GTYPE ATK_TYPE_OBJECT
    
    AtkRegistry *registry = NULL;
    AtkObjectFactory *factory = NULL;
    AtkObjectFactory *factory_get;
    gpointer factory_pointer;
    GType factory_type;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Get default implementation of the AtkObjectFactory/type registry.*/
    registry = atk_get_default_registry();
    
    if (registry == NULL)
    {
        TEST_FAIL("Registry is not gotten correctly!\n",NULL);
    }
    
    /*Get AtkObjectFactory appropriate for GTYPE.*/
    factory_get = atk_registry_get_factory(REGISTRY,GTYPE);
    
    factory_type = atk_registry_get_factory_type (REGISTRY, GTYPE);
    
    if (factory_type == G_TYPE_INVALID)
    {
     /* Factory type has not been specified for this object type */
        static AtkObjectFactory* default_factory = NULL;
    
        default_factory = atk_no_op_object_factory_new ();
    
        factory = default_factory;
    }
    else
    {
    /* ask second hashtable for instance of factory type */
        factory_pointer =
        g_hash_table_lookup (registry->factory_singleton_cache,
        (gpointer) factory_type);
    
        if (factory_pointer == NULL)
        {
            factory_pointer = g_type_create_instance (factory_type);
    
            factory = ATK_OBJECT_FACTORY (factory_pointer);
        }
    }
    
    /*Check whether the factory gotten is correct.*/
    if (!struc_cmp((char *)factory,(char *)factory_get))
    {
        TEST_FAIL("Factory is not gotten correctly!\n",NULL);
    }
    
    #undef REGISTRY
    #undef GTYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_registry_get_factory
 * Params: AtkRegistry *registry, GType type
 * Returns: an AtkObjectFactory appropriate for creating AtkObjects appropriate for type.
 * Assertion: Gets an AtkObjectFactory appropriate for creating AtkObjects appropriate for type.
 * Params Values: registry,ATK_TYPE_ACTION 
 * Expected: Get an AtkObjectFactory appropriate for creating appropriate for ATK_TYPE_ACTION
 *   
 */
static void test_purpose_22()
{
    #define REGISTRY registry
    #define GTYPE ATK_TYPE_ACTION
    
    AtkRegistry *registry = NULL;
    AtkObjectFactory *factory = NULL;
    AtkObjectFactory *factory_get;
    gpointer factory_pointer;
    GType factory_type;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Get default implementation of the AtkObjectFactory/type registry.*/
    registry = atk_get_default_registry();
    
    if (registry == NULL)
    {
        TEST_FAIL("Registry is not gotten correctly!\n",NULL);
    }
    
    /*Get AtkObjectFactory appropriate for GTYPE.*/
    factory_get = atk_registry_get_factory(REGISTRY,GTYPE);
    
    factory_type = atk_registry_get_factory_type (REGISTRY, GTYPE);
    
    if (factory_type == G_TYPE_INVALID)
    {
     /* Factory type has not been specified for this object type */
        static AtkObjectFactory* default_factory = NULL;
    
        default_factory = atk_no_op_object_factory_new ();
    
        factory = default_factory;
    }
    else
    {
    /* ask second hashtable for instance of factory type */
        factory_pointer =
        g_hash_table_lookup (registry->factory_singleton_cache,
        (gpointer) factory_type);
    
        if (factory_pointer == NULL)
        {
            factory_pointer = g_type_create_instance (factory_type);
    
            factory = ATK_OBJECT_FACTORY (factory_pointer);
        }
    }
    
    /*Check whether the factory gotten is correct.*/
    if (!struc_cmp((char *)factory,(char *)factory_get))
    {
        TEST_FAIL("Factory is not gotten correctly!\n",NULL);
    }
    
    #undef REGISTRY
    #undef GTYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_get_default_registry
 * Params: void
 * Returns: a default implementation of the AtkObjectFactory/type registry
 * Assertion: Gets a default implementation of the AtkObjectFactory/type registry. 
 * Params Values: void 
 * Expected: The default implementation of the AtkObjectFactory/type registry.
 *   
 */
static void test_purpose_23()
{
    
    AtkRegistry *registry = NULL;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Get default implementation of the AtkObjectFactory/type registry.*/
    registry = atk_get_default_registry();
    
    if (registry == NULL)
    {
        TEST_FAIL("Registry is not gotten correctly!\n",NULL);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_relation_new
 * Params: AtkObject **targets, gint n_targets, AtkRelationType relationship
 * Returns: a pointer to a new AtkRelation
 * Assertion: Create a new relation for the specified key and the specified list of targets.
 * Params Values: targets,2,ATK_RELATION_NULL 
 * Expected: a new relation type of ATK_RELATION_NULL for list of targets targets
 *   
 */
static void test_purpose_24()
{
    #define TARGETS targets
    #define NUM  2
    #define RELATION ATK_RELATION_NULL
    
    AtkObject *accessible_1 = NULL;
    GObject *obj_1;
    AtkObject *accessible_2 = NULL;
    GObject *obj_2;
    AtkObject *targets[2];
    AtkRelation *relation;
    AtkRelationType relation_type;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj_1 = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible_1 = atk_no_op_object_new(obj_1);
    
    /*check that the AtkObject is created.*/
    if (accessible_1 == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Create another new GObject.*/
    obj_2 = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create another new AtkObject.*/
    accessible_2 = atk_no_op_object_new(obj_2);
    
    /*check that the AtkObject is created.*/
    if (accessible_2 == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    targets[0] = accessible_1;
    targets[1] = accessible_2;
    
    /*Create new relation for the list of targets.*/
    relation = atk_relation_new(TARGETS,NUM,RELATION);
    
    /*Get relation type of the new created relation.*/
    relation_type = atk_relation_get_relation_type(relation);
    
    /*Check whether the relation type is correct.*/
    if (relation_type != RELATION)
    {
        TEST_FAIL("Relation type is not correct!\n",NULL);
    }
    
    g_object_unref(obj_1);
    g_object_unref(obj_2);
    g_object_unref(relation);
    
    #undef TARGETS
    #undef NUM
    #undef RELATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_relation_new
 * Params: AtkObject **targets, gint n_targets, AtkRelationType relationship
 * Returns: a pointer to a new AtkRelation
 * Assertion: Create a new relation for the specified key and the specified list of targets.
 * Params Values: targets,2,ATK_RELATION_CONTROLLED_BY 
 * Expected: a new relation type of ATK_RELATION_CONTROLLED_BY for list of targets targets
 *   
 */
static void test_purpose_25()
{
    #define TARGETS targets
    #define NUM  2
    #define RELATION ATK_RELATION_CONTROLLED_BY
    
    AtkObject *accessible_1 = NULL;
    GObject *obj_1;
    AtkObject *accessible_2 = NULL;
    GObject *obj_2;
    AtkObject *targets[2];
    AtkRelation *relation;
    AtkRelationType relation_type;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj_1 = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible_1 = atk_no_op_object_new(obj_1);
    
    /*check that the AtkObject is created.*/
    if (accessible_1 == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Create another new GObject.*/
    obj_2 = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create another new AtkObject.*/
    accessible_2 = atk_no_op_object_new(obj_2);
    
    /*check that the AtkObject is created.*/
    if (accessible_2 == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    targets[0] = accessible_1;
    targets[1] = accessible_2;
    
    /*Create new relation for the list of targets.*/
    relation = atk_relation_new(TARGETS,NUM,RELATION);
    
    /*Get relation type of the new created relation.*/
    relation_type = atk_relation_get_relation_type(relation);
    
    /*Check whether the relation type is correct.*/
    if (relation_type != RELATION)
    {
        TEST_FAIL("Relation type is not correct!\n",NULL);
    }
    
    g_object_unref(obj_1);
    g_object_unref(obj_2);
    g_object_unref(relation);
    
    #undef TARGETS
    #undef NUM
    #undef RELATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_relation_new
 * Params: AtkObject **targets, gint n_targets, AtkRelationType relationship
 * Returns: a pointer to a new AtkRelation
 * Assertion: Create a new relation for the specified key and the specified list of targets.
 * Params Values: targets,2,ATK_RELATION_LABEL_FOR 
 * Expected: a new relation type of ATK_RELATION_LABEL_FOR for list of targets targets
 *   
 */
static void test_purpose_26()
{
    #define TARGETS targets
    #define NUM  2
    #define RELATION ATK_RELATION_LABEL_FOR
    
    AtkObject *accessible_1 = NULL;
    GObject *obj_1;
    AtkObject *accessible_2 = NULL;
    GObject *obj_2;
    AtkObject *targets[2];
    AtkRelation *relation;
    AtkRelationType relation_type;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj_1 = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible_1 = atk_no_op_object_new(obj_1);
    
    /*check that the AtkObject is created.*/
    if (accessible_1 == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Create another new GObject.*/
    obj_2 = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create another new AtkObject.*/
    accessible_2 = atk_no_op_object_new(obj_2);
    
    /*check that the AtkObject is created.*/
    if (accessible_2 == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    targets[0] = accessible_1;
    targets[1] = accessible_2;
    
    /*Create new relation for the list of targets.*/
    relation = atk_relation_new(TARGETS,NUM,RELATION);
    
    /*Get relation type of the new created relation.*/
    relation_type = atk_relation_get_relation_type(relation);
    
    /*Check whether the relation type is correct.*/
    if (relation_type != RELATION)
    {
        TEST_FAIL("Relation type is not correct!\n",NULL);
    }
    
    g_object_unref(obj_1);
    g_object_unref(obj_2);
    g_object_unref(relation);
    
    #undef TARGETS
    #undef NUM
    #undef RELATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_relation_new
 * Params: AtkObject **targets, gint n_targets, AtkRelationType relationship
 * Returns: a pointer to a new AtkRelation
 * Assertion: Create a new relation for the specified key and the specified list of targets.
 * Params Values: targets,2,ATK_RELATION_MEMBER_OF 
 * Expected: a new relation type of ATK_RELATION_MEMBER_OF for list of targets targets
 *   
 */
static void test_purpose_27()
{
    #define TARGETS targets
    #define NUM  2
    #define RELATION ATK_RELATION_MEMBER_OF
    
    AtkObject *accessible_1 = NULL;
    GObject *obj_1;
    AtkObject *accessible_2 = NULL;
    GObject *obj_2;
    AtkObject *targets[2];
    AtkRelation *relation;
    AtkRelationType relation_type;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj_1 = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible_1 = atk_no_op_object_new(obj_1);
    
    /*check that the AtkObject is created.*/
    if (accessible_1 == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Create another new GObject.*/
    obj_2 = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create another new AtkObject.*/
    accessible_2 = atk_no_op_object_new(obj_2);
    
    /*check that the AtkObject is created.*/
    if (accessible_2 == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    targets[0] = accessible_1;
    targets[1] = accessible_2;
    
    /*Create new relation for the list of targets.*/
    relation = atk_relation_new(TARGETS,NUM,RELATION);
    
    /*Get relation type of the new created relation.*/
    relation_type = atk_relation_get_relation_type(relation);
    
    /*Check whether the relation type is correct.*/
    if (relation_type != RELATION)
    {
        TEST_FAIL("Relation type is not correct!\n",NULL);
    }
    
    g_object_unref(obj_1);
    g_object_unref(obj_2);
    g_object_unref(relation);
    
    #undef TARGETS
    #undef NUM
    #undef RELATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_relation_new
 * Params: AtkObject **targets, gint n_targets, AtkRelationType relationship
 * Returns: a pointer to a new AtkRelation
 * Assertion: Create a new relation for the specified key and the specified list of targets.
 * Params Values: targets,2,ATK_RELATION_EMBEDS 
 * Expected: a new relation type of ATK_RELATION_EMBEDS for list of targets targets
 *   
 */
static void test_purpose_28()
{
    #define TARGETS targets
    #define NUM  2
    #define RELATION ATK_RELATION_EMBEDS
    
    AtkObject *accessible_1 = NULL;
    GObject *obj_1;
    AtkObject *accessible_2 = NULL;
    GObject *obj_2;
    AtkObject *targets[2];
    AtkRelation *relation;
    AtkRelationType relation_type;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj_1 = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible_1 = atk_no_op_object_new(obj_1);
    
    /*check that the AtkObject is created.*/
    if (accessible_1 == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Create another new GObject.*/
    obj_2 = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create another new AtkObject.*/
    accessible_2 = atk_no_op_object_new(obj_2);
    
    /*check that the AtkObject is created.*/
    if (accessible_2 == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    targets[0] = accessible_1;
    targets[1] = accessible_2;
    
    /*Create new relation for the list of targets.*/
    relation = atk_relation_new(TARGETS,NUM,RELATION);
    
    /*Get relation type of the new created relation.*/
    relation_type = atk_relation_get_relation_type(relation);
    
    /*Check whether the relation type is correct.*/
    if (relation_type != RELATION)
    {
        TEST_FAIL("Relation type is not correct!\n",NULL);
    }
    
    g_object_unref(obj_1);
    g_object_unref(obj_2);
    g_object_unref(relation);
    
    #undef TARGETS
    #undef NUM
    #undef RELATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_relation_set_add
 * Params: AtkRelationSet *set, AtkRelation *relation
 * Returns: void
 * Assertion: Add a new relation to the current relation set if it is not already present. This function ref's the AtkRelation so the caller of this function should unref it to ensure that it will be destroyed when the AtkRelationSet is destroyed.
 * Params Values: relation_set,relation 
 * Expected: Relation relation is added to relation set relation_set,and reference count of relation is increased by 1.
 *   
 */
static void test_purpose_29()
{
    #define RELATION_SET relation_set
    #define RELATION relation
    
    AtkObject *accessible_1 = NULL;
    GObject *obj_1;
    AtkObject *accessible_2 = NULL;
    GObject *obj_2;
    AtkObject *targets[2];
    AtkRelation *relation;
    AtkRelationSet *relation_set;
    gint num;
    guint ref_num;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj_1 = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible_1 = atk_no_op_object_new(obj_1);
    
    /*check that the AtkObject is created.*/
    if (accessible_1 == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Create another new GObject.*/
    obj_2 = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create another new AtkObject.*/
    accessible_2 = atk_no_op_object_new(obj_2);
    
    /*check that the AtkObject is created.*/
    if (accessible_2 == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    targets[0] = accessible_1;
    targets[1] = accessible_2;
    
    /*Create new relation for the list of targets.*/
    relation = atk_relation_new(targets,2,ATK_RELATION_CONTROLLED_BY);
    
    ref_num = ((GObject *)relation)->ref_count;
    /*
    *g_printf("Before relation set add reference num of relation is %d.\n",ref_num);
    */
    
    /*Create a new relation set.*/
    relation_set = atk_relation_set_new();
    
    /*Add the new relation to the relation set.*/
    atk_relation_set_add(RELATION_SET,RELATION);
    
    /*Get number of the relation set.*/
    num = atk_relation_set_get_n_relations(relation_set);
    
    /*Check whether the number of the relation set is correct.*/
    if (num != 1)
    {
        TEST_FAIL("Number of relation set is not correct!\n",NULL);
    }
    
    /*Check that the reference number is increased by 1.*/
    if ((ref_num + 1) != ((GObject *)relation)->ref_count)
    {
        TEST_FAIL("Reference number of relation is not correct!\n",NULL);
    }
    
    g_object_unref(relation);
    
    g_object_unref(obj_1);
    g_object_unref(obj_2);
    g_object_unref(relation);
    
    #undef RELATION_SET
    #undef RELATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_state_set_add_state
 * Params: AtkStateSet *set, AtkStateType type
 * Returns: TRUE if the state for type is not already in set.
 * Assertion: Add a new state for the specified type to the current state set if it is not already present.
 * Params Values: state_set,ATK_STATE_ACTIVE  
 * Expected: Add state type ATK_STATE_ACTIVE  if it's not in the current state set.
 *   
 */
static void test_purpose_30()
{
    #define STATE_SET state_set
    #define STATE_TYPE ATK_STATE_ACTIVE 
    
    AtkStateSet *state_set;
    AtkStateType state_type;
    gboolean flag;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new empty state set.*/
    state_set = atk_state_set_new();
    
    flag = atk_state_set_is_empty(state_set);
    
    /*Check whether the new created state set is empty.*/
    if (!flag)
    {
        TEST_FAIL("New created state set is not empty!\n",NULL);
    }
    
    /*Add a state type into the empty state set.*/
    flag = atk_state_set_add_state(STATE_SET,STATE_TYPE);
    
    if (!flag)
    {
        TEST_FAIL("State type is not added into state set!\n",NULL);
    }
    
    /*Check whether the state set contains the new added state type.*/
    flag = atk_state_set_contains_state(STATE_SET,STATE_TYPE);
    
    if (!flag)
    {
        TEST_FAIL("State set not contains the new added state type!\n",NULL);
    }
    
    /*Re-add the state type into the state set.*/
    flag = atk_state_set_add_state(STATE_SET,STATE_TYPE);
    
    if (flag)
    {
        TEST_FAIL("State type is should not be added into state set!\n",NULL);
    }
    
    #undef STATE_SET
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_state_set_add_state
 * Params: AtkStateSet *set, AtkStateType type
 * Returns: TRUE if the state for type is not already in set.
 * Assertion: Add a new state for the specified type to the current state set if it is not already present.
 * Params Values: state_set,ATK_STATE_SHOWING 
 * Expected: Add state type ATK_STATE_SHOWING if it's not in the current state set.
 *   
 */
static void test_purpose_31()
{
    #define STATE_SET state_set
    #define STATE_TYPE ATK_STATE_SHOWING
    
    AtkStateSet *state_set;
    AtkStateType state_type;
    gboolean flag;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new empty state set.*/
    state_set = atk_state_set_new();
    
    flag = atk_state_set_is_empty(state_set);
    
    /*Check whether the new created state set is empty.*/
    if (!flag)
    {
        TEST_FAIL("New created state set is not empty!\n",NULL);
    }
    
    /*Add a state type into the empty state set.*/
    flag = atk_state_set_add_state(STATE_SET,STATE_TYPE);
    
    if (!flag)
    {
        TEST_FAIL("State type is not added into state set!\n",NULL);
    }
    
    /*Check whether the state set contains the new added state type.*/
    flag = atk_state_set_contains_state(STATE_SET,STATE_TYPE);
    
    if (!flag)
    {
        TEST_FAIL("State set not contains the new added state type!\n",NULL);
    }
    
    /*Re-add the state type into the state set.*/
    flag = atk_state_set_add_state(STATE_SET,STATE_TYPE);
    
    if (flag)
    {
        TEST_FAIL("State type is should not be added into state set!\n",NULL);
    }
    
    #undef STATE_SET
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_state_set_add_state
 * Params: AtkStateSet *set, AtkStateType type
 * Returns: TRUE if the state for type is not already in set.
 * Assertion: Add a new state for the specified type to the current state set if it is not already present.
 * Params Values: state_set,ATK_STATE_VISIBLE 
 * Expected: Add state type ATK_STATE_VISIBLE if it's not in the current state set.
 *   
 */
static void test_purpose_32()
{
    #define STATE_SET state_set
    #define STATE_TYPE ATK_STATE_VISIBLE
    
    AtkStateSet *state_set;
    AtkStateType state_type;
    gboolean flag;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new empty state set.*/
    state_set = atk_state_set_new();
    
    flag = atk_state_set_is_empty(state_set);
    
    /*Check whether the new created state set is empty.*/
    if (!flag)
    {
        TEST_FAIL("New created state set is not empty!\n",NULL);
    }
    
    /*Add a state type into the empty state set.*/
    flag = atk_state_set_add_state(STATE_SET,STATE_TYPE);
    
    if (!flag)
    {
        TEST_FAIL("State type is not added into state set!\n",NULL);
    }
    
    /*Check whether the state set contains the new added state type.*/
    flag = atk_state_set_contains_state(STATE_SET,STATE_TYPE);
    
    if (!flag)
    {
        TEST_FAIL("State set not contains the new added state type!\n",NULL);
    }
    
    /*Re-add the state type into the state set.*/
    flag = atk_state_set_add_state(STATE_SET,STATE_TYPE);
    
    if (flag)
    {
        TEST_FAIL("State type is should not be added into state set!\n",NULL);
    }
    
    #undef STATE_SET
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_state_set_new
 * Params: void
 * Returns: a new AtkStateSet
 * Assertion: Creates a new empty state set.
 * Params Values: void 
 * Expected: a new empty state set.
 *   
 */
static void test_purpose_33()
{
    
    AtkStateSet *state_set;
    gboolean flag;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new empty state set.*/
    state_set = atk_state_set_new();
    
    flag = atk_state_set_is_empty(state_set);
    
    /*Check whether the new created state set is empty.*/
    if (!flag)
    {
        TEST_FAIL("New created state set is not empty!\n",NULL);
    }
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: atk_focus_tracker_notify
 * Params: AtkObject *object
 * Returns: void
 * Assertion: Cause the focus tracker functions which have been specified to be executed for the object.
 * Params Values: accessible 
 * Expected: Cause the focus tracker function to be executed on accessible
 *   
 */
static void test_purpose_34()
{
    #define OBJECT accessible
    
    AtkObject *accessible = NULL;
    GObject *obj;
    const char *name;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*Create a new GObject.*/
    obj = g_object_new(ATK_TYPE_NO_OP_OBJECT,NULL);
    
    /*Create a new AtkObject.*/
    accessible = atk_no_op_object_new(obj);
    
    /*check that the AtkObject is created.*/
    if (accessible == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Add the focus tracker.*/
    atk_add_focus_tracker(func_focus_tracker);
    
    /*
    *Call the focus tracker function set for the object,
    *in the implementation the focus tracker funtion will set 
    *the name of the object to "My AtkObject".
    */
    atk_focus_tracker_notify(OBJECT);
    
    /*Get the name of the object.*/
    name = atk_object_get_name(accessible);
    
    /*
    *g_printf("Name of AtkObject is %s\n",name);
    */
    
    /*Check that the name was set by the focus tracker function.*/
    if (strcmp(name,"My AtkObject"))
    {
        TEST_FAIL("Atk focus tracker notify is not called!\n",NULL);
    }
    
    g_object_unref(obj);
    #undef OBJECT
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for atk_tcs ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {NULL,0}
};
