/*
 * GdkWindows methods tests
 * Testing GdkWindows methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;


/*
 * Name: gdk_window_new 
 * Params: GdkWindow *parent, GdkWindowAttr *attributes, gint attributes_mask
 * Returns: GdkWindow*
 * Assertion: Creates a new GdkWindow using the attributes from attributes. See GdkWindowAttr and GdkWindowAttributesType for more details. Note: to use this on displays other than the default display, parent must be specified.
 * Params Values: a GdkWindow, or NULL to create the window as a child of the default root window for the default display; attributes of the new window; mask indicating which fields in attributes are valid.
 * Expected: the new GdkWindow.  
 */
static void test_purpose_1()
{
    #define PARENT NULL
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    GdkWindowType window_type;
    gint x;
    gint y;
    gint width;
    gint height;
    gint depth;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (PARENT, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    window_type = gdk_window_get_window_type (window);
    if (window_type != attributes.window_type)
        TEST_FAIL ("window_type should be %d, not %d", attributes.window_type, window_type, NULL);
    
    gdk_window_get_geometry (window, &x, &y, &width, &height, &depth);
    
    if ((ATTRIBUTES_MASK) & GDK_WA_X)
        if (x != attributes.x)
            TEST_FAIL ("X coordinate should be %d, not %d", attributes.x, x, NULL);
    
    if ((ATTRIBUTES_MASK) & GDK_WA_Y)
        if (y != attributes.y)
            TEST_FAIL ("Y coordinate should be %d, not %d", attributes.y, y, NULL);
    
    if (width != attributes.width)
        TEST_FAIL ("width of window should be %d, not %d", attributes.width, width, NULL);
    
    if (height != attributes.height)
        TEST_FAIL ("height of window should be %d, not %d", attributes.height, height, NULL);
    
    gdk_window_destroy (window);
    
    #undef PARENT
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_new 
 * Params: GdkWindow *parent, GdkWindowAttr *attributes, gint attributes_mask
 * Returns: GdkWindow*
 * Assertion: Creates a new GdkWindow using the attributes from attributes. See GdkWindowAttr and GdkWindowAttributesType for more details. Note: to use this on displays other than the default display, parent must be specified.
 * Params Values: a GdkWindow, or NULL to create the window as a child of the default root window for the default display; attributes of the new window; mask indicating which fields in attributes are valid.
 * Expected: the new GdkWindow.  
 */
static void test_purpose_2()
{
    #define PARENT NULL
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    GdkWindowType window_type;
    gint x;
    gint y;
    gint width;
    gint height;
    gint depth;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (PARENT, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    window_type = gdk_window_get_window_type (window);
    if (window_type != attributes.window_type)
        TEST_FAIL ("window_type should be %d, not %d", attributes.window_type, window_type, NULL);
    
    gdk_window_get_geometry (window, &x, &y, &width, &height, &depth);
    
    if ((ATTRIBUTES_MASK) & GDK_WA_X)
        if (x != attributes.x)
            TEST_FAIL ("X coordinate should be %d, not %d", attributes.x, x, NULL);
    
    if ((ATTRIBUTES_MASK) & GDK_WA_Y)
        if (y != attributes.y)
            TEST_FAIL ("Y coordinate should be %d, not %d", attributes.y, y, NULL);
    
    if (width != attributes.width)
        TEST_FAIL ("width of window should be %d, not %d", attributes.width, width, NULL);
    
    if (height != attributes.height)
        TEST_FAIL ("height of window should be %d, not %d", attributes.height, height, NULL);
    
    gdk_window_destroy (window);
    
    #undef PARENT
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_new 
 * Params: GdkWindow *parent, GdkWindowAttr *attributes, gint attributes_mask
 * Returns: GdkWindow*
 * Assertion: Creates a new GdkWindow using the attributes from attributes. See GdkWindowAttr and GdkWindowAttributesType for more details. Note: to use this on displays other than the default display, parent must be specified.
 * Params Values: a GdkWindow, or NULL to create the window as a child of the default root window for the default display; attributes of the new window; mask indicating which fields in attributes are valid.
 * Expected: the new GdkWindow.  
 */
static void test_purpose_3()
{
    #define PARENT NULL
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_Y
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    GdkWindowType window_type;
    gint x;
    gint y;
    gint width;
    gint height;
    gint depth;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (PARENT, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    window_type = gdk_window_get_window_type (window);
    if (window_type != attributes.window_type)
        TEST_FAIL ("window_type should be %d, not %d", attributes.window_type, window_type, NULL);
    
    gdk_window_get_geometry (window, &x, &y, &width, &height, &depth);
    
    if ((ATTRIBUTES_MASK) & GDK_WA_X)
        if (x != attributes.x)
            TEST_FAIL ("X coordinate should be %d, not %d", attributes.x, x, NULL);
    
    if ((ATTRIBUTES_MASK) & GDK_WA_Y)
        if (y != attributes.y)
            TEST_FAIL ("Y coordinate should be %d, not %d", attributes.y, y, NULL);
    
    if (width != attributes.width)
        TEST_FAIL ("width of window should be %d, not %d", attributes.width, width, NULL);
    
    if (height != attributes.height)
        TEST_FAIL ("height of window should be %d, not %d", attributes.height, height, NULL);
    
    gdk_window_destroy (window);
    
    #undef PARENT
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_new 
 * Params: GdkWindow *parent, GdkWindowAttr *attributes, gint attributes_mask
 * Returns: GdkWindow*
 * Assertion: Creates a new GdkWindow using the attributes from attributes. See GdkWindowAttr and GdkWindowAttributesType for more details. Note: to use this on displays other than the default display, parent must be specified.
 * Params Values: a GdkWindow, or NULL to create the window as a child of the default root window for the default display; attributes of the new window; mask indicating which fields in attributes are valid.
 * Expected: the new GdkWindow.  
 */
static void test_purpose_4()
{
    #define PARENT NULL
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    GdkWindowType window_type;
    gint x;
    gint y;
    gint width;
    gint height;
    gint depth;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (PARENT, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    window_type = gdk_window_get_window_type (window);
    if (window_type != attributes.window_type)
        TEST_FAIL ("window_type should be %d, not %d", attributes.window_type, window_type, NULL);
    
    gdk_window_get_geometry (window, &x, &y, &width, &height, &depth);
    
    if ((ATTRIBUTES_MASK) & GDK_WA_X)
        if (x != attributes.x)
            TEST_FAIL ("X coordinate should be %d, not %d", attributes.x, x, NULL);
    
    if ((ATTRIBUTES_MASK) & GDK_WA_Y)
        if (y != attributes.y)
            TEST_FAIL ("Y coordinate should be %d, not %d", attributes.y, y, NULL);
    
    if (width != attributes.width)
        TEST_FAIL ("width of window should be %d, not %d", attributes.width, width, NULL);
    
    if (height != attributes.height)
        TEST_FAIL ("height of window should be %d, not %d", attributes.height, height, NULL);
    
    gdk_window_destroy (window);
    
    #undef PARENT
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_origin
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: gint
 * Assertion: Obtains the position of a window in root window coordinates. (Compare with gdk_window_get_position() and gdk_window_get_geometry() which return the position of a window relative to its parent window.)
 * Params Values: a GdkWindow, return location for X coordinate, return location for Y coordinate
 * Expected: not meaningful, ignore  
 */
static void test_purpose_5()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_origin (window, &x, &y);
    
    if (x != attributes.x)
        TEST_FAIL ("X coordinate should be %d, not %d", attributes.x, x, NULL);
    
    if (y != attributes.y)
        TEST_FAIL ("Y coordinate should be %d, not %d", attributes.y, y, NULL);
    
    gdk_window_destroy (window);
    
    #undef ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_origin
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: gint
 * Assertion: Obtains the position of a window in root window coordinates. (Compare with gdk_window_get_position() and gdk_window_get_geometry() which return the position of a window relative to its parent window.)
 * Params Values: a GdkWindow, return location for X coordinate, return location for Y coordinate
 * Expected: not meaningful, ignore  
 */
static void test_purpose_6()
{
    #define ATTRIBUTES {"foo", 0, 100, 100, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_origin (window, &x, &y);
    
    if (x != attributes.x)
        TEST_FAIL ("X coordinate should be %d, not %d", attributes.x, x, NULL);
    
    if (y != attributes.y)
        TEST_FAIL ("Y coordinate should be %d, not %d", attributes.y, y, NULL);
    
    gdk_window_destroy (window);
    
    #undef ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_origin
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: gint
 * Assertion: Obtains the position of a window in root window coordinates. (Compare with gdk_window_get_position() and gdk_window_get_geometry() which return the position of a window relative to its parent window.)
 * Params Values: a GdkWindow, return location for X coordinate, return location for Y coordinate
 * Expected: not meaningful, ignore  
 */
static void test_purpose_7()
{
    #define ATTRIBUTES {"foo", 0, 1000, 1000, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_origin (window, &x, &y);
    
    if (x != attributes.x)
        TEST_FAIL ("X coordinate should be %d, not %d", attributes.x, x, NULL);
    
    if (y != attributes.y)
        TEST_FAIL ("Y coordinate should be %d, not %d", attributes.y, y, NULL);
    
    gdk_window_destroy (window);
    
    #undef ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_origin
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: gint
 * Assertion: Obtains the position of a window in root window coordinates. (Compare with gdk_window_get_position() and gdk_window_get_geometry() which return the position of a window relative to its parent window.)
 * Params Values: a GdkWindow, return location for X coordinate, return location for Y coordinate
 * Expected: not meaningful, ignore  
 */
static void test_purpose_8()
{
    #define ATTRIBUTES {"foo", 0, 6000, 8000, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_origin (window, &x, &y);
    
    if (x != attributes.x)
        TEST_FAIL ("X coordinate should be %d, not %d", attributes.x, x, NULL);
    
    if (y != attributes.y)
        TEST_FAIL ("Y coordinate should be %d, not %d", attributes.y, y, NULL);
    
    gdk_window_destroy (window);
    
    #undef ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_origin
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: gint
 * Assertion: Obtains the position of a window in root window coordinates. (Compare with gdk_window_get_position() and gdk_window_get_geometry() which return the position of a window relative to its parent window.)
 * Params Values: a GdkWindow, return location for X coordinate, return location for Y coordinate
 * Expected: not meaningful, ignore  
 */
static void test_purpose_9()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 1, 2, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 9, 8, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint parent_x;
    gint parent_y;
    gint child_x;
    gint child_y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_origin (parent_window, &parent_x, &parent_y);
    gdk_window_get_origin (child_window, &child_x, &child_y);
    
    if ((parent_attributes.x + child_attributes.x) != child_x)
        TEST_FAIL ("X coordinate of child window should be %d, not %d", parent_attributes.x + child_attributes.x, child_x, NULL);
    
    if ((parent_attributes.y + child_attributes.y) != child_y)
        TEST_FAIL ("Y coordinate should of child window be %d, not %d", parent_attributes.y + child_attributes.y, child_y, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_origin
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: gint
 * Assertion: Obtains the position of a window in root window coordinates. (Compare with gdk_window_get_position() and gdk_window_get_geometry() which return the position of a window relative to its parent window.)
 * Params Values: a GdkWindow, return location for X coordinate, return location for Y coordinate
 * Expected: not meaningful, ignore  
 */
static void test_purpose_10()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 23, 34, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 77, 66, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint parent_x;
    gint parent_y;
    gint child_x;
    gint child_y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_origin (parent_window, &parent_x, &parent_y);
    gdk_window_get_origin (child_window, &child_x, &child_y);
    
    if ((parent_attributes.x + child_attributes.x) != child_x)
        TEST_FAIL ("X coordinate of child window should be %d, not %d", parent_attributes.x + child_attributes.x, child_x, NULL);
    
    if ((parent_attributes.y + child_attributes.y) != child_y)
        TEST_FAIL ("Y coordinate should of child window be %d, not %d", parent_attributes.y + child_attributes.y, child_y, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_origin
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: gint
 * Assertion: Obtains the position of a window in root window coordinates. (Compare with gdk_window_get_position() and gdk_window_get_geometry() which return the position of a window relative to its parent window.)
 * Params Values: a GdkWindow, return location for X coordinate, return location for Y coordinate
 * Expected: not meaningful, ignore  
 */
static void test_purpose_11()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 123, 456, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 789, 654, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint parent_x;
    gint parent_y;
    gint child_x;
    gint child_y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_origin (parent_window, &parent_x, &parent_y);
    gdk_window_get_origin (child_window, &child_x, &child_y);
    
    if ((parent_attributes.x + child_attributes.x) != child_x)
        TEST_FAIL ("X coordinate of child window should be %d, not %d", parent_attributes.x + child_attributes.x, child_x, NULL);
    
    if ((parent_attributes.y + child_attributes.y) != child_y)
        TEST_FAIL ("Y coordinate should of child window be %d, not %d", parent_attributes.y + child_attributes.y, child_y, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_origin
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: gint
 * Assertion: Obtains the position of a window in root window coordinates. (Compare with gdk_window_get_position() and gdk_window_get_geometry() which return the position of a window relative to its parent window.)
 * Params Values: a GdkWindow, return location for X coordinate, return location for Y coordinate
 * Expected: not meaningful, ignore  
 */
static void test_purpose_12()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 32767, 0, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 0, 32767, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint parent_x;
    gint parent_y;
    gint child_x;
    gint child_y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_origin (parent_window, &parent_x, &parent_y);
    gdk_window_get_origin (child_window, &child_x, &child_y);
    
    if ((parent_attributes.x + child_attributes.x) != child_x)
        TEST_FAIL ("X coordinate of child window should be %d, not %d", parent_attributes.x + child_attributes.x, child_x, NULL);
    
    if ((parent_attributes.y + child_attributes.y) != child_y)
        TEST_FAIL ("Y coordinate should of child window be %d, not %d", parent_attributes.y + child_attributes.y, child_y, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_position
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: void
 * Assertion: Obtains the position of the window as reported in the most-recently-processed GdkEventConfigure. Contrast with gdk_window_get_geometry() which queries the X server for the current window position, regardless of which events have been received or processed. The position coordinates are relative to the window's parent window.
 * Params Values: a GdkWindow, X coordinate of window, Y coordinate of window
 * Expected: void  
 */
static void test_purpose_13()
{
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_position (window, &x, &y);
    
    if (x != attributes.x)
        TEST_FAIL ("X coordinate should be %d, not %d", attributes.x, x, NULL);
    
    if (y != attributes.y)
        TEST_FAIL ("Y coordinate should be %d, not %d", attributes.y, y, NULL);
    
    gdk_window_destroy (window);
    
    #undef ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_position
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: void
 * Assertion: Obtains the position of the window as reported in the most-recently-processed GdkEventConfigure. Contrast with gdk_window_get_geometry() which queries the X server for the current window position, regardless of which events have been received or processed. The position coordinates are relative to the window's parent window.
 * Params Values: a GdkWindow, X coordinate of window, Y coordinate of window
 * Expected: void  
 */
static void test_purpose_14()
{
    #define ATTRIBUTES {"foo", 0, 100, 100, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_position (window, &x, &y);
    
    if (x != attributes.x)
        TEST_FAIL ("X coordinate should be %d, not %d", attributes.x, x, NULL);
    
    if (y != attributes.y)
        TEST_FAIL ("Y coordinate should be %d, not %d", attributes.y, y, NULL);
    
    gdk_window_destroy (window);
    
    #undef ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_position
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: void
 * Assertion: Obtains the position of the window as reported in the most-recently-processed GdkEventConfigure. Contrast with gdk_window_get_geometry() which queries the X server for the current window position, regardless of which events have been received or processed. The position coordinates are relative to the window's parent window.
 * Params Values: a GdkWindow, X coordinate of window, Y coordinate of window
 * Expected: void  
 */
static void test_purpose_15()
{
    #define ATTRIBUTES {"foo", 0, 1000, 1000, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_position (window, &x, &y);
    
    if (x != attributes.x)
        TEST_FAIL ("X coordinate should be %d, not %d", attributes.x, x, NULL);
    
    if (y != attributes.y)
        TEST_FAIL ("Y coordinate should be %d, not %d", attributes.y, y, NULL);
    
    gdk_window_destroy (window);
    
    #undef ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_position
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: void
 * Assertion: Obtains the position of the window as reported in the most-recently-processed GdkEventConfigure. Contrast with gdk_window_get_geometry() which queries the X server for the current window position, regardless of which events have been received or processed. The position coordinates are relative to the window's parent window.
 * Params Values: a GdkWindow, X coordinate of window, Y coordinate of window
 * Expected: void  
 */
static void test_purpose_16()
{
    #define ATTRIBUTES {"foo", 0, 32767, 32767, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    
    GdkWindow *window;
    GdkWindowAttr attributes = ATTRIBUTES;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_position (window, &x, &y);
    
    if (x != attributes.x)
        TEST_FAIL ("X coordinate should be %d, not %d", attributes.x, x, NULL);
    
    if (y != attributes.y)
        TEST_FAIL ("Y coordinate should be %d, not %d", attributes.y, y, NULL);
    
    gdk_window_destroy (window);
    
    #undef ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_position
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: void
 * Assertion: Obtains the position of the window as reported in the most-recently-processed GdkEventConfigure. Contrast with gdk_window_get_geometry() which queries the X server for the current window position, regardless of which events have been received or processed. The position coordinates are relative to the window's parent window.
 * Params Values: a GdkWindow, X coordinate of window, Y coordinate of window
 * Expected: void  
 */
static void test_purpose_17()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 1, 2, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 9, 8, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint child_x;
    gint child_y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_position (child_window, &child_x, &child_y);
    
    if (child_attributes.x != child_x)
        TEST_FAIL ("X coordinate of child window should be %d, not %d", child_attributes.x, child_x, NULL);
    
    if (child_attributes.y != child_y)
        TEST_FAIL ("Y coordinate should of child window be %d, not %d", child_attributes.y, child_y, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_position
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: void
 * Assertion: Obtains the position of the window as reported in the most-recently-processed GdkEventConfigure. Contrast with gdk_window_get_geometry() which queries the X server for the current window position, regardless of which events have been received or processed. The position coordinates are relative to the window's parent window.
 * Params Values: a GdkWindow, X coordinate of window, Y coordinate of window
 * Expected: void  
 */
static void test_purpose_18()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 23, 34, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 77, 66, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint child_x;
    gint child_y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_position (child_window, &child_x, &child_y);
    
    if (child_attributes.x != child_x)
        TEST_FAIL ("X coordinate of child window should be %d, not %d", child_attributes.x, child_x, NULL);
    
    if (child_attributes.y != child_y)
        TEST_FAIL ("Y coordinate should of child window be %d, not %d", child_attributes.y, child_y, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_position
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: void
 * Assertion: Obtains the position of the window as reported in the most-recently-processed GdkEventConfigure. Contrast with gdk_window_get_geometry() which queries the X server for the current window position, regardless of which events have been received or processed. The position coordinates are relative to the window's parent window.
 * Params Values: a GdkWindow, X coordinate of window, Y coordinate of window
 * Expected: void  
 */
static void test_purpose_19()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 123, 456, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 789, 654, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint child_x;
    gint child_y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_position (child_window, &child_x, &child_y);
    
    if (child_attributes.x != child_x)
        TEST_FAIL ("X coordinate of child window should be %d, not %d", child_attributes.x, child_x, NULL);
    
    if (child_attributes.y != child_y)
        TEST_FAIL ("Y coordinate should of child window be %d, not %d", child_attributes.y, child_y, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_position
 * Params: GdkWindow *window, gint *x, gint *y
 * Returns: void
 * Assertion: Obtains the position of the window as reported in the most-recently-processed GdkEventConfigure. Contrast with gdk_window_get_geometry() which queries the X server for the current window position, regardless of which events have been received or processed. The position coordinates are relative to the window's parent window.
 * Params Values: a GdkWindow, X coordinate of window, Y coordinate of window
 * Expected: void  
 */
static void test_purpose_20()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 32767, 0, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 0, 32767, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint child_x;
    gint child_y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_position (child_window, &child_x, &child_y);
    
    if (child_attributes.x != child_x)
        TEST_FAIL ("X coordinate of child window should be %d, not %d", child_attributes.x, child_x, NULL);
    
    if (child_attributes.y != child_y)
        TEST_FAIL ("Y coordinate should of child window be %d, not %d", child_attributes.y, child_y, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_geometry
 * Params: GdkWindow *window, gint *x, gint *y, gint *width, gint *height, gint *depth
 * Returns: void
 * Assertion: Any of the return location arguments to this function may be NULL, if you aren't interested in getting the value of that field. The X and Y coordinates returned are relative to the parent window of window, which for toplevels usually means relative to the window decorations (titlebar, etc.) rather than relative to the root window (screen-size background window). On the X11 platform, the geometry is obtained from the X server, so reflects the latest position of window; this may be out-of-sync with the position of window delivered in the most-recently-processed GdkEventConfigure. gdk_window_get_position() in contrast gets the position from the most recent configure event.
 * Params Values: a GdkWindow, return location for X coordinate of window (relative to its parent), return location for Y coordinate of window (relative to its parent), return location for width of window, return location for height of window, return location for bit depth of window
 * Expected: void  
 */
static void test_purpose_21()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 1, 2, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 9, 8, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint child_x;
    gint child_y;
    gint width;
    gint height;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_geometry (child_window, &child_x, &child_y, &width, &height, NULL);
    
    if (child_attributes.x != child_x)
        TEST_FAIL ("X coordinate of child window should be %d, not %d", child_attributes.x, child_x, NULL);
    
    if (child_attributes.y != child_y)
        TEST_FAIL ("Y coordinate should of child window be %d, not %d", child_attributes.y, child_y, NULL);
    
    if (child_attributes.width != width)
        TEST_FAIL ("width of window should be %d, not %d", child_attributes.width, width, NULL);
    
    if (child_attributes.height != height)
        TEST_FAIL ("height of window should be %d, not %d", child_attributes.height, height, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_geometry
 * Params: GdkWindow *window, gint *x, gint *y, gint *width, gint *height, gint *depth
 * Returns: void
 * Assertion: Any of the return location arguments to this function may be NULL, if you aren't interested in getting the value of that field. The X and Y coordinates returned are relative to the parent window of window, which for toplevels usually means relative to the window decorations (titlebar, etc.) rather than relative to the root window (screen-size background window). On the X11 platform, the geometry is obtained from the X server, so reflects the latest position of window; this may be out-of-sync with the position of window delivered in the most-recently-processed GdkEventConfigure. gdk_window_get_position() in contrast gets the position from the most recent configure event.
 * Params Values: a GdkWindow, return location for X coordinate of window (relative to its parent), return location for Y coordinate of window (relative to its parent), return location for width of window, return location for height of window, return location for bit depth of window
 * Expected: void  
 */
static void test_purpose_22()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 23, 34, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 77, 66, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint child_x;
    gint child_y;
    gint width;
    gint height;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_geometry (child_window, &child_x, &child_y, &width, &height, NULL);
    
    if (child_attributes.x != child_x)
        TEST_FAIL ("X coordinate of child window should be %d, not %d", child_attributes.x, child_x, NULL);
    
    if (child_attributes.y != child_y)
        TEST_FAIL ("Y coordinate should of child window be %d, not %d", child_attributes.y, child_y, NULL);
    
    if (child_attributes.width != width)
        TEST_FAIL ("width of window should be %d, not %d", child_attributes.width, width, NULL);
    
    if (child_attributes.height != height)
        TEST_FAIL ("height of window should be %d, not %d", child_attributes.height, height, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_geometry
 * Params: GdkWindow *window, gint *x, gint *y, gint *width, gint *height, gint *depth
 * Returns: void
 * Assertion: Any of the return location arguments to this function may be NULL, if you aren't interested in getting the value of that field. The X and Y coordinates returned are relative to the parent window of window, which for toplevels usually means relative to the window decorations (titlebar, etc.) rather than relative to the root window (screen-size background window). On the X11 platform, the geometry is obtained from the X server, so reflects the latest position of window; this may be out-of-sync with the position of window delivered in the most-recently-processed GdkEventConfigure. gdk_window_get_position() in contrast gets the position from the most recent configure event.
 * Params Values: a GdkWindow, return location for X coordinate of window (relative to its parent), return location for Y coordinate of window (relative to its parent), return location for width of window, return location for height of window, return location for bit depth of window
 * Expected: void  
 */
static void test_purpose_23()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 123, 456, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 789, 654, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint child_x;
    gint child_y;
    gint width;
    gint height;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_geometry (child_window, &child_x, &child_y, &width, &height, NULL);
    
    if (child_attributes.x != child_x)
        TEST_FAIL ("X coordinate of child window should be %d, not %d", child_attributes.x, child_x, NULL);
    
    if (child_attributes.y != child_y)
        TEST_FAIL ("Y coordinate should of child window be %d, not %d", child_attributes.y, child_y, NULL);
    
    if (child_attributes.width != width)
        TEST_FAIL ("width of window should be %d, not %d", child_attributes.width, width, NULL);
    
    if (child_attributes.height != height)
        TEST_FAIL ("height of window should be %d, not %d", child_attributes.height, height, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_geometry
 * Params: GdkWindow *window, gint *x, gint *y, gint *width, gint *height, gint *depth
 * Returns: void
 * Assertion: Any of the return location arguments to this function may be NULL, if you aren't interested in getting the value of that field. The X and Y coordinates returned are relative to the parent window of window, which for toplevels usually means relative to the window decorations (titlebar, etc.) rather than relative to the root window (screen-size background window). On the X11 platform, the geometry is obtained from the X server, so reflects the latest position of window; this may be out-of-sync with the position of window delivered in the most-recently-processed GdkEventConfigure. gdk_window_get_position() in contrast gets the position from the most recent configure event.
 * Params Values: a GdkWindow, return location for X coordinate of window (relative to its parent), return location for Y coordinate of window (relative to its parent), return location for width of window, return location for height of window, return location for bit depth of window
 * Expected: void  
 */
static void test_purpose_24()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 32767, 0, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 0, 32767, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint child_x;
    gint child_y;
    gint width;
    gint height;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_get_geometry (child_window, &child_x, &child_y, &width, &height, NULL);
    
    if (child_attributes.x != child_x)
        TEST_FAIL ("X coordinate of child window should be %d, not %d", child_attributes.x, child_x, NULL);
    
    if (child_attributes.y != child_y)
        TEST_FAIL ("Y coordinate should of child window be %d, not %d", child_attributes.y, child_y, NULL);
    
    if (child_attributes.width != width)
        TEST_FAIL ("width of window should be %d, not %d", child_attributes.width, width, NULL);
    
    if (child_attributes.height != height)
        TEST_FAIL ("height of window should be %d, not %d", child_attributes.height, height, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_parent
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Obtains the parent of window, as known to GDK. Does not query the X server; thus this returns the parent as passed to gdk_window_new(), not the actual parent. This should never matter unless you're using Xlib calls mixed with GDK calls on the X11 platform. It may also matter for toplevel windows, because the window manager may choose to reparent them.
 * Params Values: a GdkWindow
 * Expected: parent of window  
 */
static void test_purpose_25()
{
    #define PARENT NULL
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y
    
    GdkWindow *window;
    GdkWindow *parent;
    GdkWindowAttr attributes = ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (PARENT, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    parent = gdk_window_get_parent (window);
    
    if (gdk_window_get_window_type (parent) != GDK_WINDOW_ROOT)
        TEST_FAIL ("parent window should be root window", NULL);
    
    gdk_window_destroy (window);
    
    #undef PARENT
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_parent
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Obtains the parent of window, as known to GDK. Does not query the X server; thus this returns the parent as passed to gdk_window_new(), not the actual parent. This should never matter unless you're using Xlib calls mixed with GDK calls on the X11 platform. It may also matter for toplevel windows, because the window manager may choose to reparent them.
 * Params Values: a GdkWindow
 * Expected: parent of window  
 */
static void test_purpose_26()
{
    #define PARENT NULL
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_X
    
    GdkWindow *window;
    GdkWindow *parent;
    GdkWindowAttr attributes = ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (PARENT, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    parent = gdk_window_get_parent (window);
    
    if (gdk_window_get_window_type (parent) != GDK_WINDOW_ROOT)
        TEST_FAIL ("parent window should be root window", NULL);
    
    gdk_window_destroy (window);
    
    #undef PARENT
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_parent
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Obtains the parent of window, as known to GDK. Does not query the X server; thus this returns the parent as passed to gdk_window_new(), not the actual parent. This should never matter unless you're using Xlib calls mixed with GDK calls on the X11 platform. It may also matter for toplevel windows, because the window manager may choose to reparent them.
 * Params Values: a GdkWindow
 * Expected: parent of window  
 */
static void test_purpose_27()
{
    #define PARENT NULL
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE | GDK_WA_Y
    
    GdkWindow *window;
    GdkWindow *parent;
    GdkWindowAttr attributes = ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (PARENT, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    parent = gdk_window_get_parent (window);
    
    if (gdk_window_get_window_type (parent) != GDK_WINDOW_ROOT)
        TEST_FAIL ("parent window should be root window", NULL);
    
    gdk_window_destroy (window);
    
    #undef PARENT
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_parent
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Obtains the parent of window, as known to GDK. Does not query the X server; thus this returns the parent as passed to gdk_window_new(), not the actual parent. This should never matter unless you're using Xlib calls mixed with GDK calls on the X11 platform. It may also matter for toplevel windows, because the window manager may choose to reparent them.
 * Params Values: a GdkWindow
 * Expected: parent of window  
 */
static void test_purpose_28()
{
    #define PARENT NULL
    #define ATTRIBUTES {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES_MASK GDK_WA_TITLE
    
    GdkWindow *window;
    GdkWindow *parent;
    GdkWindowAttr attributes = ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (PARENT, &attributes, ATTRIBUTES_MASK);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    parent = gdk_window_get_parent (window);
    
    if (gdk_window_get_window_type (parent) != GDK_WINDOW_ROOT)
        TEST_FAIL ("parent window should be root window", NULL);
    
    gdk_window_destroy (window);
    
    #undef PARENT
    #undef ATTRIBUTES
    #undef ATTRIBUTES_MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_parent
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Obtains the parent of window, as known to GDK. Does not query the X server; thus this returns the parent as passed to gdk_window_new(), not the actual parent. This should never matter unless you're using Xlib calls mixed with GDK calls on the X11 platform. It may also matter for toplevel windows, because the window manager may choose to reparent them.
 * Params Values: a GdkWindow
 * Expected: parent of window  
 */
static void test_purpose_29()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 1, 2, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 9, 8, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindow *parent;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    parent = gdk_window_get_parent (child_window);
    
    if (gdk_window_get_window_type (parent) != GDK_WINDOW_TOPLEVEL)
        TEST_FAIL ("parent window should be toplevel window", NULL);
    
    if (parent != parent_window)
        TEST_FAIL ("parent window should be %p, not %p", parent_window, parent, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_parent
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Obtains the parent of window, as known to GDK. Does not query the X server; thus this returns the parent as passed to gdk_window_new(), not the actual parent. This should never matter unless you're using Xlib calls mixed with GDK calls on the X11 platform. It may also matter for toplevel windows, because the window manager may choose to reparent them.
 * Params Values: a GdkWindow
 * Expected: parent of window  
 */
static void test_purpose_30()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 23, 34, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 77, 66, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindow *parent;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    parent = gdk_window_get_parent (child_window);
    
    if (gdk_window_get_window_type (parent) != GDK_WINDOW_TOPLEVEL)
        TEST_FAIL ("parent window should be toplevel window", NULL);
    
    if (parent != parent_window)
        TEST_FAIL ("parent window should be %p, not %p", parent_window, parent, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_parent
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Obtains the parent of window, as known to GDK. Does not query the X server; thus this returns the parent as passed to gdk_window_new(), not the actual parent. This should never matter unless you're using Xlib calls mixed with GDK calls on the X11 platform. It may also matter for toplevel windows, because the window manager may choose to reparent them.
 * Params Values: a GdkWindow
 * Expected: parent of window  
 */
static void test_purpose_31()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 123, 456, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 789, 654, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindow *parent;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    parent = gdk_window_get_parent (child_window);
    
    if (gdk_window_get_window_type (parent) != GDK_WINDOW_TOPLEVEL)
        TEST_FAIL ("parent window should be toplevel window", NULL);
    
    if (parent != parent_window)
        TEST_FAIL ("parent window should be %p, not %p", parent_window, parent, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_parent
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Obtains the parent of window, as known to GDK. Does not query the X server; thus this returns the parent as passed to gdk_window_new(), not the actual parent. This should never matter unless you're using Xlib calls mixed with GDK calls on the X11 platform. It may also matter for toplevel windows, because the window manager may choose to reparent them.
 * Params Values: a GdkWindow
 * Expected: parent of window  
 */
static void test_purpose_32()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 32767, 0, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 0, 32767, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindow *parent;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    parent = gdk_window_get_parent (child_window);
    
    if (gdk_window_get_window_type (parent) != GDK_WINDOW_TOPLEVEL)
        TEST_FAIL ("parent window should be toplevel window", NULL);
    
    if (parent != parent_window)
        TEST_FAIL ("parent window should be %p, not %p", parent_window, parent, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_set_user_data 
 * Params: GdkWindow *window, gpointer user_data
 * Returns: void
 * Assertion: For most purposes this function is deprecated in favor of g_object_set_data(). However, for historical reasons GTK+ stores the GtkWidget that owns a GdkWindow as user data on the GdkWindow. So, custom widget implementations should use this function for that. If GTK+ receives an event for a GdkWindow, and the user data for the window is non-NULL, GTK+ will assume the user data is a GtkWidget, and forward the event to that widget.
 * Params Values: a GdkWindow, user data
 * Expected: void  
 */
static void test_purpose_33()
{
    #define USER_DATA NULL
    
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    gpointer user_data1 = USER_DATA;
    gpointer user_data2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_set_user_data (window, user_data1);
    
    gdk_window_get_user_data (window, &user_data2);
    
    if (user_data1 != user_data2)
        TEST_FAIL ("user data should be %p, not %p", user_data1, user_data2, NULL);
    
    gdk_window_destroy (window);
    
    #undef USER_DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_set_user_data 
 * Params: GdkWindow *window, gpointer user_data
 * Returns: void
 * Assertion: For most purposes this function is deprecated in favor of g_object_set_data(). However, for historical reasons GTK+ stores the GtkWidget that owns a GdkWindow as user data on the GdkWindow. So, custom widget implementations should use this function for that. If GTK+ receives an event for a GdkWindow, and the user data for the window is non-NULL, GTK+ will assume the user data is a GtkWidget, and forward the event to that widget.
 * Params Values: a GdkWindow, user data
 * Expected: void  
 */
static void test_purpose_34()
{
    #define USER_DATA gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    gpointer user_data1 = USER_DATA;
    gpointer user_data2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_set_user_data (window, user_data1);
    
    gdk_window_get_user_data (window, &user_data2);
    
    if (user_data1 != user_data2)
        TEST_FAIL ("user data should be %p, not %p", user_data1, user_data2, NULL);
    
    gdk_window_destroy (window);
    
    #undef USER_DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_set_user_data 
 * Params: GdkWindow *window, gpointer user_data
 * Returns: void
 * Assertion: For most purposes this function is deprecated in favor of g_object_set_data(). However, for historical reasons GTK+ stores the GtkWidget that owns a GdkWindow as user data on the GdkWindow. So, custom widget implementations should use this function for that. If GTK+ receives an event for a GdkWindow, and the user data for the window is non-NULL, GTK+ will assume the user data is a GtkWidget, and forward the event to that widget.
 * Params Values: a GdkWindow, user data
 * Expected: void  
 */
static void test_purpose_35()
{
    #define USER_DATA gtk_button_new ();
    
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    gpointer user_data1 = USER_DATA;
    gpointer user_data2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_set_user_data (window, user_data1);
    
    gdk_window_get_user_data (window, &user_data2);
    
    if (user_data1 != user_data2)
        TEST_FAIL ("user data should be %p, not %p", user_data1, user_data2, NULL);
    
    gdk_window_destroy (window);
    
    #undef USER_DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_set_user_data 
 * Params: GdkWindow *window, gpointer user_data
 * Returns: void
 * Assertion: For most purposes this function is deprecated in favor of g_object_set_data(). However, for historical reasons GTK+ stores the GtkWidget that owns a GdkWindow as user data on the GdkWindow. So, custom widget implementations should use this function for that. If GTK+ receives an event for a GdkWindow, and the user data for the window is non-NULL, GTK+ will assume the user data is a GtkWidget, and forward the event to that widget.
 * Params Values: a GdkWindow, user data
 * Expected: void  
 */
static void test_purpose_36()
{
    #define USER_DATA g_list_append (NULL, "first");
    
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    gpointer user_data1 = USER_DATA;
    gpointer user_data2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_set_user_data (window, user_data1);
    
    gdk_window_get_user_data (window, &user_data2);
    
    if (user_data1 != user_data2)
        TEST_FAIL ("user data should be %p, not %p", user_data1, user_data2, NULL);
    
    gdk_window_destroy (window);
    
    #undef USER_DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_user_data
 * Params: GdkWindow *window, gpointer *data
 * Returns: void
 * Assertion: Retrieves the user data for window, which is normally the widget that window belongs to.
 * Params Values: a GdkWindow, return location for user data
 * Expected: void  
 */
static void test_purpose_37()
{
    #define USER_DATA NULL
    
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    gpointer user_data1 = USER_DATA;
    gpointer user_data2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_set_user_data (window, user_data1);
    
    gdk_window_get_user_data (window, &user_data2);
    
    if (user_data1 != user_data2)
        TEST_FAIL ("user data should be %p, not %p", user_data1, user_data2, NULL);
    
    gdk_window_destroy (window);
    
    #undef USER_DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_user_data
 * Params: GdkWindow *window, gpointer *data
 * Returns: void
 * Assertion: Retrieves the user data for window, which is normally the widget that window belongs to.
 * Params Values: a GdkWindow, return location for user data
 * Expected: void  
 */
static void test_purpose_38()
{
    #define USER_DATA gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    gpointer user_data1 = USER_DATA;
    gpointer user_data2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_set_user_data (window, user_data1);
    
    gdk_window_get_user_data (window, &user_data2);
    
    if (user_data1 != user_data2)
        TEST_FAIL ("user data should be %p, not %p", user_data1, user_data2, NULL);
    
    gdk_window_destroy (window);
    
    #undef USER_DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_user_data
 * Params: GdkWindow *window, gpointer *data
 * Returns: void
 * Assertion: Retrieves the user data for window, which is normally the widget that window belongs to.
 * Params Values: a GdkWindow, return location for user data
 * Expected: void  
 */
static void test_purpose_39()
{
    #define USER_DATA gtk_button_new ();
    
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    gpointer user_data1 = USER_DATA;
    gpointer user_data2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_set_user_data (window, user_data1);
    
    gdk_window_get_user_data (window, &user_data2);
    
    if (user_data1 != user_data2)
        TEST_FAIL ("user data should be %p, not %p", user_data1, user_data2, NULL);
    
    gdk_window_destroy (window);
    
    #undef USER_DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_user_data
 * Params: GdkWindow *window, gpointer *data
 * Returns: void
 * Assertion: Retrieves the user data for window, which is normally the widget that window belongs to.
 * Params Values: a GdkWindow, return location for user data
 * Expected: void  
 */
static void test_purpose_40()
{
    #define USER_DATA g_list_append (NULL, "first");
    
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    gpointer user_data1 = USER_DATA;
    gpointer user_data2;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_set_user_data (window, user_data1);
    
    gdk_window_get_user_data (window, &user_data2);
    
    if (user_data1 != user_data2)
        TEST_FAIL ("user data should be %p, not %p", user_data1, user_data2, NULL);
    
    gdk_window_destroy (window);
    
    #undef USER_DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_iconify
 * Params: GdkWindow *window
 * Returns: void
 * Assertion: Asks to iconify (minimize) window. The window manager may choose to ignore the request, but normally will honor it. Using gtk_window_iconify() is preferred, if you have a GtkWindow widget. This function only makes sense when window is a toplevel window.
 * Params Values: a toplevel GdkWindow
 * Expected: void  
 */
static void test_purpose_41()
{
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    GdkWindowState window_state;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_iconify (window);
    
    window_state = gdk_window_get_state (window);
    
    if (!(window_state & GDK_WINDOW_STATE_ICONIFIED))
        TEST_FAIL ("window wasn't iconified", NULL);
    
    gdk_window_destroy (window);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_withdraw
 * Params: GdkWindow *window
 * Returns: void
 * Assertion: Withdraws a window (unmaps it and asks the window manager to forget about it). This function is not really useful as gdk_window_hide() automatically withdraws toplevel windows before hiding them.
 * Params Values: a toplevel GdkWindow
 * Expected: void  
 */
static void test_purpose_42()
{
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    GdkWindowState window_state;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_withdraw (window);
    
    window_state = gdk_window_get_state (window);
    
    if (!(window_state & GDK_WINDOW_STATE_WITHDRAWN))
        TEST_FAIL ("window wasn't withdrawn", NULL);
    
    gdk_window_destroy (window);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_hide
 * Params: GdkWindow *window
 * Returns: void
 * Assertion: For toplevel windows, withdraws them, so they will no longer be known to the window manager; for all windows, unmaps them, so they won't be displayed. Normally done automatically as part of gtk_widget_hide().
 * Params Values: a GdkWindow
 * Expected: void  
 */
static void test_purpose_43()
{
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    GdkWindowState window_state;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_hide (window);
    
    window_state = gdk_window_get_state (window);
    
    if (!(window_state & GDK_WINDOW_STATE_WITHDRAWN))
        TEST_FAIL ("window wasn't withdrawn", NULL);
    
    gdk_window_destroy (window);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_show
 * Params: GdkWindow *window
 * Returns: void
 * Assertion: Like gdk_window_show_unraised(), but also raises the window to the top of the window stack (moves the window to the front of the Z-order). This function maps a window so it is visible onscreen. Its opposite is gdk_window_hide(). When implementing a GtkWidget, you should call this function on the widget's GdkWindow as part of the "map" method.
 * Params Values: a GdkWindow
 * Expected: void  
 */
static void test_purpose_44()
{
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    GdkWindowState window_state;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_show (window);
    
    window_state = gdk_window_get_state (window);
    
    if (window_state & GDK_WINDOW_STATE_WITHDRAWN)
        TEST_FAIL ("the window is not shown", NULL);
    
    if (!gdk_window_is_visible (window))
        TEST_FAIL ("the window is invisible", NULL);
    
    gdk_window_destroy (window);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_is_visible
 * Params: GdkWindow *window
 * Returns: gboolean
 * Assertion: Checks whether the window has been mapped (with gdk_window_show() or gdk_window_show_unraised()).
 * Params Values: a GdkWindow
 * Expected: TRUE if the window is mapped  
 */
static void test_purpose_45()
{
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_window_is_visible (window))
        TEST_FAIL ("the window is visible before shown", NULL);
    
    gdk_window_show (window);
    
    if (!gdk_window_is_visible (window))
        TEST_FAIL ("the window is invisible after shown", NULL);
    
    gdk_window_hide (window);
    
    if (gdk_window_is_visible (window))
        TEST_FAIL ("the window is visible after being hidden", NULL);
    
    gdk_window_show_unraised (window);
    
    if (!gdk_window_is_visible (window))
        TEST_FAIL ("the window is invisible after being unraised", NULL);
    
    gdk_window_destroy (window);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_state
 * Params: GdkWindow *window
 * Returns: GdkWindowState
 * Assertion: Gets the bitwise OR of the currently active window state flags, from the GdkWindowState enumeration.
 * Params Values: a GdkWindow
 * Expected: window state bitfield  
 */
static void test_purpose_46()
{
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    GdkWindowState window_state;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_iconify (window);
    
    window_state = gdk_window_get_state (window);
    
    if (!(window_state & GDK_WINDOW_STATE_ICONIFIED))
        TEST_FAIL ("the bitfield GDK_WINDOW_STATE_ICONIFIED is off after window is iconified", NULL);
    
    gdk_window_deiconify (window);
    
    window_state = gdk_window_get_state (window);
    
    if (window_state & GDK_WINDOW_STATE_ICONIFIED)
        TEST_FAIL ("the bitfield GDK_WINDOW_STATE_ICONIFIED is on after window is deiconified", NULL);
    
    gdk_window_maximize (window);
    
    window_state = gdk_window_get_state (window);
    
    if (!(window_state & GDK_WINDOW_STATE_MAXIMIZED))
        TEST_FAIL ("the bitfield GDK_WINDOW_STATE_MAXIMIZED is off after window is maximized", NULL);
    
    gdk_window_unmaximize (window);
    
    window_state = gdk_window_get_state (window);
    
    if (window_state & GDK_WINDOW_STATE_MAXIMIZED)
        TEST_FAIL ("the bitfield GDK_WINDOW_STATE_MAXIMIZED is on after window is unmaximized", NULL);
    
    gdk_window_stick (window);
    
    window_state = gdk_window_get_state (window);
    
    if (!(window_state & GDK_WINDOW_STATE_STICKY))
        TEST_FAIL ("the bitfield GDK_WINDOW_STATE_STICKY is off after window is sticked", NULL);
    
    gdk_window_unstick (window);
    
    window_state = gdk_window_get_state (window);
    
    if (window_state & GDK_WINDOW_STATE_STICKY)
        TEST_FAIL ("the bitfield GDK_WINDOW_STATE_MAXIMIZED is on after window is unsticked", NULL);
    
    gdk_window_fullscreen (window);
    
    window_state = gdk_window_get_state (window);
    
    if (!(window_state & GDK_WINDOW_STATE_FULLSCREEN))
        TEST_FAIL ("the bitfield GDK_WINDOW_STATE_STICKY is off after window is sticked", NULL);
    
    gdk_window_unfullscreen (window);
    
    window_state = gdk_window_get_state (window);
    
    if (window_state & GDK_WINDOW_STATE_FULLSCREEN)
        TEST_FAIL ("the bitfield GDK_WINDOW_STATE_MAXIMIZED is on after window is unsticked", NULL);
    
    window_state = gdk_window_get_state (window);
    
    if (!(window_state & GDK_WINDOW_STATE_WITHDRAWN))
        TEST_FAIL ("the bitfield GDK_WINDOW_STATE_WITHDRAWN is on before window is shown", NULL);
    
    gdk_window_show (window);
    
    window_state = gdk_window_get_state (window);
    
    if (window_state & GDK_WINDOW_STATE_WITHDRAWN)
        TEST_FAIL ("the bitfield GDK_WINDOW_STATE_WITHDRAWN is off after window is shown", NULL);
    
    gdk_window_destroy (window);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_set_events 
 * Params: GdkWindow *window, GdkEventMask event_mask
 * Returns: void
 * Assertion: The event mask for a window determines which events will be reported for that window. For example, an event mask including GDK_BUTTON_PRESS_MASK means the window should report button press events. The event mask is the bitwise OR of values from the GdkEventMask enumeration.
 * Params Values: a GdkWindow, event mask for window
 * Expected: void  
 */
static void test_purpose_47()
{
    #define EVENT_MASK GDK_BUTTON_PRESS_MASK
    
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    GdkEventMask event_mask;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_input_set_extension_events (window, GDK_PROXIMITY_IN_MASK | GDK_PROXIMITY_OUT_MASK, GDK_EXTENSION_EVENTS_ALL);
    
    gdk_window_set_events (window, EVENT_MASK);
    
    event_mask = gdk_window_get_events (window);
    
    if ((event_mask & EVENT_MASK) == 0) {
        TEST_FAIL ("event_mask should be %x, not %x", EVENT_MASK, event_mask, NULL);
    }
    
    gdk_window_destroy (window);
    
    #undef EVENT_MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_set_events 
 * Params: GdkWindow *window, GdkEventMask event_mask
 * Returns: void
 * Assertion: The event mask for a window determines which events will be reported for that window. For example, an event mask including GDK_BUTTON_PRESS_MASK means the window should report button press events. The event mask is the bitwise OR of values from the GdkEventMask enumeration.
 * Params Values: a GdkWindow, event mask for window
 * Expected: void  
 */
static void test_purpose_48()
{
    #define EVENT_MASK GDK_KEY_PRESS_MASK
    
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    GdkEventMask event_mask;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_input_set_extension_events (window, GDK_PROXIMITY_IN_MASK | GDK_PROXIMITY_OUT_MASK, GDK_EXTENSION_EVENTS_ALL);
    
    gdk_window_set_events (window, EVENT_MASK);
    
    event_mask = gdk_window_get_events (window);
    
    if ((event_mask & EVENT_MASK) == 0) {
        TEST_FAIL ("event_mask should be %x, not %x", EVENT_MASK, event_mask, NULL);
    }
    
    gdk_window_destroy (window);
    
    #undef EVENT_MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_set_events 
 * Params: GdkWindow *window, GdkEventMask event_mask
 * Returns: void
 * Assertion: The event mask for a window determines which events will be reported for that window. For example, an event mask including GDK_BUTTON_PRESS_MASK means the window should report button press events. The event mask is the bitwise OR of values from the GdkEventMask enumeration.
 * Params Values: a GdkWindow, event mask for window
 * Expected: void  
 */
static void test_purpose_49()
{
    #define EVENT_MASK GDK_BUTTON_RELEASE_MASK
    
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    GdkEventMask event_mask;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_input_set_extension_events (window, GDK_PROXIMITY_IN_MASK | GDK_PROXIMITY_OUT_MASK, GDK_EXTENSION_EVENTS_ALL);
    
    gdk_window_set_events (window, EVENT_MASK);
    
    event_mask = gdk_window_get_events (window);
    
    if ((event_mask & EVENT_MASK) == 0) {
        TEST_FAIL ("event_mask should be %x, not %x", EVENT_MASK, event_mask, NULL);
    }
    
    gdk_window_destroy (window);
    
    #undef EVENT_MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_set_events 
 * Params: GdkWindow *window, GdkEventMask event_mask
 * Returns: void
 * Assertion: The event mask for a window determines which events will be reported for that window. For example, an event mask including GDK_BUTTON_PRESS_MASK means the window should report button press events. The event mask is the bitwise OR of values from the GdkEventMask enumeration.
 * Params Values: a GdkWindow, event mask for window
 * Expected: void  
 */
static void test_purpose_50()
{
    #define EVENT_MASK GDK_KEY_RELEASE_MASK
    
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    GdkEventMask event_mask;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_input_set_extension_events (window, GDK_PROXIMITY_IN_MASK | GDK_PROXIMITY_OUT_MASK, GDK_EXTENSION_EVENTS_ALL);
    
    gdk_window_set_events (window, EVENT_MASK);
    
    event_mask = gdk_window_get_events (window);
    
    if ((event_mask & EVENT_MASK) == 0) {
        TEST_FAIL ("event_mask should be %x, not %x", EVENT_MASK, event_mask, NULL);
    }
    
    gdk_window_destroy (window);
    
    #undef EVENT_MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_set_events 
 * Params: GdkWindow *window, GdkEventMask event_mask
 * Returns: void
 * Assertion: The event mask for a window determines which events will be reported for that window. For example, an event mask including GDK_BUTTON_PRESS_MASK means the window should report button press events. The event mask is the bitwise OR of values from the GdkEventMask enumeration.
 * Params Values: a GdkWindow, event mask for window
 * Expected: void  
 */
static void test_purpose_51()
{
    #define EVENT_MASK GDK_BUTTON_MOTION_MASK
    
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    GdkEventMask event_mask;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_input_set_extension_events (window, GDK_PROXIMITY_IN_MASK | GDK_PROXIMITY_OUT_MASK, GDK_EXTENSION_EVENTS_ALL);
    
    gdk_window_set_events (window, EVENT_MASK);
    
    event_mask = gdk_window_get_events (window);
    
    if ((event_mask & EVENT_MASK) == 0) {
        TEST_FAIL ("event_mask should be %x, not %x", EVENT_MASK, event_mask, NULL);
    }
    
    gdk_window_destroy (window);
    
    #undef EVENT_MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_set_events 
 * Params: GdkWindow *window, GdkEventMask event_mask
 * Returns: void
 * Assertion: The event mask for a window determines which events will be reported for that window. For example, an event mask including GDK_BUTTON_PRESS_MASK means the window should report button press events. The event mask is the bitwise OR of values from the GdkEventMask enumeration.
 * Params Values: a GdkWindow, event mask for window
 * Expected: void  
 */
static void test_purpose_52()
{
    #define EVENT_MASK GDK_POINTER_MOTION_MASK
    
    GdkWindow *window;
    GdkWindowAttr attributes = {"foo", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE};
    GdkEventMask event_mask;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gdk_window_new (NULL, &attributes, GDK_WA_TITLE | GDK_WA_X | GDK_WA_Y);
    
    if (!window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_input_set_extension_events (window, GDK_PROXIMITY_IN_MASK | GDK_PROXIMITY_OUT_MASK, GDK_EXTENSION_EVENTS_ALL);
    
    gdk_window_set_events (window, EVENT_MASK);
    
    event_mask = gdk_window_get_events (window);
    
    if ((event_mask & EVENT_MASK) == 0) {
        TEST_FAIL ("event_mask should be %x, not %x", EVENT_MASK, event_mask, NULL);
    }
    
    gdk_window_destroy (window);
    
    #undef EVENT_MASK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_toplevel
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Gets the toplevel window that's an ancestor of window.
 * Params Values: a GdkWindow
 * Expected: the toplevel window containing window  
 */
static void test_purpose_53()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 1, 2, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 9, 8, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindow *toplevel_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    toplevel_window = gdk_window_get_toplevel (child_window);
    
    if (toplevel_window != parent_window)
        TEST_FAIL ("toplevel window should be %p, not %p", parent_window, toplevel_window, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_toplevel
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Gets the toplevel window that's an ancestor of window.
 * Params Values: a GdkWindow
 * Expected: the toplevel window containing window  
 */
static void test_purpose_54()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 23, 34, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 77, 66, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindow *toplevel_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    toplevel_window = gdk_window_get_toplevel (child_window);
    
    if (toplevel_window != parent_window)
        TEST_FAIL ("toplevel window should be %p, not %p", parent_window, toplevel_window, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_toplevel
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Gets the toplevel window that's an ancestor of window.
 * Params Values: a GdkWindow
 * Expected: the toplevel window containing window  
 */
static void test_purpose_55()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 123, 456, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 789, 654, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindow *toplevel_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    toplevel_window = gdk_window_get_toplevel (child_window);
    
    if (toplevel_window != parent_window)
        TEST_FAIL ("toplevel window should be %p, not %p", parent_window, toplevel_window, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_toplevel
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Gets the toplevel window that's an ancestor of window.
 * Params Values: a GdkWindow
 * Expected: the toplevel window containing window  
 */
static void test_purpose_56()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 32767, 0, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"foo", 0, 0, 32767, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindow *toplevel_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    toplevel_window = gdk_window_get_toplevel (child_window);
    
    if (toplevel_window != parent_window)
        TEST_FAIL ("toplevel window should be %p, not %p", parent_window, toplevel_window, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_toplevel
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Gets the toplevel window that's an ancestor of window.
 * Params Values: a GdkWindow
 * Expected: the toplevel window containing window  
 */
static void test_purpose_57()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 1, 2, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 9, 8, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define GRANDCHILD_ATTRIBUTES {"grandchild", 0, 1, 1, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindow *grandchild_window;
    GdkWindow *toplevel_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    GdkWindowAttr grandchild_attributes = GRANDCHILD_ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    grandchild_window = gdk_window_new (child_window, &grandchild_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!grandchild_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (grandchild_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    toplevel_window = gdk_window_get_toplevel (grandchild_window);
    
    if (toplevel_window != parent_window)
        TEST_FAIL ("toplevel window should be %p, not %p", parent_window, toplevel_window, NULL);
    
    gdk_window_destroy (grandchild_window);
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef GRANDCHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_toplevel
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Gets the toplevel window that's an ancestor of window.
 * Params Values: a GdkWindow
 * Expected: the toplevel window containing window  
 */
static void test_purpose_58()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 23, 34, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 77, 66, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define GRANDCHILD_ATTRIBUTES {"grandchild", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindow *grandchild_window;
    GdkWindow *toplevel_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    GdkWindowAttr grandchild_attributes = GRANDCHILD_ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    grandchild_window = gdk_window_new (child_window, &grandchild_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!grandchild_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (grandchild_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    toplevel_window = gdk_window_get_toplevel (grandchild_window);
    
    if (toplevel_window != parent_window)
        TEST_FAIL ("toplevel window should be %p, not %p", parent_window, toplevel_window, NULL);
    
    gdk_window_destroy (grandchild_window);
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef GRANDCHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_toplevel
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Gets the toplevel window that's an ancestor of window.
 * Params Values: a GdkWindow
 * Expected: the toplevel window containing window  
 */
static void test_purpose_59()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 123, 456, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 789, 654, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define GRANDCHILD_ATTRIBUTES {"grandchild", 0, 100, 100, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindow *grandchild_window;
    GdkWindow *toplevel_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    GdkWindowAttr grandchild_attributes = GRANDCHILD_ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    grandchild_window = gdk_window_new (child_window, &grandchild_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!grandchild_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (grandchild_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    toplevel_window = gdk_window_get_toplevel (grandchild_window);
    
    if (toplevel_window != parent_window)
        TEST_FAIL ("toplevel window should be %p, not %p", parent_window, toplevel_window, NULL);
    
    gdk_window_destroy (grandchild_window);
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef GRANDCHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_get_toplevel
 * Params: GdkWindow *window
 * Returns: GdkWindow*
 * Assertion: Gets the toplevel window that's an ancestor of window.
 * Params Values: a GdkWindow
 * Expected: the toplevel window containing window  
 */
static void test_purpose_60()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 32767, 0, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 0, 32767, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define GRANDCHILD_ATTRIBUTES {"grandchild", 0, 1000, 1000, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindow *grandchild_window;
    GdkWindow *toplevel_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    GdkWindowAttr grandchild_attributes = GRANDCHILD_ATTRIBUTES;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    grandchild_window = gdk_window_new (child_window, &grandchild_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!grandchild_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (grandchild_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    toplevel_window = gdk_window_get_toplevel (grandchild_window);
    
    if (toplevel_window != parent_window)
        TEST_FAIL ("toplevel window should be %p, not %p", parent_window, toplevel_window, NULL);
    
    gdk_window_destroy (grandchild_window);
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef GRANDCHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_peek_children
 * Params: GdkWindow *window
 * Returns: GList*
 * Assertion: Like gdk_window_get_children(), but does not copy the list of children, so the list does not need to be freed.
 * Params Values: a GdkWindow
 * Expected: list of child windows inside window   
 */
static void test_purpose_61()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 1, 2, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define NUM_OF_CHILDREN 1
    #define CHILD_ATTRIBUTES {{"child", 0, 9, 8, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}}
    
    GdkWindow *parent_window;
    GdkWindow *child_window[NUM_OF_CHILDREN];
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes[NUM_OF_CHILDREN] = CHILD_ATTRIBUTES;
    int i;
    GList *list = NULL;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    for (i = 0; i < NUM_OF_CHILDREN; i++) {
        child_window[i] = gdk_window_new (parent_window, &child_attributes[i], GDK_WA_X | GDK_WA_Y);
        
        if (!child_window[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL);
            return;
        }
        
        if (!GDK_IS_WINDOW (child_window[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL);
            return;
        }
    }
    
    list = gdk_window_peek_children (parent_window);
    
    if (list == NULL)
        TEST_FAIL ("window should have child windows", NULL);
    
    for (i = 0; i < NUM_OF_CHILDREN; i++) {
        if (g_list_find (list, child_window[i]) == NULL)
            TEST_FAIL ("parent window should have child window %p", child_window[i], NULL);
    }
    
    for (i = 0; i < NUM_OF_CHILDREN; i++)
        gdk_window_destroy (child_window[i]);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef NUM_OF_CHILDREN
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_peek_children
 * Params: GdkWindow *window
 * Returns: GList*
 * Assertion: Like gdk_window_get_children(), but does not copy the list of children, so the list does not need to be freed.
 * Params Values: a GdkWindow
 * Expected: list of child windows inside window   
 */
static void test_purpose_62()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 23, 34, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define NUM_OF_CHILDREN 2
    #define CHILD_ATTRIBUTES {{"child1", 0, 77, 66, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}, {"child2", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}}
    
    GdkWindow *parent_window;
    GdkWindow *child_window[NUM_OF_CHILDREN];
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes[NUM_OF_CHILDREN] = CHILD_ATTRIBUTES;
    int i;
    GList *list = NULL;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    for (i = 0; i < NUM_OF_CHILDREN; i++) {
        child_window[i] = gdk_window_new (parent_window, &child_attributes[i], GDK_WA_X | GDK_WA_Y);
        
        if (!child_window[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL);
            return;
        }
        
        if (!GDK_IS_WINDOW (child_window[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL);
            return;
        }
    }
    
    list = gdk_window_peek_children (parent_window);
    
    if (list == NULL)
        TEST_FAIL ("window should have child windows", NULL);
    
    for (i = 0; i < NUM_OF_CHILDREN; i++) {
        if (g_list_find (list, child_window[i]) == NULL)
            TEST_FAIL ("parent window should have child window %p", child_window[i], NULL);
    }
    
    for (i = 0; i < NUM_OF_CHILDREN; i++)
        gdk_window_destroy (child_window[i]);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef NUM_OF_CHILDREN
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_peek_children
 * Params: GdkWindow *window
 * Returns: GList*
 * Assertion: Like gdk_window_get_children(), but does not copy the list of children, so the list does not need to be freed.
 * Params Values: a GdkWindow
 * Expected: list of child windows inside window   
 */
static void test_purpose_63()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 123, 456, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define NUM_OF_CHILDREN 3
    #define CHILD_ATTRIBUTES {{"child1", 0, 789, 654, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}, {"child2", 0, 100, 100, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}, {"child3", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}}
    
    GdkWindow *parent_window;
    GdkWindow *child_window[NUM_OF_CHILDREN];
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes[NUM_OF_CHILDREN] = CHILD_ATTRIBUTES;
    int i;
    GList *list = NULL;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    for (i = 0; i < NUM_OF_CHILDREN; i++) {
        child_window[i] = gdk_window_new (parent_window, &child_attributes[i], GDK_WA_X | GDK_WA_Y);
        
        if (!child_window[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL);
            return;
        }
        
        if (!GDK_IS_WINDOW (child_window[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL);
            return;
        }
    }
    
    list = gdk_window_peek_children (parent_window);
    
    if (list == NULL)
        TEST_FAIL ("window should have child windows", NULL);
    
    for (i = 0; i < NUM_OF_CHILDREN; i++) {
        if (g_list_find (list, child_window[i]) == NULL)
            TEST_FAIL ("parent window should have child window %p", child_window[i], NULL);
    }
    
    for (i = 0; i < NUM_OF_CHILDREN; i++)
        gdk_window_destroy (child_window[i]);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef NUM_OF_CHILDREN
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_peek_children
 * Params: GdkWindow *window
 * Returns: GList*
 * Assertion: Like gdk_window_get_children(), but does not copy the list of children, so the list does not need to be freed.
 * Params Values: a GdkWindow
 * Expected: list of child windows inside window   
 */
static void test_purpose_64()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 32767, 0, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define NUM_OF_CHILDREN 4
    #define CHILD_ATTRIBUTES {{"child1", 0, 789, 654, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}, {"child2", 0, 100, 100, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}, {"child3", 0, 10, 10, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}, {"child4", 0, 1, 1, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}}
    
    GdkWindow *parent_window;
    GdkWindow *child_window[NUM_OF_CHILDREN];
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes[NUM_OF_CHILDREN] = CHILD_ATTRIBUTES;
    int i;
    GList *list = NULL;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    for (i = 0; i < NUM_OF_CHILDREN; i++) {
        child_window[i] = gdk_window_new (parent_window, &child_attributes[i], GDK_WA_X | GDK_WA_Y);
        
        if (!child_window[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL);
            return;
        }
        
        if (!GDK_IS_WINDOW (child_window[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL);
            return;
        }
    }
    
    list = gdk_window_peek_children (parent_window);
    
    if (list == NULL)
        TEST_FAIL ("window should have child windows", NULL);
    
    for (i = 0; i < NUM_OF_CHILDREN; i++) {
        if (g_list_find (list, child_window[i]) == NULL)
            TEST_FAIL ("parent window should have child window %p", child_window[i], NULL);
    }
    
    for (i = 0; i < NUM_OF_CHILDREN; i++)
        gdk_window_destroy (child_window[i]);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef NUM_OF_CHILDREN
    #undef CHILD_ATTRIBUTES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_set_group
 * Params: GdkWindow *window, GdkWindow *leader
 * Returns: void
 * Assertion: Sets the group leader window for window. By default, GDK sets the group leader for all toplevel windows to a global window implicitly created by GDK. With this function you can override this default. The group leader window allows the window manager to distinguish all windows that belong to a single application. It may for example allow users to minimize/unminimize all windows belonging to an application at once. You should only set a non-default group window if your application pretends to be multiple applications.
 * Params Values: a toplevel GdkWindow, group leader window, or NULL to restore the default group leader window
 * Expected: void  
 */
static void test_purpose_65()
{
    #define ATTRIBUTES1 {"foo", 0, 1, 2, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES2 {"foo", 0, 9, 8, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    
    GdkWindow *window1;
    GdkWindow *window2;
    GdkWindowAttr attributes1 = ATTRIBUTES1;
    GdkWindowAttr attributes2 = ATTRIBUTES2;
    GdkWindow *default_leader;
    GdkWindow *new_leader;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window1 = gdk_window_new (NULL, &attributes1, GDK_WA_X | GDK_WA_Y);
    
    if (!window1)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    window2 = gdk_window_new (NULL, &attributes2, GDK_WA_X | GDK_WA_Y);
    
    if (!window2)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window2))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    default_leader = gdk_display_get_default_group (gdk_drawable_get_display (window2));
    
    gdk_window_set_group (window2, window1);
    
    new_leader = gdk_window_get_group (window2);
    
    if (new_leader != window1)
        TEST_FAIL ("group leader window should be %p, not %p", window1, new_leader, NULL);
    
    gdk_window_set_group (window2, NULL);
    
    new_leader = gdk_window_get_group (window2);
    
    if (new_leader != default_leader)
        TEST_FAIL ("default group leader window should be %p, not %p", default_leader, new_leader, NULL);
    
    gdk_window_destroy (window1);
    gdk_window_destroy (window2);
    
    #undef ATTRIBUTES1
    #undef ATTRIBUTES2
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_set_group
 * Params: GdkWindow *window, GdkWindow *leader
 * Returns: void
 * Assertion: Sets the group leader window for window. By default, GDK sets the group leader for all toplevel windows to a global window implicitly created by GDK. With this function you can override this default. The group leader window allows the window manager to distinguish all windows that belong to a single application. It may for example allow users to minimize/unminimize all windows belonging to an application at once. You should only set a non-default group window if your application pretends to be multiple applications.
 * Params Values: a toplevel GdkWindow, group leader window, or NULL to restore the default group leader window
 * Expected: void  
 */
static void test_purpose_66()
{
    #define ATTRIBUTES1 {"foo", 0, 23, 34, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES2 {"foo", 0, 77, 66, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    
    GdkWindow *window1;
    GdkWindow *window2;
    GdkWindowAttr attributes1 = ATTRIBUTES1;
    GdkWindowAttr attributes2 = ATTRIBUTES2;
    GdkWindow *default_leader;
    GdkWindow *new_leader;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window1 = gdk_window_new (NULL, &attributes1, GDK_WA_X | GDK_WA_Y);
    
    if (!window1)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    window2 = gdk_window_new (NULL, &attributes2, GDK_WA_X | GDK_WA_Y);
    
    if (!window2)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window2))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    default_leader = gdk_display_get_default_group (gdk_drawable_get_display (window2));
    
    gdk_window_set_group (window2, window1);
    
    new_leader = gdk_window_get_group (window2);
    
    if (new_leader != window1)
        TEST_FAIL ("group leader window should be %p, not %p", window1, new_leader, NULL);
    
    gdk_window_set_group (window2, NULL);
    
    new_leader = gdk_window_get_group (window2);
    
    if (new_leader != default_leader)
        TEST_FAIL ("default group leader window should be %p, not %p", default_leader, new_leader, NULL);
    
    gdk_window_destroy (window1);
    gdk_window_destroy (window2);
    
    #undef ATTRIBUTES1
    #undef ATTRIBUTES2
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_set_group
 * Params: GdkWindow *window, GdkWindow *leader
 * Returns: void
 * Assertion: Sets the group leader window for window. By default, GDK sets the group leader for all toplevel windows to a global window implicitly created by GDK. With this function you can override this default. The group leader window allows the window manager to distinguish all windows that belong to a single application. It may for example allow users to minimize/unminimize all windows belonging to an application at once. You should only set a non-default group window if your application pretends to be multiple applications.
 * Params Values: a toplevel GdkWindow, group leader window, or NULL to restore the default group leader window
 * Expected: void  
 */
static void test_purpose_67()
{
    #define ATTRIBUTES1 {"foo", 0, 123, 456, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES2 {"foo", 0, 789, 654, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    
    GdkWindow *window1;
    GdkWindow *window2;
    GdkWindowAttr attributes1 = ATTRIBUTES1;
    GdkWindowAttr attributes2 = ATTRIBUTES2;
    GdkWindow *default_leader;
    GdkWindow *new_leader;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window1 = gdk_window_new (NULL, &attributes1, GDK_WA_X | GDK_WA_Y);
    
    if (!window1)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    window2 = gdk_window_new (NULL, &attributes2, GDK_WA_X | GDK_WA_Y);
    
    if (!window2)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window2))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    default_leader = gdk_display_get_default_group (gdk_drawable_get_display (window2));
    
    gdk_window_set_group (window2, window1);
    
    new_leader = gdk_window_get_group (window2);
    
    if (new_leader != window1)
        TEST_FAIL ("group leader window should be %p, not %p", window1, new_leader, NULL);
    
    gdk_window_set_group (window2, NULL);
    
    new_leader = gdk_window_get_group (window2);
    
    if (new_leader != default_leader)
        TEST_FAIL ("default group leader window should be %p, not %p", default_leader, new_leader, NULL);
    
    gdk_window_destroy (window1);
    gdk_window_destroy (window2);
    
    #undef ATTRIBUTES1
    #undef ATTRIBUTES2
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_set_group
 * Params: GdkWindow *window, GdkWindow *leader
 * Returns: void
 * Assertion: Sets the group leader window for window. By default, GDK sets the group leader for all toplevel windows to a global window implicitly created by GDK. With this function you can override this default. The group leader window allows the window manager to distinguish all windows that belong to a single application. It may for example allow users to minimize/unminimize all windows belonging to an application at once. You should only set a non-default group window if your application pretends to be multiple applications.
 * Params Values: a toplevel GdkWindow, group leader window, or NULL to restore the default group leader window
 * Expected: void  
 */
static void test_purpose_68()
{
    #define ATTRIBUTES1 {"foo", 0, 32767, 0, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define ATTRIBUTES2 {"foo", 0, 0, 32767, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    
    GdkWindow *window1;
    GdkWindow *window2;
    GdkWindowAttr attributes1 = ATTRIBUTES1;
    GdkWindowAttr attributes2 = ATTRIBUTES2;
    GdkWindow *default_leader;
    GdkWindow *new_leader;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window1 = gdk_window_new (NULL, &attributes1, GDK_WA_X | GDK_WA_Y);
    
    if (!window1)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    window2 = gdk_window_new (NULL, &attributes2, GDK_WA_X | GDK_WA_Y);
    
    if (!window2)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (window2))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    default_leader = gdk_display_get_default_group (gdk_drawable_get_display (window2));
    
    gdk_window_set_group (window2, window1);
    
    new_leader = gdk_window_get_group (window2);
    
    if (new_leader != window1)
        TEST_FAIL ("group leader window should be %p, not %p", window1, new_leader, NULL);
    
    gdk_window_set_group (window2, NULL);
    
    new_leader = gdk_window_get_group (window2);
    
    if (new_leader != default_leader)
        TEST_FAIL ("default group leader window should be %p, not %p", default_leader, new_leader, NULL);
    
    gdk_window_destroy (window1);
    gdk_window_destroy (window2);
    
    #undef ATTRIBUTES1
    #undef ATTRIBUTES2
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_move
 * Params: GdkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: Repositions a window relative to its parent window. For toplevel windows, window managers may ignore or modify the move; you should probably use gtk_window_move() on a GtkWindow widget anyway, instead of using GDK functions. For child windows, the move will reliably succeed. If you're also planning to resize the window, use gdk_window_move_resize() to both move and resize simultaneously, for a nicer visual effect.
 * Params Values: a GdkWindow, X coordinate relative to window's parent, Y coordinate relative to window's parent
 * Expected: void  
 */
static void test_purpose_69()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 1, 2, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 9, 8, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define X 1
    #define Y 2
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_move (child_window, X, Y);
    
    gdk_window_get_position (child_window, &x, &y);
    
    if (x != X)
        TEST_FAIL ("X coordinate relative to the parent window should be %d, not %d", X, x, NULL);
    
    if (y != Y)
        TEST_FAIL ("Y coordinate relative to the parent window should be %d, not %d", Y, y, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_move
 * Params: GdkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: Repositions a window relative to its parent window. For toplevel windows, window managers may ignore or modify the move; you should probably use gtk_window_move() on a GtkWindow widget anyway, instead of using GDK functions. For child windows, the move will reliably succeed. If you're also planning to resize the window, use gdk_window_move_resize() to both move and resize simultaneously, for a nicer visual effect.
 * Params Values: a GdkWindow, X coordinate relative to window's parent, Y coordinate relative to window's parent
 * Expected: void  
 */
static void test_purpose_70()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 23, 34, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 77, 66, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define X 23
    #define Y 34
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_move (child_window, X, Y);
    
    gdk_window_get_position (child_window, &x, &y);
    
    if (x != X)
        TEST_FAIL ("X coordinate relative to the parent window should be %d, not %d", X, x, NULL);
    
    if (y != Y)
        TEST_FAIL ("Y coordinate relative to the parent window should be %d, not %d", Y, y, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_move
 * Params: GdkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: Repositions a window relative to its parent window. For toplevel windows, window managers may ignore or modify the move; you should probably use gtk_window_move() on a GtkWindow widget anyway, instead of using GDK functions. For child windows, the move will reliably succeed. If you're also planning to resize the window, use gdk_window_move_resize() to both move and resize simultaneously, for a nicer visual effect.
 * Params Values: a GdkWindow, X coordinate relative to window's parent, Y coordinate relative to window's parent
 * Expected: void  
 */
static void test_purpose_71()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 123, 456, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 789, 654, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define X 211
    #define Y 346
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_move (child_window, X, Y);
    
    gdk_window_get_position (child_window, &x, &y);
    
    if (x != X)
        TEST_FAIL ("X coordinate relative to the parent window should be %d, not %d", X, x, NULL);
    
    if (y != Y)
        TEST_FAIL ("Y coordinate relative to the parent window should be %d, not %d", Y, y, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_move
 * Params: GdkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: Repositions a window relative to its parent window. For toplevel windows, window managers may ignore or modify the move; you should probably use gtk_window_move() on a GtkWindow widget anyway, instead of using GDK functions. For child windows, the move will reliably succeed. If you're also planning to resize the window, use gdk_window_move_resize() to both move and resize simultaneously, for a nicer visual effect.
 * Params Values: a GdkWindow, X coordinate relative to window's parent, Y coordinate relative to window's parent
 * Expected: void  
 */
static void test_purpose_72()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 32767, 0, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 0, 32767, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define X 0
    #define Y 0
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_move (child_window, X, Y);
    
    gdk_window_get_position (child_window, &x, &y);
    
    if (x != X)
        TEST_FAIL ("X coordinate relative to the parent window should be %d, not %d", X, x, NULL);
    
    if (y != Y)
        TEST_FAIL ("Y coordinate relative to the parent window should be %d, not %d", Y, y, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_resize
 * Params: GdkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Resizes window; for toplevel windows, asks the window manager to resize the window. The window manager may not allow the resize. When using GTK+, use gtk_window_resize() instead of this low-level GDK function. Windows may not be resized below 1x1. If you're also planning to move the window, use gdk_window_move_resize() to both move and resize simultaneously, for a nicer visual effect.
 * Params Values: a GdkWindow, new width of the window, new height of the window
 * Expected: void  
 */
static void test_purpose_73()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 1, 2, 1000, 1000, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 9, 8, 1, 1, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define WIDTH 10
    #define HEIGHT 22
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint width;
    gint height;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_resize (child_window, WIDTH, HEIGHT);
    
    gdk_window_get_geometry (child_window, NULL, NULL, &width, &height, NULL);
    
    if (width != WIDTH)
        TEST_FAIL ("width of window should be %d, not %d", WIDTH, width, NULL);
    
    if (height != HEIGHT)
        TEST_FAIL ("height of window should be %d, not %d", HEIGHT, height, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_resize
 * Params: GdkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Resizes window; for toplevel windows, asks the window manager to resize the window. The window manager may not allow the resize. When using GTK+, use gtk_window_resize() instead of this low-level GDK function. Windows may not be resized below 1x1. If you're also planning to move the window, use gdk_window_move_resize() to both move and resize simultaneously, for a nicer visual effect.
 * Params Values: a GdkWindow, new width of the window, new height of the window
 * Expected: void  
 */
static void test_purpose_74()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 23, 34, 1000, 1000, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 77, 66, 10, 10, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define WIDTH 230
    #define HEIGHT 349
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint width;
    gint height;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_resize (child_window, WIDTH, HEIGHT);
    
    gdk_window_get_geometry (child_window, NULL, NULL, &width, &height, NULL);
    
    if (width != WIDTH)
        TEST_FAIL ("width of window should be %d, not %d", WIDTH, width, NULL);
    
    if (height != HEIGHT)
        TEST_FAIL ("height of window should be %d, not %d", HEIGHT, height, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_resize
 * Params: GdkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Resizes window; for toplevel windows, asks the window manager to resize the window. The window manager may not allow the resize. When using GTK+, use gtk_window_resize() instead of this low-level GDK function. Windows may not be resized below 1x1. If you're also planning to move the window, use gdk_window_move_resize() to both move and resize simultaneously, for a nicer visual effect.
 * Params Values: a GdkWindow, new width of the window, new height of the window
 * Expected: void  
 */
static void test_purpose_75()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 123, 456, 6000, 8000, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 789, 654, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define WIDTH 2110
    #define HEIGHT 3460
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint width;
    gint height;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_resize (child_window, WIDTH, HEIGHT);
    
    gdk_window_get_geometry (child_window, NULL, NULL, &width, &height, NULL);
    
    if (width != WIDTH)
        TEST_FAIL ("width of window should be %d, not %d", WIDTH, width, NULL);
    
    if (height != HEIGHT)
        TEST_FAIL ("height of window should be %d, not %d", HEIGHT, height, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_resize
 * Params: GdkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Resizes window; for toplevel windows, asks the window manager to resize the window. The window manager may not allow the resize. When using GTK+, use gtk_window_resize() instead of this low-level GDK function. Windows may not be resized below 1x1. If you're also planning to move the window, use gdk_window_move_resize() to both move and resize simultaneously, for a nicer visual effect.
 * Params Values: a GdkWindow, new width of the window, new height of the window
 * Expected: void  
 */
static void test_purpose_76()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 32767, 0, 1000, 1000, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 0, 32767, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define WIDTH 1
    #define HEIGHT 1
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint width;
    gint height;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_resize (child_window, WIDTH, HEIGHT);
    
    gdk_window_get_geometry (child_window, NULL, NULL, &width, &height, NULL);
    
    if (width != WIDTH)
        TEST_FAIL ("width of window should be %d, not %d", WIDTH, width, NULL);
    
    if (height != HEIGHT)
        TEST_FAIL ("height of window should be %d, not %d", HEIGHT, height, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_move_resize
 * Params: GdkWindow *window, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Equivalent to calling gdk_window_move() and gdk_window_resize(), except that both operations are performed at once, avoiding strange visual effects. (i.e. the user may be able to see the window first move, then resize, if you don't use gdk_window_move_resize().)
 * Params Values: a GdkWindow, new X position relative to window's parent, new Y position relative to window's parent, new width, new height
 * Expected: void  
 */
static void test_purpose_77()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 1, 2, 1000, 1000, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 9, 8, 1, 1, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define X 1
    #define Y 2
    #define WIDTH 10
    #define HEIGHT 22
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint x;
    gint y;
    gint width;
    gint height;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_move_resize (child_window, X, Y, WIDTH, HEIGHT);
    
    gdk_window_get_geometry (child_window, &x, &y, &width, &height, NULL);
    
    if (x != X)
        TEST_FAIL ("X coordinate relative to the parent window should be %d, not %d", X, x, NULL);
    
    if (y != Y)
        TEST_FAIL ("Y coordinate relative to the parent window should be %d, not %d", Y, y, NULL);
    
    if (width != WIDTH)
        TEST_FAIL ("width of window should be %d, not %d", WIDTH, width, NULL);
    
    if (height != HEIGHT)
        TEST_FAIL ("height of window should be %d, not %d", HEIGHT, height, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_move_resize
 * Params: GdkWindow *window, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Equivalent to calling gdk_window_move() and gdk_window_resize(), except that both operations are performed at once, avoiding strange visual effects. (i.e. the user may be able to see the window first move, then resize, if you don't use gdk_window_move_resize().)
 * Params Values: a GdkWindow, new X position relative to window's parent, new Y position relative to window's parent, new width, new height
 * Expected: void  
 */
static void test_purpose_78()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 23, 34, 1000, 1000, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 77, 66, 10, 10, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define X 23
    #define Y 34
    #define WIDTH 230
    #define HEIGHT 349
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint x;
    gint y;
    gint width;
    gint height;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_move_resize (child_window, X, Y, WIDTH, HEIGHT);
    
    gdk_window_get_geometry (child_window, &x, &y, &width, &height, NULL);
    
    if (x != X)
        TEST_FAIL ("X coordinate relative to the parent window should be %d, not %d", X, x, NULL);
    
    if (y != Y)
        TEST_FAIL ("Y coordinate relative to the parent window should be %d, not %d", Y, y, NULL);
    
    if (width != WIDTH)
        TEST_FAIL ("width of window should be %d, not %d", WIDTH, width, NULL);
    
    if (height != HEIGHT)
        TEST_FAIL ("height of window should be %d, not %d", HEIGHT, height, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_move_resize
 * Params: GdkWindow *window, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Equivalent to calling gdk_window_move() and gdk_window_resize(), except that both operations are performed at once, avoiding strange visual effects. (i.e. the user may be able to see the window first move, then resize, if you don't use gdk_window_move_resize().)
 * Params Values: a GdkWindow, new X position relative to window's parent, new Y position relative to window's parent, new width, new height
 * Expected: void  
 */
static void test_purpose_79()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 123, 456, 6000, 8000, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 789, 654, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define X 211
    #define Y 346
    #define WIDTH 2110
    #define HEIGHT 3460
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint x;
    gint y;
    gint width;
    gint height;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_move_resize (child_window, X, Y, WIDTH, HEIGHT);
    
    gdk_window_get_geometry (child_window, &x, &y, &width, &height, NULL);
    
    if (x != X)
        TEST_FAIL ("X coordinate relative to the parent window should be %d, not %d", X, x, NULL);
    
    if (y != Y)
        TEST_FAIL ("Y coordinate relative to the parent window should be %d, not %d", Y, y, NULL);
    
    if (width != WIDTH)
        TEST_FAIL ("width of window should be %d, not %d", WIDTH, width, NULL);
    
    if (height != HEIGHT)
        TEST_FAIL ("height of window should be %d, not %d", HEIGHT, height, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_window_move_resize
 * Params: GdkWindow *window, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Equivalent to calling gdk_window_move() and gdk_window_resize(), except that both operations are performed at once, avoiding strange visual effects. (i.e. the user may be able to see the window first move, then resize, if you don't use gdk_window_move_resize().)
 * Params Values: a GdkWindow, new X position relative to window's parent, new Y position relative to window's parent, new width, new height
 * Expected: void  
 */
static void test_purpose_80()
{
    #define PARENT_ATTRIBUTES {"foo", 0, 32767, 0, 1000, 1000, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_TOPLEVEL, NULL, NULL, NULL, FALSE}
    #define CHILD_ATTRIBUTES {"bar", 0, 0, 32767, 100, 100, GDK_INPUT_OUTPUT, NULL, NULL, GDK_WINDOW_CHILD, NULL, NULL, NULL, FALSE}
    #define X 0
    #define Y 0
    #define WIDTH 1
    #define HEIGHT 1
    
    GdkWindow *parent_window;
    GdkWindow *child_window;
    GdkWindowAttr parent_attributes = PARENT_ATTRIBUTES;
    GdkWindowAttr child_attributes = CHILD_ATTRIBUTES;
    gint x;
    gint y;
    gint width;
    gint height;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent_window = gdk_window_new (NULL, &parent_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!parent_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (parent_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    child_window = gdk_window_new (parent_window, &child_attributes, GDK_WA_X | GDK_WA_Y);
    
    if (!child_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_WINDOW (child_window))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    gdk_window_move_resize (child_window, X, Y, WIDTH, HEIGHT);
    
    gdk_window_get_geometry (child_window, &x, &y, &width, &height, NULL);
    
    if (x != X)
        TEST_FAIL ("X coordinate relative to the parent window should be %d, not %d", X, x, NULL);
    
    if (y != Y)
        TEST_FAIL ("Y coordinate relative to the parent window should be %d, not %d", Y, y, NULL);
    
    if (width != WIDTH)
        TEST_FAIL ("width of window should be %d, not %d", WIDTH, width, NULL);
    
    if (height != HEIGHT)
        TEST_FAIL ("height of window should be %d, not %d", HEIGHT, height, NULL);
    
    gdk_window_destroy (child_window);
    gdk_window_destroy (parent_window);
    
    #undef PARENT_ATTRIBUTES
    #undef CHILD_ATTRIBUTES
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkWindows ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {NULL,0}
};
