/*
 * GtkTextIter methods tests
 * Testing GtkTextIter methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
gint global_counter;

gboolean global_pred (gunichar ch, gpointer user_data)
{
    global_counter++;
    return FALSE;
}

gboolean global_pred_1 (gunichar ch, gpointer user_data)
{
    if (++global_counter == 4)
    {
        return TRUE;
    }
    return FALSE;
}

gboolean global_pred_2 (gunichar ch, gpointer user_data)
{
    return FALSE;
}

/*
 * Name:  gtk_text_iter_get_buffer
 * Params: const GtkTextIter* iter
 * Returns: GtkTextBuffer*
 * Assertion: Returns the GtkTextBuffer this iterator is associated with
 * Params Values: GtkTextIter* iter
 * Expected: GtkTextBuffer*  
 */
static void test_purpose_1()
{
    #define    TEST_LINE "Line"             
    #define    OFFSET 0
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkTextBuffer *real_buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    real_buffer = gtk_text_iter_get_buffer (&iter);
    if (real_buffer != buffer)
    {
        TEST_FAIL ("real_buffer differs from buffer", NULL);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_buffer
 * Params: const GtkTextIter* iter
 * Returns: GtkTextBuffer*
 * Assertion: Returns the GtkTextBuffer this iterator is associated with
 * Params Values: GtkTextIter* iter
 * Expected: GtkTextBuffer*  
 */
static void test_purpose_2()
{
    #define    TEST_LINE "Line"             
    #define    OFFSET 5
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkTextBuffer *real_buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    real_buffer = gtk_text_iter_get_buffer (&iter);
    if (real_buffer != buffer)
    {
        TEST_FAIL ("real_buffer differs from buffer", NULL);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of an iterator.
 * Params Values: GtkTextIter*
 * Expected: 0 
 * 
 * Name: gtk_text_iter_set_offset
 * Params: const GtkTextIter* iter, gint offset
 * Returns: void
 * Assertion: Sets iter to point to char_offset.
 * Params Values: GtkTextIter*, 0
 * Expected: void 
 * 
 * Name: gtk_text_iter_set_offset
 * Params: const GtkTextIter* iter, gint offset
 * Returns: void
 * Assertion: char_offset counts from the start of the entire text buffer, starting with 0
 * Params Values: GtkTextIter*, 0
 * Expected: void   
 */
static void test_purpose_3()
{
    #define    TEST_LINE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    OFFS 0
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    
    gtk_text_iter_set_offset (&iter, OFFS);
    offs = gtk_text_iter_get_offset (&iter);
    
    if (offs != OFFS)
    {
        TEST_FAIL ("offset = %d, should be %d\n", offs, (gint) OFFS);
        return;
    }
    
    gtk_text_iter_set_line (&iter, 0);
    offs = gtk_text_iter_get_offset (&iter);
    if (offs != 0)
    {
        TEST_FAIL ("offset = %d, should be 0\n", offs );
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef OFFS
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of an iterator.
 * Params Values: GtkTextIter*
 * Expected: 10 
 * 
 * Name: gtk_text_iter_set_offset
 * Params: const GtkTextIter* iter, gint offset
 * Returns: void
 * Assertion: Sets iter to point to char_offset.
 * Params Values: GtkTextIter*, 10
 * Expected: void 
 * 
 * Name: gtk_text_iter_set_offset
 * Params: const GtkTextIter* iter, gint offset
 * Returns: void
 * Assertion: char_offset counts from the start of the entire text buffer, starting with 0
 * Params Values: GtkTextIter*, 10
 * Expected: void   
 */
static void test_purpose_4()
{
    #define    TEST_LINE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    OFFS 10
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    
    gtk_text_iter_set_offset (&iter, OFFS);
    offs = gtk_text_iter_get_offset (&iter);
    
    if (offs != OFFS)
    {
        TEST_FAIL ("offset = %d, should be %d\n", offs, (gint) OFFS);
        return;
    }
    
    gtk_text_iter_set_line (&iter, 0);
    offs = gtk_text_iter_get_offset (&iter);
    if (offs != 0)
    {
        TEST_FAIL ("offset = %d, should be 0\n", offs );
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef OFFS
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of an iterator.
 * Params Values: GtkTextIter*
 * Expected: 6 
 * 
 * Name: gtk_text_iter_set_offset
 * Params: const GtkTextIter* iter, gint offset
 * Returns: void
 * Assertion: Sets iter to point to char_offset.
 * Params Values: GtkTextIter*, 6
 * Expected: void 
 * 
 * Name: gtk_text_iter_set_offset
 * Params: const GtkTextIter* iter, gint offset
 * Returns: void
 * Assertion: char_offset counts from the start of the entire text buffer, starting with 0
 * Params Values: GtkTextIter*, 6
 * Expected: void   
 */
static void test_purpose_5()
{
    #define    TEST_LINE "abcdef"
    #define    OFFS 6
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    
    gtk_text_iter_set_offset (&iter, OFFS);
    offs = gtk_text_iter_get_offset (&iter);
    
    if (offs != OFFS)
    {
        TEST_FAIL ("offset = %d, should be %d\n", offs, (gint) OFFS);
        return;
    }
    
    gtk_text_iter_set_line (&iter, 0);
    offs = gtk_text_iter_get_offset (&iter);
    if (offs != 0)
    {
        TEST_FAIL ("offset = %d, should be 0\n", offs );
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef OFFS
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Each character in a GtkTextBuffer has an offset, starting with 0 for the first character in the buffer.
 * Params Values: GtkTextIter*
 * Expected: <%1%>   
 */
static void test_purpose_6()
{
    #define    TEST_LINE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gunichar ch;
    gchar*   c_from_utf8;
    gchar* test_line;
    gchar*   c_ucs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    test_line = TEST_LINE;
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, test_line, strlen(test_line));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    
    ch = gtk_text_iter_get_char (&iter);
    c_ucs = g_ucs4_to_utf8 (&ch, 1, NULL, NULL, NULL);
    c_from_utf8 = g_locale_from_utf8 (c_ucs, 1, NULL, NULL, NULL); 
    g_free(c_ucs);
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (*test_line != *c_from_utf8 )
    {
        TEST_FAIL ("char = '%c', should be '%c'", *c_from_utf8, *test_line);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Each character in a GtkTextBuffer has an offset, starting with 0 for the first character in the buffer.
 * Params Values: GtkTextIter*
 * Expected: <%1%>   
 */
static void test_purpose_7()
{
    #define    TEST_LINE "\n"
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gunichar ch;
    gchar*   c_from_utf8;
    gchar* test_line;
    gchar*   c_ucs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    test_line = TEST_LINE;
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, test_line, strlen(test_line));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    
    ch = gtk_text_iter_get_char (&iter);
    c_ucs = g_ucs4_to_utf8 (&ch, 1, NULL, NULL, NULL);
    c_from_utf8 = g_locale_from_utf8 (c_ucs, 1, NULL, NULL, NULL); 
    g_free(c_ucs);
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (*test_line != *c_from_utf8 )
    {
        TEST_FAIL ("char = '%c', should be '%c'", *c_from_utf8, *test_line);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Each character in a GtkTextBuffer has an offset, starting with 0 for the first character in the buffer.
 * Params Values: GtkTextIter*
 * Expected: <%1%>   
 */
static void test_purpose_8()
{
    #define    TEST_LINE " "
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gunichar ch;
    gchar*   c_from_utf8;
    gchar* test_line;
    gchar*   c_ucs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    test_line = TEST_LINE;
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, test_line, strlen(test_line));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    
    ch = gtk_text_iter_get_char (&iter);
    c_ucs = g_ucs4_to_utf8 (&ch, 1, NULL, NULL, NULL);
    c_from_utf8 = g_locale_from_utf8 (c_ucs, 1, NULL, NULL, NULL); 
    g_free(c_ucs);
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (*test_line != *c_from_utf8 )
    {
        TEST_FAIL ("char = '%c', should be '%c'", *c_from_utf8, *test_line);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the line number containing the iterator.
 * Params Values: GtkTextIter*
 * Expected: 0 
 * 
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Lines in a GtkTextBuffer are numbered beginning with 0 for the first line in the buffer
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_9()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define OFFSET 0
    #define CORRECT_LINE 0
    
    GtkTextIter iter;
    gint line;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line = gtk_text_iter_get_line (&iter);
    
    if (line != CORRECT_LINE)
    {
        TEST_FAIL ("line = %d, should be %d\n", line, CORRECT_LINE);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    line = gtk_text_iter_get_line (&iter);
    if (line != 0)
    {
        TEST_FAIL ("line = %d, should be 0\n", line);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the line number containing the iterator.
 * Params Values: GtkTextIter*
 * Expected: 0 
 * 
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Lines in a GtkTextBuffer are numbered beginning with 0 for the first line in the buffer
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_10()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define OFFSET 6
    #define CORRECT_LINE 0
    
    GtkTextIter iter;
    gint line;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line = gtk_text_iter_get_line (&iter);
    
    if (line != CORRECT_LINE)
    {
        TEST_FAIL ("line = %d, should be %d\n", line, CORRECT_LINE);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    line = gtk_text_iter_get_line (&iter);
    if (line != 0)
    {
        TEST_FAIL ("line = %d, should be 0\n", line);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the line number containing the iterator.
 * Params Values: GtkTextIter*
 * Expected: 0 
 * 
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Lines in a GtkTextBuffer are numbered beginning with 0 for the first line in the buffer
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_11()
{
    #define TEST_LINE "Line 0\r\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define OFFSET 6
    #define CORRECT_LINE 0
    
    GtkTextIter iter;
    gint line;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line = gtk_text_iter_get_line (&iter);
    
    if (line != CORRECT_LINE)
    {
        TEST_FAIL ("line = %d, should be %d\n", line, CORRECT_LINE);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    line = gtk_text_iter_get_line (&iter);
    if (line != 0)
    {
        TEST_FAIL ("line = %d, should be 0\n", line);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the line number containing the iterator.
 * Params Values: GtkTextIter*
 * Expected: 0 
 * 
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Lines in a GtkTextBuffer are numbered beginning with 0 for the first line in the buffer
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_12()
{
    #define TEST_LINE "Line 0\r\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define OFFSET 7
    #define CORRECT_LINE 0
    
    GtkTextIter iter;
    gint line;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line = gtk_text_iter_get_line (&iter);
    
    if (line != CORRECT_LINE)
    {
        TEST_FAIL ("line = %d, should be %d\n", line, CORRECT_LINE);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    line = gtk_text_iter_get_line (&iter);
    if (line != 0)
    {
        TEST_FAIL ("line = %d, should be 0\n", line);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the line number containing the iterator.
 * Params Values: GtkTextIter*
 * Expected: 1 
 * 
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Lines in a GtkTextBuffer are numbered beginning with 0 for the first line in the buffer
 * Params Values: GtkTextIter*
 * Expected: 1   
 */
static void test_purpose_13()
{
    #define TEST_LINE "Line 0\n Line 1"
    #define OFFSET 14
    #define CORRECT_LINE 1
    
    GtkTextIter iter;
    gint line;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line = gtk_text_iter_get_line (&iter);
    
    if (line != CORRECT_LINE)
    {
        TEST_FAIL ("line = %d, should be %d\n", line, CORRECT_LINE);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    line = gtk_text_iter_get_line (&iter);
    if (line != 0)
    {
        TEST_FAIL ("line = %d, should be 0\n", line);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the line number containing the iterator.
 * Params Values: GtkTextIter*
 * Expected: 2 
 * 
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Lines in a GtkTextBuffer are numbered beginning with 0 for the first line in the buffer
 * Params Values: GtkTextIter*
 * Expected: 2   
 */
static void test_purpose_14()
{
    #define TEST_LINE "Line 0\n Line 1\r"
    #define OFFSET 15
    #define CORRECT_LINE 2
    
    GtkTextIter iter;
    gint line;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line = gtk_text_iter_get_line (&iter);
    
    if (line != CORRECT_LINE)
    {
        TEST_FAIL ("line = %d, should be %d\n", line, CORRECT_LINE);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    line = gtk_text_iter_get_line (&iter);
    if (line != 0)
    {
        TEST_FAIL ("line = %d, should be 0\n", line);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the line number containing the iterator.
 * Params Values: GtkTextIter*
 * Expected: 2 
 * 
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Lines in a GtkTextBuffer are numbered beginning with 0 for the first line in the buffer
 * Params Values: GtkTextIter*
 * Expected: 2   
 */
static void test_purpose_15()
{
    #define TEST_LINE "Line 0\n Line 1\r"
    #define OFFSET 16
    #define CORRECT_LINE 2
    
    GtkTextIter iter;
    gint line;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line = gtk_text_iter_get_line (&iter);
    
    if (line != CORRECT_LINE)
    {
        TEST_FAIL ("line = %d, should be %d\n", line, CORRECT_LINE);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    line = gtk_text_iter_get_line (&iter);
    if (line != 0)
    {
        TEST_FAIL ("line = %d, should be 0\n", line);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the line number containing the iterator.
 * Params Values: GtkTextIter*
 * Expected: 0 
 * 
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Lines in a GtkTextBuffer are numbered beginning with 0 for the first line in the buffer
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_16()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define OFFSET 0
    #define CORRECT_LINE 0
    
    GtkTextIter iter;
    gint line;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line = gtk_text_iter_get_line (&iter);
    
    if (line != CORRECT_LINE)
    {
        TEST_FAIL ("line = %d, should be %d\n", line, CORRECT_LINE);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    line = gtk_text_iter_get_line (&iter);
    if (line != 0)
    {
        TEST_FAIL ("line = %d, should be 0\n", line);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the line number containing the iterator.
 * Params Values: GtkTextIter*
 * Expected: 1 
 * 
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Lines in a GtkTextBuffer are numbered beginning with 0 for the first line in the buffer
 * Params Values: GtkTextIter*
 * Expected: 1   
 */
static void test_purpose_17()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define OFFSET 1
    #define CORRECT_LINE 1
    
    GtkTextIter iter;
    gint line;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line = gtk_text_iter_get_line (&iter);
    
    if (line != CORRECT_LINE)
    {
        TEST_FAIL ("line = %d, should be %d\n", line, CORRECT_LINE);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    line = gtk_text_iter_get_line (&iter);
    if (line != 0)
    {
        TEST_FAIL ("line = %d, should be 0\n", line);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the line number containing the iterator.
 * Params Values: GtkTextIter*
 * Expected: 1 
 * 
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Lines in a GtkTextBuffer are numbered beginning with 0 for the first line in the buffer
 * Params Values: GtkTextIter*
 * Expected: 1   
 */
static void test_purpose_18()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define OFFSET 2
    #define CORRECT_LINE 1
    
    GtkTextIter iter;
    gint line;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line = gtk_text_iter_get_line (&iter);
    
    if (line != CORRECT_LINE)
    {
        TEST_FAIL ("line = %d, should be %d\n", line, CORRECT_LINE);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    line = gtk_text_iter_get_line (&iter);
    if (line != 0)
    {
        TEST_FAIL ("line = %d, should be 0\n", line);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the line number containing the iterator.
 * Params Values: GtkTextIter*
 * Expected: 3 
 * 
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Lines in a GtkTextBuffer are numbered beginning with 0 for the first line in the buffer
 * Params Values: GtkTextIter*
 * Expected: 3   
 */
static void test_purpose_19()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define OFFSET 4
    #define CORRECT_LINE 3
    
    GtkTextIter iter;
    gint line;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line = gtk_text_iter_get_line (&iter);
    
    if (line != CORRECT_LINE)
    {
        TEST_FAIL ("line = %d, should be %d\n", line, CORRECT_LINE);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    line = gtk_text_iter_get_line (&iter);
    if (line != 0)
    {
        TEST_FAIL ("line = %d, should be 0\n", line);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the line number containing the iterator.
 * Params Values: GtkTextIter*
 * Expected: 6 
 * 
 * Name: gtk_text_iter_get_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Lines in a GtkTextBuffer are numbered beginning with 0 for the first line in the buffer
 * Params Values: GtkTextIter*
 * Expected: 6   
 */
static void test_purpose_20()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define OFFSET 8
    #define CORRECT_LINE 6
    
    GtkTextIter iter;
    gint line;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line = gtk_text_iter_get_line (&iter);
    
    if (line != CORRECT_LINE)
    {
        TEST_FAIL ("line = %d, should be %d\n", line, CORRECT_LINE);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    line = gtk_text_iter_get_line (&iter);
    if (line != 0)
    {
        TEST_FAIL ("line = %d, should be 0\n", line);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Moves iterator iter to the start of the line line_number.
 * Params Values: GtkTextIter*, 0
 * Expected: void   
 */
static void test_purpose_21()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE 0
    #define CORRECT_OFFSET 0
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Moves iterator iter to the start of the line line_number.
 * Params Values: GtkTextIter*, 1
 * Expected: void   
 */
static void test_purpose_22()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE 1
    #define CORRECT_OFFSET 7
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Moves iterator iter to the start of the line line_number.
 * Params Values: GtkTextIter*, 6
 * Expected: void   
 */
static void test_purpose_23()
{
    #define TEST_LINE "Line 0\r\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE 6
    #define CORRECT_OFFSET 48
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Moves iterator iter to the start of the line line_number.
 * Params Values: GtkTextIter*, 7
 * Expected: void   
 */
static void test_purpose_24()
{
    #define TEST_LINE "Line 0\r\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE 7
    #define CORRECT_OFFSET 48
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Moves iterator iter to the start of the line line_number.
 * Params Values: GtkTextIter*, 8
 * Expected: void   
 */
static void test_purpose_25()
{
    #define TEST_LINE "Line 0\r\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE 8
    #define CORRECT_OFFSET 48
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, 2
 * Expected: void   
 */
static void test_purpose_26()
{
    #define TEST_LINE ""
    #define LINE 2
    #define CORRECT_OFFSET 0
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, 2
 * Expected: void   
 */
static void test_purpose_27()
{
    #define TEST_LINE "Line 0"
    #define LINE 2
    #define CORRECT_OFFSET 0
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, -2
 * Expected: void   
 */
static void test_purpose_28()
{
    #define TEST_LINE "Line 0"
    #define LINE -2
    #define CORRECT_OFFSET 0
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, 3
 * Expected: void   
 */
static void test_purpose_29()
{
    #define TEST_LINE "Line 0\n"
    #define LINE 3
    #define CORRECT_OFFSET 7
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, -3
 * Expected: void   
 */
static void test_purpose_30()
{
    #define TEST_LINE "Line 0\n"
    #define LINE -3
    #define CORRECT_OFFSET 7
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, 3
 * Expected: void   
 */
static void test_purpose_31()
{
    #define TEST_LINE "Line 0\r"
    #define LINE 3
    #define CORRECT_OFFSET 7
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, -3
 * Expected: void   
 */
static void test_purpose_32()
{
    #define TEST_LINE "Line 0\r"
    #define LINE -3
    #define CORRECT_OFFSET 7
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, 3
 * Expected: void   
 */
static void test_purpose_33()
{
    #define TEST_LINE "Line 0\r\n"
    #define LINE 3
    #define CORRECT_OFFSET 8
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, -3
 * Expected: void   
 */
static void test_purpose_34()
{
    #define TEST_LINE "Line 0\r\n"
    #define LINE -3
    #define CORRECT_OFFSET 8
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, 3
 * Expected: void   
 */
static void test_purpose_35()
{
    #define TEST_LINE "Line 0\n Line 1"
    #define LINE 3
    #define CORRECT_OFFSET 7
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, -3
 * Expected: void   
 */
static void test_purpose_36()
{
    #define TEST_LINE "Line 0\n Line 1"
    #define LINE -3
    #define CORRECT_OFFSET 7
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, 3
 * Expected: void   
 */
static void test_purpose_37()
{
    #define TEST_LINE "Line 0\r Line 1"
    #define LINE 3
    #define CORRECT_OFFSET 7
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, -3
 * Expected: void   
 */
static void test_purpose_38()
{
    #define TEST_LINE "Line 0\r Line 1"
    #define LINE -3
    #define CORRECT_OFFSET 7
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, 3
 * Expected: void   
 */
static void test_purpose_39()
{
    #define TEST_LINE "Line 0\r\n Line 1"
    #define LINE 3
    #define CORRECT_OFFSET 8
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: If line_number is negative or larger than the number of lines in the buffer, moves iter to the start of the last line in the buffer.
 * Params Values: GtkTextIter*, -3
 * Expected: void   
 */
static void test_purpose_40()
{
    #define TEST_LINE "Line 0\r\n Line 1"
    #define LINE -3
    #define CORRECT_OFFSET 8
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_41()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define OFFSET 0
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 6   
 */
static void test_purpose_42()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define OFFSET 6
    #define CORRECT_LINE_OFFSET 6
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 7   
 */
static void test_purpose_43()
{
    #define TEST_LINE "Line 0\r\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define OFFSET 7
    #define CORRECT_LINE_OFFSET 7
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_44()
{
    #define TEST_LINE "Line 0\r\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define OFFSET 8
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 7   
 */
static void test_purpose_45()
{
    #define TEST_LINE "Line 0\n Line 1"
    #define OFFSET 14
    #define CORRECT_LINE_OFFSET 7
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_46()
{
    #define TEST_LINE "Line 0\n Line 1\r"
    #define OFFSET 15
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_47()
{
    #define TEST_LINE "Line 0\n Line 1\r"
    #define OFFSET 16
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_48()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define OFFSET 0
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_49()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define OFFSET 1
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 1   
 */
static void test_purpose_50()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define OFFSET 2
    #define CORRECT_LINE_OFFSET 1
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_51()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define OFFSET 4
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the character offset of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 1   
 */
static void test_purpose_52()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define OFFSET 7
    #define CORRECT_LINE_OFFSET 1
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: The first character on the line has offset 0.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_53()
{
    #define TEST_LINE "Line 0\n "
    #define OFFSET 0
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: The first character on the line has offset 0.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_54()
{
    #define TEST_LINE "Line 0\n "
    #define OFFSET 7
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: The first character on the line has offset 0.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_55()
{
    #define TEST_LINE "Line 0\n\n"
    #define OFFSET 7
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: The first character on the line has offset 0.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_56()
{
    #define TEST_LINE "Line 0\n\n"
    #define OFFSET 8
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: The first character on the line has offset 0.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_57()
{
    #define TEST_LINE "Line 0\r "
    #define OFFSET 0
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: The first character on the line has offset 0.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_58()
{
    #define TEST_LINE "Line 0\r "
    #define OFFSET 7
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: The first character on the line has offset 0.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_59()
{
    #define TEST_LINE "Line 0\r\r"
    #define OFFSET 7
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: The first character on the line has offset 0.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_60()
{
    #define TEST_LINE "Line 0\r\r"
    #define OFFSET 8
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: The first character on the line has offset 0.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_61()
{
    #define TEST_LINE "Line 0\r\n\n"
    #define OFFSET 8
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: The first character on the line has offset 0.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_62()
{
    #define TEST_LINE "Line 0\r\n\n"
    #define OFFSET 9
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_offset = gtk_text_iter_get_line_offset (&iter);
    
    if (line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("line_offset = %d, should be %d\n", line_offset, CORRECT_LINE_OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_offset
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Moves iter within a line, to a new character (not byte) offset.
 * Params Values: GtkTextIter*, 0
 * Expected: void   
 */
static void test_purpose_63()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE 0
    #define LINE_OFFSET 0
    #define CORRECT_OFFSET 0
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    gtk_text_iter_set_line_offset (&iter, LINE_OFFSET);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef LINE_OFFSET
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_offset
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Moves iter within a line, to a new character (not byte) offset.
 * Params Values: GtkTextIter*, 1
 * Expected: void   
 */
static void test_purpose_64()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE 1
    #define LINE_OFFSET 0
    #define CORRECT_OFFSET 7
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    gtk_text_iter_set_line_offset (&iter, LINE_OFFSET);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef LINE_OFFSET
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_offset
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Moves iter within a line, to a new character (not byte) offset.
 * Params Values: GtkTextIter*, 6
 * Expected: void   
 */
static void test_purpose_65()
{
    #define TEST_LINE "Line 0\r\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE 6
    #define LINE_OFFSET 0
    #define CORRECT_OFFSET 48
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    gtk_text_iter_set_line_offset (&iter, LINE_OFFSET);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef LINE_OFFSET
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_offset
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Moves iter within a line, to a new character (not byte) offset.
 * Params Values: GtkTextIter*, 7
 * Expected: void   
 */
static void test_purpose_66()
{
    #define TEST_LINE "Line 0\r\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE 7
    #define LINE_OFFSET 0
    #define CORRECT_OFFSET 48
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    gtk_text_iter_set_line_offset (&iter, LINE_OFFSET);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef LINE_OFFSET
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_offset
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Moves iter within a line, to a new character (not byte) offset.
 * Params Values: GtkTextIter*, 8
 * Expected: void   
 */
static void test_purpose_67()
{
    #define TEST_LINE "Line 0\r\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE 8
    #define LINE_OFFSET 0
    #define CORRECT_OFFSET 48
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    gtk_text_iter_set_line_offset (&iter, LINE_OFFSET);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET)
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef LINE_OFFSET
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_offset
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: The given character offset must be less than or equal to the number of characters in the line; if equal, iter moves to the start of the next line.
 * Params Values: GtkTextIter*, 0
 * Expected: void   
 */
static void test_purpose_68()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE 0
    #define LINE_OFFSET 7
    #define CORRECT_LINE 1
    #define CORRECT_LINE_OFFSET 0
    
    GtkTextIter iter;
    gint new_line;
    gint new_line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    gtk_text_iter_set_line_offset (&iter, LINE_OFFSET);
    
    new_line = gtk_text_iter_get_line (&iter);
    if (new_line != CORRECT_LINE)
    {
        TEST_FAIL ("new_line = %d, should be %d", new_line, CORRECT_LINE);
    } 
    
    new_line_offset = gtk_text_iter_get_line_offset (&iter);
    if (new_line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("new_line_offset = %d, should be 0", 
                   new_line_offset, CORRECT_LINE);
    } 
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef LINE_OFFSET
    #undef CORRECT_LINE
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_offset
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: The given character offset must be less than or equal to the number of characters in the line; if equal, iter moves to the start of the next line.
 * Params Values: GtkTextIter*, 1
 * Expected: void   
 */
static void test_purpose_69()
{
    #define TEST_LINE "Line 0\n Line 1"
    #define LINE 1
    #define LINE_OFFSET 7
    #define CORRECT_LINE 1
    #define CORRECT_LINE_OFFSET 7
    
    GtkTextIter iter;
    gint new_line;
    gint new_line_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE);
    gtk_text_iter_set_line_offset (&iter, LINE_OFFSET);
    
    new_line = gtk_text_iter_get_line (&iter);
    if (new_line != CORRECT_LINE)
    {
        TEST_FAIL ("new_line = %d, should be %d", new_line, CORRECT_LINE);
    } 
    
    new_line_offset = gtk_text_iter_get_line_offset (&iter);
    if (new_line_offset != CORRECT_LINE_OFFSET)
    {
        TEST_FAIL ("new_line_offset = %d, should be 0", 
                   new_line_offset, CORRECT_LINE);
    } 
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef LINE_OFFSET
    #undef CORRECT_LINE
    #undef CORRECT_LINE_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the byte index of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_70()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define OFFSET 0
    #define CORRECT_LINE_INDEX 0
    
    GtkTextIter iter;
    gint line_index;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_index = gtk_text_iter_get_line_index (&iter);
    
    if (line_index != CORRECT_LINE_INDEX)
    {
        TEST_FAIL ("line_index = %d, should be %d\n", line_index, CORRECT_LINE_INDEX);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the byte index of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 6   
 */
static void test_purpose_71()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define OFFSET 6
    #define CORRECT_LINE_INDEX 6
    
    GtkTextIter iter;
    gint line_index;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_index = gtk_text_iter_get_line_index (&iter);
    
    if (line_index != CORRECT_LINE_INDEX)
    {
        TEST_FAIL ("line_index = %d, should be %d\n", line_index, CORRECT_LINE_INDEX);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the byte index of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 9   
 */
static void test_purpose_72()
{
    #define TEST_LINE "Lin$ 0\r\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define OFFSET 7
    #define CORRECT_LINE_INDEX 9
    
    GtkTextIter iter;
    gint line_index;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_index = gtk_text_iter_get_line_index (&iter);
    
    if (line_index != CORRECT_LINE_INDEX)
    {
        TEST_FAIL ("line_index = %d, should be %d\n", line_index, CORRECT_LINE_INDEX);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the byte index of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_73()
{
    #define TEST_LINE "Line 0\r\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define OFFSET 8
    #define CORRECT_LINE_INDEX 0
    
    GtkTextIter iter;
    gint line_index;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_index = gtk_text_iter_get_line_index (&iter);
    
    if (line_index != CORRECT_LINE_INDEX)
    {
        TEST_FAIL ("line_index = %d, should be %d\n", line_index, CORRECT_LINE_INDEX);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the byte index of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 11   
 */
static void test_purpose_74()
{
    #define TEST_LINE "Line 0\n Li$$ 1"
    #define OFFSET 14
    #define CORRECT_LINE_INDEX 11
    
    GtkTextIter iter;
    gint line_index;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_index = gtk_text_iter_get_line_index (&iter);
    
    if (line_index != CORRECT_LINE_INDEX)
    {
        TEST_FAIL ("line_index = %d, should be %d\n", line_index, CORRECT_LINE_INDEX);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the byte index of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_75()
{
    #define TEST_LINE "Line 0\n L$$$ 1\r"
    #define OFFSET 15
    #define CORRECT_LINE_INDEX 0
    
    GtkTextIter iter;
    gint line_index;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_index = gtk_text_iter_get_line_index (&iter);
    
    if (line_index != CORRECT_LINE_INDEX)
    {
        TEST_FAIL ("line_index = %d, should be %d\n", line_index, CORRECT_LINE_INDEX);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the byte index of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_76()
{
    #define TEST_LINE "Line 0\n Line 1\r"
    #define OFFSET 16
    #define CORRECT_LINE_INDEX 0
    
    GtkTextIter iter;
    gint line_index;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_index = gtk_text_iter_get_line_index (&iter);
    
    if (line_index != CORRECT_LINE_INDEX)
    {
        TEST_FAIL ("line_index = %d, should be %d\n", line_index, CORRECT_LINE_INDEX);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the byte index of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_77()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define OFFSET 0
    #define CORRECT_LINE_INDEX 0
    
    GtkTextIter iter;
    gint line_index;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_index = gtk_text_iter_get_line_index (&iter);
    
    if (line_index != CORRECT_LINE_INDEX)
    {
        TEST_FAIL ("line_index = %d, should be %d\n", line_index, CORRECT_LINE_INDEX);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the byte index of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 6   
 */
static void test_purpose_78()
{
    #define TEST_LINE "\r$$\r\n\n\r\r\r\n\r\n"
    #define OFFSET 3
    #define CORRECT_LINE_INDEX 6
    
    GtkTextIter iter;
    gint line_index;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_index = gtk_text_iter_get_line_index (&iter);
    
    if (line_index != CORRECT_LINE_INDEX)
    {
        TEST_FAIL ("line_index = %d, should be %d\n", line_index, CORRECT_LINE_INDEX);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the byte index of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 1   
 */
static void test_purpose_79()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define OFFSET 2
    #define CORRECT_LINE_INDEX 1
    
    GtkTextIter iter;
    gint line_index;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_index = gtk_text_iter_get_line_index (&iter);
    
    if (line_index != CORRECT_LINE_INDEX)
    {
        TEST_FAIL ("line_index = %d, should be %d\n", line_index, CORRECT_LINE_INDEX);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the byte index of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 0   
 */
static void test_purpose_80()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define OFFSET 4
    #define CORRECT_LINE_INDEX 0
    
    GtkTextIter iter;
    gint line_index;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_index = gtk_text_iter_get_line_index (&iter);
    
    if (line_index != CORRECT_LINE_INDEX)
    {
        TEST_FAIL ("line_index = %d, should be %d\n", line_index, CORRECT_LINE_INDEX);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the byte index of the iterator, counting from the start of a newline-terminated line.
 * Params Values: GtkTextIter*
 * Expected: 1   
 */
static void test_purpose_81()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define OFFSET 7
    #define CORRECT_LINE_INDEX 1
    
    GtkTextIter iter;
    gint line_index;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    line_index = gtk_text_iter_get_line_index (&iter);
    
    if (line_index != CORRECT_LINE_INDEX)
    {
        TEST_FAIL ("line_index = %d, should be %d\n", line_index, CORRECT_LINE_INDEX);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_LINE_INDEX
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_index
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Same as gtk_text_iter_set_line_offset(), but works with a byte index.
 * Params Values: GtkTextIter*, 0
 * Expected: void   
 */
static void test_purpose_82()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE_NO 0
    #define LINE_INDEX 0
    #define CORRECT_OFFSET 0
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE_NO);
    gtk_text_iter_set_line_index (&iter, LINE_INDEX);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef LINE_NO
    #undef LINE_INDEX
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_index
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Same as gtk_text_iter_set_line_offset(), but works with a byte index.
 * Params Values: GtkTextIter*, 1
 * Expected: void   
 */
static void test_purpose_83()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE_NO 1
    #define LINE_INDEX 0
    #define CORRECT_OFFSET 7
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE_NO);
    gtk_text_iter_set_line_index (&iter, LINE_INDEX);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef LINE_NO
    #undef LINE_INDEX
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_index
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Same as gtk_text_iter_set_line_offset(), but works with a byte index.
 * Params Values: GtkTextIter*, 1
 * Expected: void   
 */
static void test_purpose_84()
{
    #define TEST_LINE "Line 0\n$$ Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE_NO 1
    #define LINE_INDEX 3
    #define CORRECT_OFFSET 8
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE_NO);
    gtk_text_iter_set_line_index (&iter, LINE_INDEX);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef LINE_NO
    #undef LINE_INDEX
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_index
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Same as gtk_text_iter_set_line_offset(), but works with a byte index.
 * Params Values: GtkTextIter*, 1
 * Expected: void   
 */
static void test_purpose_85()
{
    #define TEST_LINE "Line 0\n$$ Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE_NO 1
    #define LINE_INDEX 6
    #define CORRECT_OFFSET 9
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE_NO);
    gtk_text_iter_set_line_index (&iter, LINE_INDEX);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef LINE_NO
    #undef LINE_INDEX
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_index
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Same as gtk_text_iter_set_line_offset(), but works with a byte index.
 * Params Values: GtkTextIter*, 7
 * Expected: void   
 */
static void test_purpose_86()
{
    #define TEST_LINE "Line 0\r\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE_NO 7
    #define LINE_INDEX 0
    #define CORRECT_OFFSET 48
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE_NO);
    gtk_text_iter_set_line_index (&iter, LINE_INDEX);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef LINE_NO
    #undef LINE_INDEX
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_index
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Same as gtk_text_iter_set_line_offset(), but works with a byte index.
 * Params Values: GtkTextIter*, 8
 * Expected: void   
 */
static void test_purpose_87()
{
    #define TEST_LINE "Line 0\r\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE_NO 8
    #define LINE_INDEX 0
    #define CORRECT_OFFSET 48
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE_NO);
    gtk_text_iter_set_line_index (&iter, LINE_INDEX);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef LINE_NO
    #undef LINE_INDEX
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_index
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Same as gtk_text_iter_set_line_offset(), but works with a byte index.
 * Params Values: GtkTextIter*, 0
 * Expected: void   
 */
static void test_purpose_88()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define LINE_NO 0
    #define LINE_INDEX 7
    #define CORRECT_OFFSET 7
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE_NO);
    gtk_text_iter_set_line_index (&iter, LINE_INDEX);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef LINE_NO
    #undef LINE_INDEX
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_set_line_index
 * Params: const GtkTextIter* iter, gint line
 * Returns: void
 * Assertion: Same as gtk_text_iter_set_line_offset(), but works with a byte index.
 * Params Values: GtkTextIter*, 1
 * Expected: void   
 */
static void test_purpose_89()
{
    #define TEST_LINE "Line 0\n Line 1"
    #define LINE_NO 1
    #define LINE_INDEX 7
    #define CORRECT_OFFSET 14
    
    GtkTextIter iter;
    gint real_offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar** splitted_str;
    char* outbuf;
    gchar *line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    line = TEST_LINE;
    /* hack to add 0xFFFC to line */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (line, "$", 0);
    line = g_strjoinv (outbuf, splitted_str);
    
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, line, strlen(line));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_iter_set_line (&iter, LINE_NO);
    gtk_text_iter_set_line_index (&iter, LINE_INDEX);
    
    real_offset = gtk_text_iter_get_offset (&iter);
    if (real_offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("real_offset = %d, should be %d\n", real_offset, CORRECT_OFFSET);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef LINE_NO
    #undef LINE_INDEX
    #undef CORRECT_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_visible_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the number of bytes from the start of the line to the given iter, not counting bytes that are invisible due to tags with the "invisible" flag toggled on.
 * Params Values: GtkTextIter*
 * Expected: 0 
 * 
 * Name: gtk_text_iter_set_visible_line_index
 * Params: const GtkTextIter* iter, gint ind
 * Returns: void
 * Assertion: Like gtk_text_iter_set_line_index(), but the index is in visible bytes, i.e. text with a tag making it invisible is not counted in the index.
 * Params Values: GtkTextIter*, 0
 * Expected: void   
 */
static void test_purpose_90()
{
    #define    TEST_LINE "Line 0\n Line 1\n\n"
    #define    LINE_NO 0
    #define    IND 0
    #define    INV_TAG_START_POS 0
    #define    INV_TAG_END_POS 5
    #define    CORRECT_OFFSET 6
    
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    gint ind;
    gint offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag *invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, INV_TAG_START_POS);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, INV_TAG_END_POS);
    gtk_text_iter_set_line (&iter, LINE_NO);
    
    /*
    invisible_tag = gtk_text_buffer_create_tag(buffer, NULL, "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, &start, &end);
    gtk_text_iter_set_visible_line_index (&iter, IND);
    
    offset = gtk_text_iter_get_offset (&iter);
    if (offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("offset = %d, should be %d", offset, CORRECT_OFFSET);
    }
    
    ind = gtk_text_iter_get_visible_line_index(&iter);
    if (ind != IND)
    {
        TEST_FAIL ("visible index = %d, should be %d\n", ind, (gint) IND);
        return;
    }
    */
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE_NO
    #undef IND
    #undef INV_TAG_START_POS
    #undef INV_TAG_END_POS
    #undef CORRECT_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_visible_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the number of bytes from the start of the line to the given iter, not counting bytes that are invisible due to tags with the "invisible" flag toggled on.
 * Params Values: GtkTextIter*
 * Expected: 0 
 * 
 * Name: gtk_text_iter_set_visible_line_index
 * Params: const GtkTextIter* iter, gint ind
 * Returns: void
 * Assertion: Like gtk_text_iter_set_line_index(), but the index is in visible bytes, i.e. text with a tag making it invisible is not counted in the index.
 * Params Values: GtkTextIter*, 0
 * Expected: void   
 */
static void test_purpose_91()
{
    #define    TEST_LINE "Line 0\n Line 1\n\n"
    #define    LINE_NO 0
    #define    IND 0
    #define    INV_TAG_START_POS 0
    #define    INV_TAG_END_POS 6
    #define    CORRECT_OFFSET 0
    
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    gint ind;
    gint offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag *invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, INV_TAG_START_POS);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, INV_TAG_END_POS);
    gtk_text_iter_set_line (&iter, LINE_NO);
    
    /*
    invisible_tag = gtk_text_buffer_create_tag(buffer, NULL, "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, &start, &end);
    gtk_text_iter_set_visible_line_index (&iter, IND);
    
    offset = gtk_text_iter_get_offset (&iter);
    if (offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("offset = %d, should be %d", offset, CORRECT_OFFSET);
    }
    
    ind = gtk_text_iter_get_visible_line_index(&iter);
    if (ind != IND)
    {
        TEST_FAIL ("visible index = %d, should be %d\n", ind, (gint) IND);
        return;
    }
    */
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE_NO
    #undef IND
    #undef INV_TAG_START_POS
    #undef INV_TAG_END_POS
    #undef CORRECT_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_visible_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the number of bytes from the start of the line to the given iter, not counting bytes that are invisible due to tags with the "invisible" flag toggled on.
 * Params Values: GtkTextIter*
 * Expected: 1 
 * 
 * Name: gtk_text_iter_set_visible_line_index
 * Params: const GtkTextIter* iter, gint ind
 * Returns: void
 * Assertion: Like gtk_text_iter_set_line_index(), but the index is in visible bytes, i.e. text with a tag making it invisible is not counted in the index.
 * Params Values: GtkTextIter*, 1
 * Expected: void   
 */
static void test_purpose_92()
{
    #define    TEST_LINE "Line 0\n Line 1\n\n"
    #define    LINE_NO 1
    #define    IND 4
    #define    INV_TAG_START_POS 8
    #define    INV_TAG_END_POS 10
    #define    CORRECT_OFFSET 15
    
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    gint ind;
    gint offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag *invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, INV_TAG_START_POS);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, INV_TAG_END_POS);
    gtk_text_iter_set_line (&iter, LINE_NO);
    
    /*
    invisible_tag = gtk_text_buffer_create_tag(buffer, NULL, "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, &start, &end);
    gtk_text_iter_set_visible_line_index (&iter, IND);
    
    offset = gtk_text_iter_get_offset (&iter);
    if (offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("offset = %d, should be %d", offset, CORRECT_OFFSET);
    }
    
    ind = gtk_text_iter_get_visible_line_index(&iter);
    if (ind != IND)
    {
        TEST_FAIL ("visible index = %d, should be %d\n", ind, (gint) IND);
        return;
    }
    */
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE_NO
    #undef IND
    #undef INV_TAG_START_POS
    #undef INV_TAG_END_POS
    #undef CORRECT_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_visible_line_index
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the number of bytes from the start of the line to the given iter, not counting bytes that are invisible due to tags with the "invisible" flag toggled on.
 * Params Values: GtkTextIter*
 * Expected: 1 
 * 
 * Name: gtk_text_iter_set_visible_line_index
 * Params: const GtkTextIter* iter, gint ind
 * Returns: void
 * Assertion: Like gtk_text_iter_set_line_index(), but the index is in visible bytes, i.e. text with a tag making it invisible is not counted in the index.
 * Params Values: GtkTextIter*, 1
 * Expected: void   
 */
static void test_purpose_93()
{
    #define    TEST_LINE "Line 0\n Line 1\n\n"
    #define    LINE_NO 1
    #define    IND 4
    #define    INV_TAG_START_POS 2
    #define    INV_TAG_END_POS 5
    #define    CORRECT_OFFSET 12
    
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    gint ind;
    gint offset;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag *invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, INV_TAG_START_POS);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, INV_TAG_END_POS);
    gtk_text_iter_set_line (&iter, LINE_NO);
    
    /*
    invisible_tag = gtk_text_buffer_create_tag(buffer, NULL, "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, &start, &end);
    gtk_text_iter_set_visible_line_index (&iter, IND);
    
    offset = gtk_text_iter_get_offset (&iter);
    if (offset != CORRECT_OFFSET)
    {
        TEST_FAIL ("offset = %d, should be %d", offset, CORRECT_OFFSET);
    }
    
    ind = gtk_text_iter_get_visible_line_index(&iter);
    if (ind != IND)
    {
        TEST_FAIL ("visible index = %d, should be %d\n", ind, (gint) IND);
        return;
    }
    */
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE_NO
    #undef IND
    #undef INV_TAG_START_POS
    #undef INV_TAG_END_POS
    #undef CORRECT_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_visible_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the offset in characters from the start of the line to the given iter, not counting characters that are invisible due to tags with the "invisible" flag toggled on.
 * Params Values: GtkTextIter*
 * Expected: 0 
 * 
 * Name: gtk_text_iter_set_visible_line_offset
 * Params: const GtkTextIter* iter, gint offs
 * Returns: void
 * Assertion: Like gtk_text_iter_set_line_offset(), but the offset is in visible characters, i.e. text with a tag making it invisible is not counted in the offset.
 * Params Values: GtkTextIter*, 0
 * Expected: void   
 */
static void test_purpose_94()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "             
    #define    OFFS 0
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, 5);
    
    gtk_text_iter_set_visible_line_offset(&iter, OFFS);
    offs = gtk_text_iter_get_visible_line_offset(&iter);
    
    if (offs != OFFS)
    {
        TEST_FAIL ("offset = %d, should be %d\n", offs, (gint) OFFS);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef OFFS
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_visible_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the offset in characters from the start of the line to the given iter, not counting characters that are invisible due to tags with the "invisible" flag toggled on.
 * Params Values: GtkTextIter*
 * Expected: 2 
 * 
 * Name: gtk_text_iter_set_visible_line_offset
 * Params: const GtkTextIter* iter, gint offs
 * Returns: void
 * Assertion: Like gtk_text_iter_set_line_offset(), but the offset is in visible characters, i.e. text with a tag making it invisible is not counted in the offset.
 * Params Values: GtkTextIter*, 2
 * Expected: void   
 */
static void test_purpose_95()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "             
    #define    OFFS 2
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, 5);
    
    gtk_text_iter_set_visible_line_offset(&iter, OFFS);
    offs = gtk_text_iter_get_visible_line_offset(&iter);
    
    if (offs != OFFS)
    {
        TEST_FAIL ("offset = %d, should be %d\n", offs, (gint) OFFS);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef OFFS
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_visible_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the offset in characters from the start of the line to the given iter, not counting characters that are invisible due to tags with the "invisible" flag toggled on.
 * Params Values: GtkTextIter*
 * Expected: 5 
 * 
 * Name: gtk_text_iter_set_visible_line_offset
 * Params: const GtkTextIter* iter, gint offs
 * Returns: void
 * Assertion: Like gtk_text_iter_set_line_offset(), but the offset is in visible characters, i.e. text with a tag making it invisible is not counted in the offset.
 * Params Values: GtkTextIter*, 5
 * Expected: void   
 */
static void test_purpose_96()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "             
    #define    OFFS 5
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, 5);
    
    gtk_text_iter_set_visible_line_offset(&iter, OFFS);
    offs = gtk_text_iter_get_visible_line_offset(&iter);
    
    if (offs != OFFS)
    {
        TEST_FAIL ("offset = %d, should be %d\n", offs, (gint) OFFS);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef OFFS
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_visible_line_offset
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the offset in characters from the start of the line to the given iter, not counting characters that are invisible due to tags with the "invisible" flag toggled on.
 * Params Values: GtkTextIter*
 * Expected: 10 
 * 
 * Name: gtk_text_iter_set_visible_line_offset
 * Params: const GtkTextIter* iter, gint offs
 * Returns: void
 * Assertion: Like gtk_text_iter_set_line_offset(), but the offset is in visible characters, i.e. text with a tag making it invisible is not counted in the offset.
 * Params Values: GtkTextIter*, 10
 * Expected: void   
 */
static void test_purpose_97()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    OFFS 10
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, 5);
    
    gtk_text_iter_set_visible_line_offset(&iter, OFFS);
    offs = gtk_text_iter_get_visible_line_offset(&iter);
    
    if (offs != OFFS)
    {
        TEST_FAIL ("offset = %d, should be %d\n", offs, (gint) OFFS);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef OFFS
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_char
 * Params: const GtkTextIter* iter
 * Returns: gunichar
 * Assertion: Returns the Unicode character at this iterator.
 * Params Values: GtkTextIter*
 * Expected: "L"  
 */
static void test_purpose_98()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "             
    #define    LINE 0
    #define    OFFS 0
    #define    CHAR "L"
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gunichar ch;
    gchar*   c;
    gchar*   c_from_utf8;
    gchar*   c_ucs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    c = CHAR;
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    gtk_text_iter_set_line_offset(&iter, OFFS);
    
    ch = gtk_text_iter_get_char(&iter);
    c_ucs = g_ucs4_to_utf8 (&ch, 1, NULL, NULL, NULL);
    c_from_utf8 = g_locale_from_utf8 (c_ucs, 1, NULL, NULL, NULL); 
    g_free(c_ucs);
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (*c != *c_from_utf8 )
    {
        TEST_FAIL ("char = %c, should be %c\n", *c_from_utf8, *c);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef LINE
    #undef OFFS
    #undef CHAR
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_char
 * Params: const GtkTextIter* iter
 * Returns: gunichar
 * Assertion: Returns the Unicode character at this iterator.
 * Params Values: GtkTextIter*
 * Expected: "i"  
 */
static void test_purpose_99()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "             
    #define    LINE 0
    #define    OFFS 1
    #define    CHAR "i"
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gunichar ch;
    gchar*   c;
    gchar*   c_from_utf8;
    gchar*   c_ucs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    c = CHAR;
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    gtk_text_iter_set_line_offset(&iter, OFFS);
    
    ch = gtk_text_iter_get_char(&iter);
    c_ucs = g_ucs4_to_utf8 (&ch, 1, NULL, NULL, NULL);
    c_from_utf8 = g_locale_from_utf8 (c_ucs, 1, NULL, NULL, NULL); 
    g_free(c_ucs);
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (*c != *c_from_utf8 )
    {
        TEST_FAIL ("char = %c, should be %c\n", *c_from_utf8, *c);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef LINE
    #undef OFFS
    #undef CHAR
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_char
 * Params: const GtkTextIter* iter
 * Returns: gunichar
 * Assertion: Returns the Unicode character at this iterator.
 * Params Values: GtkTextIter*
 * Expected: " "  
 */
static void test_purpose_100()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE 0
    #define    OFFS 4
    #define    CHAR " "
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gunichar ch;
    gchar*   c;
    gchar*   c_from_utf8;
    gchar*   c_ucs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    c = CHAR;
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    gtk_text_iter_set_line_offset(&iter, OFFS);
    
    ch = gtk_text_iter_get_char(&iter);
    c_ucs = g_ucs4_to_utf8 (&ch, 1, NULL, NULL, NULL);
    c_from_utf8 = g_locale_from_utf8 (c_ucs, 1, NULL, NULL, NULL); 
    g_free(c_ucs);
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (*c != *c_from_utf8 )
    {
        TEST_FAIL ("char = %c, should be %c\n", *c_from_utf8, *c);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef LINE
    #undef OFFS
    #undef CHAR
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_char
 * Params: const GtkTextIter* iter
 * Returns: gunichar
 * Assertion: Returns the Unicode character at this iterator.
 * Params Values: GtkTextIter*
 * Expected: "i"  
 */
static void test_purpose_101()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE 1
    #define    OFFS 2
    #define    CHAR "i"
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gunichar ch;
    gchar*   c;
    gchar*   c_from_utf8;
    gchar*   c_ucs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    c = CHAR;
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    gtk_text_iter_set_line_offset(&iter, OFFS);
    
    ch = gtk_text_iter_get_char(&iter);
    c_ucs = g_ucs4_to_utf8 (&ch, 1, NULL, NULL, NULL);
    c_from_utf8 = g_locale_from_utf8 (c_ucs, 1, NULL, NULL, NULL); 
    g_free(c_ucs);
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (*c != *c_from_utf8 )
    {
        TEST_FAIL ("char = %c, should be %c\n", *c_from_utf8, *c);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef LINE
    #undef OFFS
    #undef CHAR
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_char
 * Params: const GtkTextIter* iter
 * Returns: gunichar
 * Assertion: Returns the Unicode character at this iterator.
 * Params Values: GtkTextIter*
 * Expected: "5"  
 */
static void test_purpose_102()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE 5
    #define    OFFS 6
    #define    CHAR "5"
    
    GtkTextIter iter;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gunichar ch;
    gchar*   c;
    gchar*   c_from_utf8;
    gchar*   c_ucs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    c = CHAR;
    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    gtk_text_iter_set_line_offset(&iter, OFFS);
    
    ch = gtk_text_iter_get_char(&iter);
    c_ucs = g_ucs4_to_utf8 (&ch, 1, NULL, NULL, NULL);
    c_from_utf8 = g_locale_from_utf8 (c_ucs, 1, NULL, NULL, NULL); 
    g_free(c_ucs);
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (*c != *c_from_utf8 )
    {
        TEST_FAIL ("char = %c, should be %c\n", *c_from_utf8, *c);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef LINE
    #undef OFFS
    #undef CHAR
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_char
 * Params: const GtkTextIter* iter
 * Returns: gunichar
 * Assertion: If the element at this iterator is a non-character element, such as an image embedded in the buffer, the Unicode "unknown" character 0xFFFC is returned.
 * Params Values: GtkTextIter*
 * Expected: 0xFFFC  
 */
static void test_purpose_103()
{
    #define    TEST_LINE "Line 0\n"
    #define    OFFSET 0
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GdkPixbuf* pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*  adding pixbuf  */
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_insert_pixbuf (buffer, &iter, pixbuf);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_get_char(&iter) != 0xFFFC)
    {
        TEST_FAIL ("symbol at the pos %d should be 0xFFFC", 
                   OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef OFFSET
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_char
 * Params: const GtkTextIter* iter
 * Returns: gunichar
 * Assertion: If the element at this iterator is a non-character element, such as an image embedded in the buffer, the Unicode "unknown" character 0xFFFC is returned.
 * Params Values: GtkTextIter*
 * Expected: 0xFFFC  
 */
static void test_purpose_104()
{
    #define    TEST_LINE "Line 0\n"
    #define    OFFSET 5
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GdkPixbuf* pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*  adding pixbuf  */
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_insert_pixbuf (buffer, &iter, pixbuf);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_get_char(&iter) != 0xFFFC)
    {
        TEST_FAIL ("symbol at the pos %d should be 0xFFFC", 
                   OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef OFFSET
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_char
 * Params: const GtkTextIter* iter
 * Returns: gunichar
 * Assertion: If the element at this iterator is a non-character element, such as an image embedded in the buffer, the Unicode "unknown" character 0xFFFC is returned.
 * Params Values: GtkTextIter*
 * Expected: 0xFFFC  
 */
static void test_purpose_105()
{
    #define    TEST_LINE "Line 0\n"
    #define    OFFSET 6
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GdkPixbuf* pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*  adding pixbuf  */
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_insert_pixbuf (buffer, &iter, pixbuf);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_get_char(&iter) != 0xFFFC)
    {
        TEST_FAIL ("symbol at the pos %d should be 0xFFFC", 
                   OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef OFFSET
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_char
 * Params: const GtkTextIter* iter
 * Returns: gunichar
 * Assertion: If invoked on the end iterator, zero is returned; zero is not a valid Unicode character.
 * Params Values: GtkTextIter*
 * Expected: 0xFFFC  
 */
static void test_purpose_106()
{
    #define    TEST_LINE "Line 0\n"
    #define    OFFSET 7
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GdkPixbuf* pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_get_char(&iter) != 0)
    {
        TEST_FAIL ("symbol at the pos %d should be 0", OFFSET);
    }
    
    gtk_widget_destroy(view);
    
    #undef OFFSET
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_slice
 * Params: const GtkTextIter* start, const GtkTextIter* end
 * Returns: gunichar
 * Assertion: Returns the text in the given range.
 * Params Values:  const GtkTextIter* start, const GtkTextIter* end
 * Expected: "L"  
 */
static void test_purpose_107()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "                     
    #define    LINE1 0
    #define    OFFS1 0
    #define    LINE2 0
    #define    OFFS2 1
    #define    CHAR "L"
    
    GtkTextIter start;
    GtkTextIter end;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar*   c_from_utf8;
    gchar*   ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &start, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &end, 0);
    
    gtk_text_iter_set_line(&start, LINE1);
    gtk_text_iter_set_line_offset(&start, OFFS1);
    gtk_text_iter_set_line(&end, LINE2);
    gtk_text_iter_set_line_offset(&end, OFFS2);
    
    ch = gtk_text_iter_get_slice(&start, &end);
    c_from_utf8 = g_locale_from_utf8 (ch, strlen(ch), NULL, NULL, NULL); 
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (strcmp(CHAR,  c_from_utf8))
    {
        TEST_FAIL ("char = %s, should be: %s\n", c_from_utf8, CHAR);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef LINE1
    #undef OFFS1
    #undef LINE2
    #undef OFFS2
    #undef CHAR
    #undef TEST_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_slice
 * Params: const GtkTextIter* start, const GtkTextIter* end
 * Returns: gunichar
 * Assertion: Returns the text in the given range.
 * Params Values:  const GtkTextIter* start, const GtkTextIter* end
 * Expected: "Line"  
 */
static void test_purpose_108()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "
    #define    LINE1 0
    #define    OFFS1 0
    #define    LINE2 0
    #define    OFFS2 4
    #define    CHAR "Line"
    
    GtkTextIter start;
    GtkTextIter end;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar*   c_from_utf8;
    gchar*   ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &start, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &end, 0);
    
    gtk_text_iter_set_line(&start, LINE1);
    gtk_text_iter_set_line_offset(&start, OFFS1);
    gtk_text_iter_set_line(&end, LINE2);
    gtk_text_iter_set_line_offset(&end, OFFS2);
    
    ch = gtk_text_iter_get_slice(&start, &end);
    c_from_utf8 = g_locale_from_utf8 (ch, strlen(ch), NULL, NULL, NULL); 
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (strcmp(CHAR,  c_from_utf8))
    {
        TEST_FAIL ("char = %s, should be: %s\n", c_from_utf8, CHAR);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef LINE1
    #undef OFFS1
    #undef LINE2
    #undef OFFS2
    #undef CHAR
    #undef TEST_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_slice
 * Params: const GtkTextIter* start, const GtkTextIter* end
 * Returns: gunichar
 * Assertion: Returns the text in the given range.
 * Params Values:  const GtkTextIter* start, const GtkTextIter* end
 * Expected: " Line 5 very long"  
 */
static void test_purpose_109()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE1 5
    #define    OFFS1 0
    #define    LINE2 5
    #define    OFFS2 17
    #define    CHAR " Line 5 very long"
    
    GtkTextIter start;
    GtkTextIter end;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar*   c_from_utf8;
    gchar*   ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &start, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &end, 0);
    
    gtk_text_iter_set_line(&start, LINE1);
    gtk_text_iter_set_line_offset(&start, OFFS1);
    gtk_text_iter_set_line(&end, LINE2);
    gtk_text_iter_set_line_offset(&end, OFFS2);
    
    ch = gtk_text_iter_get_slice(&start, &end);
    c_from_utf8 = g_locale_from_utf8 (ch, strlen(ch), NULL, NULL, NULL); 
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (strcmp(CHAR,  c_from_utf8))
    {
        TEST_FAIL ("char = %s, should be: %s\n", c_from_utf8, CHAR);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef LINE1
    #undef OFFS1
    #undef LINE2
    #undef OFFS2
    #undef CHAR
    #undef TEST_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_text
 * Params: const GtkTextIter* start, const GtkTextIter* end
 * Returns: gunichar
 * Assertion: Returns text in the given range.
 * Params Values:  const GtkTextIter* start, const GtkTextIter* end
 * Expected: gchar*   
 */
static void test_purpose_110()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE1 1
    #define    OFFS1 1
    #define    LINE2 1
    #define    OFFS2 2
    #define    CHAR "L"
    
    GtkTextIter start;
    GtkTextIter end;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar*   c_from_utf8;
    gchar*   ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &start, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &end, 0);
    
    gtk_text_iter_set_line(&start, LINE1);
    gtk_text_iter_set_line_offset(&start, OFFS1);
    gtk_text_iter_set_line(&end, LINE2);
    gtk_text_iter_set_line_offset(&end, OFFS2);
    
    ch = gtk_text_iter_get_text(&start, &end);
    c_from_utf8 = g_locale_from_utf8 (ch, strlen(ch), NULL, NULL, NULL); 
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (strcmp(CHAR,  c_from_utf8))
    {
        TEST_FAIL ("char = %s, should be: %s\n", c_from_utf8, CHAR);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef LINE1
    #undef OFFS1
    #undef LINE2
    #undef OFFS2
    #undef CHAR
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_text
 * Params: const GtkTextIter* start, const GtkTextIter* end
 * Returns: gunichar
 * Assertion: Returns text in the given range.
 * Params Values:  const GtkTextIter* start, const GtkTextIter* end
 * Expected: gchar*   
 */
static void test_purpose_111()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE1 0
    #define    OFFS1 0
    #define    LINE2 0
    #define    OFFS2 4
    #define    CHAR "Line"
    
    GtkTextIter start;
    GtkTextIter end;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar*   c_from_utf8;
    gchar*   ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &start, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &end, 0);
    
    gtk_text_iter_set_line(&start, LINE1);
    gtk_text_iter_set_line_offset(&start, OFFS1);
    gtk_text_iter_set_line(&end, LINE2);
    gtk_text_iter_set_line_offset(&end, OFFS2);
    
    ch = gtk_text_iter_get_text(&start, &end);
    c_from_utf8 = g_locale_from_utf8 (ch, strlen(ch), NULL, NULL, NULL); 
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (strcmp(CHAR,  c_from_utf8))
    {
        TEST_FAIL ("char = %s, should be: %s\n", c_from_utf8, CHAR);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef LINE1
    #undef OFFS1
    #undef LINE2
    #undef OFFS2
    #undef CHAR
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_text
 * Params: const GtkTextIter* start, const GtkTextIter* end
 * Returns: gunichar
 * Assertion: Returns text in the given range.
 * Params Values:  const GtkTextIter* start, const GtkTextIter* end
 * Expected: gchar*   
 */
static void test_purpose_112()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE1 5
    #define    OFFS1 0
    #define    LINE2 5
    #define    OFFS2 17
    #define    CHAR " Line 5 very long"
    
    GtkTextIter start;
    GtkTextIter end;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gchar*   c_from_utf8;
    gchar*   ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &start, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &end, 0);
    
    gtk_text_iter_set_line(&start, LINE1);
    gtk_text_iter_set_line_offset(&start, OFFS1);
    gtk_text_iter_set_line(&end, LINE2);
    gtk_text_iter_set_line_offset(&end, OFFS2);
    
    ch = gtk_text_iter_get_text(&start, &end);
    c_from_utf8 = g_locale_from_utf8 (ch, strlen(ch), NULL, NULL, NULL); 
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (strcmp(CHAR,  c_from_utf8))
    {
        TEST_FAIL ("char = %s, should be: %s\n", c_from_utf8, CHAR);
        return;
    }
    gtk_widget_destroy(view);
    
    #undef LINE1
    #undef OFFS1
    #undef LINE2
    #undef OFFS2
    #undef CHAR
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_visible_slice
 * Params: const GtkTextIter* start, const GtkTextIter* end
 * Returns: gunichar
 * Assertion: Like gtk_text_iter_get_slice(), but invisible text is not included.
 * Params Values:  const GtkTextIter* start, const GtkTextIter* end
 * Expected: gchar*   
 */
static void test_purpose_113()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE1 0
    #define    OFFS1 0
    #define    LINE2 0
    #define    OFFS2 1
    #define    CHAR "L"
    
    GtkTextIter start;
    GtkTextIter end;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag *invisible_tag;
    gchar*   c_from_utf8;
    gchar*   ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &start, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &end, 0);
    
    /*     set invisible range   */
    gtk_text_iter_set_line(&start, 4);
    gtk_text_iter_set_line_offset(&start, 0);
    gtk_text_iter_set_line(&end, 5);
    gtk_text_iter_set_line_offset(&end, 5);
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &start, &end);
    
    
    gtk_text_iter_set_line(&start, LINE1);
    gtk_text_iter_set_line_offset(&start, OFFS1);
    gtk_text_iter_set_line(&end, LINE2);
    gtk_text_iter_set_line_offset(&end, OFFS2);
    
    ch = gtk_text_iter_get_visible_slice(&start, &end);
    c_from_utf8 = g_locale_from_utf8 (ch, strlen(ch), NULL, NULL, NULL); 
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (strcmp(CHAR,  c_from_utf8))
    {
        TEST_FAIL ("char=%s, should be:%s\n", c_from_utf8, CHAR);
        return;
    }
    
    */
    
    gtk_widget_destroy(view);
    
    #undef LINE1
    #undef OFFS1
    #undef LINE2
    #undef OFFS2
    #undef CHAR
    #undef TEST_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_visible_slice
 * Params: const GtkTextIter* start, const GtkTextIter* end
 * Returns: gunichar
 * Assertion: Like gtk_text_iter_get_slice(), but invisible text is not included.
 * Params Values:  const GtkTextIter* start, const GtkTextIter* end
 * Expected: gchar*   
 */
static void test_purpose_114()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE1 0
    #define    OFFS1 0
    #define    LINE2 0
    #define    OFFS2 4
    #define    CHAR "Line"
    
    GtkTextIter start;
    GtkTextIter end;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag *invisible_tag;
    gchar*   c_from_utf8;
    gchar*   ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &start, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &end, 0);
    
    /*     set invisible range   */
    gtk_text_iter_set_line(&start, 4);
    gtk_text_iter_set_line_offset(&start, 0);
    gtk_text_iter_set_line(&end, 5);
    gtk_text_iter_set_line_offset(&end, 5);
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &start, &end);
    
    
    gtk_text_iter_set_line(&start, LINE1);
    gtk_text_iter_set_line_offset(&start, OFFS1);
    gtk_text_iter_set_line(&end, LINE2);
    gtk_text_iter_set_line_offset(&end, OFFS2);
    
    ch = gtk_text_iter_get_visible_slice(&start, &end);
    c_from_utf8 = g_locale_from_utf8 (ch, strlen(ch), NULL, NULL, NULL); 
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (strcmp(CHAR,  c_from_utf8))
    {
        TEST_FAIL ("char=%s, should be:%s\n", c_from_utf8, CHAR);
        return;
    }
    
    */
    
    gtk_widget_destroy(view);
    
    #undef LINE1
    #undef OFFS1
    #undef LINE2
    #undef OFFS2
    #undef CHAR
    #undef TEST_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_visible_slice
 * Params: const GtkTextIter* start, const GtkTextIter* end
 * Returns: gunichar
 * Assertion: Like gtk_text_iter_get_slice(), but invisible text is not included.
 * Params Values:  const GtkTextIter* start, const GtkTextIter* end
 * Expected: gchar*   
 */
static void test_purpose_115()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE1 5
    #define    OFFS1 0
    #define    LINE2 5
    #define    OFFS2 17
    #define    CHAR " 5 very long"
    
    GtkTextIter start;
    GtkTextIter end;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag *invisible_tag;
    gchar*   c_from_utf8;
    gchar*   ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &start, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &end, 0);
    
    /*     set invisible range   */
    gtk_text_iter_set_line(&start, 4);
    gtk_text_iter_set_line_offset(&start, 0);
    gtk_text_iter_set_line(&end, 5);
    gtk_text_iter_set_line_offset(&end, 5);
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &start, &end);
    
    
    gtk_text_iter_set_line(&start, LINE1);
    gtk_text_iter_set_line_offset(&start, OFFS1);
    gtk_text_iter_set_line(&end, LINE2);
    gtk_text_iter_set_line_offset(&end, OFFS2);
    
    ch = gtk_text_iter_get_visible_slice(&start, &end);
    c_from_utf8 = g_locale_from_utf8 (ch, strlen(ch), NULL, NULL, NULL); 
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (strcmp(CHAR,  c_from_utf8))
    {
        TEST_FAIL ("char=%s, should be:%s\n", c_from_utf8, CHAR);
        return;
    }
    
    */
    
    gtk_widget_destroy(view);
    
    #undef LINE1
    #undef OFFS1
    #undef LINE2
    #undef OFFS2
    #undef CHAR
    #undef TEST_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_visible_text
 * Params: const GtkTextIter* start, const GtkTextIter* end
 * Returns: gunichar
 * Assertion: Like gtk_text_iter_get_text(), but invisible text is not included.
 * Params Values:  const GtkTextIter* start, const GtkTextIter* end
 * Expected: gchar*   
 */
static void test_purpose_116()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE1 0
    #define    OFFS1 0
    #define    LINE2 0
    #define    OFFS2 1
    #define    CHAR "L"
    
    GtkTextIter start;
    GtkTextIter end;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag *invisible_tag;
    gchar*   c_from_utf8;
    gchar*   ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &start, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &end, 0);
    
    /*     set invisible range   */
    gtk_text_iter_set_line(&start, 4);
    gtk_text_iter_set_line_offset(&start, 0);
    gtk_text_iter_set_line(&end, 5);
    gtk_text_iter_set_line_offset(&end, 5);
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &start, &end);
    
    
    gtk_text_iter_set_line(&start, LINE1);
    gtk_text_iter_set_line_offset(&start, OFFS1);
    gtk_text_iter_set_line(&end, LINE2);
    gtk_text_iter_set_line_offset(&end, OFFS2);
    
    ch = gtk_text_iter_get_visible_text(&start, &end);
    c_from_utf8 = g_locale_from_utf8 (ch, strlen(ch), NULL, NULL, NULL); 
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (strcmp(CHAR,  c_from_utf8))
    {
        TEST_FAIL ("char=%s, should be:%s\n", c_from_utf8, CHAR);
        return;
    }
    */
    
    gtk_widget_destroy(view);
    
    #undef LINE1
    #undef OFFS1
    #undef LINE2
    #undef OFFS2
    #undef CHAR
    #undef TEST_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_visible_text
 * Params: const GtkTextIter* start, const GtkTextIter* end
 * Returns: gunichar
 * Assertion: Like gtk_text_iter_get_text(), but invisible text is not included.
 * Params Values:  const GtkTextIter* start, const GtkTextIter* end
 * Expected: gchar*   
 */
static void test_purpose_117()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE1 0
    #define    OFFS1 0
    #define    LINE2 0
    #define    OFFS2 4
    #define    CHAR "Line"
    
    GtkTextIter start;
    GtkTextIter end;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag *invisible_tag;
    gchar*   c_from_utf8;
    gchar*   ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &start, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &end, 0);
    
    /*     set invisible range   */
    gtk_text_iter_set_line(&start, 4);
    gtk_text_iter_set_line_offset(&start, 0);
    gtk_text_iter_set_line(&end, 5);
    gtk_text_iter_set_line_offset(&end, 5);
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &start, &end);
    
    
    gtk_text_iter_set_line(&start, LINE1);
    gtk_text_iter_set_line_offset(&start, OFFS1);
    gtk_text_iter_set_line(&end, LINE2);
    gtk_text_iter_set_line_offset(&end, OFFS2);
    
    ch = gtk_text_iter_get_visible_text(&start, &end);
    c_from_utf8 = g_locale_from_utf8 (ch, strlen(ch), NULL, NULL, NULL); 
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (strcmp(CHAR,  c_from_utf8))
    {
        TEST_FAIL ("char=%s, should be:%s\n", c_from_utf8, CHAR);
        return;
    }
    */
    
    gtk_widget_destroy(view);
    
    #undef LINE1
    #undef OFFS1
    #undef LINE2
    #undef OFFS2
    #undef CHAR
    #undef TEST_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_visible_text
 * Params: const GtkTextIter* start, const GtkTextIter* end
 * Returns: gunichar
 * Assertion: Like gtk_text_iter_get_text(), but invisible text is not included.
 * Params Values:  const GtkTextIter* start, const GtkTextIter* end
 * Expected: gchar*   
 */
static void test_purpose_118()
{
    #define    TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE1 5
    #define    OFFS1 0
    #define    LINE2 5
    #define    OFFS2 17
    #define    CHAR " 5 very long"
    
    GtkTextIter start;
    GtkTextIter end;
    gint offs;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag *invisible_tag;
    gchar*   c_from_utf8;
    gchar*   ch;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &start, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &end, 0);
    
    /*     set invisible range   */
    gtk_text_iter_set_line(&start, 4);
    gtk_text_iter_set_line_offset(&start, 0);
    gtk_text_iter_set_line(&end, 5);
    gtk_text_iter_set_line_offset(&end, 5);
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &start, &end);
    
    
    gtk_text_iter_set_line(&start, LINE1);
    gtk_text_iter_set_line_offset(&start, OFFS1);
    gtk_text_iter_set_line(&end, LINE2);
    gtk_text_iter_set_line_offset(&end, OFFS2);
    
    ch = gtk_text_iter_get_visible_text(&start, &end);
    c_from_utf8 = g_locale_from_utf8 (ch, strlen(ch), NULL, NULL, NULL); 
    
    if (!c_from_utf8)
    {
        TEST_FAIL ("c_from_utf8 == NULL", NULL);
        return;
    }
    
    if (strcmp(CHAR,  c_from_utf8))
    {
        TEST_FAIL ("char=%s, should be:%s\n", c_from_utf8, CHAR);
        return;
    }
    */
    
    gtk_widget_destroy(view);
    
    #undef LINE1
    #undef OFFS1
    #undef LINE2
    #undef OFFS2
    #undef CHAR
    #undef TEST_LINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_pixbuf
 * Params: const GtkTextIter* iter
 * Returns: GdkPixbuf*
 * Assertion: If the element at iter is a pixbuf, the pixbuf is returned (with no new reference count added).
 * Params Values:  const GtkTextIter* iter
 * Expected: GdkPixbuf*  
 */
static void test_purpose_119()
{
    #define    TEST_LINE "line 1"
    #define    OFFSET 0
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GdkPixbuf* pixbuf;
    GdkPixbuf* real_pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*  adding pixbuf  */
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_insert_pixbuf (buffer, &iter, pixbuf);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    real_pixbuf = gtk_text_iter_get_pixbuf(&iter);
    
    if (real_pixbuf != pixbuf)
    {
        TEST_FAIL ("real_pixbuf = %p, should be:%p\n", pixbuf, real_pixbuf);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_pixbuf
 * Params: const GtkTextIter* iter
 * Returns: GdkPixbuf*
 * Assertion: If the element at iter is a pixbuf, the pixbuf is returned (with no new reference count added).
 * Params Values:  const GtkTextIter* iter
 * Expected: GdkPixbuf*  
 */
static void test_purpose_120()
{
    #define    TEST_LINE "line 1"
    #define    OFFSET 4
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GdkPixbuf* pixbuf;
    GdkPixbuf* real_pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*  adding pixbuf  */
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_insert_pixbuf (buffer, &iter, pixbuf);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    real_pixbuf = gtk_text_iter_get_pixbuf(&iter);
    
    if (real_pixbuf != pixbuf)
    {
        TEST_FAIL ("real_pixbuf = %p, should be:%p\n", pixbuf, real_pixbuf);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_pixbuf
 * Params: const GtkTextIter* iter
 * Returns: GdkPixbuf*
 * Assertion: If the element at iter is a pixbuf, the pixbuf is returned (with no new reference count added).
 * Params Values:  const GtkTextIter* iter
 * Expected: GdkPixbuf*  
 */
static void test_purpose_121()
{
    #define    TEST_LINE "line 1"
    #define    OFFSET 6
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GdkPixbuf* pixbuf;
    GdkPixbuf* real_pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*  adding pixbuf  */
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_insert_pixbuf (buffer, &iter, pixbuf);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    real_pixbuf = gtk_text_iter_get_pixbuf(&iter);
    
    if (real_pixbuf != pixbuf)
    {
        TEST_FAIL ("real_pixbuf = %p, should be:%p\n", pixbuf, real_pixbuf);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_pixbuf
 * Params: const GtkTextIter* iter
 * Returns: GdkPixbuf*
 * Assertion: Otherwise, NULL is returned.
 * Params Values:  const GtkTextIter* iter
 * Expected: NULL  
 */
static void test_purpose_122()
{
    #define    TEST_LINE "line 1"
    #define    PIXBUF_OFFSET 4
    #define    OFFSET 3
    
    GtkTextIter pixbuf_iter;
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GdkPixbuf* pixbuf;
    GdkPixbuf* real_pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*  adding pixbuf  */
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_get_iter_at_offset (buffer, &pixbuf_iter, PIXBUF_OFFSET);
    gtk_text_buffer_insert_pixbuf (buffer, &pixbuf_iter, pixbuf);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    real_pixbuf = gtk_text_iter_get_pixbuf(&iter);
    
    if (real_pixbuf != NULL)
    {
        TEST_FAIL ("real_pixbuf = %p, should be NULL", pixbuf);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef PIXBUF_OFFSET
    #undef OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_pixbuf
 * Params: const GtkTextIter* iter
 * Returns: GdkPixbuf*
 * Assertion: Otherwise, NULL is returned.
 * Params Values:  const GtkTextIter* iter
 * Expected: NULL  
 */
static void test_purpose_123()
{
    #define    TEST_LINE "line 1"
    #define    PIXBUF_OFFSET 6
    #define    OFFSET 5
    
    GtkTextIter pixbuf_iter;
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GdkPixbuf* pixbuf;
    GdkPixbuf* real_pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*  adding pixbuf  */
    pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 10, 10);
    gtk_text_buffer_get_iter_at_offset (buffer, &pixbuf_iter, PIXBUF_OFFSET);
    gtk_text_buffer_insert_pixbuf (buffer, &pixbuf_iter, pixbuf);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    real_pixbuf = gtk_text_iter_get_pixbuf(&iter);
    
    if (real_pixbuf != NULL)
    {
        TEST_FAIL ("real_pixbuf = %p, should be NULL", pixbuf);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef PIXBUF_OFFSET
    #undef OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_marks
 * Params: const GtkTextIter* iter
 * Returns: GSList*
 * Assertion: Returns a list of all GtkTextMark at this location.
 * Params Values:  const GtkTextIter* iter
 * Expected: GSList*  
 */
static void test_purpose_124()
{
    #define    TEST_LINE  "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    COUNT 3
    #define    LINE1 1
    #define    OFFS1 1
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextMark* mark;
    GSList* list;
    gint i;
    gchar  buff[20];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    
    gtk_text_iter_set_line(&iter, LINE1);
    gtk_text_iter_set_line_offset(&iter, OFFS1);
    
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Mark %i", i);
        mark = gtk_text_buffer_create_mark(buffer, buff, &iter, TRUE);
    }
    
    list = gtk_text_iter_get_marks(&iter);
    
    if (!list)
    {
        TEST_FAIL ("list == NULL", NULL);
        return;
    }
    
    if (g_slist_length(list) != COUNT)
    {
        TEST_FAIL ("list count %i != %i", g_slist_length(list), COUNT );
        return;
    }
    
    for (i = 0; i < g_slist_length(list); i++) 
    {
        mark = (GtkTextMark*)g_slist_nth_data(list, i); 
        sprintf(buff, "Mark %i", COUNT - i - 1);
        if ((gtk_text_mark_get_buffer(mark) != buffer) ||
            (strcmp(buff, gtk_text_mark_get_name(mark) )))
             
        {
            TEST_FAIL ("Mark(%i) is wrong", i);
        }    
     
    }
    g_slist_free(list);
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef COUNT
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_marks
 * Params: const GtkTextIter* iter
 * Returns: GSList*
 * Assertion: Returns a list of all GtkTextMark at this location.
 * Params Values:  const GtkTextIter* iter
 * Expected: GSList*  
 */
static void test_purpose_125()
{
    #define    TEST_LINE  "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    COUNT 10
    #define    LINE1 2
    #define    OFFS1 5
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextMark* mark;
    GSList* list;
    gint i;
    gchar  buff[20];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    
    gtk_text_iter_set_line(&iter, LINE1);
    gtk_text_iter_set_line_offset(&iter, OFFS1);
    
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Mark %i", i);
        mark = gtk_text_buffer_create_mark(buffer, buff, &iter, TRUE);
    }
    
    list = gtk_text_iter_get_marks(&iter);
    
    if (!list)
    {
        TEST_FAIL ("list == NULL", NULL);
        return;
    }
    
    if (g_slist_length(list) != COUNT)
    {
        TEST_FAIL ("list count %i != %i", g_slist_length(list), COUNT );
        return;
    }
    
    for (i = 0; i < g_slist_length(list); i++) 
    {
        mark = (GtkTextMark*)g_slist_nth_data(list, i); 
        sprintf(buff, "Mark %i", COUNT - i - 1);
        if ((gtk_text_mark_get_buffer(mark) != buffer) ||
            (strcmp(buff, gtk_text_mark_get_name(mark) )))
             
        {
            TEST_FAIL ("Mark(%i) is wrong", i);
        }    
     
    }
    g_slist_free(list);
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef COUNT
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_toggled_tags
 * Params: const GtkTextIter* iter, gboolean toggled_on
 * Returns: GSList*
 * Assertion: Returns a list of GtkTextTag that are toggled on or off at this point.
 * Params Values:  const GtkTextIter* iter, TRUE
 * Expected: GSList*
 * 
 * Name:  gtk_text_iter_get_toggled_tags
 * Params: const GtkTextIter* iter, gboolean toggled_on
 * Returns: GSList*
 * Assertion: (If toggled_on is TRUE, the list contains tags that are toggled on.) 
 * Params Values:  const GtkTextIter* iter, TRUE
 * Expected: GSList*
 * 
 * Name:  gtk_text_iter_get_toggled_tags
 * Params: const GtkTextIter* iter, gboolean toggled_on
 * Returns: GSList*
 * Assertion: If a tag is toggled off, then some non-empty range following iter does not have the tag applied to it.
 * Params Values:  const GtkTextIter* iter, TRUE
 * Expected: GSList*
 * 
 * Name:  gtk_text_iter_get_toggled_tags
 * Params: const GtkTextIter* iter, gboolean toggled_on
 * Returns: GSList*
 * Assertion: If a tag is toggled on at iter, then some non-empty range of characters following iter has that tag applied to it.
 * Params Values:  const GtkTextIter* iter, TRUE
 * Expected: GSList*  
 */
static void test_purpose_126()
{
    #define TEST_LINE  "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "
    #define OFFSET1 6
    #define OFFSET2 12
    #define TEST_OFFSET 6
    #define TOGGLED TRUE
    #define COUNT 8
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag* tag;
    GSList* list;
    gint i;
    gchar  buff[20];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, TEST_OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET2);
    
    for (i = 0; i < COUNT; i++) 
    {
        sprintf (buff, "Tag %i", i);
        tag = gtk_text_buffer_create_tag (buffer, buff, "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    }
    
    list = gtk_text_iter_get_toggled_tags (&iter, TOGGLED);
    
    if (!list)
    {
        TEST_FAIL ("toggled tags list is NULL", NULL);
        return;
    }
    
    if (g_slist_length (list) != COUNT)
    {
        TEST_FAIL ("toggled tags list length = %d, should be %d", g_slist_length (list), COUNT);
    }
    
    for (i = 0; i < g_slist_length(list); i++) 
    {
        tag = (GtkTextTag*)g_slist_nth_data (list, i); 
        if (!TOGGLED && gtk_text_iter_has_tag (&iter, tag))
        {
            TEST_FAIL ("Not toggled Tag(%i) is applied to iter", i);
        }
    
        if (TOGGLED && !gtk_text_iter_has_tag (&iter, tag))
        {
            TEST_FAIL ("Toggled Tag(%i) isn't applied to iter", i);
        }
    }
    
    g_slist_free (list);
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef OFFSET1
    #undef OFFSET2
    #undef TEST_OFFSET
    #undef TOGGLED
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_toggled_tags
 * Params: const GtkTextIter* iter, gboolean toggled_on
 * Returns: GSList*
 * Assertion: Returns a list of GtkTextTag that are toggled on or off at this point.
 * Params Values:  const GtkTextIter* iter, FALSE
 * Expected: GSList*
 * 
 * Name:  gtk_text_iter_get_toggled_tags
 * Params: const GtkTextIter* iter, gboolean toggled_on
 * Returns: GSList*
 * Assertion: (If toggled_on is TRUE, the list contains tags that are toggled on.) 
 * Params Values:  const GtkTextIter* iter, FALSE
 * Expected: GSList*
 * 
 * Name:  gtk_text_iter_get_toggled_tags
 * Params: const GtkTextIter* iter, gboolean toggled_on
 * Returns: GSList*
 * Assertion: If a tag is toggled off, then some non-empty range following iter does not have the tag applied to it.
 * Params Values:  const GtkTextIter* iter, FALSE
 * Expected: GSList*
 * 
 * Name:  gtk_text_iter_get_toggled_tags
 * Params: const GtkTextIter* iter, gboolean toggled_on
 * Returns: GSList*
 * Assertion: If a tag is toggled on at iter, then some non-empty range of characters following iter has that tag applied to it.
 * Params Values:  const GtkTextIter* iter, FALSE
 * Expected: GSList*  
 */
static void test_purpose_127()
{
    #define TEST_LINE  "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "
    #define OFFSET1 5
    #define OFFSET2 15
    #define TEST_OFFSET 15
    #define TOGGLED FALSE
    #define COUNT 4
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag* tag;
    GSList* list;
    gint i;
    gchar  buff[20];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, TEST_OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET2);
    
    for (i = 0; i < COUNT; i++) 
    {
        sprintf (buff, "Tag %i", i);
        tag = gtk_text_buffer_create_tag (buffer, buff, "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    }
    
    list = gtk_text_iter_get_toggled_tags (&iter, TOGGLED);
    
    if (!list)
    {
        TEST_FAIL ("toggled tags list is NULL", NULL);
        return;
    }
    
    if (g_slist_length (list) != COUNT)
    {
        TEST_FAIL ("toggled tags list length = %d, should be %d", g_slist_length (list), COUNT);
    }
    
    for (i = 0; i < g_slist_length(list); i++) 
    {
        tag = (GtkTextTag*)g_slist_nth_data (list, i); 
        if (!TOGGLED && gtk_text_iter_has_tag (&iter, tag))
        {
            TEST_FAIL ("Not toggled Tag(%i) is applied to iter", i);
        }
    
        if (TOGGLED && !gtk_text_iter_has_tag (&iter, tag))
        {
            TEST_FAIL ("Toggled Tag(%i) isn't applied to iter", i);
        }
    }
    
    g_slist_free (list);
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef OFFSET1
    #undef OFFSET2
    #undef TEST_OFFSET
    #undef TOGGLED
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_child_anchor
 * Params: const GtkTextIter* iter
 * Returns: GtkTextChildAnchor*
 * Assertion: If the location at iter contains a child anchor, the anchor is returned (with no new reference count added).
 * Params Values:  const GtkTextIter* iter
 * Expected: GtkTextChildAnchor*  
 */
static void test_purpose_128()
{
    #define    TEST_LINE  "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE1 1
    #define    OFFS1 1
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag* tag;
    GtkTextChildAnchor* anchor;
    GtkTextChildAnchor* real_anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE1);
    gtk_text_iter_set_line_offset(&iter, OFFS1);
    
    anchor = gtk_text_buffer_create_child_anchor(buffer, &iter);
    
    gtk_text_iter_set_line_offset(&iter, OFFS1);
    real_anchor = gtk_text_iter_get_child_anchor(&iter);
    
    if (anchor != real_anchor)
    {
        TEST_FAIL ("anchor is wrong", NULL);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_child_anchor
 * Params: const GtkTextIter* iter
 * Returns: GtkTextChildAnchor*
 * Assertion: If the location at iter contains a child anchor, the anchor is returned (with no new reference count added).
 * Params Values:  const GtkTextIter* iter
 * Expected: GtkTextChildAnchor*  
 */
static void test_purpose_129()
{
    #define    TEST_LINE  "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    LINE1 2
    #define    OFFS1 5
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag* tag;
    GtkTextChildAnchor* anchor;
    GtkTextChildAnchor* real_anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE1);
    gtk_text_iter_set_line_offset(&iter, OFFS1);
    
    anchor = gtk_text_buffer_create_child_anchor(buffer, &iter);
    
    gtk_text_iter_set_line_offset(&iter, OFFS1);
    real_anchor = gtk_text_iter_get_child_anchor(&iter);
    
    if (anchor != real_anchor)
    {
        TEST_FAIL ("anchor is wrong", NULL);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_child_anchor
 * Params: const GtkTextIter* iter
 * Returns: GtkTextChildAnchor*
 * Assertion: Otherwise, NULL is returned.
 * Params Values:  const GtkTextIter* iter
 * Expected: GtkTextChildAnchor*  
 */
static void test_purpose_130()
{
    #define    TEST_LINE  "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    OFFSET 5
    #define    ANCHOR_OFFSET 4
    
    GtkTextIter anchor_iter;
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag* tag;
    GtkTextChildAnchor* anchor;
    GtkTextChildAnchor* real_anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /* adding a child anchor */
    gtk_text_buffer_get_iter_at_offset(buffer, &anchor_iter, ANCHOR_OFFSET);
    anchor = gtk_text_buffer_create_child_anchor(buffer, &anchor_iter);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    real_anchor = gtk_text_iter_get_child_anchor(&iter);
    
    if (real_anchor != NULL)
    {
        TEST_FAIL ("anchor should be NULL", NULL);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef ANCHOR_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_child_anchor
 * Params: const GtkTextIter* iter
 * Returns: GtkTextChildAnchor*
 * Assertion: Otherwise, NULL is returned.
 * Params Values:  const GtkTextIter* iter
 * Expected: GtkTextChildAnchor*  
 */
static void test_purpose_131()
{
    #define    TEST_LINE  "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    OFFSET 28
    #define    ANCHOR_OFFSET 20
    
    GtkTextIter anchor_iter;
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag* tag;
    GtkTextChildAnchor* anchor;
    GtkTextChildAnchor* real_anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /* adding a child anchor */
    gtk_text_buffer_get_iter_at_offset(buffer, &anchor_iter, ANCHOR_OFFSET);
    anchor = gtk_text_buffer_create_child_anchor(buffer, &anchor_iter);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    real_anchor = gtk_text_iter_get_child_anchor(&iter);
    
    if (real_anchor != NULL)
    {
        TEST_FAIL ("anchor should be NULL", NULL);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef ANCHOR_OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_tags
 * Params: const GtkTextIter* iter
 * Returns: GSList*
 * Assertion: Returns a list of tags that apply to iter, in ascending order of priority (highest-priority tags are last).
 * Params Values:  const GtkTextIter* iter
 * Expected: GSList*
 * 
 * Name:  gtk_text_iter_get_tags
 * Params: const GtkTextIter* iter
 * Returns: GSList*
 * Assertion: The GtkTextTag in the list don't have a reference added, but you have to free the list itself.'
 * Params Values:  const GtkTextIter* iter
 * Expected: GSList*  
 */
static void test_purpose_132()
{
    #define    TEST_LINE  "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    COUNT 3
    #define    LINE1 1
    #define    OFFS1 1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag* tag;
    GSList* list;
    gint i;
    gchar  buff[20];
    gchararray name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, 0);
    
    gtk_text_iter_set_line(&iter, LINE1);
    gtk_text_iter_set_line_offset(&iter, OFFS1);
    gtk_text_iter_set_line(&iter1, LINE1);
    gtk_text_iter_set_line_offset(&iter1, OFFS1+1);
    
    
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Tag %i", i);
        tag = gtk_text_buffer_create_tag(buffer, buff, "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, tag, &iter, &iter1);
    }
    
    list = gtk_text_iter_get_tags(&iter);
    
    if (!list)
    {
        TEST_FAIL ("list == NULL", NULL);
        return;
    }
    
    for (i = 0; i < g_slist_length(list); i++) 
    {
        tag = (GtkTextTag*)g_slist_nth_data(list, i); 
        g_object_get(tag, "name", &name, NULL);
        sprintf(buff, "Tag %i", i);
        if (strcmp(buff, name))
        {
            TEST_FAIL ("Tag(%i) %s is wrong", i, name);
        }
        if (G_OBJECT (tag)->ref_count != 2)
        {
            TEST_FAIL ("Tag(%i)->ref_count = %i, should be 2", i, G_OBJECT (tag)->ref_count);
        }
        if (i < g_slist_length(list) - 1)
        {
            gint priority;
            gint priority1;
            GtkTextTag* tag1;
    
            tag1 = (GtkTextTag*)g_slist_nth_data(list, i + 1);
            priority = gtk_text_tag_get_priority (tag);
            priority1 = gtk_text_tag_get_priority (tag1);
    
            if (priority > priority1)
            {
                TEST_FAIL 
                    ("tag #%d priority (%d) > tag #%d priority (%d), should be <", 
                     i, priority, i + 1, priority1);
            }
        }
    }
    
    g_slist_free (list);
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef COUNT
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_tags
 * Params: const GtkTextIter* iter
 * Returns: GSList*
 * Assertion: Returns a list of tags that apply to iter, in ascending order of priority (highest-priority tags are last).
 * Params Values:  const GtkTextIter* iter
 * Expected: GSList*
 * 
 * Name:  gtk_text_iter_get_tags
 * Params: const GtkTextIter* iter
 * Returns: GSList*
 * Assertion: The GtkTextTag in the list don't have a reference added, but you have to free the list itself.'
 * Params Values:  const GtkTextIter* iter
 * Expected: GSList*  
 */
static void test_purpose_133()
{
    #define    TEST_LINE  "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    COUNT 10
    #define    LINE1 1
    #define    OFFS1 5
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag* tag;
    GSList* list;
    gint i;
    gchar  buff[20];
    gchararray name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, 0);
    
    gtk_text_iter_set_line(&iter, LINE1);
    gtk_text_iter_set_line_offset(&iter, OFFS1);
    gtk_text_iter_set_line(&iter1, LINE1);
    gtk_text_iter_set_line_offset(&iter1, OFFS1+1);
    
    
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Tag %i", i);
        tag = gtk_text_buffer_create_tag(buffer, buff, "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, tag, &iter, &iter1);
    }
    
    list = gtk_text_iter_get_tags(&iter);
    
    if (!list)
    {
        TEST_FAIL ("list == NULL", NULL);
        return;
    }
    
    for (i = 0; i < g_slist_length(list); i++) 
    {
        tag = (GtkTextTag*)g_slist_nth_data(list, i); 
        g_object_get(tag, "name", &name, NULL);
        sprintf(buff, "Tag %i", i);
        if (strcmp(buff, name))
        {
            TEST_FAIL ("Tag(%i) %s is wrong", i, name);
        }
        if (G_OBJECT (tag)->ref_count != 2)
        {
            TEST_FAIL ("Tag(%i)->ref_count = %i, should be 2", i, G_OBJECT (tag)->ref_count);
        }
        if (i < g_slist_length(list) - 1)
        {
            gint priority;
            gint priority1;
            GtkTextTag* tag1;
    
            tag1 = (GtkTextTag*)g_slist_nth_data(list, i + 1);
            priority = gtk_text_tag_get_priority (tag);
            priority1 = gtk_text_tag_get_priority (tag1);
    
            if (priority > priority1)
            {
                TEST_FAIL 
                    ("tag #%d priority (%d) > tag #%d priority (%d), should be <", 
                     i, priority, i + 1, priority1);
            }
        }
    }
    
    g_slist_free (list);
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef COUNT
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_tags
 * Params: const GtkTextIter* iter
 * Returns: GSList*
 * Assertion: Returns a list of tags that apply to iter, in ascending order of priority (highest-priority tags are last).
 * Params Values:  const GtkTextIter* iter
 * Expected: GSList*
 * 
 * Name:  gtk_text_iter_get_tags
 * Params: const GtkTextIter* iter
 * Returns: GSList*
 * Assertion: The GtkTextTag in the list don't have a reference added, but you have to free the list itself.'
 * Params Values:  const GtkTextIter* iter
 * Expected: GSList*  
 */
static void test_purpose_134()
{
    #define    TEST_LINE  "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5 very long\n "             
    #define    COUNT 1
    #define    LINE1 2
    #define    OFFS1 3
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag* tag;
    GSList* list;
    gint i;
    gchar  buff[20];
    gchararray name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, 0);
    
    gtk_text_iter_set_line(&iter, LINE1);
    gtk_text_iter_set_line_offset(&iter, OFFS1);
    gtk_text_iter_set_line(&iter1, LINE1);
    gtk_text_iter_set_line_offset(&iter1, OFFS1+1);
    
    
    for (i = 0; i < COUNT; i++) 
    {
        sprintf(buff, "Tag %i", i);
        tag = gtk_text_buffer_create_tag(buffer, buff, "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, tag, &iter, &iter1);
    }
    
    list = gtk_text_iter_get_tags(&iter);
    
    if (!list)
    {
        TEST_FAIL ("list == NULL", NULL);
        return;
    }
    
    for (i = 0; i < g_slist_length(list); i++) 
    {
        tag = (GtkTextTag*)g_slist_nth_data(list, i); 
        g_object_get(tag, "name", &name, NULL);
        sprintf(buff, "Tag %i", i);
        if (strcmp(buff, name))
        {
            TEST_FAIL ("Tag(%i) %s is wrong", i, name);
        }
        if (G_OBJECT (tag)->ref_count != 2)
        {
            TEST_FAIL ("Tag(%i)->ref_count = %i, should be 2", i, G_OBJECT (tag)->ref_count);
        }
        if (i < g_slist_length(list) - 1)
        {
            gint priority;
            gint priority1;
            GtkTextTag* tag1;
    
            tag1 = (GtkTextTag*)g_slist_nth_data(list, i + 1);
            priority = gtk_text_tag_get_priority (tag);
            priority1 = gtk_text_tag_get_priority (tag1);
    
            if (priority > priority1)
            {
                TEST_FAIL 
                    ("tag #%d priority (%d) > tag #%d priority (%d), should be <", 
                     i, priority, i + 1, priority1);
            }
        }
    }
    
    g_slist_free (list);
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef COUNT
    #undef LINE1
    #undef OFFS1
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_chars_in_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the number of characters in the line containing iter, including the paragraph delimiters.
 * Params Values:  const GtkTextIter* iter
 * Expected: gint  
 */
static void test_purpose_135()
{
    #define    TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5\n"
    #define    LINE  0
    #define    COUNT 9
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    
    i = gtk_text_iter_get_chars_in_line(&iter);
    
    if (i != COUNT)
    {
        TEST_FAIL ("COUNT = %i, should be %i", i, COUNT);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef COUNT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_chars_in_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the number of characters in the line containing iter, including the paragraph delimiters.
 * Params Values:  const GtkTextIter* iter
 * Expected: gint  
 */
static void test_purpose_136()
{
    #define    TEST_LINE  "String 1\n\r  String 2\nString 3\nString 4\nString 5\n"
    #define    LINE  0
    #define    COUNT 9
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    
    i = gtk_text_iter_get_chars_in_line(&iter);
    
    if (i != COUNT)
    {
        TEST_FAIL ("COUNT = %i, should be %i", i, COUNT);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef COUNT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_chars_in_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the number of characters in the line containing iter, including the paragraph delimiters.
 * Params Values:  const GtkTextIter* iter
 * Expected: gint  
 */
static void test_purpose_137()
{
    #define    TEST_LINE  "String 1\r  String 2\nString 3\nString 4\nString 5\n"
    #define    LINE  0
    #define    COUNT 9
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    
    i = gtk_text_iter_get_chars_in_line(&iter);
    
    if (i != COUNT)
    {
        TEST_FAIL ("COUNT = %i, should be %i", i, COUNT);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef COUNT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_chars_in_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the number of characters in the line containing iter, including the paragraph delimiters.
 * Params Values:  const GtkTextIter* iter
 * Expected: gint  
 */
static void test_purpose_138()
{
    #define    TEST_LINE  "String 1\r\r\n  String 2\nString 3\nString 4\nString 5\n"
    #define    LINE  0
    #define    COUNT 9
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    
    i = gtk_text_iter_get_chars_in_line(&iter);
    
    if (i != COUNT)
    {
        TEST_FAIL ("COUNT = %i, should be %i", i, COUNT);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef COUNT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_chars_in_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the number of characters in the line containing iter, including the paragraph delimiters.
 * Params Values:  const GtkTextIter* iter
 * Expected: gint  
 */
static void test_purpose_139()
{
    #define    TEST_LINE  "String 1\r\n  String 2\nString 3\nString 4\nString 5\n"
    #define    LINE  0
    #define    COUNT 10
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    
    i = gtk_text_iter_get_chars_in_line(&iter);
    
    if (i != COUNT)
    {
        TEST_FAIL ("COUNT = %i, should be %i", i, COUNT);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef COUNT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_chars_in_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the number of characters in the line containing iter, including the paragraph delimiters.
 * Params Values:  const GtkTextIter* iter
 * Expected: gint  
 */
static void test_purpose_140()
{
    #define    TEST_LINE  "String 1\n \t  String 2\nString 3\nString 4\nString 5\n"
    #define    LINE  1
    #define    COUNT 13
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    
    i = gtk_text_iter_get_chars_in_line(&iter);
    
    if (i != COUNT)
    {
        TEST_FAIL ("COUNT = %i, should be %i", i, COUNT);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef COUNT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_chars_in_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the number of characters in the line containing iter, including the paragraph delimiters.
 * Params Values:  const GtkTextIter* iter
 * Expected: gint  
 */
static void test_purpose_141()
{
    #define    TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5123456789012345\n"
    #define    LINE  4
    #define    COUNT 24
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    
    i = gtk_text_iter_get_chars_in_line(&iter);
    
    if (i != COUNT)
    {
        TEST_FAIL ("COUNT = %i, should be %i", i, COUNT);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef COUNT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_bytes_in_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the number of bytes in the line containing iter, including the paragraph delimiters.
 * Params Values:  const GtkTextIter* iter
 * Expected: gint  
 */
static void test_purpose_142()
{
    #define    TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5\n"
    #define    LINE  0
    #define    COUNT 9
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    
    i = gtk_text_iter_get_bytes_in_line(&iter);
    
    if (i != COUNT)
    {
        TEST_FAIL ("COUNT = %i, should be %i", i, COUNT);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef COUNT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_bytes_in_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the number of bytes in the line containing iter, including the paragraph delimiters.
 * Params Values:  const GtkTextIter* iter
 * Expected: gint  
 */
static void test_purpose_143()
{
    #define    TEST_LINE  "String 1\n\t  String 2\nString 3\nString 4\nString 5\n"
    #define    LINE  1
    #define    COUNT 12
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    
    i = gtk_text_iter_get_bytes_in_line(&iter);
    
    if (i != COUNT)
    {
        TEST_FAIL ("COUNT = %i, should be %i", i, COUNT);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef COUNT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_get_bytes_in_line
 * Params: const GtkTextIter* iter
 * Returns: gint
 * Assertion: Returns the number of bytes in the line containing iter, including the paragraph delimiters.
 * Params Values:  const GtkTextIter* iter
 * Expected: gint  
 */
static void test_purpose_144()
{
    #define    TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5 12345678901234\n"
    #define    LINE  4
    #define    COUNT 24
    
    GtkTextIter iter;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_iter_set_line(&iter, LINE);
    
    i = gtk_text_iter_get_bytes_in_line(&iter);
    
    if (i != COUNT)
    {
        TEST_FAIL ("COUNT = %i, should be %i", i, COUNT);
        return;
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef COUNT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: gtk_text_iter_get_attributes() will modify values, applying the effects of any tags present at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: Computes the effect of any tags applied to this spot in the text
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean  
 */
static void test_purpose_145()
{
    #define TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5\n"
    #define OFFSET  10
    #define TAG_START  8
    #define TAG_END  12
    #define FIELD_NAME "direction"
    #define FIELD direction
    #define VALUE GTK_TEXT_DIR_LTR
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextAttributes *values;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    values = gtk_text_attributes_new ();
    values->FIELD = VALUE;
    
    
    if (CORRECT_RESULT == TRUE)
    {
        tag = gtk_text_buffer_create_tag (buffer, "Tag", FIELD_NAME, VALUE, NULL);
        gtk_text_buffer_get_iter_at_offset (buffer, &iter1, TAG_START);
        gtk_text_buffer_get_iter_at_offset (buffer, &iter2, TAG_END);
        gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    }
    
    if (gtk_text_iter_get_attributes (&iter, values) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_get_attributes() should return %d", 
                   CORRECT_RESULT);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef TAG_START
    #undef TAG_END
    #undef FIELD_NAME
    #undef FIELD
    #undef VALUE
    #undef CORRECT_RESULT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: gtk_text_iter_get_attributes() will modify values, applying the effects of any tags present at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: Computes the effect of any tags applied to this spot in the text
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean  
 */
static void test_purpose_146()
{
    #define TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5\n"
    #define OFFSET  22
    #define TAG_START  20
    #define TAG_END  25
    #define FIELD_NAME "justification"
    #define FIELD justification
    #define VALUE GTK_JUSTIFY_LEFT
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextAttributes *values;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    values = gtk_text_attributes_new ();
    values->FIELD = VALUE;
    
    
    if (CORRECT_RESULT == TRUE)
    {
        tag = gtk_text_buffer_create_tag (buffer, "Tag", FIELD_NAME, VALUE, NULL);
        gtk_text_buffer_get_iter_at_offset (buffer, &iter1, TAG_START);
        gtk_text_buffer_get_iter_at_offset (buffer, &iter2, TAG_END);
        gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    }
    
    if (gtk_text_iter_get_attributes (&iter, values) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_get_attributes() should return %d", 
                   CORRECT_RESULT);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef TAG_START
    #undef TAG_END
    #undef FIELD_NAME
    #undef FIELD
    #undef VALUE
    #undef CORRECT_RESULT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: gtk_text_iter_get_attributes() will modify values, applying the effects of any tags present at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: Computes the effect of any tags applied to this spot in the text
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean  
 */
static void test_purpose_147()
{
    #define TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5 \n"
    #define OFFSET  10
    #define TAG_START  8
    #define TAG_END  11
    #define FIELD_NAME "left-margin"
    #define FIELD left_margin
    #define VALUE 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextAttributes *values;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    values = gtk_text_attributes_new ();
    values->FIELD = VALUE;
    
    
    if (CORRECT_RESULT == TRUE)
    {
        tag = gtk_text_buffer_create_tag (buffer, "Tag", FIELD_NAME, VALUE, NULL);
        gtk_text_buffer_get_iter_at_offset (buffer, &iter1, TAG_START);
        gtk_text_buffer_get_iter_at_offset (buffer, &iter2, TAG_END);
        gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    }
    
    if (gtk_text_iter_get_attributes (&iter, values) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_get_attributes() should return %d", 
                   CORRECT_RESULT);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef TAG_START
    #undef TAG_END
    #undef FIELD_NAME
    #undef FIELD
    #undef VALUE
    #undef CORRECT_RESULT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: gtk_text_iter_get_attributes() will modify values, applying the effects of any tags present at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: Computes the effect of any tags applied to this spot in the text
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean  
 */
static void test_purpose_148()
{
    #define TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5 \n"
    #define OFFSET  22
    #define TAG_START  20
    #define TAG_END  23
    #define FIELD_NAME "right-margin"
    #define FIELD right_margin
    #define VALUE 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextAttributes *values;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    values = gtk_text_attributes_new ();
    values->FIELD = VALUE;
    
    
    if (CORRECT_RESULT == TRUE)
    {
        tag = gtk_text_buffer_create_tag (buffer, "Tag", FIELD_NAME, VALUE, NULL);
        gtk_text_buffer_get_iter_at_offset (buffer, &iter1, TAG_START);
        gtk_text_buffer_get_iter_at_offset (buffer, &iter2, TAG_END);
        gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    }
    
    if (gtk_text_iter_get_attributes (&iter, values) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_get_attributes() should return %d", 
                   CORRECT_RESULT);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef TAG_START
    #undef TAG_END
    #undef FIELD_NAME
    #undef FIELD
    #undef VALUE
    #undef CORRECT_RESULT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: gtk_text_iter_get_attributes() will modify values, applying the effects of any tags present at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: Computes the effect of any tags applied to this spot in the text
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean  
 */
static void test_purpose_149()
{
    #define TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5\n"
    #define OFFSET  32
    #define TAG_START  30
    #define TAG_END  35
    #define FIELD_NAME "indent"
    #define FIELD indent
    #define VALUE 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextAttributes *values;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    values = gtk_text_attributes_new ();
    values->FIELD = VALUE;
    
    
    if (CORRECT_RESULT == TRUE)
    {
        tag = gtk_text_buffer_create_tag (buffer, "Tag", FIELD_NAME, VALUE, NULL);
        gtk_text_buffer_get_iter_at_offset (buffer, &iter1, TAG_START);
        gtk_text_buffer_get_iter_at_offset (buffer, &iter2, TAG_END);
        gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    }
    
    if (gtk_text_iter_get_attributes (&iter, values) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_get_attributes() should return %d", 
                   CORRECT_RESULT);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef TAG_START
    #undef TAG_END
    #undef FIELD_NAME
    #undef FIELD
    #undef VALUE
    #undef CORRECT_RESULT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: gtk_text_iter_get_attributes() will modify values, applying the effects of any tags present at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: Computes the effect of any tags applied to this spot in the text
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean  
 */
static void test_purpose_150()
{
    #define TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5\n"
    #define OFFSET  33
    #define TAG_START  30
    #define TAG_END  34
    #define FIELD_NAME "editable"
    #define FIELD editable
    #define VALUE TRUE
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextAttributes *values;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    values = gtk_text_attributes_new ();
    values->FIELD = VALUE;
    
    
    if (CORRECT_RESULT == TRUE)
    {
        tag = gtk_text_buffer_create_tag (buffer, "Tag", FIELD_NAME, VALUE, NULL);
        gtk_text_buffer_get_iter_at_offset (buffer, &iter1, TAG_START);
        gtk_text_buffer_get_iter_at_offset (buffer, &iter2, TAG_END);
        gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    }
    
    if (gtk_text_iter_get_attributes (&iter, values) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_get_attributes() should return %d", 
                   CORRECT_RESULT);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef TAG_START
    #undef TAG_END
    #undef FIELD_NAME
    #undef FIELD
    #undef VALUE
    #undef CORRECT_RESULT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: gtk_text_iter_get_attributes() will modify values, applying the effects of any tags present at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: Computes the effect of any tags applied to this spot in the text
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean  
 */
static void test_purpose_151()
{
    #define TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5\n"
    #define OFFSET  10
    #define TAG_START  8
    #define TAG_END  12
    #define FIELD_NAME "direction"
    #define FIELD direction
    #define VALUE GTK_TEXT_DIR_LTR
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextAttributes *values;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    values = gtk_text_attributes_new ();
    values->FIELD = VALUE;
    
    
    if (CORRECT_RESULT == TRUE)
    {
        tag = gtk_text_buffer_create_tag (buffer, "Tag", FIELD_NAME, VALUE, NULL);
        gtk_text_buffer_get_iter_at_offset (buffer, &iter1, TAG_START);
        gtk_text_buffer_get_iter_at_offset (buffer, &iter2, TAG_END);
        gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    }
    
    if (gtk_text_iter_get_attributes (&iter, values) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_get_attributes() should return %d", 
                   CORRECT_RESULT);
    }
    
    gtk_widget_destroy (view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef TAG_START
    #undef TAG_END
    #undef FIELD_NAME
    #undef FIELD
    #undef VALUE
    #undef CORRECT_RESULT
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_attributes
 * Params: const GtkTextIter* iter, GtkTextAttributes *values
 * Returns: gboolean
 * Assertion: If any tags affected values, the function returns TRUE.
 * Params Values:  const GtkTextIter* iter, GtkTextAttributes *values
 * Expected: gboolean  
 */
static void test_purpose_152()
{
    #define TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5\n"
    #define OFFSET  10
    #define TAG_START  8
    #define TAG_END  12
    #define FIELD_NAME "direction"
    #define FIELD direction
    #define VALUE FALSE
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextAttributes *values;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    values = gtk_text_attributes_new();
    values->FIELD = VALUE;
    
    
    tag = gtk_text_buffer_create_tag(buffer, "Tag", FIELD_NAME, VALUE, NULL);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, TAG_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, TAG_END);
    gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    
    if (!gtk_text_iter_get_attributes(&iter, values))
    {
        TEST_FAIL ("gtk_text_iter_get_attributes() should return TRUE", NULL); 
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    #undef TAG_START
    #undef TAG_END
    #undef FIELD_NAME
    #undef FIELD
    #undef VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_language
 * Params: const GtkTextIter* iter
 * Returns: gchar*
 * Assertion: A convenience wrapper around gtk_text_iter_get_attributes(), which returns the language in effect at iter.
 * Params Values:  const GtkTextIter* iter
 * Expected: gchar  
 */
static void test_purpose_153()
{
    #define    TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5 \n"
    #define    LINE  0
    #define    OFFS  0
    #define    LANGUAGE "en-us"
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, 0);
    gtk_text_iter_set_line(&iter, LINE);
    gtk_text_iter_set_offset(&iter, OFFS);
    gtk_text_iter_set_line(&iter1, LINE);
    gtk_text_iter_set_offset(&iter1, OFFS+1);
    tag = gtk_text_buffer_create_tag(buffer, "Tag", "language", LANGUAGE, NULL);
    gtk_text_buffer_apply_tag(buffer, tag, &iter, &iter1);
    
    if (strcmp(pango_language_to_string (gtk_text_iter_get_language(&iter)), LANGUAGE))
    {
        TEST_FAIL ("Language  = %s, should be %s", 
                   pango_language_to_string (gtk_text_iter_get_language(&iter)), 
                   LANGUAGE);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LANGUAGE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_language
 * Params: const GtkTextIter* iter
 * Returns: gchar*
 * Assertion: A convenience wrapper around gtk_text_iter_get_attributes(), which returns the language in effect at iter.
 * Params Values:  const GtkTextIter* iter
 * Expected: gchar  
 */
static void test_purpose_154()
{
    #define    TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5 \n"
    #define    LINE  0
    #define    OFFS  0
    #define    LANGUAGE "ru-ru"
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, 0);
    gtk_text_iter_set_line(&iter, LINE);
    gtk_text_iter_set_offset(&iter, OFFS);
    gtk_text_iter_set_line(&iter1, LINE);
    gtk_text_iter_set_offset(&iter1, OFFS+1);
    tag = gtk_text_buffer_create_tag(buffer, "Tag", "language", LANGUAGE, NULL);
    gtk_text_buffer_apply_tag(buffer, tag, &iter, &iter1);
    
    if (strcmp(pango_language_to_string (gtk_text_iter_get_language(&iter)), LANGUAGE))
    {
        TEST_FAIL ("Language  = %s, should be %s", 
                   pango_language_to_string (gtk_text_iter_get_language(&iter)), 
                   LANGUAGE);
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LANGUAGE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_language
 * Params: const GtkTextIter* iter
 * Returns: gchar*
 * Assertion: If no tags affecting language apply to iter, the return value is identical to that of gtk_get_default_language().
 * Params Values:  const GtkTextIter* iter
 * Expected: gchar  
 */
static void test_purpose_155()
{
    #define TEST_LINE  "String 1"
    #define OFFSET 6
    
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextIter iter;
    PangoLanguage *language;
    PangoLanguage *default_language;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    language = gtk_text_iter_get_language (&iter);
    default_language = gtk_get_default_language();
    
    if (strcmp(pango_language_to_string (language), 
               pango_language_to_string (default_language)))
    {
        TEST_FAIL ("Language  = %s, default language is %s, they should be the same",
                   pango_language_to_string (language), 
                   pango_language_to_string (default_language));
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_get_language
 * Params: const GtkTextIter* iter
 * Returns: gchar*
 * Assertion: If no tags affecting language apply to iter, the return value is identical to that of gtk_get_default_language().
 * Params Values:  const GtkTextIter* iter
 * Expected: gchar  
 */
static void test_purpose_156()
{
    #define TEST_LINE  "String 1"
    #define OFFSET 9
    
    GtkTextBuffer *buffer;
    GtkWidget *view;
    GtkTextIter iter;
    PangoLanguage *language;
    PangoLanguage *default_language;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    view = gtk_text_view_new ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    language = gtk_text_iter_get_language (&iter);
    default_language = gtk_get_default_language();
    
    if (strcmp(pango_language_to_string (language), 
               pango_language_to_string (default_language)))
    {
        TEST_FAIL ("Language  = %s, default language is %s, they should be the same",
                   pango_language_to_string (language), 
                   pango_language_to_string (default_language));
    }
    
    gtk_widget_destroy(view);
    
    #undef TEST_LINE
    #undef OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_copy
 * Params: const GtkTextIter* iter
 * Returns: GtkTextIter*
 * Assertion: Creates a dynamically-allocated copy of an iterator.
 * Params Values:  const GtkTextIter* iter
 * Expected: GtkTextIter* equal to that was passed as the param.  
 */
static void test_purpose_157()
{
    #define    TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5 \n"
    #define    OFFSET  0
    
    GtkTextIter iter;
    GtkTextIter* iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    iter1 = gtk_text_iter_copy (&iter);
    if (!gtk_text_iter_equal (&iter, iter1))
    {
        TEST_FAIL ("iter and iter1 are not equal but should be", NULL);
    }
    
    gtk_text_iter_free (iter1);
    
    #undef TEST_LINE
    #undef OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_copy
 * Params: const GtkTextIter* iter
 * Returns: GtkTextIter*
 * Assertion: Creates a dynamically-allocated copy of an iterator.
 * Params Values:  const GtkTextIter* iter
 * Expected: GtkTextIter* equal to that was passed as the param.  
 */
static void test_purpose_158()
{
    #define    TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5 \n"
    #define    OFFSET  5
    
    GtkTextIter iter;
    GtkTextIter* iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    iter1 = gtk_text_iter_copy (&iter);
    if (!gtk_text_iter_equal (&iter, iter1))
    {
        TEST_FAIL ("iter and iter1 are not equal but should be", NULL);
    }
    
    gtk_text_iter_free (iter1);
    
    #undef TEST_LINE
    #undef OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_copy
 * Params: const GtkTextIter* iter
 * Returns: GtkTextIter*
 * Assertion: Creates a dynamically-allocated copy of an iterator.
 * Params Values:  const GtkTextIter* iter
 * Expected: GtkTextIter* equal to that was passed as the param.  
 */
static void test_purpose_159()
{
    #define    TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5 \n"
    #define    OFFSET  strlen ("String 1\n  String 2\nString 3\nString 4\nString 5 \n" - 1)
    
    GtkTextIter iter;
    GtkTextIter* iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    iter1 = gtk_text_iter_copy (&iter);
    if (!gtk_text_iter_equal (&iter, iter1))
    {
        TEST_FAIL ("iter and iter1 are not equal but should be", NULL);
    }
    
    gtk_text_iter_free (iter1);
    
    #undef TEST_LINE
    #undef OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_copy
 * Params: const GtkTextIter* iter
 * Returns: GtkTextIter*
 * Assertion: Creates a dynamically-allocated copy of an iterator.
 * Params Values:  const GtkTextIter* iter
 * Expected: GtkTextIter* equal to that was passed as the param.  
 */
static void test_purpose_160()
{
    #define    TEST_LINE  "!@#$%^&*()_+|~=\";:'?<>`/" 
    #define    OFFSET  0
    
    GtkTextIter iter;
    GtkTextIter* iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    iter1 = gtk_text_iter_copy (&iter);
    if (!gtk_text_iter_equal (&iter, iter1))
    {
        TEST_FAIL ("iter and iter1 are not equal but should be", NULL);
    }
    
    gtk_text_iter_free (iter1);
    
    #undef TEST_LINE
    #undef OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_copy
 * Params: const GtkTextIter* iter
 * Returns: GtkTextIter*
 * Assertion: Creates a dynamically-allocated copy of an iterator.
 * Params Values:  const GtkTextIter* iter
 * Expected: GtkTextIter* equal to that was passed as the param.  
 */
static void test_purpose_161()
{
    #define    TEST_LINE  "!@#$%^&*()_+|~=\";:'?<>`/" 
    #define    OFFSET  10
    
    GtkTextIter iter;
    GtkTextIter* iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    iter1 = gtk_text_iter_copy (&iter);
    if (!gtk_text_iter_equal (&iter, iter1))
    {
        TEST_FAIL ("iter and iter1 are not equal but should be", NULL);
    }
    
    gtk_text_iter_free (iter1);
    
    #undef TEST_LINE
    #undef OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_copy
 * Params: const GtkTextIter* iter
 * Returns: GtkTextIter*
 * Assertion: Creates a dynamically-allocated copy of an iterator.
 * Params Values:  const GtkTextIter* iter
 * Expected: GtkTextIter* equal to that was passed as the param.  
 */
static void test_purpose_162()
{
    #define    TEST_LINE  " " 
    #define    OFFSET  0
    
    GtkTextIter iter;
    GtkTextIter* iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    iter1 = gtk_text_iter_copy (&iter);
    if (!gtk_text_iter_equal (&iter, iter1))
    {
        TEST_FAIL ("iter and iter1 are not equal but should be", NULL);
    }
    
    gtk_text_iter_free (iter1);
    
    #undef TEST_LINE
    #undef OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_free
 * Params: const GtkTextIter* iter
 * Returns: void
 * Assertion: Free an iterator allocated on the heap.
 * Params Values:  GtkTextIter* iter
 * Expected: void  
 */
static void test_purpose_163()
{
    #define    TEST_LINE  "String 1\n  String 2\nString 3\nString 4\nString 5 \n"
    #define    OFFSET  0
    
    GtkTextIter iter;
    GtkTextIter* iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    iter1 = gtk_text_iter_copy (&iter);
    gtk_text_iter_free (iter1);
    
    #undef TEST_LINE
    #undef OFFSET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if tag is toggled on at exactly this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Note that the gtk_text_iter_begins_tag() returns TRUE if iter is the start of the tagged range; gtk_text_iter_has_tag() tells you whether an iterator is within a tagged range.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_164()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START  0
    #define    END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define    OFFSET 20
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, START);
    if (gtk_text_iter_begins_tag (&iter3, invisible_tag) != TRUE)
    {
        TEST_FAIL ("gtk_text_begins_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_begins_tag (&iter3, invisible_tag) != FALSE)
    {
        TEST_FAIL ("gtk_text_begins_tag() returned not FALSE incorrectly", NULL);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if tag is toggled on at exactly this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Note that the gtk_text_iter_begins_tag() returns TRUE if iter is the start of the tagged range; gtk_text_iter_has_tag() tells you whether an iterator is within a tagged range.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_165()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START  0
    #define    END  5
    #define    OFFSET 4
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, START);
    if (gtk_text_iter_begins_tag (&iter3, invisible_tag) != TRUE)
    {
        TEST_FAIL ("gtk_text_begins_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_begins_tag (&iter3, invisible_tag) != FALSE)
    {
        TEST_FAIL ("gtk_text_begins_tag() returned not FALSE incorrectly", NULL);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if tag is toggled on at exactly this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Note that the gtk_text_iter_begins_tag() returns TRUE if iter is the start of the tagged range; gtk_text_iter_has_tag() tells you whether an iterator is within a tagged range.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_166()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START  0
    #define    END  5
    #define    OFFSET 5
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, START);
    if (gtk_text_iter_begins_tag (&iter3, invisible_tag) != TRUE)
    {
        TEST_FAIL ("gtk_text_begins_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_begins_tag (&iter3, invisible_tag) != FALSE)
    {
        TEST_FAIL ("gtk_text_begins_tag() returned not FALSE incorrectly", NULL);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if tag is toggled on at exactly this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Note that the gtk_text_iter_begins_tag() returns TRUE if iter is the start of the tagged range; gtk_text_iter_has_tag() tells you whether an iterator is within a tagged range.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_167()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START  10
    #define    END  25
    #define    OFFSET 5
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, START);
    if (gtk_text_iter_begins_tag (&iter3, invisible_tag) != TRUE)
    {
        TEST_FAIL ("gtk_text_begins_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_begins_tag (&iter3, invisible_tag) != FALSE)
    {
        TEST_FAIL ("gtk_text_begins_tag() returned not FALSE incorrectly", NULL);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if tag is toggled on at exactly this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Note that the gtk_text_iter_begins_tag() returns TRUE if iter is the start of the tagged range; gtk_text_iter_has_tag() tells you whether an iterator is within a tagged range.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_168()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START  10
    #define    END  25
    #define    OFFSET 15
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, START);
    if (gtk_text_iter_begins_tag (&iter3, invisible_tag) != TRUE)
    {
        TEST_FAIL ("gtk_text_begins_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_begins_tag (&iter3, invisible_tag) != FALSE)
    {
        TEST_FAIL ("gtk_text_begins_tag() returned not FALSE incorrectly", NULL);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if tag is toggled on at exactly this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Note that the gtk_text_iter_begins_tag() returns TRUE if iter is the start of the tagged range; gtk_text_iter_has_tag() tells you whether an iterator is within a tagged range.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_169()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START  25
    #define    END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define    OFFSET 10
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, START);
    if (gtk_text_iter_begins_tag (&iter3, invisible_tag) != TRUE)
    {
        TEST_FAIL ("gtk_text_begins_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_begins_tag (&iter3, invisible_tag) != FALSE)
    {
        TEST_FAIL ("gtk_text_begins_tag() returned not FALSE incorrectly", NULL);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If tag is NULL, returns TRUE if any tag is toggled on at this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_170()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START1  0
    #define    END1  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define    START2  1
    #define    END2  5
    #define    OFFSET 5
    #define    CORRECT_RESULT FALSE
    
    GtkTextIter iter11;
    GtkTextIter iter12;
    GtkTextIter iter21;
    GtkTextIter iter22;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag1;
    GtkTextTag* invisible_tag2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter11, START1);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter12, END1);
    invisible_tag1 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag1", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag1, &iter11, &iter12);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter21, START2);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter22, END2);
    invisible_tag2 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag2", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag2, &iter21, &iter22);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, START1);
    if (gtk_text_iter_begins_tag (&iter3, NULL) != TRUE)
    {
        TEST_FAIL ("1: gtk_text_begins_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_begins_tag (&iter3, NULL) != CORRECT_RESULT)
    {
        TEST_FAIL ("2: gtk_text_begins_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START1
    #undef END1
    #undef START2
    #undef END2
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If tag is NULL, returns TRUE if any tag is toggled on at this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_171()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START1  0
    #define    END1  5
    #define    START2  4
    #define    END2  5
    #define    OFFSET 4
    #define    CORRECT_RESULT TRUE
    
    GtkTextIter iter11;
    GtkTextIter iter12;
    GtkTextIter iter21;
    GtkTextIter iter22;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag1;
    GtkTextTag* invisible_tag2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter11, START1);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter12, END1);
    invisible_tag1 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag1", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag1, &iter11, &iter12);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter21, START2);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter22, END2);
    invisible_tag2 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag2", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag2, &iter21, &iter22);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, START1);
    if (gtk_text_iter_begins_tag (&iter3, NULL) != TRUE)
    {
        TEST_FAIL ("1: gtk_text_begins_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_begins_tag (&iter3, NULL) != CORRECT_RESULT)
    {
        TEST_FAIL ("2: gtk_text_begins_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START1
    #undef END1
    #undef START2
    #undef END2
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If tag is NULL, returns TRUE if any tag is toggled on at this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_172()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START1  0
    #define    END1  5
    #define    START2  4
    #define    END2  5
    #define    OFFSET 3
    #define    CORRECT_RESULT FALSE
    
    GtkTextIter iter11;
    GtkTextIter iter12;
    GtkTextIter iter21;
    GtkTextIter iter22;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag1;
    GtkTextTag* invisible_tag2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter11, START1);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter12, END1);
    invisible_tag1 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag1", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag1, &iter11, &iter12);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter21, START2);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter22, END2);
    invisible_tag2 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag2", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag2, &iter21, &iter22);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, START1);
    if (gtk_text_iter_begins_tag (&iter3, NULL) != TRUE)
    {
        TEST_FAIL ("1: gtk_text_begins_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_begins_tag (&iter3, NULL) != CORRECT_RESULT)
    {
        TEST_FAIL ("2: gtk_text_begins_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START1
    #undef END1
    #undef START2
    #undef END2
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If tag is NULL, returns TRUE if any tag is toggled on at this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_173()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START1  10
    #define    END1  25
    #define    START2  10
    #define    END2  25
    #define    OFFSET 10
    #define    CORRECT_RESULT TRUE
    
    GtkTextIter iter11;
    GtkTextIter iter12;
    GtkTextIter iter21;
    GtkTextIter iter22;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag1;
    GtkTextTag* invisible_tag2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter11, START1);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter12, END1);
    invisible_tag1 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag1", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag1, &iter11, &iter12);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter21, START2);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter22, END2);
    invisible_tag2 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag2", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag2, &iter21, &iter22);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, START1);
    if (gtk_text_iter_begins_tag (&iter3, NULL) != TRUE)
    {
        TEST_FAIL ("1: gtk_text_begins_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_begins_tag (&iter3, NULL) != CORRECT_RESULT)
    {
        TEST_FAIL ("2: gtk_text_begins_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START1
    #undef END1
    #undef START2
    #undef END2
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If tag is NULL, returns TRUE if any tag is toggled on at this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_174()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START1  10
    #define    END1  25
    #define    START2  10
    #define    END2  25
    #define    OFFSET 5
    #define    CORRECT_RESULT FALSE
    
    GtkTextIter iter11;
    GtkTextIter iter12;
    GtkTextIter iter21;
    GtkTextIter iter22;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag1;
    GtkTextTag* invisible_tag2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter11, START1);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter12, END1);
    invisible_tag1 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag1", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag1, &iter11, &iter12);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter21, START2);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter22, END2);
    invisible_tag2 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag2", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag2, &iter21, &iter22);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, START1);
    if (gtk_text_iter_begins_tag (&iter3, NULL) != TRUE)
    {
        TEST_FAIL ("1: gtk_text_begins_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_begins_tag (&iter3, NULL) != CORRECT_RESULT)
    {
        TEST_FAIL ("2: gtk_text_begins_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START1
    #undef END1
    #undef START2
    #undef END2
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_begins_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If tag is NULL, returns TRUE if any tag is toggled on at this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_175()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START1  25
    #define    END1  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define    START2  25
    #define    END2  26
    #define    OFFSET 25
    #define    CORRECT_RESULT TRUE
    
    GtkTextIter iter11;
    GtkTextIter iter12;
    GtkTextIter iter21;
    GtkTextIter iter22;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag1;
    GtkTextTag* invisible_tag2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter11, START1);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter12, END1);
    invisible_tag1 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag1", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag1, &iter11, &iter12);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter21, START2);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter22, END2);
    invisible_tag2 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag2", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag2, &iter21, &iter22);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, START1);
    if (gtk_text_iter_begins_tag (&iter3, NULL) != TRUE)
    {
        TEST_FAIL ("1: gtk_text_begins_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_begins_tag (&iter3, NULL) != CORRECT_RESULT)
    {
        TEST_FAIL ("2: gtk_text_begins_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START1
    #undef END1
    #undef START2
    #undef END2
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if tag is toggled off at exactly this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Note that the gtk_text_iter_ends_tag() returns TRUE if iter is the end of the tagged range; gtk_text_iter_has_tag() tells you whether an iterator is within a tagged range.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_176()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START  0
    #define    END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define    OFFSET 20
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, &iter1, &iter2);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, END);
    if (gtk_text_iter_ends_tag (&iter3, invisible_tag) != TRUE)
    {
        TEST_FAIL ("gtk_text_ends_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_tag (&iter3, invisible_tag) != FALSE)
    {
        TEST_FAIL ("gtk_text_ends_tag() returned not FALSE incorrectly", NULL);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if tag is toggled off at exactly this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Note that the gtk_text_iter_ends_tag() returns TRUE if iter is the end of the tagged range; gtk_text_iter_has_tag() tells you whether an iterator is within a tagged range.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_177()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START  0
    #define    END  5
    #define    OFFSET 4
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, &iter1, &iter2);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, END);
    if (gtk_text_iter_ends_tag (&iter3, invisible_tag) != TRUE)
    {
        TEST_FAIL ("gtk_text_ends_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_tag (&iter3, invisible_tag) != FALSE)
    {
        TEST_FAIL ("gtk_text_ends_tag() returned not FALSE incorrectly", NULL);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if tag is toggled off at exactly this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Note that the gtk_text_iter_ends_tag() returns TRUE if iter is the end of the tagged range; gtk_text_iter_has_tag() tells you whether an iterator is within a tagged range.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_178()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START  0
    #define    END  5
    #define    OFFSET 0
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, &iter1, &iter2);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, END);
    if (gtk_text_iter_ends_tag (&iter3, invisible_tag) != TRUE)
    {
        TEST_FAIL ("gtk_text_ends_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_tag (&iter3, invisible_tag) != FALSE)
    {
        TEST_FAIL ("gtk_text_ends_tag() returned not FALSE incorrectly", NULL);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if tag is toggled off at exactly this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Note that the gtk_text_iter_ends_tag() returns TRUE if iter is the end of the tagged range; gtk_text_iter_has_tag() tells you whether an iterator is within a tagged range.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_179()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START  10
    #define    END  25
    #define    OFFSET 5
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, &iter1, &iter2);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, END);
    if (gtk_text_iter_ends_tag (&iter3, invisible_tag) != TRUE)
    {
        TEST_FAIL ("gtk_text_ends_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_tag (&iter3, invisible_tag) != FALSE)
    {
        TEST_FAIL ("gtk_text_ends_tag() returned not FALSE incorrectly", NULL);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if tag is toggled off at exactly this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Note that the gtk_text_iter_ends_tag() returns TRUE if iter is the end of the tagged range; gtk_text_iter_has_tag() tells you whether an iterator is within a tagged range.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_180()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START  10
    #define    END  25
    #define    OFFSET 15
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, &iter1, &iter2);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, END);
    if (gtk_text_iter_ends_tag (&iter3, invisible_tag) != TRUE)
    {
        TEST_FAIL ("gtk_text_ends_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_tag (&iter3, invisible_tag) != FALSE)
    {
        TEST_FAIL ("gtk_text_ends_tag() returned not FALSE incorrectly", NULL);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if tag is toggled off at exactly this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean
 * 
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Note that the gtk_text_iter_ends_tag() returns TRUE if iter is the end of the tagged range; gtk_text_iter_has_tag() tells you whether an iterator is within a tagged range.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_181()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START  25
    #define    END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define    OFFSET 10
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    
    
    invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag (buffer, invisible_tag, &iter1, &iter2);
    
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, END);
    if (gtk_text_iter_ends_tag (&iter3, invisible_tag) != TRUE)
    {
        TEST_FAIL ("gtk_text_ends_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_tag (&iter3, invisible_tag) != FALSE)
    {
        TEST_FAIL ("gtk_text_ends_tag() returned not FALSE incorrectly", NULL);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If tag is NULL, returns TRUE if any tag is toggled off at this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_182()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START1  0
    #define    END1  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define    START2  1
    #define    END2  5
    #define    OFFSET 5
    #define    CORRECT_RESULT TRUE
    
    GtkTextIter iter11;
    GtkTextIter iter12;
    GtkTextIter iter21;
    GtkTextIter iter22;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag1;
    GtkTextTag* invisible_tag2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter11, START1);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter12, END1);
    invisible_tag1 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag1", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag1, &iter11, &iter12);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter21, START2);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter22, END2);
    invisible_tag2 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag2", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag2, &iter21, &iter22);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, END1);
    if (gtk_text_iter_ends_tag (&iter3, NULL) != TRUE)
    {
        TEST_FAIL ("1: gtk_text_ends_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_tag (&iter3, NULL) != CORRECT_RESULT)
    {
        TEST_FAIL ("2: gtk_text_ends_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START1
    #undef END1
    #undef START2
    #undef END2
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If tag is NULL, returns TRUE if any tag is toggled off at this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_183()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START1  0
    #define    END1  5
    #define    START2  4
    #define    END2  5
    #define    OFFSET 5
    #define    CORRECT_RESULT TRUE
    
    GtkTextIter iter11;
    GtkTextIter iter12;
    GtkTextIter iter21;
    GtkTextIter iter22;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag1;
    GtkTextTag* invisible_tag2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter11, START1);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter12, END1);
    invisible_tag1 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag1", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag1, &iter11, &iter12);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter21, START2);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter22, END2);
    invisible_tag2 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag2", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag2, &iter21, &iter22);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, END1);
    if (gtk_text_iter_ends_tag (&iter3, NULL) != TRUE)
    {
        TEST_FAIL ("1: gtk_text_ends_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_tag (&iter3, NULL) != CORRECT_RESULT)
    {
        TEST_FAIL ("2: gtk_text_ends_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START1
    #undef END1
    #undef START2
    #undef END2
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If tag is NULL, returns TRUE if any tag is toggled off at this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_184()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START1  0
    #define    END1  5
    #define    START2  4
    #define    END2  5
    #define    OFFSET 3
    #define    CORRECT_RESULT FALSE
    
    GtkTextIter iter11;
    GtkTextIter iter12;
    GtkTextIter iter21;
    GtkTextIter iter22;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag1;
    GtkTextTag* invisible_tag2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter11, START1);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter12, END1);
    invisible_tag1 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag1", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag1, &iter11, &iter12);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter21, START2);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter22, END2);
    invisible_tag2 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag2", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag2, &iter21, &iter22);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, END1);
    if (gtk_text_iter_ends_tag (&iter3, NULL) != TRUE)
    {
        TEST_FAIL ("1: gtk_text_ends_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_tag (&iter3, NULL) != CORRECT_RESULT)
    {
        TEST_FAIL ("2: gtk_text_ends_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START1
    #undef END1
    #undef START2
    #undef END2
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If tag is NULL, returns TRUE if any tag is toggled off at this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_185()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START1  10
    #define    END1  25
    #define    START2  10
    #define    END2  25
    #define    OFFSET 10
    #define    CORRECT_RESULT FALSE
    
    GtkTextIter iter11;
    GtkTextIter iter12;
    GtkTextIter iter21;
    GtkTextIter iter22;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag1;
    GtkTextTag* invisible_tag2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter11, START1);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter12, END1);
    invisible_tag1 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag1", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag1, &iter11, &iter12);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter21, START2);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter22, END2);
    invisible_tag2 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag2", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag2, &iter21, &iter22);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, END1);
    if (gtk_text_iter_ends_tag (&iter3, NULL) != TRUE)
    {
        TEST_FAIL ("1: gtk_text_ends_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_tag (&iter3, NULL) != CORRECT_RESULT)
    {
        TEST_FAIL ("2: gtk_text_ends_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START1
    #undef END1
    #undef START2
    #undef END2
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If tag is NULL, returns TRUE if any tag is toggled off at this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_186()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START1  10
    #define    END1  25
    #define    START2  10
    #define    END2  25
    #define    OFFSET 5
    #define    CORRECT_RESULT FALSE
    
    GtkTextIter iter11;
    GtkTextIter iter12;
    GtkTextIter iter21;
    GtkTextIter iter22;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag1;
    GtkTextTag* invisible_tag2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter11, START1);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter12, END1);
    invisible_tag1 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag1", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag1, &iter11, &iter12);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter21, START2);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter22, END2);
    invisible_tag2 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag2", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag2, &iter21, &iter22);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, END1);
    if (gtk_text_iter_ends_tag (&iter3, NULL) != TRUE)
    {
        TEST_FAIL ("1: gtk_text_ends_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_tag (&iter3, NULL) != CORRECT_RESULT)
    {
        TEST_FAIL ("2: gtk_text_ends_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START1
    #undef END1
    #undef START2
    #undef END2
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If tag is NULL, returns TRUE if any tag is toggled off at this point.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: gboolean  
 */
static void test_purpose_187()
{
    #define    TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define    START1  1
    #define    END1  26
    #define    START2  25
    #define    END2  26
    #define    OFFSET 26
    #define    CORRECT_RESULT TRUE
    
    GtkTextIter iter11;
    GtkTextIter iter12;
    GtkTextIter iter21;
    GtkTextIter iter22;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag1;
    GtkTextTag* invisible_tag2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter11, START1);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter12, END1);
    invisible_tag1 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag1", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag1, &iter11, &iter12);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter21, START2);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter22, END2);
    invisible_tag2 = gtk_text_buffer_create_tag(buffer, "strikethrough-tag2", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag2, &iter21, &iter22);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, END1);
    if (gtk_text_iter_ends_tag (&iter3, NULL) != TRUE)
    {
        TEST_FAIL ("1: gtk_text_ends_tag() returned not TRUE incorrectly", NULL);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_tag (&iter3, NULL) != CORRECT_RESULT)
    {
        TEST_FAIL ("2: gtk_text_ends_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START1
    #undef END1
    #undef START2
    #undef END2
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_toggles_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: This is equivalent to (gtk_text_iter_begins_tag() || gtk_text_iter_ends_tag()), i.e. it tells you whether a range with tag applied to it begins or ends at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_188()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_toggles_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_toggles_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_toggles_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: This is equivalent to (gtk_text_iter_begins_tag() || gtk_text_iter_ends_tag()), i.e. it tells you whether a range with tag applied to it begins or ends at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_189()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define OFFSET strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_toggles_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_toggles_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_toggles_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: This is equivalent to (gtk_text_iter_begins_tag() || gtk_text_iter_ends_tag()), i.e. it tells you whether a range with tag applied to it begins or ends at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: FALSE  
 */
static void test_purpose_190()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define OFFSET 49
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_toggles_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_toggles_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_toggles_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: This is equivalent to (gtk_text_iter_begins_tag() || gtk_text_iter_ends_tag()), i.e. it tells you whether a range with tag applied to it begins or ends at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_191()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  5
    #define OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_toggles_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_toggles_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_toggles_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: This is equivalent to (gtk_text_iter_begins_tag() || gtk_text_iter_ends_tag()), i.e. it tells you whether a range with tag applied to it begins or ends at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_192()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  5
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_toggles_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_toggles_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_toggles_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: This is equivalent to (gtk_text_iter_begins_tag() || gtk_text_iter_ends_tag()), i.e. it tells you whether a range with tag applied to it begins or ends at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: FALSE  
 */
static void test_purpose_193()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  5
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_toggles_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_toggles_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_toggles_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: This is equivalent to (gtk_text_iter_begins_tag() || gtk_text_iter_ends_tag()), i.e. it tells you whether a range with tag applied to it begins or ends at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: FALSE  
 */
static void test_purpose_194()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  10
    #define END  25
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_toggles_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_toggles_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_toggles_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: This is equivalent to (gtk_text_iter_begins_tag() || gtk_text_iter_ends_tag()), i.e. it tells you whether a range with tag applied to it begins or ends at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_195()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  10
    #define END  25
    #define OFFSET 25
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_toggles_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_toggles_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_toggles_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: This is equivalent to (gtk_text_iter_begins_tag() || gtk_text_iter_ends_tag()), i.e. it tells you whether a range with tag applied to it begins or ends at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: FALSE  
 */
static void test_purpose_196()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  10
    #define END  25
    #define OFFSET 15
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_toggles_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_toggles_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_toggles_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: This is equivalent to (gtk_text_iter_begins_tag() || gtk_text_iter_ends_tag()), i.e. it tells you whether a range with tag applied to it begins or ends at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_197()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  25
    #define END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define OFFSET 25
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_toggles_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_toggles_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_toggles_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: This is equivalent to (gtk_text_iter_begins_tag() || gtk_text_iter_ends_tag()), i.e. it tells you whether a range with tag applied to it begins or ends at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_198()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  25
    #define END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define OFFSET strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_toggles_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_toggles_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_toggles_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: This is equivalent to (gtk_text_iter_begins_tag() || gtk_text_iter_ends_tag()), i.e. it tells you whether a range with tag applied to it begins or ends at iter.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: FALSE  
 */
static void test_purpose_199()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  25
    #define END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define OFFSET 49
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_toggles_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_toggles_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_200()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: FALSE  
 */
static void test_purpose_201()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define OFFSET strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_202()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define OFFSET 49
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_203()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  5
    #define OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: FALSE  
 */
static void test_purpose_204()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  5
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_205()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  5
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: FALSE  
 */
static void test_purpose_206()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  5
    #define OFFSET 6
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: FALSE  
 */
static void test_purpose_207()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  10
    #define END  25
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: FALSE  
 */
static void test_purpose_208()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  10
    #define END  25
    #define OFFSET 25
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_209()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  10
    #define END  25
    #define OFFSET 15
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_210()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  10
    #define END  25
    #define OFFSET 24
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_211()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  25
    #define END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define OFFSET 25
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: FALSE  
 */
static void test_purpose_212()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  25
    #define END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define OFFSET strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_213()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  25
    #define END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define OFFSET 49
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: FALSE  
 */
static void test_purpose_214()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  25
    #define END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define OFFSET 24
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_215()
{
    #define TEST_LINE  "\b\n\t"
    #define START  0
    #define END  strlen ("\b\n\t") - 1
    #define OFFSET 1
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: TRUE  
 */
static void test_purpose_216()
{
    #define TEST_LINE  " "
    #define START  0
    #define END  1
    #define OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_has_tag
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is within a range tagged with tag.
 * Params Values:  const GtkTextIter* iter, GtkTextTag *tag
 * Expected: FALSE  
 */
static void test_purpose_217()
{
    #define TEST_LINE  " "
    #define START  0
    #define END  1
    #define OFFSET 1
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
    invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
    gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_has_tag (&iter3, invisible_tag) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_has_tag() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_editable
 * Params: const GtkTextIter* iter, gboolean default_setting
 * Returns: gboolean
 * Assertion: Returns whether the character at iter is within an editable region of text.
 * Params Values:  const GtkTextIter* iter with offset 5, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_218()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  strlen ("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890") - 1
    #define OFFSET 5
    #define TAG_NAME "editable1"
    #define TAG_PROP_NAME "editable"
    #define TAG_PROP_VALUE TRUE
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, END);
    tag = gtk_text_buffer_create_tag (buffer, TAG_NAME, TAG_PROP_NAME, 
                                                TAG_PROP_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter3, OFFSET);
    if (gtk_text_iter_editable (&iter3, FALSE) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_editable() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef TAG_NAME
    #undef TAG_PROP_NAME
    #undef TAG_PROP_VALUE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_editable
 * Params: const GtkTextIter* iter, gboolean default_setting
 * Returns: gboolean
 * Assertion: Returns whether the character at iter is within an editable region of text.
 * Params Values:  const GtkTextIter* iter with offset 5, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_219()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  25
    #define OFFSET 5
    #define TAG_NAME "editable1"
    #define TAG_PROP_NAME "editable"
    #define TAG_PROP_VALUE TRUE
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, END);
    tag = gtk_text_buffer_create_tag (buffer, TAG_NAME, TAG_PROP_NAME, 
                                                TAG_PROP_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter3, OFFSET);
    if (gtk_text_iter_editable (&iter3, FALSE) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_editable() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef TAG_NAME
    #undef TAG_PROP_NAME
    #undef TAG_PROP_VALUE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_editable
 * Params: const GtkTextIter* iter, gboolean default_setting
 * Returns: gboolean
 * Assertion: Returns whether the character at iter is within an editable region of text.
 * Params Values:  const GtkTextIter* iter with offset 5, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_220()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  25
    #define OFFSET 5
    #define TAG_NAME "editable1"
    #define TAG_PROP_NAME "editable"
    #define TAG_PROP_VALUE FALSE
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, END);
    tag = gtk_text_buffer_create_tag (buffer, TAG_NAME, TAG_PROP_NAME, 
                                                TAG_PROP_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter3, OFFSET);
    if (gtk_text_iter_editable (&iter3, FALSE) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_editable() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef TAG_NAME
    #undef TAG_PROP_NAME
    #undef TAG_PROP_VALUE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_editable
 * Params: const GtkTextIter* iter, gboolean default_setting
 * Returns: gboolean
 * Assertion: Returns whether the character at iter is within an editable region of text.
 * Params Values:  const GtkTextIter* iter with offset 25, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_221()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  25
    #define OFFSET 25
    #define TAG_NAME "editable1"
    #define TAG_PROP_NAME "editable"
    #define TAG_PROP_VALUE TRUE
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, END);
    tag = gtk_text_buffer_create_tag (buffer, TAG_NAME, TAG_PROP_NAME, 
                                                TAG_PROP_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter3, OFFSET);
    if (gtk_text_iter_editable (&iter3, FALSE) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_editable() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef TAG_NAME
    #undef TAG_PROP_NAME
    #undef TAG_PROP_VALUE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_editable
 * Params: const GtkTextIter* iter, gboolean default_setting
 * Returns: gboolean
 * Assertion: Returns whether the character at iter is within an editable region of text.
 * Params Values:  const GtkTextIter* iter with offset 0, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_222()
{
    #define TEST_LINE  " "
    #define START  0
    #define END  1
    #define OFFSET 0
    #define TAG_NAME "editable1"
    #define TAG_PROP_NAME "editable"
    #define TAG_PROP_VALUE TRUE
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, END);
    tag = gtk_text_buffer_create_tag (buffer, TAG_NAME, TAG_PROP_NAME, 
                                                TAG_PROP_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter3, OFFSET);
    if (gtk_text_iter_editable (&iter3, FALSE) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_editable() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef TAG_NAME
    #undef TAG_PROP_NAME
    #undef TAG_PROP_VALUE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_editable
 * Params: const GtkTextIter* iter, gboolean default_setting
 * Returns: gboolean
 * Assertion: Returns whether the character at iter is within an editable region of text.
 * Params Values:  const GtkTextIter* iter with offset 1, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_223()
{
    #define TEST_LINE  " "
    #define START  0
    #define END  1
    #define OFFSET 1
    #define TAG_NAME "editable1"
    #define TAG_PROP_NAME "editable"
    #define TAG_PROP_VALUE TRUE
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, END);
    tag = gtk_text_buffer_create_tag (buffer, TAG_NAME, TAG_PROP_NAME, 
                                                TAG_PROP_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter3, OFFSET);
    if (gtk_text_iter_editable (&iter3, FALSE) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_editable() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef TAG_NAME
    #undef TAG_PROP_NAME
    #undef TAG_PROP_VALUE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_editable
 * Params: const GtkTextIter* iter, gboolean default_setting
 * Returns: gboolean
 * Assertion: If no tags applied to this text affect editability, default_setting will be returned.
 * Params Values:  const GtkTextIter* iter with offset 26, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_224()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define START  0
    #define END  25
    #define OFFSET 26
    #define TAG_NAME "editable1"
    #define TAG_PROP_NAME "editable"
    #define TAG_PROP_VALUE TRUE
    #define DEFAULT_VALUE TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, END);
    tag = gtk_text_buffer_create_tag (buffer, TAG_NAME, TAG_PROP_NAME, 
                                                TAG_PROP_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, tag, &iter1, &iter2);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter3, OFFSET);
    if (gtk_text_iter_editable (&iter3, DEFAULT_VALUE) != DEFAULT_VALUE)
    {
        TEST_FAIL ("gtk_text_iter_editable() returned not %d incorrectly", DEFAULT_VALUE);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef TAG_NAME
    #undef TAG_PROP_NAME
    #undef TAG_PROP_VALUE
    #undef DEFAULT_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_225()
{
    #define TEST_LINE  "wo\nrd1 word2 word3"
    #define OFFSET 2
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_226()
{
    #define TEST_LINE  "wo\nrd1 word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_227()
{
    #define TEST_LINE  "wo\r\nrd1 word2 word3"
    #define OFFSET 2
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_228()
{
    #define TEST_LINE  "wo\r\nrd1 word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_229()
{
    #define TEST_LINE  "wo\r\nrd1 word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_230()
{
    #define TEST_LINE  "wo\rrd1 word2 word3"
    #define OFFSET 2
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_231()
{
    #define TEST_LINE  "wo\rrd1 word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_232()
{
    #define TEST_LINE  "wo\rrd1 word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_233()
{
    #define TEST_LINE  "wo\trd1 word2 word3"
    #define OFFSET 2
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_234()
{
    #define TEST_LINE  "word1word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_235()
{
    #define TEST_LINE  "word1word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_236()
{
    #define TEST_LINE  "word1 word2 word3"
    #define OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_237()
{
    #define TEST_LINE  "word1 word2 word3"
    #define OFFSET 6
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_238()
{
    #define TEST_LINE  "word1 word2 word3"
    #define OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_239()
{
    #define TEST_LINE  "word1 word2 word3"
    #define OFFSET 1
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_240()
{
    #define TEST_LINE  "word1 word2 word3"
    #define OFFSET 7
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_241()
{
    #define TEST_LINE  "word1_word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_242()
{
    #define TEST_LINE  "word1_word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_243()
{
    #define TEST_LINE  "word_word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_244()
{
    #define TEST_LINE  "word_word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_245()
{
    #define TEST_LINE  "word_word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_246()
{
    #define TEST_LINE  "word~word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_247()
{
    #define TEST_LINE  "word~word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_248()
{
    #define TEST_LINE  "word~word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_249()
{
    #define TEST_LINE  "word`word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_250()
{
    #define TEST_LINE  "word`word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_251()
{
    #define TEST_LINE  "word`word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_252()
{
    #define TEST_LINE  "word!word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_253()
{
    #define TEST_LINE  "word!word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_254()
{
    #define TEST_LINE  "word!word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_255()
{
    #define TEST_LINE  "word@word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_256()
{
    #define TEST_LINE  "word@word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_257()
{
    #define TEST_LINE  "word@word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_258()
{
    #define TEST_LINE  "word#word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_259()
{
    #define TEST_LINE  "word#word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_260()
{
    #define TEST_LINE  "word#word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_261()
{
    #define TEST_LINE  "word$word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_262()
{
    #define TEST_LINE  "word$word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_263()
{
    #define TEST_LINE  "word$word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_264()
{
    #define TEST_LINE  "word%word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_265()
{
    #define TEST_LINE  "word%word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_266()
{
    #define TEST_LINE  "word%word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_267()
{
    #define TEST_LINE  "word^word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_268()
{
    #define TEST_LINE  "word^word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_269()
{
    #define TEST_LINE  "word^word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_270()
{
    #define TEST_LINE  "word&word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_271()
{
    #define TEST_LINE  "word&word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_272()
{
    #define TEST_LINE  "word&word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_273()
{
    #define TEST_LINE  "word*word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_274()
{
    #define TEST_LINE  "word*word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_275()
{
    #define TEST_LINE  "word*word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_276()
{
    #define TEST_LINE  "word(word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_277()
{
    #define TEST_LINE  "word(word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_278()
{
    #define TEST_LINE  "word(word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_279()
{
    #define TEST_LINE  "word)word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_280()
{
    #define TEST_LINE  "word)word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_281()
{
    #define TEST_LINE  "word)word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_282()
{
    #define TEST_LINE  "word-word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_283()
{
    #define TEST_LINE  "word-word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_284()
{
    #define TEST_LINE  "word-word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_285()
{
    #define TEST_LINE  "word+word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_286()
{
    #define TEST_LINE  "word+word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_287()
{
    #define TEST_LINE  "word+word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_288()
{
    #define TEST_LINE  "word|word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_289()
{
    #define TEST_LINE  "word|word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_290()
{
    #define TEST_LINE  "word|word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_291()
{
    #define TEST_LINE  "word\\word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_292()
{
    #define TEST_LINE  "word\\word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_293()
{
    #define TEST_LINE  "word\\word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_294()
{
    #define TEST_LINE  "word:word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_295()
{
    #define TEST_LINE  "word:word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_296()
{
    #define TEST_LINE  "word:word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_297()
{
    #define TEST_LINE  "word;word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_298()
{
    #define TEST_LINE  "word;word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_299()
{
    #define TEST_LINE  "word;word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_300()
{
    #define TEST_LINE  "word\"word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_301()
{
    #define TEST_LINE  "word\"word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_302()
{
    #define TEST_LINE  "word\"word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_303()
{
    #define TEST_LINE  "word'word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_304()
{
    #define TEST_LINE  "word'word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_305()
{
    #define TEST_LINE  "word'word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_306()
{
    #define TEST_LINE  "word?word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_307()
{
    #define TEST_LINE  "word?word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_308()
{
    #define TEST_LINE  "word?word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_309()
{
    #define TEST_LINE  "word/word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_310()
{
    #define TEST_LINE  "word/word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_311()
{
    #define TEST_LINE  "word/word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_312()
{
    #define TEST_LINE  "word>word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_313()
{
    #define TEST_LINE  "word>word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_314()
{
    #define TEST_LINE  "word>word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_315()
{
    #define TEST_LINE  "word.word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_316()
{
    #define TEST_LINE  "word.word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_317()
{
    #define TEST_LINE  "word.word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_318()
{
    #define TEST_LINE  "word,word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_319()
{
    #define TEST_LINE  "word,word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_320()
{
    #define TEST_LINE  "word,word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_321()
{
    #define TEST_LINE  "word<word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_322()
{
    #define TEST_LINE  "word<word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_323()
{
    #define TEST_LINE  "word<word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_324()
{
    #define TEST_LINE  "word__word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_325()
{
    #define TEST_LINE  "word\t_word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_326()
{
    #define TEST_LINE  "word\\\\word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_327()
{
    #define TEST_LINE  "word\\\tword2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_328()
{
    #define TEST_LINE  "word@#word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_329()
{
    #define TEST_LINE  "word?!word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_starts_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_330()
{
    #define TEST_LINE  "wo\nrd1 word2 word3"
    #define OFFSET 1
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_331()
{
    #define TEST_LINE  "wo\nrd1 word2 word3"
    #define OFFSET 2
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_332()
{
    #define TEST_LINE  "wo\r\nrd1 word2 word3"
    #define OFFSET 2
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_333()
{
    #define TEST_LINE  "wo\r\nrd1 word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_334()
{
    #define TEST_LINE  "wo\r\nrd1 word2 word3"
    #define OFFSET 1
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_335()
{
    #define TEST_LINE  "wo\rrd1 word2 word3"
    #define OFFSET 2
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_336()
{
    #define TEST_LINE  "wo\rrd1 word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_337()
{
    #define TEST_LINE  "wo\trd1 word2 word3"
    #define OFFSET 2
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_338()
{
    #define TEST_LINE  "wo\trd1 word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_339()
{
    #define TEST_LINE  "word1word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_340()
{
    #define TEST_LINE  "word1word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_341()
{
    #define TEST_LINE  "word1word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_342()
{
    #define TEST_LINE  "word1 word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_343()
{
    #define TEST_LINE  "word1 word2 word3"
    #define OFFSET 10
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_344()
{
    #define TEST_LINE  "word1 word2 word3"
    #define OFFSET 16
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_345()
{
    #define TEST_LINE  "word1 word2 word3"
    #define OFFSET 17
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_346()
{
    #define TEST_LINE  "word1 word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_347()
{
    #define TEST_LINE  "word1 word2 word3"
    #define OFFSET 11
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_348()
{
    #define TEST_LINE  "word1_word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_349()
{
    #define TEST_LINE  "word1_word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_350()
{
    #define TEST_LINE  "word1_word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_351()
{
    #define TEST_LINE  "word_word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_352()
{
    #define TEST_LINE  "word_word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_353()
{
    #define TEST_LINE  "word_word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_354()
{
    #define TEST_LINE  "word~word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_355()
{
    #define TEST_LINE  "word~word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_356()
{
    #define TEST_LINE  "word~word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_357()
{
    #define TEST_LINE  "word`word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_358()
{
    #define TEST_LINE  "word`word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_359()
{
    #define TEST_LINE  "word`word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_360()
{
    #define TEST_LINE  "word!word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_361()
{
    #define TEST_LINE  "word!word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_362()
{
    #define TEST_LINE  "word!word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_363()
{
    #define TEST_LINE  "word@word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_364()
{
    #define TEST_LINE  "word@word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_365()
{
    #define TEST_LINE  "word@word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_366()
{
    #define TEST_LINE  "word#word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_367()
{
    #define TEST_LINE  "word#word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_368()
{
    #define TEST_LINE  "word#word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_369()
{
    #define TEST_LINE  "word$word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_370()
{
    #define TEST_LINE  "word$word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_371()
{
    #define TEST_LINE  "word$word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_372()
{
    #define TEST_LINE  "word%word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_373()
{
    #define TEST_LINE  "word%word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_374()
{
    #define TEST_LINE  "word%word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_375()
{
    #define TEST_LINE  "word^word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_376()
{
    #define TEST_LINE  "word^word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_377()
{
    #define TEST_LINE  "word^word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_378()
{
    #define TEST_LINE  "word&word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_379()
{
    #define TEST_LINE  "word&word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_380()
{
    #define TEST_LINE  "word&word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_381()
{
    #define TEST_LINE  "word*word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_382()
{
    #define TEST_LINE  "word*word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_383()
{
    #define TEST_LINE  "word*word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_384()
{
    #define TEST_LINE  "word(word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_385()
{
    #define TEST_LINE  "word(word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_386()
{
    #define TEST_LINE  "word(word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_387()
{
    #define TEST_LINE  "word)word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_388()
{
    #define TEST_LINE  "word)word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_389()
{
    #define TEST_LINE  "word)word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_390()
{
    #define TEST_LINE  "word-word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_391()
{
    #define TEST_LINE  "word-word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_392()
{
    #define TEST_LINE  "word-word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_393()
{
    #define TEST_LINE  "word+word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_394()
{
    #define TEST_LINE  "word+word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_395()
{
    #define TEST_LINE  "word+word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_396()
{
    #define TEST_LINE  "word|word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_397()
{
    #define TEST_LINE  "word|word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_398()
{
    #define TEST_LINE  "word|word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_399()
{
    #define TEST_LINE  "word\\word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_400()
{
    #define TEST_LINE  "word\\word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_401()
{
    #define TEST_LINE  "word\\word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_402()
{
    #define TEST_LINE  "word:word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_403()
{
    #define TEST_LINE  "word:word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_404()
{
    #define TEST_LINE  "word:word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_405()
{
    #define TEST_LINE  "word;word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_406()
{
    #define TEST_LINE  "word;word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_407()
{
    #define TEST_LINE  "word;word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_408()
{
    #define TEST_LINE  "word\"word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_409()
{
    #define TEST_LINE  "word\"word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_410()
{
    #define TEST_LINE  "word\"word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_411()
{
    #define TEST_LINE  "word'word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_412()
{
    #define TEST_LINE  "word'word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_413()
{
    #define TEST_LINE  "word'word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_414()
{
    #define TEST_LINE  "word?word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_415()
{
    #define TEST_LINE  "word?word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_416()
{
    #define TEST_LINE  "word?word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_417()
{
    #define TEST_LINE  "word/word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_418()
{
    #define TEST_LINE  "word/word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_419()
{
    #define TEST_LINE  "word/word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_420()
{
    #define TEST_LINE  "word>word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_421()
{
    #define TEST_LINE  "word>word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_422()
{
    #define TEST_LINE  "word>word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_423()
{
    #define TEST_LINE  "word.word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_424()
{
    #define TEST_LINE  "word.word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_425()
{
    #define TEST_LINE  "word.word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_426()
{
    #define TEST_LINE  "word,word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_427()
{
    #define TEST_LINE  "word,word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_428()
{
    #define TEST_LINE  "word,word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_429()
{
    #define TEST_LINE  "word<word2 word3"
    #define OFFSET 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_430()
{
    #define TEST_LINE  "word<word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_431()
{
    #define TEST_LINE  "word<word2 word3"
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_432()
{
    #define TEST_LINE  "word__word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_433()
{
    #define TEST_LINE  "word\t_word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_434()
{
    #define TEST_LINE  "word\\\\word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_435()
{
    #define TEST_LINE  "word\\\tword2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_436()
{
    #define TEST_LINE  "word@#word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a natural-language word.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%4%>  
 */
static void test_purpose_437()
{
    #define TEST_LINE  "word?!word2 word3"
    #define OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_ends_word (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_word () returned not %d incorrectly, line = '%s', pos = %d", CORRECT_RESULT, TEST_LINE, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_438()
{
    #define TEST_LINE  "This is a very long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 3
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_439()
{
    #define TEST_LINE  "This is a very long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 4
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_440()
{
    #define TEST_LINE  "This is a very long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 1
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_441()
{
    #define TEST_LINE  "This is a very long sentence"
    #define START  1
    #define END  3
    #define OFFSET 6
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_442()
{
    #define TEST_LINE  "This is a very long sentence"
    #define START  1
    #define END  3
    #define OFFSET 7
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_443()
{
    #define TEST_LINE  "This is a very long sentence"
    #define START  1
    #define END  9
    #define OFFSET 8
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_444()
{
    #define TEST_LINE  "This is a very long sentence"
    #define START  1
    #define END  9
    #define OFFSET 9
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_445()
{
    #define TEST_LINE  "This is a very long sentence"
    #define START  5
    #define END  6
    #define OFFSET 15
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_446()
{
    #define TEST_LINE  "This is a very long sentence"
    #define START  5
    #define END  6
    #define OFFSET 18
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_447()
{
    #define TEST_LINE  "This is a very long sentence"
    #define START  5
    #define END  6
    #define OFFSET 19
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_448()
{
    #define TEST_LINE  "This is a very long sentence"
    #define START  5
    #define END  6
    #define OFFSET 21
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_449()
{
    #define TEST_LINE  "This is a very long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 27
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_450()
{
    #define TEST_LINE  "This is a very long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 28
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_451()
{
    #define TEST_LINE  "This is a very\n long sentence"
    #define START  0
    #define END  20
    #define OFFSET 15
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_452()
{
    #define TEST_LINE  "This is a very\n long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 21
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_453()
{
    #define TEST_LINE  "This is a very\n long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 22
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_454()
{
    #define TEST_LINE  "This is a very,very\n long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 13
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_455()
{
    #define TEST_LINE  "This is a very,very\n long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 14
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_456()
{
    #define TEST_LINE  "This is a very,very\n long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 15
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_457()
{
    #define TEST_LINE  "This is a very,very\n long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 16
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_458()
{
    #define TEST_LINE  "This is a very;very\n long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 14
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_459()
{
    #define TEST_LINE  "This is a very:very, very\n long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 14
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_460()
{
    #define TEST_LINE  "This is a very, very, etc. long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 25
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_461()
{
    #define TEST_LINE  "This is a very \"very\"\n long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 19
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_462()
{
    #define TEST_LINE  "This is a very \"very\"\n long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 20
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_463()
{
    #define TEST_LINE  "This is a very (very)\n long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 19
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_464()
{
    #define TEST_LINE  "This is a very (very)\n long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 20
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_465()
{
    #define TEST_LINE  "This is a very (very)\n n-words long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 30
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_word
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a natural-language word (as opposed to say inside some whitespace).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_466()
{
    #define TEST_LINE  "This is a very 7-words long sentence"
    #define START  -1
    #define END  0
    #define OFFSET 22
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_word (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_word () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter begins a paragraph, i.e. if gtk_text_iter_get_line_offset() would return 0.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_467()
{
    #define TEST_LINE  "Line number 1\n Line number2\nLinenumber3\nlineNumber_4"
    #define START  -1
    #define END  0
    #define OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
      ???
    
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter begins a paragraph, i.e. if gtk_text_iter_get_line_offset() would return 0.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_468()
{
    #define TEST_LINE  "Line number 1\n Line number2\nLinenumber3\nlineNumber_4"
    #define START  -1
    #define END  0
    #define OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
      ???
    
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter begins a paragraph, i.e. if gtk_text_iter_get_line_offset() would return 0.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_469()
{
    #define TEST_LINE  "Line number 1\n Line number2\nLinenumber3\nlineNumber_4"
    #define START  -1
    #define END  0
    #define OFFSET 13
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
      ???
    
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter begins a paragraph, i.e. if gtk_text_iter_get_line_offset() would return 0.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_470()
{
    #define TEST_LINE  "Line number 1\n Line number2\nLinenumber3\nlineNumber_4"
    #define START  -1
    #define END  0
    #define OFFSET 14
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
      ???
    
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter begins a paragraph, i.e. if gtk_text_iter_get_line_offset() would return 0.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_471()
{
    #define TEST_LINE  "Line number 1\n Line number2\nLinenumber3\nlineNumber_4"
    #define START  0
    #define END  30
    #define OFFSET 27
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
      ???
    
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter begins a paragraph, i.e. if gtk_text_iter_get_line_offset() would return 0.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_472()
{
    #define TEST_LINE  "Line number 1\n Line number2\nLinenumber3\nlineNumber_4"
    #define START  0
    #define END  10
    #define OFFSET 28
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
      ???
    
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter points to the start of the paragraph delimiter characters for a line (delimiters will be either a newline, a carriage return, a carriage return followed by a newline, or a Unicode paragraph separator character).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_473()
{
    #define TEST_LINE  "Line number 1\n Line number2"
    #define START  -1
    #define END  0
    #define OFFSET 0
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*
     why ?
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter points to the start of the paragraph delimiter characters for a line (delimiters will be either a newline, a carriage return, a carriage return followed by a newline, or a Unicode paragraph separator character).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_474()
{
    #define TEST_LINE  "Line number 1\n Line number2"
    #define START  5
    #define END  10
    #define OFFSET 13
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*
     why ?
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter points to the start of the paragraph delimiter characters for a line (delimiters will be either a newline, a carriage return, a carriage return followed by a newline, or a Unicode paragraph separator character).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_475()
{
    #define TEST_LINE  "Line number 1\n Line number2\n"
    #define START  5
    #define END  10
    #define OFFSET 27
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*
     why ?
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter points to the start of the paragraph delimiter characters for a line (delimiters will be either a newline, a carriage return, a carriage return followed by a newline, or a Unicode paragraph separator character).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_476()
{
    #define TEST_LINE  "Line number 1\n Line number2"
    #define START  5
    #define END  10
    #define OFFSET 27
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*
     why ?
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter points to the start of the paragraph delimiter characters for a line (delimiters will be either a newline, a carriage return, a carriage return followed by a newline, or a Unicode paragraph separator character).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_477()
{
    #define TEST_LINE  "Line number 1\n Line number2"
    #define START  5
    #define END  10
    #define OFFSET 28
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*
     why ?
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter points to the start of the paragraph delimiter characters for a line (delimiters will be either a newline, a carriage return, a carriage return followed by a newline, or a Unicode paragraph separator character).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_478()
{
    #define TEST_LINE  "Line number 1\n Line number2\n"
    #define START  5
    #define END  10
    #define OFFSET 27
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*
     why ?
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter points to the start of the paragraph delimiter characters for a line (delimiters will be either a newline, a carriage return, a carriage return followed by a newline, or a Unicode paragraph separator character).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_479()
{
    #define TEST_LINE  "Line number 1\n Line number\n"
    #define START  5
    #define END  10
    #define OFFSET 28
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*
     why ?
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter points to the start of the paragraph delimiter characters for a line (delimiters will be either a newline, a carriage return, a carriage return followed by a newline, or a Unicode paragraph separator character).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_480()
{
    #define TEST_LINE  "Line number 1\r Line number2"
    #define START  5
    #define END  10
    #define OFFSET 13
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*
     why ?
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter points to the start of the paragraph delimiter characters for a line (delimiters will be either a newline, a carriage return, a carriage return followed by a newline, or a Unicode paragraph separator character).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_481()
{
    #define TEST_LINE  "Line number 1\r\n Line number2"
    #define START  5
    #define END  10
    #define OFFSET 13
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /*
     why ?
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Note that an iterator pointing to the \n of a \r\n pair will not be counted as the end of a line, the line ends before the \r.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_482()
{
    #define TEST_LINE  "Line1\r\nline2"
    #define START  0
    #define END  8
    #define OFFSET 6
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: The end iterator is considered to be at the end of a line, even though there are no paragraph delimiter chars there.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_483()
{
    #define TEST_LINE  "Line1\r"
    #define START  0
    #define END  4
    #define OFFSET 6
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: The end iterator is considered to be at the end of a line, even though there are no paragraph delimiter chars there.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_484()
{
    #define TEST_LINE  "Line1\n"
    #define START  0
    #define END  4
    #define OFFSET 6
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: The end iterator is considered to be at the end of a line, even though there are no paragraph delimiter chars there.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_485()
{
    #define TEST_LINE  "Line1\r\n"
    #define START  0
    #define END  4
    #define OFFSET 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: The end iterator is considered to be at the end of a line, even though there are no paragraph delimiter chars there.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_486()
{
    #define TEST_LINE  "Line1"
    #define START  0
    #define END  4
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_line (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_line () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_487()
{
    #define TEST_LINE  "Sentence 1"
    #define START  -1
    #define END  0
    #define OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_488()
{
    #define TEST_LINE  "Sentence 1"
    #define START  0
    #define END  5
    #define OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_489()
{
    #define TEST_LINE  "Sentence 1"
    #define START  -1
    #define END  0
    #define OFFSET 10
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_490()
{
    #define TEST_LINE  "Sentence 1"
    #define START  0
    #define END  8
    #define OFFSET 10
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_491()
{
    #define TEST_LINE  "Sentence 1. Sentence2"
    #define START  -1
    #define END  8
    #define OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_492()
{
    #define TEST_LINE  "Sentence 1.\nSentence2"
    #define START  1
    #define END  8
    #define OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_493()
{
    #define TEST_LINE  "Sentence 1 Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_494()
{
    #define TEST_LINE  "Sentence 1.Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_495()
{
    #define TEST_LINE  "Sentence 1;Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_496()
{
    #define TEST_LINE  "Sentence 1-Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_497()
{
    #define TEST_LINE  "Sentence 1:Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_498()
{
    #define TEST_LINE  "Sentence 1\"Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_499()
{
    #define TEST_LINE  "Sentence 1,Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_500()
{
    #define TEST_LINE  "Sentence 1! Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_501()
{
    #define TEST_LINE  "Sentence 1!\nSentence2"
    #define START  1
    #define END  8
    #define OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_502()
{
    #define TEST_LINE  "Sentence 1!Sentence2! "
    #define START  -1
    #define END  8
    #define OFFSET 21
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_503()
{
    #define TEST_LINE  "Sentence 1!Sentence2!\n"
    #define START  -1
    #define END  8
    #define OFFSET 21
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_504()
{
    #define TEST_LINE  "Sentence 1!Sentence2!"
    #define START  1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_505()
{
    #define TEST_LINE  "Sent\n\nence 1!Sentence2!"
    #define START  1
    #define END  8
    #define OFFSET 23
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_506()
{
    #define TEST_LINE  "Sent\n\nence 1!Sentence2\n\n"
    #define START  1
    #define END  8
    #define OFFSET 23
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_507()
{
    #define TEST_LINE  "Sentence 1... Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 14
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_508()
{
    #define TEST_LINE  "Sentence 1...\nSentence2"
    #define START  1
    #define END  8
    #define OFFSET 14
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_509()
{
    #define TEST_LINE  "Sentence 1... Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 13
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_510()
{
    #define TEST_LINE  "Sentence 1... Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 12
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_511()
{
    #define TEST_LINE  "Sentence 1? Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_512()
{
    #define TEST_LINE  "Sentence 1?! Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 12
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_513()
{
    #define TEST_LINE  "Sentence 1?! Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 13
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_514()
{
    #define TEST_LINE  "Sentence \none!"
    #define START  1
    #define END  8
    #define OFFSET 10
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_starts_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter begins a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_515()
{
    #define TEST_LINE  "Sentence\n one!"
    #define START  1
    #define END  8
    #define OFFSET 10
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_starts_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_starts_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_516()
{
    #define TEST_LINE  "Sentence 1"
    #define START  -1
    #define END  0
    #define OFFSET 0
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_517()
{
    #define TEST_LINE  "Sentence 1"
    #define START  -1
    #define END  0
    #define OFFSET 9
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_518()
{
    #define TEST_LINE  "Sentence 1"
    #define START  0
    #define END  8
    #define OFFSET 9
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_519()
{
    #define TEST_LINE  "Sentence 1.Sentence2"
    #define START  -1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_520()
{
    #define TEST_LINE  "Sentence 1!Sentence2"
    #define START  -1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_521()
{
    #define TEST_LINE  "Sentence 1. Sentence2"
    #define START  -1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_522()
{
    #define TEST_LINE  "Sentence 1. Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 12
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_523()
{
    #define TEST_LINE  "Sentence 1 Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 10
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_524()
{
    #define TEST_LINE  "Sentence 1; Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_525()
{
    #define TEST_LINE  "Sentence 1-Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_526()
{
    #define TEST_LINE  "Sentence 1: Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_527()
{
    #define TEST_LINE  "Sentence 1\" Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_528()
{
    #define TEST_LINE  "Sentence 1, Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_529()
{
    #define TEST_LINE  "Sentence 1! Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 11
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_530()
{
    #define TEST_LINE  "Sentence 1! Sentence2!"
    #define START  -1
    #define END  8
    #define OFFSET 22
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_531()
{
    #define TEST_LINE  "Sentence 1!Sentence2!"
    #define START  1
    #define END  8
    #define OFFSET 21
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_532()
{
    #define TEST_LINE  "Sent\n\nence 1!Sentence2!"
    #define START  1
    #define END  8
    #define OFFSET 23
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_533()
{
    #define TEST_LINE  "Sent\n\nence 1!Sentence2\n\n!"
    #define START  1
    #define END  8
    #define OFFSET 24
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_534()
{
    #define TEST_LINE  "Sent\n\nence 1!Sentence2\n\n."
    #define START  1
    #define END  8
    #define OFFSET 24
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_535()
{
    #define TEST_LINE  "Sent\n\nence 1!Sentence2\n\n"
    #define START  1
    #define END  8
    #define OFFSET 24
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_536()
{
    #define TEST_LINE  "Sent\n\nence 1!Sentence2\r\n"
    #define START  1
    #define END  8
    #define OFFSET 24
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_537()
{
    #define TEST_LINE  "Sent\n\nence 1!Sentence2\n\r"
    #define START  1
    #define END  8
    #define OFFSET 24
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_538()
{
    #define TEST_LINE  "Sentence \none!"
    #define START  1
    #define END  8
    #define OFFSET 8
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_539()
{
    #define TEST_LINE  "Sentence \none!"
    #define START  1
    #define END  8
    #define OFFSET 9
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_540()
{
    #define TEST_LINE  "Sentence\n one!"
    #define START  1
    #define END  8
    #define OFFSET 8
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_541()
{
    #define TEST_LINE  "Sentence\n one!"
    #define START  1
    #define END  8
    #define OFFSET 9
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_542()
{
    #define TEST_LINE  "Sentence 1?! Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_ends_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter ends a sentence.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_543()
{
    #define TEST_LINE  "Sentence 1?! Sentence2"
    #define START  1
    #define END  8
    #define OFFSET 13
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    /*
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag(buffer, "invisible-tag", "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    */
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_ends_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_ends_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_544()
{
    #define TEST_LINE  "Sentence one"
    #define START  -1
    #define END  0
    #define OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_545()
{
    #define TEST_LINE  "Sentence one"
    #define START  -1
    #define END  0
    #define OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_546()
{
    #define TEST_LINE  "Sentence one"
    #define START  1
    #define END  3
    #define OFFSET 12
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_547()
{
    #define TEST_LINE  "Sentence one."
    #define START  1
    #define END  3
    #define OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_548()
{
    #define TEST_LINE  "Sentence one. Sentence two."
    #define START  1
    #define END  3
    #define OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_549()
{
    #define TEST_LINE  "Sentence one. Sentence two."
    #define START  1
    #define END  3
    #define OFFSET 13
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_550()
{
    #define TEST_LINE  "Sentence one.Sentence two."
    #define START  1
    #define END  3
    #define OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_551()
{
    #define TEST_LINE  "Sentence one.Sentence two."
    #define START  1
    #define END  3
    #define OFFSET 13
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_552()
{
    #define TEST_LINE  "Sentence\n one.Sentence two."
    #define START  1
    #define END  3
    #define OFFSET 9
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_553()
{
    #define TEST_LINE  "Sentence one!Sentence two."
    #define START  1
    #define END  3
    #define OFFSET 13
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_554()
{
    #define TEST_LINE  "Sentence one! Sentence two."
    #define START  1
    #define END  3
    #define OFFSET 13
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_555()
{
    #define TEST_LINE  "Sentence one?Sentence two."
    #define START  1
    #define END  3
    #define OFFSET 13
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_556()
{
    #define TEST_LINE  "Sentence one? Sentence two."
    #define START  1
    #define END  3
    #define OFFSET 13
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_557()
{
    #define TEST_LINE  "Sentence one?!Sentence two."
    #define START  1
    #define END  3
    #define OFFSET 14
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_inside_sentence
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Determines whether iter is inside a sentence (as opposed to in between two sentences, e.g. after a period and before the first letter of the next sentence).
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_558()
{
    #define TEST_LINE  "Sentence one?! Sentence two."
    #define START  1
    #define END  3
    #define OFFSET 14
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextIter iter3;
    GtkTextBuffer* buffer;
    GtkTextTag* invisible_tag;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    if (START > 0)
    {
        gtk_text_buffer_get_iter_at_offset(buffer, &iter1, START);
        gtk_text_buffer_get_iter_at_offset(buffer, &iter2, END);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "strikethrough-tag", "strikethrough", TRUE, NULL);
        gtk_text_buffer_apply_tag(buffer, invisible_tag, &iter1, &iter2);
    }
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter3, OFFSET);
    if (gtk_text_iter_inside_sentence (&iter3) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_inside_sentence () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef START
    #undef END
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: See gtk_text_iter_forward_cursor_position() or PangoLogAttr or pango_break() for details on what a cursor position is.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_559()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_cursor_position () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: See gtk_text_iter_forward_cursor_position() or PangoLogAttr or pango_break() for details on what a cursor position is.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_560()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 8
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_cursor_position () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: See gtk_text_iter_forward_cursor_position() or PangoLogAttr or pango_break() for details on what a cursor position is.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_561()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 11
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_cursor_position () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: See gtk_text_iter_forward_cursor_position() or PangoLogAttr or pango_break() for details on what a cursor position is.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_562()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_cursor_position () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: See gtk_text_iter_forward_cursor_position() or PangoLogAttr or pango_break() for details on what a cursor position is.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_563()
{
    #define TEST_LINE  "Sentence one.\nSentence two"
    #define OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_cursor_position () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: See gtk_text_iter_forward_cursor_position() or PangoLogAttr or pango_break() for details on what a cursor position is.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_564()
{
    #define TEST_LINE  "Sentence one.\r\nSentence two"
    #define OFFSET 13
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_cursor_position () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: See gtk_text_iter_forward_cursor_position() or PangoLogAttr or pango_break() for details on what a cursor position is.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_565()
{
    #define TEST_LINE  "Sentence one.\r\nSentence two"
    #define OFFSET 14
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_cursor_position () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: See gtk_text_iter_forward_cursor_position() or PangoLogAttr or pango_break() for details on what a cursor position is.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_566()
{
    #define TEST_LINE  "Sentence one.\r\nSentence two"
    #define OFFSET 15
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_cursor_position () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_start
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is the first iterator in the buffer, that is if iter has a character offset of 0.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_567()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_start (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_start () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_start
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is the first iterator in the buffer, that is if iter has a character offset of 0.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_568()
{
    #define TEST_LINE  "\n\nSentence"
    #define OFFSET 1
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_start (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_start () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_start
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is the first iterator in the buffer, that is if iter has a character offset of 0.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_569()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 9
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_start (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_start () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is the end iterator, i.e. one past the last dereferenceable iterator in the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_570()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 0
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_end (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_end () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is the end iterator, i.e. one past the last dereferenceable iterator in the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_571()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 9
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_end (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_end () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is the end iterator, i.e. one past the last dereferenceable iterator in the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_572()
{
    #define TEST_LINE  "Sentence\n"
    #define OFFSET 9
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_end (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_end () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is the end iterator, i.e. one past the last dereferenceable iterator in the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_573()
{
    #define TEST_LINE  "Sent\0ence\n"
    #define OFFSET 10
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_end (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_end () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is the end iterator, i.e. one past the last dereferenceable iterator in the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_574()
{
    #define TEST_LINE  "Sentence\n\n"
    #define OFFSET 10
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_end (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_end () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_is_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter is the end iterator, i.e. one past the last dereferenceable iterator in the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_575()
{
    #define TEST_LINE  "Sentence\r\n"
    #define OFFSET 10
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_is_end (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_is_end () returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_char
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter forward by one character offset.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_576()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 0
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_char (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_char () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET + 1)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, new_offset + 1);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_char
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter forward by one character offset.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_577()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 5
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_char (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_char () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET + 1)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, new_offset + 1);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_char
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter forward by one character offset.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_578()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 6
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_char (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_char () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET + 1)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, new_offset + 1);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_char
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter forward by one character offset.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_579()
{
    #define TEST_LINE  "Sentence\n\n\n\nSentence"
    #define OFFSET 9
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_char (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_char () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET + 1)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, new_offset + 1);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_char
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If iter is the end iterator or one character before it, iter will now point at the end iterator, and gtk_text_iter_forward_char() returns FALSE for convenience when writing loops.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_580()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 8
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean is_end = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    if (gtk_text_iter_is_end (&iter))
    {
        is_end = TRUE;
    }
    
    if (gtk_text_iter_forward_char (&iter) != FALSE)
    {
        TEST_FAIL ("gtk_text_forward_char () returned TRUE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (is_end)
    {
        if (new_offset != OFFSET)
        {
            TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET);
        }
    } else {
        if (new_offset != OFFSET + 1)
        {
            TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET + 1);
        }
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_char
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If iter is the end iterator or one character before it, iter will now point at the end iterator, and gtk_text_iter_forward_char() returns FALSE for convenience when writing loops.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_581()
{
    #define TEST_LINE  "Sentence\n"
    #define OFFSET 8
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean is_end = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    if (gtk_text_iter_is_end (&iter))
    {
        is_end = TRUE;
    }
    
    if (gtk_text_iter_forward_char (&iter) != FALSE)
    {
        TEST_FAIL ("gtk_text_forward_char () returned TRUE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (is_end)
    {
        if (new_offset != OFFSET)
        {
            TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET);
        }
    } else {
        if (new_offset != OFFSET + 1)
        {
            TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET + 1);
        }
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_char
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If iter is the end iterator or one character before it, iter will now point at the end iterator, and gtk_text_iter_forward_char() returns FALSE for convenience when writing loops.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_582()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 8
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean is_end = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    if (gtk_text_iter_is_end (&iter))
    {
        is_end = TRUE;
    }
    
    if (gtk_text_iter_forward_char (&iter) != FALSE)
    {
        TEST_FAIL ("gtk_text_forward_char () returned TRUE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (is_end)
    {
        if (new_offset != OFFSET)
        {
            TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET);
        }
    } else {
        if (new_offset != OFFSET + 1)
        {
            TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET + 1);
        }
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_char
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If iter is the end iterator or one character before it, iter will now point at the end iterator, and gtk_text_iter_forward_char() returns FALSE for convenience when writing loops.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_583()
{
    #define TEST_LINE  "Sentence\n"
    #define OFFSET 9
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean is_end = FALSE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    if (gtk_text_iter_is_end (&iter))
    {
        is_end = TRUE;
    }
    
    if (gtk_text_iter_forward_char (&iter) != FALSE)
    {
        TEST_FAIL ("gtk_text_forward_char () returned TRUE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (is_end)
    {
        if (new_offset != OFFSET)
        {
            TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET);
        }
    } else {
        if (new_offset != OFFSET + 1)
        {
            TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET + 1);
        }
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_char
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward by one character offset.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_584()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 1
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_char (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_char () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET - 1)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, new_offset - 1);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_char
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward by one character offset.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_585()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 5
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_char (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_char () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET - 1)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, new_offset - 1);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_char
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward by one character offset.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_586()
{
    #define TEST_LINE  "\n\nSentence"
    #define OFFSET 1
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_char (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_char () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET - 1)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, new_offset - 1);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_char
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if movement was possible; if iter was the first in the buffer (character offset 0), gtk_text_iter_backward_char() returns FALSE for convenience when writing loops.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_587()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 0
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    if (gtk_text_iter_backward_char (&iter) != FALSE)
    {
        TEST_FAIL ("gtk_text_backward_char () returned TRUE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_char
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if movement was possible; if iter was the first in the buffer (character offset 0), gtk_text_iter_backward_char() returns FALSE for convenience when writing loops.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_588()
{
    #define TEST_LINE  "\r\tSentence"
    #define OFFSET 0
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    if (gtk_text_iter_backward_char (&iter) != FALSE)
    {
        TEST_FAIL ("gtk_text_backward_char () returned TRUE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count characters backward, if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_589()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 1
    #define COUNT 1
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_chars (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_chars () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET - (COUNT))
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET - (COUNT));
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count characters backward, if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, 3
 * Expected: TRUE  
 */
static void test_purpose_590()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 5
    #define COUNT 3
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_chars (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_chars () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET - (COUNT))
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET - (COUNT));
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count characters backward, if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, -2
 * Expected: TRUE  
 */
static void test_purpose_591()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 5
    #define COUNT -2
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_chars (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_chars () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET - (COUNT))
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET - (COUNT));
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count characters backward, if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, 4
 * Expected: TRUE  
 */
static void test_purpose_592()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 8
    #define COUNT 4
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_chars (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_chars () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET - (COUNT))
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET - (COUNT));
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_593()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 1
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_backward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 2
 * Expected: TRUE  
 */
static void test_purpose_594()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 1
    #define COUNT 2
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_backward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_595()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 0
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_backward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 3
 * Expected: TRUE  
 */
static void test_purpose_596()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 0
    #define COUNT 3
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_backward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 3
 * Expected: TRUE  
 */
static void test_purpose_597()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 5
    #define COUNT 3
    #define CORRECT_NEW_OFFSET 2
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_backward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, -5
 * Expected: TRUE  
 */
static void test_purpose_598()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 5
    #define COUNT -5
    #define CORRECT_NEW_OFFSET 8
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_backward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, -3
 * Expected: TRUE  
 */
static void test_purpose_599()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 5
    #define COUNT -3
    #define CORRECT_NEW_OFFSET 8
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_backward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, G_MAXINT
 * Expected: TRUE  
 */
static void test_purpose_600()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 3
    #define COUNT G_MAXINT
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_backward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is 0, the function does nothing and returns FALSE.
 * Params Values:  const GtkTextIter* iter, 0
 * Expected: FALSE  
 */
static void test_purpose_601()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 1
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_chars (&iter, 0) != FALSE)
    {
        TEST_FAIL ("gtk_text_backward_chars () returned TRUE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count characters if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_602()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 1
    #define COUNT 1
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_chars (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_chars () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET + (COUNT))
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET + (COUNT));
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count characters if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, 3
 * Expected: TRUE  
 */
static void test_purpose_603()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 4
    #define COUNT 3
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_chars (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_chars () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET + (COUNT))
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET + (COUNT));
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count characters if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, -2
 * Expected: TRUE  
 */
static void test_purpose_604()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 5
    #define COUNT -2
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_chars (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_chars () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET + (COUNT))
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET + (COUNT));
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count characters if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, 4
 * Expected: TRUE  
 */
static void test_purpose_605()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 0
    #define COUNT 4
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_chars (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_chars () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET + (COUNT))
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET + (COUNT));
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the new position of iter is different from its original position, and dereferenceable (the last iterator in the buffer is not dereferenceable).
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_606()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 7
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 8
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the new position of iter is different from its original position, and dereferenceable (the last iterator in the buffer is not dereferenceable).
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_607()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 8
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 8
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the new position of iter is different from its original position, and dereferenceable (the last iterator in the buffer is not dereferenceable).
 * Params Values:  const GtkTextIter* iter, G_MAXINT
 * Expected: TRUE  
 */
static void test_purpose_608()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 0
    #define COUNT G_MAXINT
    #define CORRECT_NEW_OFFSET 8
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the new position of iter is different from its original position, and dereferenceable (the last iterator in the buffer is not dereferenceable).
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_609()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 7
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 8
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the new position of iter is different from its original position, and dereferenceable (the last iterator in the buffer is not dereferenceable).
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_610()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 0
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 1
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the new position of iter is different from its original position, and dereferenceable (the last iterator in the buffer is not dereferenceable).
 * Params Values:  const GtkTextIter* iter, 3
 * Expected: TRUE  
 */
static void test_purpose_611()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 7
    #define COUNT 3
    #define CORRECT_NEW_OFFSET 8
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the new position of iter is different from its original position, and dereferenceable (the last iterator in the buffer is not dereferenceable).
 * Params Values:  const GtkTextIter* iter, -3
 * Expected: TRUE  
 */
static void test_purpose_612()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 5
    #define COUNT -3
    #define CORRECT_NEW_OFFSET 2
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the new position of iter is different from its original position, and dereferenceable (the last iterator in the buffer is not dereferenceable).
 * Params Values:  const GtkTextIter* iter, -10
 * Expected: TRUE  
 */
static void test_purpose_613()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 5
    #define COUNT -10
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_chars (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_chars () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_chars
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is 0, the function does nothing and returns FALSE.
 * Params Values:  const GtkTextIter* iter, <%2%>
 * Expected: FALSE  
 */
static void test_purpose_614()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 1
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_chars (&iter, 0) != FALSE)
    {
        TEST_FAIL ("gtk_text_forward_chars () returned TRUE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter to the start of the next line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_615()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 7
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_line () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter to the start of the next line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_616()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 7
    #define CORRECT_NEW_OFFSET 15
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_line () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter to the start of the next line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_617()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 21
    #define CORRECT_NEW_OFFSET 22
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_line () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter to the start of the next line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_618()
{
    #define TEST_LINE  "line 1\r\n line 2\n"
    #define OFFSET 6
    #define CORRECT_NEW_OFFSET 8
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_line () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if there was a next line to move to, and FALSE if iter was simply moved to the end of the buffer and is now not dereferenceable, or if iter was already at the end of the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_619()
{
    #define TEST_LINE  "line 1\n line 2\n"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if there was a next line to move to, and FALSE if iter was simply moved to the end of the buffer and is now not dereferenceable, or if iter was already at the end of the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_620()
{
    #define TEST_LINE  "line 1\n line 2\n"
    #define OFFSET 8
    #define CORRECT_NEW_OFFSET 15
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if there was a next line to move to, and FALSE if iter was simply moved to the end of the buffer and is now not dereferenceable, or if iter was already at the end of the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_621()
{
    #define TEST_LINE  "line 1\n line 2\n"
    #define OFFSET 15
    #define CORRECT_NEW_OFFSET 15
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if there was a next line to move to, and FALSE if iter was simply moved to the end of the buffer and is now not dereferenceable, or if iter was already at the end of the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_622()
{
    #define TEST_LINE  "line 1\n line 2\nu"
    #define OFFSET 15
    #define CORRECT_NEW_OFFSET 16
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if there was a next line to move to, and FALSE if iter was simply moved to the end of the buffer and is now not dereferenceable, or if iter was already at the end of the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_623()
{
    #define TEST_LINE  "line1"
    #define OFFSET 4
    #define CORRECT_NEW_OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if there was a next line to move to, and FALSE if iter was simply moved to the end of the buffer and is now not dereferenceable, or if iter was already at the end of the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_624()
{
    #define TEST_LINE  "line1"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if there was a next line to move to, and FALSE if iter was simply moved to the end of the buffer and is now not dereferenceable, or if iter was already at the end of the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_625()
{
    #define TEST_LINE  "line1\n"
    #define OFFSET 4
    #define CORRECT_NEW_OFFSET 6
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if there was a next line to move to, and FALSE if iter was simply moved to the end of the buffer and is now not dereferenceable, or if iter was already at the end of the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_626()
{
    #define TEST_LINE  "line1\n"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 6
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if there was a next line to move to, and FALSE if iter was simply moved to the end of the buffer and is now not dereferenceable, or if iter was already at the end of the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_627()
{
    #define TEST_LINE  "line\r\n"
    #define OFFSET 4
    #define CORRECT_NEW_OFFSET 6
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if there was a next line to move to, and FALSE if iter was simply moved to the end of the buffer and is now not dereferenceable, or if iter was already at the end of the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_628()
{
    #define TEST_LINE  "line\r\n"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 6
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if there was a next line to move to, and FALSE if iter was simply moved to the end of the buffer and is now not dereferenceable, or if iter was already at the end of the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_629()
{
    #define TEST_LINE  "line\r\nqw"
    #define OFFSET 4
    #define CORRECT_NEW_OFFSET 6
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if there was a next line to move to, and FALSE if iter was simply moved to the end of the buffer and is now not dereferenceable, or if iter was already at the end of the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_630()
{
    #define TEST_LINE  "line\r\nqw"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 6
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter to the start of the previous line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_631()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 8
    #define CORRECT_NEW_OFFSET 0
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_line (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_line () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter to the start of the previous line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_632()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 18
    #define CORRECT_NEW_OFFSET 7
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_line (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_line () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter to the start of the previous line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_633()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 23
    #define CORRECT_NEW_OFFSET 22
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_line (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_line () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter could be moved; i.e. if iter was at character offset 0, this function returns FALSE. 
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_634()
{
    #define TEST_LINE  "line 1\n line 2\n"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter could be moved; i.e. if iter was at character offset 0, this function returns FALSE. 
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_635()
{
    #define TEST_LINE  "line 1\n line 2\n"
    #define OFFSET 8
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter could be moved; i.e. if iter was at character offset 0, this function returns FALSE. 
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_636()
{
    #define TEST_LINE  "line 1\n line 2\n"
    #define OFFSET 15
    #define CORRECT_NEW_OFFSET 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter could be moved; i.e. if iter was at character offset 0, this function returns FALSE. 
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_637()
{
    #define TEST_LINE  "line 1\r\n line 2\nu"
    #define OFFSET 8
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter could be moved; i.e. if iter was at character offset 0, this function returns FALSE. 
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_638()
{
    #define TEST_LINE  "line1\r\n"
    #define OFFSET 7
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter could be moved; i.e. if iter was at character offset 0, this function returns FALSE. 
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_639()
{
    #define TEST_LINE  "line1\r\n"
    #define OFFSET 6
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter could be moved; i.e. if iter was at character offset 0, this function returns FALSE. 
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_640()
{
    #define TEST_LINE  "line1\r\n"
    #define OFFSET 0
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_line (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_line () returned %d incorrectly", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_line
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion:  Therefore if iter was already on line 0, but not at the start of the line, iter is snapped to the start of the line and the function returns TRUE.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_641()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 3
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_line (&iter) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_line () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != 0)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 0);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count lines forward, if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_642()
{
    #define TEST_LINE  "Sentence1\n Sentence1\n"
    #define OFFSET 1
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 10
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count lines forward, if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, -2
 * Expected: TRUE  
 */
static void test_purpose_643()
{
    #define TEST_LINE  "Sentence1\nSentence2\nSentence3\nSentence4\nSentence5\nSentence6\n"
    #define OFFSET 30
    #define COUNT -2
    #define CORRECT_NEW_OFFSET 10
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_644()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 5
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 8
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_645()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 8
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 8
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, G_MAXINT
 * Expected: TRUE  
 */
static void test_purpose_646()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 0
    #define COUNT G_MAXINT
    #define CORRECT_NEW_OFFSET 8
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 2
 * Expected: TRUE  
 */
static void test_purpose_647()
{
    #define TEST_LINE  "Sentence1\nSentence2\nSentence3\nSentence4\nSentence5\n"
    #define OFFSET 22
    #define COUNT 2
    #define CORRECT_NEW_OFFSET 40
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 2
 * Expected: TRUE  
 */
static void test_purpose_648()
{
    #define TEST_LINE  "Sentence1\nSentence2\nSentence3\r\nSentence4\nSentence5\n"
    #define OFFSET 22
    #define COUNT 2
    #define CORRECT_NEW_OFFSET 41
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 4
 * Expected: TRUE  
 */
static void test_purpose_649()
{
    #define TEST_LINE  "Sentence1\nSentence2\nSentence3\nSentence4\nSentence5\n"
    #define OFFSET 22
    #define COUNT 4
    #define CORRECT_NEW_OFFSET 50
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 4
 * Expected: TRUE  
 */
static void test_purpose_650()
{
    #define TEST_LINE  "Sentence1\r\nSentence2\nSentence3\nSentence4\nSentence5\n"
    #define OFFSET 23
    #define COUNT 4
    #define CORRECT_NEW_OFFSET 51
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_651()
{
    #define TEST_LINE  "Sentence1\r\n"
    #define OFFSET 9
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 11
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_652()
{
    #define TEST_LINE  "Sentence1\r\n"
    #define OFFSET 10
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 11
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_653()
{
    #define TEST_LINE  "Sentence1\r\n"
    #define OFFSET 11
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 11
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_654()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 5
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 7
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_655()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 7
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 15
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_656()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 21
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 22
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_657()
{
    #define TEST_LINE  "line 1\r\n line 2\n"
    #define OFFSET 6
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 8
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves backward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -1
 * Expected: TRUE  
 */
static void test_purpose_658()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 8
    #define COUNT -1
    #define NEW_CORRECT_OFFSET 0
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves backward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -1
 * Expected: TRUE  
 */
static void test_purpose_659()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 18
    #define COUNT -1
    #define NEW_CORRECT_OFFSET 7
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves backward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -1
 * Expected: TRUE  
 */
static void test_purpose_660()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 23
    #define COUNT -1
    #define NEW_CORRECT_OFFSET 22
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves backward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -2
 * Expected: TRUE  
 */
static void test_purpose_661()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 23
    #define COUNT -2
    #define NEW_CORRECT_OFFSET 15
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves backward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -3
 * Expected: TRUE  
 */
static void test_purpose_662()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 23
    #define COUNT -3
    #define NEW_CORRECT_OFFSET 7
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_forward_lines () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is 0, the function does nothing and returns FALSE.
 * Params Values:  const GtkTextIter* iter, <%2%>
 * Expected: FALSE  
 */
static void test_purpose_663()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 8
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, 0) != FALSE)
    {
        TEST_FAIL ("gtk_text_forward_lines () returned TRUE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is 0, the function does nothing and returns FALSE.
 * Params Values:  const GtkTextIter* iter, <%2%>
 * Expected: FALSE  
 */
static void test_purpose_664()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 18
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_lines (&iter, 0) != FALSE)
    {
        TEST_FAIL ("gtk_text_forward_lines () returned TRUE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count lines backward, if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_665()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 8
    #define COUNT 1
    #define NEW_CORRECT_OFFSET 0
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_lines (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count lines backward, if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_666()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 18
    #define COUNT 1
    #define NEW_CORRECT_OFFSET 7
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_lines (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count lines backward, if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_667()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 23
    #define COUNT 1
    #define NEW_CORRECT_OFFSET 22
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_lines (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count lines backward, if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, 2
 * Expected: TRUE  
 */
static void test_purpose_668()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 23
    #define COUNT 2
    #define NEW_CORRECT_OFFSET 15
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_lines (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves count lines backward, if possible (if count would move past the start or end of the buffer, moves to the start or end of the buffer).
 * Params Values:  const GtkTextIter* iter, 3
 * Expected: TRUE  
 */
static void test_purpose_669()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 23
    #define COUNT 3
    #define NEW_CORRECT_OFFSET 7
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_lines (&iter, COUNT) != TRUE)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned FALSE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_670()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 3
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_backward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, -10
 * Expected: TRUE  
 */
static void test_purpose_671()
{
    #define TEST_LINE  "line 1\n line 2\n"
    #define OFFSET 5
    #define COUNT -10
    #define CORRECT_NEW_OFFSET 15
    #define CORRECT_RETURN_VALUE FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_backward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_672()
{
    #define TEST_LINE  "line 1\r\n line 2\n"
    #define OFFSET 6
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_backward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_673()
{
    #define TEST_LINE  "line 1\r\n line 2\n"
    #define OFFSET 7
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_backward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: The return value indicates whether the iterator moved onto a dereferenceable position; if the iterator didn't move, or moved onto the end iterator, then FALSE is returned.'
 * Params Values:  const GtkTextIter* iter, 1
 * Expected: TRUE  
 */
static void test_purpose_674()
{
    #define TEST_LINE  "line 1\r\n line 2\n"
    #define OFFSET 8
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RETURN_VALUE TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_lines (&iter, COUNT) != CORRECT_RETURN_VALUE)
    {
        TEST_FAIL ("gtk_text_backward_lines () should return %d", CORRECT_RETURN_VALUE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RETURN_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is 0, the function does nothing and returns FALSE.
 * Params Values:  const GtkTextIter* iter, 0
 * Expected: FALSE  
 */
static void test_purpose_675()
{
    #define TEST_LINE  "Sentence"
    #define OFFSET 6
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_lines (&iter, 0) != FALSE)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned TRUE incorrectly", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -1
 * Expected: TRUE  
 */
static void test_purpose_676()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 8
    #define COUNT -1
    #define NEW_CORRECT_OFFSET 15
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    res = gtk_text_iter_backward_lines (&iter, COUNT);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned %d incorrectly", res, CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -1
 * Expected: TRUE  
 */
static void test_purpose_677()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 18
    #define COUNT -1
    #define NEW_CORRECT_OFFSET 22
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    res = gtk_text_iter_backward_lines (&iter, COUNT);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned %d incorrectly", res, CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -1
 * Expected: TRUE  
 */
static void test_purpose_678()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 23
    #define COUNT -1
    #define NEW_CORRECT_OFFSET 24
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    res = gtk_text_iter_backward_lines (&iter, COUNT);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned %d incorrectly", res, CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -2
 * Expected: TRUE  
 */
static void test_purpose_679()
{
    #define TEST_LINE  "line 1\n line 2\n line3\n\n\n\n"
    #define OFFSET 22
    #define COUNT -2
    #define NEW_CORRECT_OFFSET 24
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    res = gtk_text_iter_backward_lines (&iter, COUNT);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned %d incorrectly", res, CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -1
 * Expected: TRUE  
 */
static void test_purpose_680()
{
    #define TEST_LINE  "line 1\r line 2\r line3\r\r\r\r"
    #define OFFSET 8
    #define COUNT -1
    #define NEW_CORRECT_OFFSET 15
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    res = gtk_text_iter_backward_lines (&iter, COUNT);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned %d incorrectly", res, CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -1
 * Expected: TRUE  
 */
static void test_purpose_681()
{
    #define TEST_LINE  "line 1\r line 2\r line3\r\r\r\r"
    #define OFFSET 18
    #define COUNT -1
    #define NEW_CORRECT_OFFSET 22
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    res = gtk_text_iter_backward_lines (&iter, COUNT);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned %d incorrectly", res, CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -1
 * Expected: TRUE  
 */
static void test_purpose_682()
{
    #define TEST_LINE  "line 1\r line 2\r line3\r\r\r\r"
    #define OFFSET 23
    #define COUNT -1
    #define NEW_CORRECT_OFFSET 24
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    res = gtk_text_iter_backward_lines (&iter, COUNT);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned %d incorrectly", res, CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -2
 * Expected: TRUE  
 */
static void test_purpose_683()
{
    #define TEST_LINE  "line 1\r line 2\r line3\r\r\r\r"
    #define OFFSET 22
    #define COUNT -2
    #define NEW_CORRECT_OFFSET 24
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    res = gtk_text_iter_backward_lines (&iter, COUNT);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned %d incorrectly", res, CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -1
 * Expected: TRUE  
 */
static void test_purpose_684()
{
    #define TEST_LINE  "line 1\r\n line 2\r\n line3\r\n\r\n"
    #define OFFSET 8
    #define COUNT -1
    #define NEW_CORRECT_OFFSET 17
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    res = gtk_text_iter_backward_lines (&iter, COUNT);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned %d incorrectly", res, CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -1
 * Expected: TRUE  
 */
static void test_purpose_685()
{
    #define TEST_LINE  "line 1\r\n line 2\r\n line3\r\n\r\n"
    #define OFFSET 18
    #define COUNT -1
    #define NEW_CORRECT_OFFSET 25
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    res = gtk_text_iter_backward_lines (&iter, COUNT);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned %d incorrectly", res, CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -1
 * Expected: TRUE  
 */
static void test_purpose_686()
{
    #define TEST_LINE  "line1\r\n\r\n"
    #define OFFSET 6
    #define COUNT -1
    #define NEW_CORRECT_OFFSET 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    res = gtk_text_iter_backward_lines (&iter, COUNT);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned %d incorrectly", res, CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_lines
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward by 0 - count lines.
 * Params Values:  const GtkTextIter* iter, -1
 * Expected: TRUE  
 */
static void test_purpose_687()
{
    #define TEST_LINE  "line1\r\n\r\n"
    #define OFFSET 7
    #define COUNT -1
    #define NEW_CORRECT_OFFSET 9
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    res = gtk_text_iter_backward_lines (&iter, COUNT);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_lines () returned %d incorrectly", res, CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != NEW_CORRECT_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", new_offset, 
                   NEW_CORRECT_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef NEW_CORRECT_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter forward by a single cursor position.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_688()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 0
    #define CORRECT_NEW_OFFSET 1
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter forward by a single cursor position.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_689()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 8
    #define CORRECT_NEW_OFFSET 9
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter forward by a single cursor position.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_690()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 12
    #define CORRECT_NEW_OFFSET 12
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter forward by a single cursor position.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_691()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 13
    #define CORRECT_NEW_OFFSET 12
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter forward by a single cursor position.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_692()
{
    #define TEST_LINE  "Sentence one.\nSentence two"
    #define OFFSET 12
    #define CORRECT_NEW_OFFSET 13
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter forward by a single cursor position.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_693()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 3
    #define CORRECT_NEW_OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter forward by a single cursor position.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_694()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 4
    #define CORRECT_NEW_OFFSET 6
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter forward by a single cursor position.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_695()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 6
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves iter forward by a single cursor position.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_696()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 6
    #define CORRECT_NEW_OFFSET 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Like gtk_text_iter_forward_cursor_position(), but moves backward.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_697()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 0
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Like gtk_text_iter_forward_cursor_position(), but moves backward.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_698()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 1
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Like gtk_text_iter_forward_cursor_position(), but moves backward.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_699()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 9
    #define CORRECT_NEW_OFFSET 8
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Like gtk_text_iter_forward_cursor_position(), but moves backward.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_700()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 12
    #define CORRECT_NEW_OFFSET 11
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Like gtk_text_iter_forward_cursor_position(), but moves backward.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_701()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 4
    #define CORRECT_NEW_OFFSET 3
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Like gtk_text_iter_forward_cursor_position(), but moves backward.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_702()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Like gtk_text_iter_forward_cursor_position(), but moves backward.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_703()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 6
    #define CORRECT_NEW_OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_position
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Like gtk_text_iter_forward_cursor_position(), but moves backward.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_704()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 7
    #define CORRECT_NEW_OFFSET 6
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_position (&iter) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_position () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_705()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 0
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 1
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_706()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 0
    #define COUNT -1
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_707()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 0
    #define COUNT 13
    #define CORRECT_NEW_OFFSET 12
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_708()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 8
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 9
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_709()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 11
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 12
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_710()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 13
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 12
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_711()
{
    #define TEST_LINE  "Sentence one.\nSentence two"
    #define OFFSET 12
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 13
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_712()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 3
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_713()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 3
    #define COUNT 2
    #define CORRECT_NEW_OFFSET 6
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_714()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 4
    #define COUNT 2
    #define CORRECT_NEW_OFFSET 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_715()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 5
    #define COUNT 2
    #define CORRECT_NEW_OFFSET 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_716()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 6
    #define COUNT 2
    #define CORRECT_NEW_OFFSET 8
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_forward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_forward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_717()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 0
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_718()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 0
    #define COUNT -1
    #define CORRECT_NEW_OFFSET 1
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_719()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 0
    #define COUNT -13
    #define CORRECT_NEW_OFFSET 12
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_720()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 8
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_721()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 12
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 11
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_722()
{
    #define TEST_LINE  "Sentence one"
    #define OFFSET 12
    #define COUNT -1
    #define CORRECT_NEW_OFFSET 12
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_723()
{
    #define TEST_LINE  "Sentence one.\nSentence two"
    #define OFFSET 13
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_724()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 4
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 3
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_725()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 6
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_726()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 5
    #define COUNT 1
    #define CORRECT_NEW_OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_727()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 5
    #define COUNT 2
    #define CORRECT_NEW_OFFSET 3
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_cursor_positions
 * Params: const GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves up to count cursor positions.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_728()
{
    #define TEST_LINE  "foo \r\n foo"
    #define OFFSET 6
    #define COUNT 2
    #define CORRECT_NEW_OFFSET 3
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    if (gtk_text_iter_backward_cursor_positions (&iter, COUNT) != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_backward_cursor_positions () should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef COUNT
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_end
 * Params: const GtkTextIter* iter
 * Returns: void
 * Assertion: Moves iter forward to the "end iterator," which points one past the last valid character in the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: void  
 */
static void test_purpose_729()
{
    #define TEST_LINE  "012345678"
    #define OFFSET 1
    #define CORRECT_NEW_OFFSET 9
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    gtk_text_iter_forward_to_end (&iter);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d (i.e. end iterator)", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_end
 * Params: const GtkTextIter* iter
 * Returns: void
 * Assertion: Moves iter forward to the "end iterator," which points one past the last valid character in the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: void  
 */
static void test_purpose_730()
{
    #define TEST_LINE  "012345678"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 9
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    gtk_text_iter_forward_to_end (&iter);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d (i.e. end iterator)", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_end
 * Params: const GtkTextIter* iter
 * Returns: void
 * Assertion: Moves iter forward to the "end iterator," which points one past the last valid character in the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: void  
 */
static void test_purpose_731()
{
    #define TEST_LINE  "012345678\n"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 10
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    gtk_text_iter_forward_to_end (&iter);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d (i.e. end iterator)", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_end
 * Params: const GtkTextIter* iter
 * Returns: void
 * Assertion: Moves iter forward to the "end iterator," which points one past the last valid character in the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: void  
 */
static void test_purpose_732()
{
    #define TEST_LINE  "012345678\r\n"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 11
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    gtk_text_iter_forward_to_end (&iter);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d (i.e. end iterator)", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_end
 * Params: const GtkTextIter* iter
 * Returns: void
 * Assertion: Moves iter forward to the "end iterator," which points one past the last valid character in the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: void  
 */
static void test_purpose_733()
{
    #define TEST_LINE  "012345678\r\n"
    #define OFFSET 10
    #define CORRECT_NEW_OFFSET 11
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    gtk_text_iter_forward_to_end (&iter);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d (i.e. end iterator)", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_end
 * Params: const GtkTextIter* iter
 * Returns: void
 * Assertion: Moves iter forward to the "end iterator," which points one past the last valid character in the buffer.
 * Params Values:  const GtkTextIter* iter
 * Expected: void  
 */
static void test_purpose_734()
{
    #define TEST_LINE  "012345678\r\n"
    #define OFFSET 11
    #define CORRECT_NEW_OFFSET 11
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset(buffer, &iter, OFFSET);
    
    gtk_text_iter_forward_to_end (&iter);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d (i.e. end iterator)", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves the iterator to point to the paragraph delimiter characters, which will be either a newline, a carriage return, a carriage return/newline in sequence, or the Unicode paragraph separator character.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_735()
{
    #define TEST_LINE  "line1\n line2\n line3"
    #define OFFSET 0
    #define CORRECT_NEW_OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves the iterator to point to the paragraph delimiter characters, which will be either a newline, a carriage return, a carriage return/newline in sequence, or the Unicode paragraph separator character.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_736()
{
    #define TEST_LINE  "line1\n line2\n line3"
    #define OFFSET 14
    #define CORRECT_NEW_OFFSET 19
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves the iterator to point to the paragraph delimiter characters, which will be either a newline, a carriage return, a carriage return/newline in sequence, or the Unicode paragraph separator character.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_737()
{
    #define TEST_LINE  "line1\r line2\r line3"
    #define OFFSET 0
    #define CORRECT_NEW_OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves the iterator to point to the paragraph delimiter characters, which will be either a newline, a carriage return, a carriage return/newline in sequence, or the Unicode paragraph separator character.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_738()
{
    #define TEST_LINE  "line1\r line2\r line3"
    #define OFFSET 14
    #define CORRECT_NEW_OFFSET 19
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves the iterator to point to the paragraph delimiter characters, which will be either a newline, a carriage return, a carriage return/newline in sequence, or the Unicode paragraph separator character.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_739()
{
    #define TEST_LINE  "line1\r\n line2\r\n line3"
    #define OFFSET 0
    #define CORRECT_NEW_OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves the iterator to point to the paragraph delimiter characters, which will be either a newline, a carriage return, a carriage return/newline in sequence, or the Unicode paragraph separator character.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_740()
{
    #define TEST_LINE  "line1\r\n line2\r\n line3\n"
    #define OFFSET 16
    #define CORRECT_NEW_OFFSET 21
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves the iterator to point to the paragraph delimiter characters, which will be either a newline, a carriage return, a carriage return/newline in sequence, or the Unicode paragraph separator character.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_741()
{
    #define TEST_LINE  "line1\r\n line2\r\n line3\r"
    #define OFFSET 16
    #define CORRECT_NEW_OFFSET 21
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves the iterator to point to the paragraph delimiter characters, which will be either a newline, a carriage return, a carriage return/newline in sequence, or the Unicode paragraph separator character.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_742()
{
    #define TEST_LINE  "line1\r\n line2\r\n line3\r\n"
    #define OFFSET 16
    #define CORRECT_NEW_OFFSET 21
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If the iterator is already at the paragraph delimiter characters, moves to the paragraph delimiter characters for the next line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_743()
{
    #define TEST_LINE  "line1\n line2\n line3"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If the iterator is already at the paragraph delimiter characters, moves to the paragraph delimiter characters for the next line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_744()
{
    #define TEST_LINE  "line1\r line2\n line3"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 12
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If the iterator is already at the paragraph delimiter characters, moves to the paragraph delimiter characters for the next line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_745()
{
    #define TEST_LINE  "line1\r\n line2\n line3"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 13
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If the iterator is already at the paragraph delimiter characters, moves to the paragraph delimiter characters for the next line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_746()
{
    #define TEST_LINE  "line1\r\n line2\n line3"
    #define OFFSET 6
    #define CORRECT_NEW_OFFSET 13
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If the iterator is already at the paragraph delimiter characters, moves to the paragraph delimiter characters for the next line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_747()
{
    #define TEST_LINE  "line1\r\n line2\r\n line3"
    #define OFFSET 6
    #define CORRECT_NEW_OFFSET 13
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If the iterator is already at the paragraph delimiter characters, moves to the paragraph delimiter characters for the next line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_748()
{
    #define TEST_LINE  "line1\r\n\r line2\r\n line3"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If the iterator is already at the paragraph delimiter characters, moves to the paragraph delimiter characters for the next line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_749()
{
    #define TEST_LINE  "line1\r\n\r line2\r\n line3"
    #define OFFSET 6
    #define CORRECT_NEW_OFFSET 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If the iterator is already at the paragraph delimiter characters, moves to the paragraph delimiter characters for the next line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_750()
{
    #define TEST_LINE  "line1\r\n\r\n line2\r\n line3"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If the iterator is already at the paragraph delimiter characters, moves to the paragraph delimiter characters for the next line.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_751()
{
    #define TEST_LINE  "line1\r\n\r\n line2\r\n line3"
    #define OFFSET 6
    #define CORRECT_NEW_OFFSET 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", 
                   CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If iter is on the last line in the buffer, which does not end in paragraph delimiters, moves to the end iterator (end of the last line), and returns FALSE.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%3%>  
 */
static void test_purpose_752()
{
    #define TEST_LINE  "line1"
    #define OFFSET 0
    #define CORRECT_NEW_OFFSET 5
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != FALSE)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", FALSE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If iter is on the last line in the buffer, which does not end in paragraph delimiters, moves to the end iterator (end of the last line), and returns FALSE.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%3%>  
 */
static void test_purpose_753()
{
    #define TEST_LINE  "line\\"
    #define OFFSET 0
    #define CORRECT_NEW_OFFSET 5
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != FALSE)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", FALSE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If iter is on the last line in the buffer, which does not end in paragraph delimiters, moves to the end iterator (end of the last line), and returns FALSE.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%3%>  
 */
static void test_purpose_754()
{
    #define TEST_LINE  "line1\n line2"
    #define OFFSET 5
    #define CORRECT_NEW_OFFSET 12
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != FALSE)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", FALSE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_line_end
 * Params: const GtkTextIter* iter
 * Returns: gboolean
 * Assertion: If iter is on the last line in the buffer, which does not end in paragraph delimiters, moves to the end iterator (end of the last line), and returns FALSE.
 * Params Values:  const GtkTextIter* iter
 * Expected: <%3%>  
 */
static void test_purpose_755()
{
    #define TEST_LINE  "line1\n line2"
    #define OFFSET 6
    #define CORRECT_NEW_OFFSET 12
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_to_line_end (&iter);
    if (res != FALSE)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_line_end() should return %d", FALSE);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves forward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_756()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 5
    #define START 0
    #define END 10
    #define TAG_TO_FIND tag
    #define CORRECT_NEW_OFFSET 10
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves forward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_757()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 5
    #define START 0
    #define END 10
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 10
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves forward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_758()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 0
    #define START 5
    #define END 10
    #define TAG_TO_FIND tag
    #define CORRECT_NEW_OFFSET 5
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves forward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_759()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 0
    #define START 5
    #define END 10
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 5
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves forward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_760()
{
    #define TEST_LINE  "abcde"
    #define OFFSET 0
    #define START 0
    #define END 5
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 5
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves forward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_761()
{
    #define TEST_LINE  "!@#$%^\r\n&*()_+|~=\";:'?<>`/"
    #define OFFSET 3
    #define START 2
    #define END 10
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 10
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves forward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_762()
{
    #define TEST_LINE  "\b\n\r\t"
    #define OFFSET 1
    #define START 0
    #define END 3
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 3
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves forward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_763()
{
    #define TEST_LINE  "  "
    #define OFFSET 0
    #define START 0
    #define END 1
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 1
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If no matching tag toggles are found, returns FALSE, otherwise TRUE.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_764()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 5
    #define START 0
    #define END 10
    #define TAG_TO_FIND tag
    #define CORRECT_RESULT TRUE
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    res = gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_tag_toggle() should return %d", 
                   CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If no matching tag toggles are found, returns FALSE, otherwise TRUE.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_765()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 11
    #define START 0
    #define END 10
    #define TAG_TO_FIND tag
    #define CORRECT_RESULT FALSE
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    res = gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_tag_toggle() should return %d", 
                   CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Does not return toggles located at iter, only toggles after iter.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_766()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 9
    #define START 0
    #define END 10
    #define TAG_TO_FIND tag
    #define CORRECT_RESULT TRUE
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    res = gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_tag_toggle() should return %d", 
                   CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Does not return toggles located at iter, only toggles after iter.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_767()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 10
    #define START 0
    #define END 10
    #define TAG_TO_FIND tag
    #define CORRECT_RESULT FALSE
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    res = gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_tag_toggle() should return %d", 
                   CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Does not return toggles located at iter, only toggles after iter.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_768()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 11
    #define START 0
    #define END 10
    #define TAG_TO_FIND tag
    #define CORRECT_RESULT FALSE
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    res = gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_to_tag_toggle() should return %d", 
                   CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Sets iter to the location of the toggle, or to the end of the buffer if no toggle is found.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_769()
{
    #define TEST_LINE  "abcdef"
    #define OFFSET 1
    #define START 0
    #define END 4
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 4
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Sets iter to the location of the toggle, or to the end of the buffer if no toggle is found.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_770()
{
    #define TEST_LINE  "abcdef"
    #define OFFSET 4
    #define START 0
    #define END 4
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 6
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_forward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves backward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_771()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 5
    #define START 2
    #define END 10
    #define TAG_TO_FIND tag
    #define CORRECT_NEW_OFFSET 2
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves backward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_772()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 5
    #define START 2
    #define END 10
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 2
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves backward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_773()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 10
    #define START 0
    #define END 5
    #define TAG_TO_FIND tag
    #define CORRECT_NEW_OFFSET 5
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves backward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_774()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 10
    #define START 0
    #define END 5
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 5
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves backward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_775()
{
    #define TEST_LINE  "abcde"
    #define OFFSET 5
    #define START 0
    #define END 5
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 0
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves backward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_776()
{
    #define TEST_LINE  "!@#$%^\r\n&*()_+|~=\";:'?<>`/"
    #define OFFSET 3
    #define START 2
    #define END 10
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 2
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves backward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_777()
{
    #define TEST_LINE  "\b\n\r\t"
    #define OFFSET 1
    #define START 0
    #define END 3
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 0
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Moves backward to the next toggle (on or off) of the GtkTextTag tag, or to the next toggle of any tag if tag is NULL.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_778()
{
    #define TEST_LINE  "  "
    #define OFFSET 1
    #define START 0
    #define END 1
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 0
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gchar* str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    str = TEST_LINE;
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If no matching tag toggles are found, returns FALSE, otherwise TRUE.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_779()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 5
    #define START 0
    #define END 10
    #define TAG_TO_FIND tag
    #define CORRECT_RESULT TRUE
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    res = gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_backward_to_tag_toggle() should return %d", 
                   CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: If no matching tag toggles are found, returns FALSE, otherwise TRUE.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_780()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 9
    #define START 10
    #define END 20
    #define TAG_TO_FIND tag
    #define CORRECT_RESULT FALSE
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    res = gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_backward_to_tag_toggle() should return %d", 
                   CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Does not return toggles located at iter, only toggles before iter.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_781()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 9
    #define START 5
    #define END 10
    #define TAG_TO_FIND tag
    #define CORRECT_RESULT TRUE
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    res = gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_backward_to_tag_toggle() should return %d", 
                   CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Does not return toggles located at iter, only toggles before iter.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_782()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 5
    #define START 5
    #define END 10
    #define TAG_TO_FIND tag
    #define CORRECT_RESULT FALSE
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    res = gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_backward_to_tag_toggle() should return %d", 
                   CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion: Does not return toggles located at iter, only toggles before iter.
 * Params Values:  const GtkTextIter* iter
 * Expected: FALSE  
 */
static void test_purpose_783()
{
    #define TEST_LINE  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define OFFSET 4
    #define START 5
    #define END 10
    #define TAG_TO_FIND tag
    #define CORRECT_RESULT FALSE
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    gint res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    res = gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_backward_to_tag_toggle() should return %d", 
                   CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion:  Sets iter to the location of the toggle, or the start of the buffer if no toggle is found.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_784()
{
    #define TEST_LINE  "abcdef"
    #define OFFSET 3
    #define START 2
    #define END 4
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 2
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_to_tag_toggle
 * Params: const GtkTextIter* iter, GtkTextTag *tag
 * Returns: gboolean
 * Assertion:  Sets iter to the location of the toggle, or the start of the buffer if no toggle is found.
 * Params Values:  const GtkTextIter* iter
 * Expected: TRUE  
 */
static void test_purpose_785()
{
    #define TEST_LINE  "abcdef"
    #define OFFSET 2
    #define START 2
    #define END 4
    #define TAG_TO_FIND NULL
    #define CORRECT_NEW_OFFSET 0
    
    GtkTextIter start;
    GtkTextIter end;
    GtkTextIter iter;
    GtkTextTag* tag;
    GtkTextBuffer* buffer;
    gint new_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, END);
    
    tag = gtk_text_tag_new ("strikethrough_tag");
    g_object_set (tag, "strikethrough", TRUE, NULL);
    
    gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
    gtk_text_buffer_apply_tag (buffer, tag, &start, &end);
    
    gtk_text_iter_backward_to_tag_toggle (&iter, TAG_TO_FIND);
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef START
    #undef END
    #undef TAG_TO_FIND
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  Advances iter, calling pred on each character.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: FALSE  
 */
static void test_purpose_786()
{
    #define TEST_LINE  "abcdef"
    #define OFFSET 0
    #define CORRECT_COUNTER_VALUE 5
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_find_char (&iter, global_pred, NULL, NULL);
    if (res != FALSE)
    {
        TEST_FAIL ("gtk_text_iter_forward_find_char() should return FALSE", NULL);
    }
    
    if (global_counter != CORRECT_COUNTER_VALUE)
    {
        TEST_FAIL ("pred was called %d times instead of %d", 
                   global_counter, CORRECT_COUNTER_VALUE);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_COUNTER_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  Advances iter, calling pred on each character.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: FALSE  
 */
static void test_purpose_787()
{
    #define TEST_LINE  "abcdef\n"
    #define OFFSET 0
    #define CORRECT_COUNTER_VALUE 6
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_find_char (&iter, global_pred, NULL, NULL);
    if (res != FALSE)
    {
        TEST_FAIL ("gtk_text_iter_forward_find_char() should return FALSE", NULL);
    }
    
    if (global_counter != CORRECT_COUNTER_VALUE)
    {
        TEST_FAIL ("pred was called %d times instead of %d", 
                   global_counter, CORRECT_COUNTER_VALUE);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_COUNTER_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  Advances iter, calling pred on each character.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: FALSE  
 */
static void test_purpose_788()
{
    #define TEST_LINE  "abcdef\r\n"
    #define OFFSET 0
    #define CORRECT_COUNTER_VALUE 7
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_find_char (&iter, global_pred, NULL, NULL);
    if (res != FALSE)
    {
        TEST_FAIL ("gtk_text_iter_forward_find_char() should return FALSE", NULL);
    }
    
    if (global_counter != CORRECT_COUNTER_VALUE)
    {
        TEST_FAIL ("pred was called %d times instead of %d", 
                   global_counter, CORRECT_COUNTER_VALUE);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_COUNTER_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  Advances iter, calling pred on each character.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: FALSE  
 */
static void test_purpose_789()
{
    #define TEST_LINE  "abcdef\n"
    #define OFFSET 5
    #define CORRECT_COUNTER_VALUE 1
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_find_char (&iter, global_pred, NULL, NULL);
    if (res != FALSE)
    {
        TEST_FAIL ("gtk_text_iter_forward_find_char() should return FALSE", NULL);
    }
    
    if (global_counter != CORRECT_COUNTER_VALUE)
    {
        TEST_FAIL ("pred was called %d times instead of %d", 
                   global_counter, CORRECT_COUNTER_VALUE);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_COUNTER_VALUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  If pred returns TRUE, returns TRUE and stops scanning.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: TRUE  
 */
static void test_purpose_790()
{
    #define TEST_LINE  "abcdef"
    #define OFFSET 0
    #define CORRECT_NEW_OFFSET 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    gint new_offset;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_find_char (&iter, global_pred_1, NULL, NULL);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_find_char() should return %d", CORRECT_RESULT);
    }
    
    if (res == TRUE)
    {
        if (global_counter != 4)
        {
            TEST_FAIL ("pred was called %d times instead of 4", global_counter);
        }
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  If pred returns TRUE, returns TRUE and stops scanning.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: TRUE  
 */
static void test_purpose_791()
{
    #define TEST_LINE  "abcdef"
    #define OFFSET 1
    #define CORRECT_NEW_OFFSET 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    gint new_offset;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_find_char (&iter, global_pred_1, NULL, NULL);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_find_char() should return %d", CORRECT_RESULT);
    }
    
    if (res == TRUE)
    {
        if (global_counter != 4)
        {
            TEST_FAIL ("pred was called %d times instead of 4", global_counter);
        }
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  If pred returns TRUE, returns TRUE and stops scanning.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: FALSE  
 */
static void test_purpose_792()
{
    #define TEST_LINE  "abcdef"
    #define OFFSET 2
    #define CORRECT_NEW_OFFSET 6
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    gint new_offset;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_find_char (&iter, global_pred_1, NULL, NULL);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_find_char() should return %d", CORRECT_RESULT);
    }
    
    if (res == TRUE)
    {
        if (global_counter != 4)
        {
            TEST_FAIL ("pred was called %d times instead of 4", global_counter);
        }
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  If pred returns TRUE, returns TRUE and stops scanning.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: FALSE  
 */
static void test_purpose_793()
{
    #define TEST_LINE  "abcdef"
    #define OFFSET 6
    #define CORRECT_NEW_OFFSET 6
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    gint new_offset;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    res = gtk_text_iter_forward_find_char (&iter, global_pred_1, NULL, NULL);
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_find_char() should return %d", CORRECT_RESULT);
    }
    
    if (res == TRUE)
    {
        if (global_counter != 4)
        {
            TEST_FAIL ("pred was called %d times instead of 4", global_counter);
        }
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  If pred never returns TRUE, iter is set to limit if limit is non-NULL, otherwise to the end iterator.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: FALSE  
 */
static void test_purpose_794()
{
    #define TEST_LINE  "abcdef"
    #define OFFSET 0
    #define LIMIT_OFFSET 4
    #define CORRECT_NEW_OFFSET 4
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    gint new_offset;
    GtkTextIter limit;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_find_char (&iter, global_pred_2, NULL, &limit);
    } else {
        res = gtk_text_iter_forward_find_char (&iter, global_pred_2, NULL, NULL);
    }
    if (res != FALSE)
    {
        TEST_FAIL ("gtk_text_iter_forward_find_char() should return FALSE", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef LIMIT_OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  If pred never returns TRUE, iter is set to limit if limit is non-NULL, otherwise to the end iterator.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: FALSE  
 */
static void test_purpose_795()
{
    #define TEST_LINE  "abc\r\ndef"
    #define OFFSET 0
    #define LIMIT_OFFSET 4
    #define CORRECT_NEW_OFFSET 4
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    gint new_offset;
    GtkTextIter limit;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_find_char (&iter, global_pred_2, NULL, &limit);
    } else {
        res = gtk_text_iter_forward_find_char (&iter, global_pred_2, NULL, NULL);
    }
    if (res != FALSE)
    {
        TEST_FAIL ("gtk_text_iter_forward_find_char() should return FALSE", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef LIMIT_OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  If pred never returns TRUE, iter is set to limit if limit is non-NULL, otherwise to the end iterator.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: FALSE  
 */
static void test_purpose_796()
{
    #define TEST_LINE  "abcdef"
    #define OFFSET 2
    #define LIMIT_OFFSET -1
    #define CORRECT_NEW_OFFSET 6
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    gint new_offset;
    GtkTextIter limit;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_find_char (&iter, global_pred_2, NULL, &limit);
    } else {
        res = gtk_text_iter_forward_find_char (&iter, global_pred_2, NULL, NULL);
    }
    if (res != FALSE)
    {
        TEST_FAIL ("gtk_text_iter_forward_find_char() should return FALSE", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef LIMIT_OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  If pred never returns TRUE, iter is set to limit if limit is non-NULL, otherwise to the end iterator.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: FALSE  
 */
static void test_purpose_797()
{
    #define TEST_LINE  "abcdef"
    #define OFFSET 2
    #define LIMIT_OFFSET 2
    #define CORRECT_NEW_OFFSET 2
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    gint new_offset;
    GtkTextIter limit;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_find_char (&iter, global_pred_2, NULL, &limit);
    } else {
        res = gtk_text_iter_forward_find_char (&iter, global_pred_2, NULL, NULL);
    }
    if (res != FALSE)
    {
        TEST_FAIL ("gtk_text_iter_forward_find_char() should return FALSE", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef LIMIT_OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  If pred never returns TRUE, iter is set to limit if limit is non-NULL, otherwise to the end iterator.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: FALSE  
 */
static void test_purpose_798()
{
    #define TEST_LINE  "abcdef"
    #define OFFSET 2
    #define LIMIT_OFFSET 1
    #define CORRECT_NEW_OFFSET 2
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    gint new_offset;
    GtkTextIter limit;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_find_char (&iter, global_pred_2, NULL, &limit);
    } else {
        res = gtk_text_iter_forward_find_char (&iter, global_pred_2, NULL, NULL);
    }
    if (res != FALSE)
    {
        TEST_FAIL ("gtk_text_iter_forward_find_char() should return FALSE", NULL);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef LIMIT_OFFSET
    #undef CORRECT_NEW_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  Same as gtk_text_iter_forward_find_char(), but goes backward from iter.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: FALSE  
 */
static void test_purpose_799()
{
    #define TEST_LINE  "012345678901234567890"
    #define OFFSET 5
    #define LIMIT_OFFSET 3
    #define CORRECT_NEW_OFFSET 3
    #define CORRECT_COUNTER_VALUE 2
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    gint new_offset;
    GtkTextIter limit;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    
    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_backward_find_char (&iter, global_pred_1, NULL, &limit);
    } else {
        res = gtk_text_iter_backward_find_char (&iter, global_pred_1, NULL, NULL);
    }
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_backward_find_char() should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef LIMIT_OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_COUNTER_VALUE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  Same as gtk_text_iter_forward_find_char(), but goes backward from iter.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: FALSE  
 */
static void test_purpose_800()
{
    #define TEST_LINE  "012345678901234567890"
    #define OFFSET 1
    #define LIMIT_OFFSET 0
    #define CORRECT_NEW_OFFSET 0
    #define CORRECT_COUNTER_VALUE 1
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    gint new_offset;
    GtkTextIter limit;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    
    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_backward_find_char (&iter, global_pred_1, NULL, &limit);
    } else {
        res = gtk_text_iter_backward_find_char (&iter, global_pred_1, NULL, NULL);
    }
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_backward_find_char() should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef LIMIT_OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_COUNTER_VALUE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_find_char
 * Params: GtkTextIter *iter, GtkTextCharPredicate pred, gpointer user_data, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion:  Same as gtk_text_iter_forward_find_char(), but goes backward from iter.
 * Params Values:  const GtkTextIter* iter, a function, NULL, const GtkTextIter *limit 
 * Expected: TRUE  
 */
static void test_purpose_801()
{
    #define TEST_LINE  "012345678901234567890"
    #define OFFSET 10
    #define LIMIT_OFFSET -1
    #define CORRECT_NEW_OFFSET 6
    #define CORRECT_COUNTER_VALUE 4
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    gboolean res;
    gint new_offset;
    GtkTextIter limit;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    
    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_backward_find_char (&iter, global_pred_1, NULL, &limit);
    } else {
        res = gtk_text_iter_backward_find_char (&iter, global_pred_1, NULL, NULL);
    }
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_backward_find_char() should return %d", CORRECT_RESULT);
    }
    
    new_offset = gtk_text_iter_get_offset (&iter);
    if (new_offset != CORRECT_NEW_OFFSET)
    {
        TEST_FAIL ("new_offset is %d, should be %d", 
                   new_offset, CORRECT_NEW_OFFSET);
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef LIMIT_OFFSET
    #undef CORRECT_NEW_OFFSET
    #undef CORRECT_COUNTER_VALUE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_equal
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: Tests whether two iterators are equal, using the fastest possible mechanism. 
 * Params Values:  GtkTextIter* with offset = 0, GtkTextIter* with offset = 0
 * Expected: TRUE  
 */
static void test_purpose_802()
{
    #define TEST_LINE "string"
    #define OFFSET_1 0
    #define OFFSET_2 0
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_equal (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_equal () should return %d", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_equal
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: Tests whether two iterators are equal, using the fastest possible mechanism. 
 * Params Values:  GtkTextIter* with offset = 2, GtkTextIter* with offset = 2
 * Expected: TRUE  
 */
static void test_purpose_803()
{
    #define TEST_LINE "string"
    #define OFFSET_1 2
    #define OFFSET_2 2
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_equal (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_equal () should return %d", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_equal
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: Tests whether two iterators are equal, using the fastest possible mechanism. 
 * Params Values:  GtkTextIter* with offset = 5, GtkTextIter* with offset = 5
 * Expected: TRUE  
 */
static void test_purpose_804()
{
    #define TEST_LINE "string"
    #define OFFSET_1 5
    #define OFFSET_2 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_equal (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_equal () should return %d", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_equal
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: Tests whether two iterators are equal, using the fastest possible mechanism. 
 * Params Values:  GtkTextIter* with offset = 6, GtkTextIter* with offset = 6
 * Expected: TRUE  
 */
static void test_purpose_805()
{
    #define TEST_LINE "string"
    #define OFFSET_1 6
    #define OFFSET_2 6
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_equal (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_equal () should return %d", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_equal
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: Tests whether two iterators are equal, using the fastest possible mechanism. 
 * Params Values:  GtkTextIter* with offset = 6, GtkTextIter* with offset = 6
 * Expected: TRUE  
 */
static void test_purpose_806()
{
    #define TEST_LINE "string\n"
    #define OFFSET_1 6
    #define OFFSET_2 6
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_equal (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_equal () should return %d", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_equal
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: Tests whether two iterators are equal, using the fastest possible mechanism. 
 * Params Values:  GtkTextIter* with offset = 7, GtkTextIter* with offset = 7
 * Expected: TRUE  
 */
static void test_purpose_807()
{
    #define TEST_LINE "string"
    #define OFFSET_1 7
    #define OFFSET_2 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_equal (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_equal () should return %d", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_equal
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: Tests whether two iterators are equal, using the fastest possible mechanism. 
 * Params Values:  GtkTextIter* with offset = 7, GtkTextIter* with offset = 7
 * Expected: TRUE  
 */
static void test_purpose_808()
{
    #define TEST_LINE "string\n"
    #define OFFSET_1 7
    #define OFFSET_2 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_equal (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_equal () should return %d", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_equal
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: Tests whether two iterators are equal, using the fastest possible mechanism. 
 * Params Values:  GtkTextIter* with offset = 6, GtkTextIter* with offset = 7
 * Expected: TRUE  
 */
static void test_purpose_809()
{
    #define TEST_LINE "string"
    #define OFFSET_1 6
    #define OFFSET_2 7
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_equal (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_equal () should return %d", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_equal
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: Tests whether two iterators are equal, using the fastest possible mechanism. 
 * Params Values:  GtkTextIter* with offset = 0, GtkTextIter* with offset = 7
 * Expected: FALSE  
 */
static void test_purpose_810()
{
    #define TEST_LINE "string"
    #define OFFSET_1 0
    #define OFFSET_2 7
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_equal (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_equal () should return %d", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_equal
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: Tests whether two iterators are equal, using the fastest possible mechanism. 
 * Params Values:  GtkTextIter* with offset = 4, GtkTextIter* with offset = 5
 * Expected: FALSE  
 */
static void test_purpose_811()
{
    #define TEST_LINE "st\r\r\nring"
    #define OFFSET_1 4
    #define OFFSET_2 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_equal (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_equal () should return %d", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_compare
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: A qsort()-style function that returns negative if lhs is less than rhs, positive if lhs is greater than rhs, and 0 if they're equal.'
 * Params Values:  GtkTextIter* with offset = 0, GtkTextIter* with offset = 0
 * Expected: 0  
 */
static void test_purpose_812()
{
    #define TEST_LINE "string"
    #define OFFSET_1 0
    #define OFFSET_2 0
    #define CORRECT_RESULT 0
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_compare (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_compare () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_compare
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: A qsort()-style function that returns negative if lhs is less than rhs, positive if lhs is greater than rhs, and 0 if they're equal.'
 * Params Values:  GtkTextIter* with offset = 6, GtkTextIter* with offset = 6
 * Expected: 0  
 */
static void test_purpose_813()
{
    #define TEST_LINE "string"
    #define OFFSET_1 6
    #define OFFSET_2 6
    #define CORRECT_RESULT 0
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_compare (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_compare () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_compare
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: A qsort()-style function that returns negative if lhs is less than rhs, positive if lhs is greater than rhs, and 0 if they're equal.'
 * Params Values:  GtkTextIter* with offset = 7, GtkTextIter* with offset = 7
 * Expected: 0  
 */
static void test_purpose_814()
{
    #define TEST_LINE "string"
    #define OFFSET_1 7
    #define OFFSET_2 7
    #define CORRECT_RESULT 0
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_compare (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_compare () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_compare
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: A qsort()-style function that returns negative if lhs is less than rhs, positive if lhs is greater than rhs, and 0 if they're equal.'
 * Params Values:  GtkTextIter* with offset = 6, GtkTextIter* with offset = 7
 * Expected: 0  
 */
static void test_purpose_815()
{
    #define TEST_LINE "string"
    #define OFFSET_1 6
    #define OFFSET_2 7
    #define CORRECT_RESULT 0
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_compare (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_compare () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_compare
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: A qsort()-style function that returns negative if lhs is less than rhs, positive if lhs is greater than rhs, and 0 if they're equal.'
 * Params Values:  GtkTextIter* with offset = 3, GtkTextIter* with offset = 5
 * Expected: -1  
 */
static void test_purpose_816()
{
    #define TEST_LINE "string"
    #define OFFSET_1 3
    #define OFFSET_2 5
    #define CORRECT_RESULT -1
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_compare (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_compare () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_compare
 * Params: const GtkTextIter *lhs, const GtkTextIter *rhs
 * Returns: gboolean
 * Assertion: A qsort()-style function that returns negative if lhs is less than rhs, positive if lhs is greater than rhs, and 0 if they're equal.'
 * Params Values:  GtkTextIter* with offset = 5, GtkTextIter* with offset = 3
 * Expected: 1  
 */
static void test_purpose_817()
{
    #define TEST_LINE "string"
    #define OFFSET_1 5
    #define OFFSET_2 3
    #define CORRECT_RESULT 1
    
    GtkTextIter iter1;
    GtkTextIter iter2;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter1, OFFSET_1);
    gtk_text_buffer_get_iter_at_offset (buffer, &iter2, OFFSET_2);
    
    res = gtk_text_iter_compare (&iter1, &iter2);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_compare () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_1
    #undef OFFSET_2
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_in_range
 * Params: const GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Returns: gboolean
 * Assertion: Checks whether iter falls in the range [start, end).
 * Params Values:  GtkTextIter* with offset = 4, GtkTextIter* with offset = 0, GtkTextIter* with offset = 6
 * Expected: TRUE  
 */
static void test_purpose_818()
{
    #define TEST_LINE "string"
    #define OFFSET_ITER 4
    #define OFFSET_START 0
    #define OFFSET_END 6
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET_ITER);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, OFFSET_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, OFFSET_END);
    
    res = gtk_text_iter_in_range (&iter, &start, &end);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_in_range () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_ITER
    #undef OFFSET_START
    #undef OFFSET_END
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_in_range
 * Params: const GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Returns: gboolean
 * Assertion: Checks whether iter falls in the range [start, end).
 * Params Values:  GtkTextIter* with offset = 7, GtkTextIter* with offset = 0, GtkTextIter* with offset = 6
 * Expected: FALSE  
 */
static void test_purpose_819()
{
    #define TEST_LINE "string"
    #define OFFSET_ITER 7
    #define OFFSET_START 0
    #define OFFSET_END 6
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET_ITER);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, OFFSET_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, OFFSET_END);
    
    res = gtk_text_iter_in_range (&iter, &start, &end);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_in_range () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_ITER
    #undef OFFSET_START
    #undef OFFSET_END
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_in_range
 * Params: const GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Returns: gboolean
 * Assertion: Checks whether iter falls in the range [start, end).
 * Params Values:  GtkTextIter* with offset = 2, GtkTextIter* with offset = 2, GtkTextIter* with offset = 5
 * Expected: TRUE  
 */
static void test_purpose_820()
{
    #define TEST_LINE "string"
    #define OFFSET_ITER 2
    #define OFFSET_START 2
    #define OFFSET_END 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET_ITER);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, OFFSET_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, OFFSET_END);
    
    res = gtk_text_iter_in_range (&iter, &start, &end);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_in_range () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_ITER
    #undef OFFSET_START
    #undef OFFSET_END
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_in_range
 * Params: const GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Returns: gboolean
 * Assertion: Checks whether iter falls in the range [start, end).
 * Params Values:  GtkTextIter* with offset = 4, GtkTextIter* with offset = 2, GtkTextIter* with offset = 5
 * Expected: TRUE  
 */
static void test_purpose_821()
{
    #define TEST_LINE "string"
    #define OFFSET_ITER 4
    #define OFFSET_START 2
    #define OFFSET_END 5
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET_ITER);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, OFFSET_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, OFFSET_END);
    
    res = gtk_text_iter_in_range (&iter, &start, &end);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_in_range () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_ITER
    #undef OFFSET_START
    #undef OFFSET_END
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_in_range
 * Params: const GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Returns: gboolean
 * Assertion: Checks whether iter falls in the range [start, end).
 * Params Values:  GtkTextIter* with offset = 5, GtkTextIter* with offset = 2, GtkTextIter* with offset = 5
 * Expected: FALSE  
 */
static void test_purpose_822()
{
    #define TEST_LINE "string"
    #define OFFSET_ITER 5
    #define OFFSET_START 2
    #define OFFSET_END 5
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET_ITER);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, OFFSET_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, OFFSET_END);
    
    res = gtk_text_iter_in_range (&iter, &start, &end);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_in_range () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_ITER
    #undef OFFSET_START
    #undef OFFSET_END
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_in_range
 * Params: const GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Returns: gboolean
 * Assertion: Checks whether iter falls in the range [start, end).
 * Params Values:  GtkTextIter* with offset = 2, GtkTextIter* with offset = 2, GtkTextIter* with offset = 3
 * Expected: TRUE  
 */
static void test_purpose_823()
{
    #define TEST_LINE "string"
    #define OFFSET_ITER 2
    #define OFFSET_START 2
    #define OFFSET_END 3
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET_ITER);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, OFFSET_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, OFFSET_END);
    
    res = gtk_text_iter_in_range (&iter, &start, &end);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_in_range () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_ITER
    #undef OFFSET_START
    #undef OFFSET_END
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_in_range
 * Params: const GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Returns: gboolean
 * Assertion: Checks whether iter falls in the range [start, end).
 * Params Values:  GtkTextIter* with offset = 3, GtkTextIter* with offset = 2, GtkTextIter* with offset = 3
 * Expected: FALSE  
 */
static void test_purpose_824()
{
    #define TEST_LINE "string"
    #define OFFSET_ITER 3
    #define OFFSET_START 2
    #define OFFSET_END 3
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET_ITER);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, OFFSET_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, OFFSET_END);
    
    res = gtk_text_iter_in_range (&iter, &start, &end);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_in_range () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_ITER
    #undef OFFSET_START
    #undef OFFSET_END
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_in_range
 * Params: const GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Returns: gboolean
 * Assertion: Checks whether iter falls in the range [start, end).
 * Params Values:  GtkTextIter* with offset = 5, GtkTextIter* with offset = 5, GtkTextIter* with offset = 6
 * Expected: TRUE  
 */
static void test_purpose_825()
{
    #define TEST_LINE "string"
    #define OFFSET_ITER 5
    #define OFFSET_START 5
    #define OFFSET_END 6
    #define CORRECT_RESULT TRUE
    
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET_ITER);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, OFFSET_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, OFFSET_END);
    
    res = gtk_text_iter_in_range (&iter, &start, &end);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_in_range () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_ITER
    #undef OFFSET_START
    #undef OFFSET_END
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_in_range
 * Params: const GtkTextIter *iter, const GtkTextIter *start, const GtkTextIter *end
 * Returns: gboolean
 * Assertion: Checks whether iter falls in the range [start, end).
 * Params Values:  GtkTextIter* with offset = 7, GtkTextIter* with offset = 6, GtkTextIter* with offset = 7
 * Expected: FALSE  
 */
static void test_purpose_826()
{
    #define TEST_LINE "string"
    #define OFFSET_ITER 7
    #define OFFSET_START 6
    #define OFFSET_END 7
    #define CORRECT_RESULT FALSE
    
    GtkTextIter iter;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextBuffer* buffer;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET_ITER);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, OFFSET_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &end, OFFSET_END);
    
    res = gtk_text_iter_in_range (&iter, &start, &end);
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_in_range () returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef OFFSET_ITER
    #undef OFFSET_START
    #undef OFFSET_END
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_order
 * Params: GtkTextIter *first, GtkTextIter *second
 * Returns: void
 * Assertion: Swaps the value of first and second if second comes before first in the buffer.
 * Params Values:  GtkTextIter* with offset = 2, GtkTextIter* with offset = 3
 * Expected: void  
 */
static void test_purpose_827()
{
    #define TEST_LINE "string"
    #define OFFSET_FIRST 2
    #define OFFSET_SECOND 3
    #define OFFSET_FIRST_AFTER 2
    #define OFFSET_SECOND_AFTER 3
    
    GtkTextIter first;
    GtkTextIter second;
    GtkTextBuffer* buffer;
    gint offset_first_after;
    gint offset_second_after;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &first, OFFSET_FIRST);
    gtk_text_buffer_get_iter_at_offset (buffer, &second, OFFSET_SECOND);
    
    gtk_text_iter_order (&first, &second);
    
    offset_first_after = gtk_text_iter_get_offset (&first);
    if (offset_first_after != OFFSET_FIRST_AFTER)
    {
        TEST_FAIL ("new offset of first is %d, should be %d", 
                   offset_first_after, OFFSET_FIRST_AFTER);
    }
    
    offset_second_after = gtk_text_iter_get_offset (&second);
    if (offset_second_after != OFFSET_SECOND_AFTER)
    {
        TEST_FAIL ("new offset of second is %d, should be %d", 
                   offset_second_after, OFFSET_SECOND_AFTER);
    }
    
    #undef TEST_LINE
    #undef OFFSET_FIRST
    #undef OFFSET_SECOND
    #undef OFFSET_FIRST_AFTER
    #undef OFFSET_SECOND_AFTER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_order
 * Params: GtkTextIter *first, GtkTextIter *second
 * Returns: void
 * Assertion: Swaps the value of first and second if second comes before first in the buffer.
 * Params Values:  GtkTextIter* with offset = 3, GtkTextIter* with offset = 2
 * Expected: void  
 */
static void test_purpose_828()
{
    #define TEST_LINE "string"
    #define OFFSET_FIRST 3
    #define OFFSET_SECOND 2
    #define OFFSET_FIRST_AFTER 2
    #define OFFSET_SECOND_AFTER 3
    
    GtkTextIter first;
    GtkTextIter second;
    GtkTextBuffer* buffer;
    gint offset_first_after;
    gint offset_second_after;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &first, OFFSET_FIRST);
    gtk_text_buffer_get_iter_at_offset (buffer, &second, OFFSET_SECOND);
    
    gtk_text_iter_order (&first, &second);
    
    offset_first_after = gtk_text_iter_get_offset (&first);
    if (offset_first_after != OFFSET_FIRST_AFTER)
    {
        TEST_FAIL ("new offset of first is %d, should be %d", 
                   offset_first_after, OFFSET_FIRST_AFTER);
    }
    
    offset_second_after = gtk_text_iter_get_offset (&second);
    if (offset_second_after != OFFSET_SECOND_AFTER)
    {
        TEST_FAIL ("new offset of second is %d, should be %d", 
                   offset_second_after, OFFSET_SECOND_AFTER);
    }
    
    #undef TEST_LINE
    #undef OFFSET_FIRST
    #undef OFFSET_SECOND
    #undef OFFSET_FIRST_AFTER
    #undef OFFSET_SECOND_AFTER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_order
 * Params: GtkTextIter *first, GtkTextIter *second
 * Returns: void
 * Assertion: Swaps the value of first and second if second comes before first in the buffer.
 * Params Values:  GtkTextIter* with offset = 2, GtkTextIter* with offset = 2
 * Expected: void  
 */
static void test_purpose_829()
{
    #define TEST_LINE "string"
    #define OFFSET_FIRST 2
    #define OFFSET_SECOND 2
    #define OFFSET_FIRST_AFTER 2
    #define OFFSET_SECOND_AFTER 2
    
    GtkTextIter first;
    GtkTextIter second;
    GtkTextBuffer* buffer;
    gint offset_first_after;
    gint offset_second_after;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &first, OFFSET_FIRST);
    gtk_text_buffer_get_iter_at_offset (buffer, &second, OFFSET_SECOND);
    
    gtk_text_iter_order (&first, &second);
    
    offset_first_after = gtk_text_iter_get_offset (&first);
    if (offset_first_after != OFFSET_FIRST_AFTER)
    {
        TEST_FAIL ("new offset of first is %d, should be %d", 
                   offset_first_after, OFFSET_FIRST_AFTER);
    }
    
    offset_second_after = gtk_text_iter_get_offset (&second);
    if (offset_second_after != OFFSET_SECOND_AFTER)
    {
        TEST_FAIL ("new offset of second is %d, should be %d", 
                   offset_second_after, OFFSET_SECOND_AFTER);
    }
    
    #undef TEST_LINE
    #undef OFFSET_FIRST
    #undef OFFSET_SECOND
    #undef OFFSET_FIRST_AFTER
    #undef OFFSET_SECOND_AFTER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_order
 * Params: GtkTextIter *first, GtkTextIter *second
 * Returns: void
 * Assertion: Swaps the value of first and second if second comes before first in the buffer.
 * Params Values:  GtkTextIter* with offset = 0, GtkTextIter* with offset = 6
 * Expected: void  
 */
static void test_purpose_830()
{
    #define TEST_LINE "string"
    #define OFFSET_FIRST 0
    #define OFFSET_SECOND 6
    #define OFFSET_FIRST_AFTER 0
    #define OFFSET_SECOND_AFTER 6
    
    GtkTextIter first;
    GtkTextIter second;
    GtkTextBuffer* buffer;
    gint offset_first_after;
    gint offset_second_after;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &first, OFFSET_FIRST);
    gtk_text_buffer_get_iter_at_offset (buffer, &second, OFFSET_SECOND);
    
    gtk_text_iter_order (&first, &second);
    
    offset_first_after = gtk_text_iter_get_offset (&first);
    if (offset_first_after != OFFSET_FIRST_AFTER)
    {
        TEST_FAIL ("new offset of first is %d, should be %d", 
                   offset_first_after, OFFSET_FIRST_AFTER);
    }
    
    offset_second_after = gtk_text_iter_get_offset (&second);
    if (offset_second_after != OFFSET_SECOND_AFTER)
    {
        TEST_FAIL ("new offset of second is %d, should be %d", 
                   offset_second_after, OFFSET_SECOND_AFTER);
    }
    
    #undef TEST_LINE
    #undef OFFSET_FIRST
    #undef OFFSET_SECOND
    #undef OFFSET_FIRST_AFTER
    #undef OFFSET_SECOND_AFTER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_order
 * Params: GtkTextIter *first, GtkTextIter *second
 * Returns: void
 * Assertion: Swaps the value of first and second if second comes before first in the buffer.
 * Params Values:  GtkTextIter* with offset = 6, GtkTextIter* with offset = 0
 * Expected: void  
 */
static void test_purpose_831()
{
    #define TEST_LINE "string"
    #define OFFSET_FIRST 6
    #define OFFSET_SECOND 0
    #define OFFSET_FIRST_AFTER 0
    #define OFFSET_SECOND_AFTER 6
    
    GtkTextIter first;
    GtkTextIter second;
    GtkTextBuffer* buffer;
    gint offset_first_after;
    gint offset_second_after;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &first, OFFSET_FIRST);
    gtk_text_buffer_get_iter_at_offset (buffer, &second, OFFSET_SECOND);
    
    gtk_text_iter_order (&first, &second);
    
    offset_first_after = gtk_text_iter_get_offset (&first);
    if (offset_first_after != OFFSET_FIRST_AFTER)
    {
        TEST_FAIL ("new offset of first is %d, should be %d", 
                   offset_first_after, OFFSET_FIRST_AFTER);
    }
    
    offset_second_after = gtk_text_iter_get_offset (&second);
    if (offset_second_after != OFFSET_SECOND_AFTER)
    {
        TEST_FAIL ("new offset of second is %d, should be %d", 
                   offset_second_after, OFFSET_SECOND_AFTER);
    }
    
    #undef TEST_LINE
    #undef OFFSET_FIRST
    #undef OFFSET_SECOND
    #undef OFFSET_FIRST_AFTER
    #undef OFFSET_SECOND_AFTER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_832()
{
    #define TEST_LINE "qwertyuiop"
    #define EDITABLE_START 0
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 0
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_833()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 0
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 0
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_834()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 0
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 0
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_835()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 0
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 0
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_836()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 0
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_837()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 1
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_838()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 2
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_839()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 3
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_840()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 4
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_841()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 5
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_842()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 6
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_843()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 7
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_844()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 0
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_845()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 1
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_846()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 2
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_847()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 3
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_848()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 4
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_849()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 5
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_850()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 6
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_851()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 7
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_852()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 0
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_853()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 1
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_854()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 2
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_855()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 3
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_856()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 4
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_857()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 5
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_858()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 6
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_859()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 7
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_860()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 0
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_861()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 1
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_862()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 2
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_863()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 3
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_864()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 4
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_865()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 5
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_866()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 6
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_867()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 2
    #define EDITABLE_END 5
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 7
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_868()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 5
    #define EDITABLE_END 7
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 7
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset TRUE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_869()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 5
    #define EDITABLE_END 7
    #define EDITABLE_VALUE TRUE
    #define TEST_ITER_OFFSET 7
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: TRUE  
 */
static void test_purpose_870()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 5
    #define EDITABLE_END 7
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 7
    #define TEST_DEFAULT_EDITABLE TRUE
    #define CORRECT_RESULT TRUE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_can_insert
 * Params: const GtkTextIter* iter, gboolean gboolean default_editability
 * Returns: gboolean
 * Assertion: Considering the default editability of the buffer, and tags that affect editability, determines whether text inserted at iter would be editable.
 * Params Values:  const GtkTextIter* iter with offset FALSE, GtkTextTag *tag 
 * Expected: FALSE  
 */
static void test_purpose_871()
{
    #define TEST_LINE "0123456\0"
    #define EDITABLE_START 5
    #define EDITABLE_END 7
    #define EDITABLE_VALUE FALSE
    #define TEST_ITER_OFFSET 7
    #define TEST_DEFAULT_EDITABLE FALSE
    #define CORRECT_RESULT FALSE
    
    /*  GtkTextIter inter_iter; */
    GtkTextIter test_iter;
    GtkTextIter ed_start_iter;
    GtkTextIter ed_end_iter;
    GtkTextTag* editable_tag;
    GtkTextBuffer* buffer;
    gchar* inter_text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, -1);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_start_iter, EDITABLE_START);
    gtk_text_buffer_get_iter_at_offset (buffer, &ed_end_iter, EDITABLE_END);
    
    editable_tag = gtk_text_buffer_create_tag(buffer, NULL, "editable", EDITABLE_VALUE, NULL);
    gtk_text_buffer_apply_tag (buffer, editable_tag, 
                               &ed_start_iter, &ed_end_iter);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &test_iter, TEST_ITER_OFFSET);
    if (gtk_text_iter_can_insert (&test_iter, TEST_DEFAULT_EDITABLE) 
        != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_can_insert() returned not %d incorrectly", CORRECT_RESULT);
    }
    
    #undef TEST_LINE
    #undef EDITABLE_START
    #undef EDITABLE_END
    #undef EDITABLE_VALUE
    #undef TEST_ITER_OFFSET
    #undef TEST_DEFAULT_EDITABLE
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Searches forward for str.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: TRUE
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: If the GTK_TEXT_SEARCH_VISIBLE_ONLY flag is present, the match may have invisible text interspersed in str.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: TRUE
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Any match is returned by setting match_start to the first character of the match and match_end to the first character after the match.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: TRUE  
 */
static void test_purpose_872()
{
    #define TEST_LINE  "abcdefabcdef"
    #define OFFSET 0
    #define STR "abcde"
    #define FLAGS GTK_TEXT_SEARCH_VISIBLE_ONLY
    #define LIMIT_OFFSET 12
    #define CORRECT_RESULT TRUE
    #define CORRECT_MATCH_START_OFFSET 0
    #define CORRECT_MATCH_END_OFFSET 5
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_search (&iter, STR, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_forward_search (&iter, STR, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    if (CORRECT_MATCH_START_OFFSET >= 0)
    {
        match_start_offset = gtk_text_iter_get_offset (&match_start);
        if (match_start_offset != CORRECT_MATCH_START_OFFSET)
        {
            TEST_FAIL ("match_start_offset is %d, should be %d", 
                       match_start_offset, CORRECT_MATCH_START_OFFSET);
        }
    
        match_end_offset = gtk_text_iter_get_offset (&match_end);
        if (match_end_offset != CORRECT_MATCH_END_OFFSET)
        {
            TEST_FAIL ("match_end_offset is %d, should be %d", 
                       match_end_offset, CORRECT_MATCH_END_OFFSET);
        }
    } 
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Searches forward for str.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: TRUE
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: If the GTK_TEXT_SEARCH_VISIBLE_ONLY flag is present, the match may have invisible text interspersed in str.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: TRUE
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Any match is returned by setting match_start to the first character of the match and match_end to the first character after the match.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: TRUE  
 */
static void test_purpose_873()
{
    #define TEST_LINE  "abcdefabcdef"
    #define OFFSET 1
    #define STR "abcde"
    #define FLAGS GTK_TEXT_SEARCH_VISIBLE_ONLY
    #define LIMIT_OFFSET -1
    #define CORRECT_RESULT TRUE
    #define CORRECT_MATCH_START_OFFSET 6
    #define CORRECT_MATCH_END_OFFSET 11
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_search (&iter, STR, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_forward_search (&iter, STR, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    if (CORRECT_MATCH_START_OFFSET >= 0)
    {
        match_start_offset = gtk_text_iter_get_offset (&match_start);
        if (match_start_offset != CORRECT_MATCH_START_OFFSET)
        {
            TEST_FAIL ("match_start_offset is %d, should be %d", 
                       match_start_offset, CORRECT_MATCH_START_OFFSET);
        }
    
        match_end_offset = gtk_text_iter_get_offset (&match_end);
        if (match_end_offset != CORRECT_MATCH_END_OFFSET)
        {
            TEST_FAIL ("match_end_offset is %d, should be %d", 
                       match_end_offset, CORRECT_MATCH_END_OFFSET);
        }
    } 
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Searches forward for str.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: If the GTK_TEXT_SEARCH_VISIBLE_ONLY flag is present, the match may have invisible text interspersed in str.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Any match is returned by setting match_start to the first character of the match and match_end to the first character after the match.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE  
 */
static void test_purpose_874()
{
    #define TEST_LINE  "abcdefabcdef"
    #define OFFSET 1
    #define STR "abcde"
    #define FLAGS GTK_TEXT_SEARCH_VISIBLE_ONLY
    #define LIMIT_OFFSET 10
    #define CORRECT_RESULT FALSE
    #define CORRECT_MATCH_START_OFFSET -1
    #define CORRECT_MATCH_END_OFFSET -1
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_search (&iter, STR, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_forward_search (&iter, STR, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    if (CORRECT_MATCH_START_OFFSET >= 0)
    {
        match_start_offset = gtk_text_iter_get_offset (&match_start);
        if (match_start_offset != CORRECT_MATCH_START_OFFSET)
        {
            TEST_FAIL ("match_start_offset is %d, should be %d", 
                       match_start_offset, CORRECT_MATCH_START_OFFSET);
        }
    
        match_end_offset = gtk_text_iter_get_offset (&match_end);
        if (match_end_offset != CORRECT_MATCH_END_OFFSET)
        {
            TEST_FAIL ("match_end_offset is %d, should be %d", 
                       match_end_offset, CORRECT_MATCH_END_OFFSET);
        }
    } 
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Searches forward for str.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: If the GTK_TEXT_SEARCH_VISIBLE_ONLY flag is present, the match may have invisible text interspersed in str.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Any match is returned by setting match_start to the first character of the match and match_end to the first character after the match.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE  
 */
static void test_purpose_875()
{
    #define TEST_LINE  "abcdefabcdef"
    #define OFFSET 7
    #define STR "abcde"
    #define FLAGS GTK_TEXT_SEARCH_VISIBLE_ONLY
    #define LIMIT_OFFSET -1
    #define CORRECT_RESULT FALSE
    #define CORRECT_MATCH_START_OFFSET -1
    #define CORRECT_MATCH_END_OFFSET -1
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_search (&iter, STR, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_forward_search (&iter, STR, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    if (CORRECT_MATCH_START_OFFSET >= 0)
    {
        match_start_offset = gtk_text_iter_get_offset (&match_start);
        if (match_start_offset != CORRECT_MATCH_START_OFFSET)
        {
            TEST_FAIL ("match_start_offset is %d, should be %d", 
                       match_start_offset, CORRECT_MATCH_START_OFFSET);
        }
    
        match_end_offset = gtk_text_iter_get_offset (&match_end);
        if (match_end_offset != CORRECT_MATCH_END_OFFSET)
        {
            TEST_FAIL ("match_end_offset is %d, should be %d", 
                       match_end_offset, CORRECT_MATCH_END_OFFSET);
        }
    } 
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Searches forward for str.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: If the GTK_TEXT_SEARCH_VISIBLE_ONLY flag is present, the match may have invisible text interspersed in str.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Any match is returned by setting match_start to the first character of the match and match_end to the first character after the match.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE  
 */
static void test_purpose_876()
{
    #define TEST_LINE  "abcdefabcdef"
    #define OFFSET 7
    #define STR "abcde"
    #define FLAGS GTK_TEXT_SEARCH_VISIBLE_ONLY
    #define LIMIT_OFFSET -1
    #define CORRECT_RESULT FALSE
    #define CORRECT_MATCH_START_OFFSET -1
    #define CORRECT_MATCH_END_OFFSET -1
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_search (&iter, STR, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_forward_search (&iter, STR, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    if (CORRECT_MATCH_START_OFFSET >= 0)
    {
        match_start_offset = gtk_text_iter_get_offset (&match_start);
        if (match_start_offset != CORRECT_MATCH_START_OFFSET)
        {
            TEST_FAIL ("match_start_offset is %d, should be %d", 
                       match_start_offset, CORRECT_MATCH_START_OFFSET);
        }
    
        match_end_offset = gtk_text_iter_get_offset (&match_end);
        if (match_end_offset != CORRECT_MATCH_END_OFFSET)
        {
            TEST_FAIL ("match_end_offset is %d, should be %d", 
                       match_end_offset, CORRECT_MATCH_END_OFFSET);
        }
    } 
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Searches forward for str.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: If the GTK_TEXT_SEARCH_VISIBLE_ONLY flag is present, the match may have invisible text interspersed in str.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Any match is returned by setting match_start to the first character of the match and match_end to the first character after the match.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE  
 */
static void test_purpose_877()
{
    #define TEST_LINE  "a"
    #define OFFSET 2
    #define STR "abcde"
    #define FLAGS GTK_TEXT_SEARCH_VISIBLE_ONLY
    #define LIMIT_OFFSET -1
    #define CORRECT_RESULT FALSE
    #define CORRECT_MATCH_START_OFFSET -1
    #define CORRECT_MATCH_END_OFFSET -1
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_search (&iter, STR, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_forward_search (&iter, STR, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    if (CORRECT_MATCH_START_OFFSET >= 0)
    {
        match_start_offset = gtk_text_iter_get_offset (&match_start);
        if (match_start_offset != CORRECT_MATCH_START_OFFSET)
        {
            TEST_FAIL ("match_start_offset is %d, should be %d", 
                       match_start_offset, CORRECT_MATCH_START_OFFSET);
        }
    
        match_end_offset = gtk_text_iter_get_offset (&match_end);
        if (match_end_offset != CORRECT_MATCH_END_OFFSET)
        {
            TEST_FAIL ("match_end_offset is %d, should be %d", 
                       match_end_offset, CORRECT_MATCH_END_OFFSET);
        }
    } 
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Searches forward for str.
 * Params Values: const GtkTextIter *iter, "\n", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: If the GTK_TEXT_SEARCH_VISIBLE_ONLY flag is present, the match may have invisible text interspersed in str.
 * Params Values: const GtkTextIter *iter, "\n", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Any match is returned by setting match_start to the first character of the match and match_end to the first character after the match.
 * Params Values: const GtkTextIter *iter, "\n", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE  
 */
static void test_purpose_878()
{
    #define TEST_LINE  "a"
    #define OFFSET 1
    #define STR "\n"
    #define FLAGS GTK_TEXT_SEARCH_VISIBLE_ONLY
    #define LIMIT_OFFSET -1
    #define CORRECT_RESULT FALSE
    #define CORRECT_MATCH_START_OFFSET -1
    #define CORRECT_MATCH_END_OFFSET -1
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_search (&iter, STR, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_forward_search (&iter, STR, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    if (CORRECT_MATCH_START_OFFSET >= 0)
    {
        match_start_offset = gtk_text_iter_get_offset (&match_start);
        if (match_start_offset != CORRECT_MATCH_START_OFFSET)
        {
            TEST_FAIL ("match_start_offset is %d, should be %d", 
                       match_start_offset, CORRECT_MATCH_START_OFFSET);
        }
    
        match_end_offset = gtk_text_iter_get_offset (&match_end);
        if (match_end_offset != CORRECT_MATCH_END_OFFSET)
        {
            TEST_FAIL ("match_end_offset is %d, should be %d", 
                       match_end_offset, CORRECT_MATCH_END_OFFSET);
        }
    } 
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: If these flags are not given, the match must be exact; the special 0xFFFC character in str will match embedded pixbufs or child widgets.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: -1
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: similarly, if you specify GTK_TEXT_SEARCH_TEXT_ONLY, the match may have pixbufs or child widgets mixed inside the matched range
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: TRUE  
 */
static void test_purpose_879()
{
    #define TEST_LINE  "abcdefabcdef"
    #define OFFSET 0
    #define STR "abcde"
    #define FLAGS GTK_TEXT_SEARCH_VISIBLE_ONLY
    #define LIMIT_OFFSET -1
    #define INVISIBLE_START_POS -1
    #define INVISIBLE_END_POS -1
    #define CORRECT_RESULT TRUE
    #define CORRECT_MATCH_START_OFFSET 0
    #define CORRECT_MATCH_END_OFFSET 5
    #define CORRECT_0XFFFC_POS -1
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    GtkTextTag *invisible_tag;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    char* test_line = TEST_LINE;
    gchar* str = STR;
    int i;
    gchar** splitted_str;
    char* outbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, test_line, strlen(test_line));
    
    /*  hack for adding pixbufs and child widgets */
    for (i = 0; i < strlen (test_line); i++)
    {
        if (test_line [i] == '@')
        {
            GtkTextIter pixbuf_iter;
            GtkTextIter delstart_iter;
            GtkTextIter delend_iter;
            GdkPixbuf* pixbuf;
    
            pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 
                                                8, 10, 10);
            gtk_text_buffer_get_iter_at_offset (buffer, &pixbuf_iter, i);
            gtk_text_buffer_insert_pixbuf (buffer, &pixbuf_iter, pixbuf);
    
            gtk_text_buffer_get_iter_at_offset (buffer, &delstart_iter, i + 1);
            gtk_text_buffer_get_iter_at_offset (buffer, &delend_iter, i + 2);
            gtk_text_buffer_delete (buffer, &delstart_iter, &delend_iter);
        }
    
        /*TODO: insert child anchor here; anchors don't work at the moment */
        if (test_line [i] == '#')
        {
            GtkTextIter anchor_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &anchor_iter, i);
            gtk_text_buffer_create_child_anchor(buffer, &anchor_iter);
           
        }
    }
    
    /* hack to add 0xFFFC to str */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (str, "$", 0);
    str = g_strjoinv (outbuf, splitted_str);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    if (INVISIBLE_START_POS >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_start, 
                                            INVISIBLE_START_POS);
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_end, 
                                            INVISIBLE_END_POS);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                    "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                                   &invisible_start, &invisible_end);
    }
    */
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_search (&iter, str, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_forward_search (&iter, str, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    /* this 'if' is to avoid segving if res != CORRECT_RESULT */
    if (res == CORRECT_RESULT)
    {
        if (CORRECT_MATCH_START_OFFSET >= 0)
        {
            match_start_offset = gtk_text_iter_get_offset (&match_start);
            if (match_start_offset != CORRECT_MATCH_START_OFFSET)
            {
                TEST_FAIL ("match_start_offset is %d, should be %d", 
                           match_start_offset, CORRECT_MATCH_START_OFFSET);
            }
            
            match_end_offset = gtk_text_iter_get_offset (&match_end);
            if (match_end_offset != CORRECT_MATCH_END_OFFSET)
            {
                TEST_FAIL ("match_end_offset is %d, should be %d", 
                           match_end_offset, CORRECT_MATCH_END_OFFSET);
            }
        }
    
        if (CORRECT_0XFFFC_POS >= 0)
        {
            GtkTextIter fffc_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &fffc_iter, 
                                                CORRECT_0XFFFC_POS);
            
            if (gtk_text_iter_get_char(&fffc_iter) != 0xFFFC)
            {
                TEST_FAIL ("symbol at the pos %d should be 0xFFFC", 
                           CORRECT_0XFFFC_POS);
            }
        }
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef INVISIBLE_START_POS
    #undef INVISIBLE_END_POS
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    #undef CORRECT_0XFFFC_POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: If these flags are not given, the match must be exact; the special 0xFFFC character in str will match embedded pixbufs or child widgets.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: 2
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: similarly, if you specify GTK_TEXT_SEARCH_TEXT_ONLY, the match may have pixbufs or child widgets mixed inside the matched range
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: TRUE  
 */
static void test_purpose_880()
{
    #define TEST_LINE  "abcdefabcdef"
    #define OFFSET 0
    #define STR "abcde"
    #define FLAGS GTK_TEXT_SEARCH_VISIBLE_ONLY
    #define LIMIT_OFFSET -1
    #define INVISIBLE_START_POS 2
    #define INVISIBLE_END_POS 7
    #define CORRECT_RESULT TRUE
    #define CORRECT_MATCH_START_OFFSET 0
    #define CORRECT_MATCH_END_OFFSET 5
    #define CORRECT_0XFFFC_POS -1
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    GtkTextTag *invisible_tag;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    char* test_line = TEST_LINE;
    gchar* str = STR;
    int i;
    gchar** splitted_str;
    char* outbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, test_line, strlen(test_line));
    
    /*  hack for adding pixbufs and child widgets */
    for (i = 0; i < strlen (test_line); i++)
    {
        if (test_line [i] == '@')
        {
            GtkTextIter pixbuf_iter;
            GtkTextIter delstart_iter;
            GtkTextIter delend_iter;
            GdkPixbuf* pixbuf;
    
            pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 
                                                8, 10, 10);
            gtk_text_buffer_get_iter_at_offset (buffer, &pixbuf_iter, i);
            gtk_text_buffer_insert_pixbuf (buffer, &pixbuf_iter, pixbuf);
    
            gtk_text_buffer_get_iter_at_offset (buffer, &delstart_iter, i + 1);
            gtk_text_buffer_get_iter_at_offset (buffer, &delend_iter, i + 2);
            gtk_text_buffer_delete (buffer, &delstart_iter, &delend_iter);
        }
    
        /*TODO: insert child anchor here; anchors don't work at the moment */
        if (test_line [i] == '#')
        {
            GtkTextIter anchor_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &anchor_iter, i);
            gtk_text_buffer_create_child_anchor(buffer, &anchor_iter);
           
        }
    }
    
    /* hack to add 0xFFFC to str */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (str, "$", 0);
    str = g_strjoinv (outbuf, splitted_str);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    if (INVISIBLE_START_POS >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_start, 
                                            INVISIBLE_START_POS);
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_end, 
                                            INVISIBLE_END_POS);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                    "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                                   &invisible_start, &invisible_end);
    }
    */
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_search (&iter, str, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_forward_search (&iter, str, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    /* this 'if' is to avoid segving if res != CORRECT_RESULT */
    if (res == CORRECT_RESULT)
    {
        if (CORRECT_MATCH_START_OFFSET >= 0)
        {
            match_start_offset = gtk_text_iter_get_offset (&match_start);
            if (match_start_offset != CORRECT_MATCH_START_OFFSET)
            {
                TEST_FAIL ("match_start_offset is %d, should be %d", 
                           match_start_offset, CORRECT_MATCH_START_OFFSET);
            }
            
            match_end_offset = gtk_text_iter_get_offset (&match_end);
            if (match_end_offset != CORRECT_MATCH_END_OFFSET)
            {
                TEST_FAIL ("match_end_offset is %d, should be %d", 
                           match_end_offset, CORRECT_MATCH_END_OFFSET);
            }
        }
    
        if (CORRECT_0XFFFC_POS >= 0)
        {
            GtkTextIter fffc_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &fffc_iter, 
                                                CORRECT_0XFFFC_POS);
            
            if (gtk_text_iter_get_char(&fffc_iter) != 0xFFFC)
            {
                TEST_FAIL ("symbol at the pos %d should be 0xFFFC", 
                           CORRECT_0XFFFC_POS);
            }
        }
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef INVISIBLE_START_POS
    #undef INVISIBLE_END_POS
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    #undef CORRECT_0XFFFC_POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: If these flags are not given, the match must be exact; the special 0xFFFC character in str will match embedded pixbufs or child widgets.
 * Params Values: const GtkTextIter *iter, "abc$e", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: -1
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: similarly, if you specify GTK_TEXT_SEARCH_TEXT_ONLY, the match may have pixbufs or child widgets mixed inside the matched range
 * Params Values: const GtkTextIter *iter, "abc$e", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: TRUE  
 */
static void test_purpose_881()
{
    #define TEST_LINE  "abc@efabcdef"
    #define OFFSET 0
    #define STR "abc$e"
    #define FLAGS GTK_TEXT_SEARCH_VISIBLE_ONLY
    #define LIMIT_OFFSET -1
    #define INVISIBLE_START_POS -1
    #define INVISIBLE_END_POS -1
    #define CORRECT_RESULT TRUE
    #define CORRECT_MATCH_START_OFFSET 0
    #define CORRECT_MATCH_END_OFFSET 5
    #define CORRECT_0XFFFC_POS 3
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    GtkTextTag *invisible_tag;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    char* test_line = TEST_LINE;
    gchar* str = STR;
    int i;
    gchar** splitted_str;
    char* outbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, test_line, strlen(test_line));
    
    /*  hack for adding pixbufs and child widgets */
    for (i = 0; i < strlen (test_line); i++)
    {
        if (test_line [i] == '@')
        {
            GtkTextIter pixbuf_iter;
            GtkTextIter delstart_iter;
            GtkTextIter delend_iter;
            GdkPixbuf* pixbuf;
    
            pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 
                                                8, 10, 10);
            gtk_text_buffer_get_iter_at_offset (buffer, &pixbuf_iter, i);
            gtk_text_buffer_insert_pixbuf (buffer, &pixbuf_iter, pixbuf);
    
            gtk_text_buffer_get_iter_at_offset (buffer, &delstart_iter, i + 1);
            gtk_text_buffer_get_iter_at_offset (buffer, &delend_iter, i + 2);
            gtk_text_buffer_delete (buffer, &delstart_iter, &delend_iter);
        }
    
        /*TODO: insert child anchor here; anchors don't work at the moment */
        if (test_line [i] == '#')
        {
            GtkTextIter anchor_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &anchor_iter, i);
            gtk_text_buffer_create_child_anchor(buffer, &anchor_iter);
           
        }
    }
    
    /* hack to add 0xFFFC to str */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (str, "$", 0);
    str = g_strjoinv (outbuf, splitted_str);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    if (INVISIBLE_START_POS >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_start, 
                                            INVISIBLE_START_POS);
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_end, 
                                            INVISIBLE_END_POS);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                    "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                                   &invisible_start, &invisible_end);
    }
    */
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_search (&iter, str, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_forward_search (&iter, str, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    /* this 'if' is to avoid segving if res != CORRECT_RESULT */
    if (res == CORRECT_RESULT)
    {
        if (CORRECT_MATCH_START_OFFSET >= 0)
        {
            match_start_offset = gtk_text_iter_get_offset (&match_start);
            if (match_start_offset != CORRECT_MATCH_START_OFFSET)
            {
                TEST_FAIL ("match_start_offset is %d, should be %d", 
                           match_start_offset, CORRECT_MATCH_START_OFFSET);
            }
            
            match_end_offset = gtk_text_iter_get_offset (&match_end);
            if (match_end_offset != CORRECT_MATCH_END_OFFSET)
            {
                TEST_FAIL ("match_end_offset is %d, should be %d", 
                           match_end_offset, CORRECT_MATCH_END_OFFSET);
            }
        }
    
        if (CORRECT_0XFFFC_POS >= 0)
        {
            GtkTextIter fffc_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &fffc_iter, 
                                                CORRECT_0XFFFC_POS);
            
            if (gtk_text_iter_get_char(&fffc_iter) != 0xFFFC)
            {
                TEST_FAIL ("symbol at the pos %d should be 0xFFFC", 
                           CORRECT_0XFFFC_POS);
            }
        }
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef INVISIBLE_START_POS
    #undef INVISIBLE_END_POS
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    #undef CORRECT_0XFFFC_POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: If these flags are not given, the match must be exact; the special 0xFFFC character in str will match embedded pixbufs or child widgets.
 * Params Values: const GtkTextIter *iter, "abc$\n", GTK_TEXT_SEARCH_TEXT_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: -1
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: similarly, if you specify GTK_TEXT_SEARCH_TEXT_ONLY, the match may have pixbufs or child widgets mixed inside the matched range
 * Params Values: const GtkTextIter *iter, "abc$\n", GTK_TEXT_SEARCH_TEXT_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE  
 */
static void test_purpose_882()
{
    #define TEST_LINE  "abc@"
    #define OFFSET 0
    #define STR "abc$\n"
    #define FLAGS GTK_TEXT_SEARCH_TEXT_ONLY
    #define LIMIT_OFFSET -1
    #define INVISIBLE_START_POS -1
    #define INVISIBLE_END_POS -1
    #define CORRECT_RESULT FALSE
    #define CORRECT_MATCH_START_OFFSET -1
    #define CORRECT_MATCH_END_OFFSET -1
    #define CORRECT_0XFFFC_POS 3
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    GtkTextTag *invisible_tag;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    char* test_line = TEST_LINE;
    gchar* str = STR;
    int i;
    gchar** splitted_str;
    char* outbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, test_line, strlen(test_line));
    
    /*  hack for adding pixbufs and child widgets */
    for (i = 0; i < strlen (test_line); i++)
    {
        if (test_line [i] == '@')
        {
            GtkTextIter pixbuf_iter;
            GtkTextIter delstart_iter;
            GtkTextIter delend_iter;
            GdkPixbuf* pixbuf;
    
            pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 
                                                8, 10, 10);
            gtk_text_buffer_get_iter_at_offset (buffer, &pixbuf_iter, i);
            gtk_text_buffer_insert_pixbuf (buffer, &pixbuf_iter, pixbuf);
    
            gtk_text_buffer_get_iter_at_offset (buffer, &delstart_iter, i + 1);
            gtk_text_buffer_get_iter_at_offset (buffer, &delend_iter, i + 2);
            gtk_text_buffer_delete (buffer, &delstart_iter, &delend_iter);
        }
    
        /*TODO: insert child anchor here; anchors don't work at the moment */
        if (test_line [i] == '#')
        {
            GtkTextIter anchor_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &anchor_iter, i);
            gtk_text_buffer_create_child_anchor(buffer, &anchor_iter);
           
        }
    }
    
    /* hack to add 0xFFFC to str */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (str, "$", 0);
    str = g_strjoinv (outbuf, splitted_str);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    if (INVISIBLE_START_POS >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_start, 
                                            INVISIBLE_START_POS);
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_end, 
                                            INVISIBLE_END_POS);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                    "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                                   &invisible_start, &invisible_end);
    }
    */
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_search (&iter, str, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_forward_search (&iter, str, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    /* this 'if' is to avoid segving if res != CORRECT_RESULT */
    if (res == CORRECT_RESULT)
    {
        if (CORRECT_MATCH_START_OFFSET >= 0)
        {
            match_start_offset = gtk_text_iter_get_offset (&match_start);
            if (match_start_offset != CORRECT_MATCH_START_OFFSET)
            {
                TEST_FAIL ("match_start_offset is %d, should be %d", 
                           match_start_offset, CORRECT_MATCH_START_OFFSET);
            }
            
            match_end_offset = gtk_text_iter_get_offset (&match_end);
            if (match_end_offset != CORRECT_MATCH_END_OFFSET)
            {
                TEST_FAIL ("match_end_offset is %d, should be %d", 
                           match_end_offset, CORRECT_MATCH_END_OFFSET);
            }
        }
    
        if (CORRECT_0XFFFC_POS >= 0)
        {
            GtkTextIter fffc_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &fffc_iter, 
                                                CORRECT_0XFFFC_POS);
            
            if (gtk_text_iter_get_char(&fffc_iter) != 0xFFFC)
            {
                TEST_FAIL ("symbol at the pos %d should be 0xFFFC", 
                           CORRECT_0XFFFC_POS);
            }
        }
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef INVISIBLE_START_POS
    #undef INVISIBLE_END_POS
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    #undef CORRECT_0XFFFC_POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: If these flags are not given, the match must be exact; the special 0xFFFC character in str will match embedded pixbufs or child widgets.
 * Params Values: const GtkTextIter *iter, "abc$$\n", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: -1
 * 
 * Name:  gtk_text_iter_forward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: similarly, if you specify GTK_TEXT_SEARCH_TEXT_ONLY, the match may have pixbufs or child widgets mixed inside the matched range
 * Params Values: const GtkTextIter *iter, "abc$$\n", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: TRUE  
 */
static void test_purpose_883()
{
    #define TEST_LINE  "abc@@\n"
    #define OFFSET 0
    #define STR "abc$$\n"
    #define FLAGS GTK_TEXT_SEARCH_VISIBLE_ONLY
    #define LIMIT_OFFSET -1
    #define INVISIBLE_START_POS -1
    #define INVISIBLE_END_POS -1
    #define CORRECT_RESULT TRUE
    #define CORRECT_MATCH_START_OFFSET 0
    #define CORRECT_MATCH_END_OFFSET 6
    #define CORRECT_0XFFFC_POS 3
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    GtkTextTag *invisible_tag;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    char* test_line = TEST_LINE;
    gchar* str = STR;
    int i;
    gchar** splitted_str;
    char* outbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    gtk_text_buffer_set_text (buffer, test_line, strlen(test_line));
    
    /*  hack for adding pixbufs and child widgets */
    for (i = 0; i < strlen (test_line); i++)
    {
        if (test_line [i] == '@')
        {
            GtkTextIter pixbuf_iter;
            GtkTextIter delstart_iter;
            GtkTextIter delend_iter;
            GdkPixbuf* pixbuf;
    
            pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 
                                                8, 10, 10);
            gtk_text_buffer_get_iter_at_offset (buffer, &pixbuf_iter, i);
            gtk_text_buffer_insert_pixbuf (buffer, &pixbuf_iter, pixbuf);
    
            gtk_text_buffer_get_iter_at_offset (buffer, &delstart_iter, i + 1);
            gtk_text_buffer_get_iter_at_offset (buffer, &delend_iter, i + 2);
            gtk_text_buffer_delete (buffer, &delstart_iter, &delend_iter);
        }
    
        /*TODO: insert child anchor here; anchors don't work at the moment */
        if (test_line [i] == '#')
        {
            GtkTextIter anchor_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &anchor_iter, i);
            gtk_text_buffer_create_child_anchor(buffer, &anchor_iter);
           
        }
    }
    
    /* hack to add 0xFFFC to str */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (str, "$", 0);
    str = g_strjoinv (outbuf, splitted_str);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    if (INVISIBLE_START_POS >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_start, 
                                            INVISIBLE_START_POS);
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_end, 
                                            INVISIBLE_END_POS);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                    "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                                   &invisible_start, &invisible_end);
    }
    */
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_forward_search (&iter, str, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_forward_search (&iter, str, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_forward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    /* this 'if' is to avoid segving if res != CORRECT_RESULT */
    if (res == CORRECT_RESULT)
    {
        if (CORRECT_MATCH_START_OFFSET >= 0)
        {
            match_start_offset = gtk_text_iter_get_offset (&match_start);
            if (match_start_offset != CORRECT_MATCH_START_OFFSET)
            {
                TEST_FAIL ("match_start_offset is %d, should be %d", 
                           match_start_offset, CORRECT_MATCH_START_OFFSET);
            }
            
            match_end_offset = gtk_text_iter_get_offset (&match_end);
            if (match_end_offset != CORRECT_MATCH_END_OFFSET)
            {
                TEST_FAIL ("match_end_offset is %d, should be %d", 
                           match_end_offset, CORRECT_MATCH_END_OFFSET);
            }
        }
    
        if (CORRECT_0XFFFC_POS >= 0)
        {
            GtkTextIter fffc_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &fffc_iter, 
                                                CORRECT_0XFFFC_POS);
            
            if (gtk_text_iter_get_char(&fffc_iter) != 0xFFFC)
            {
                TEST_FAIL ("symbol at the pos %d should be 0xFFFC", 
                           CORRECT_0XFFFC_POS);
            }
        }
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef INVISIBLE_START_POS
    #undef INVISIBLE_END_POS
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    #undef CORRECT_0XFFFC_POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Same as gtk_text_iter_forward_search(), but moves backward.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: TRUE  
 */
static void test_purpose_884()
{
    #define TEST_LINE  "abcdefabcdef"
    #define OFFSET 12
    #define STR "abcde"
    #define FLAGS GTK_TEXT_SEARCH_VISIBLE_ONLY
    #define LIMIT_OFFSET -1
    #define INVISIBLE_START_POS -1
    #define INVISIBLE_END_POS -1
    #define CORRECT_RESULT TRUE
    #define CORRECT_MATCH_START_OFFSET 6
    #define CORRECT_MATCH_END_OFFSET 11
    #define CORRECT_0XFFFC_POS -1
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    GtkTextTag *invisible_tag;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    char* test_line = TEST_LINE;
    gchar* str = STR;
    int i;
    gchar** splitted_str;
    char* outbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, test_line, strlen(test_line));
    
    /*  hack for adding pixbufs and child widgets */
    for (i = 0; i < strlen (test_line); i++)
    {
        if (test_line [i] == '@')
        {
            GtkTextIter pixbuf_iter;
            GtkTextIter delstart_iter;
            GtkTextIter delend_iter;
            GdkPixbuf* pixbuf;
    
            pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 
                                                8, 10, 10);
            gtk_text_buffer_get_iter_at_offset (buffer, &pixbuf_iter, i);
            gtk_text_buffer_insert_pixbuf (buffer, &pixbuf_iter, pixbuf);
    
            gtk_text_buffer_get_iter_at_offset (buffer, &delstart_iter, i + 1);
            gtk_text_buffer_get_iter_at_offset (buffer, &delend_iter, i + 2);
            gtk_text_buffer_delete (buffer, &delstart_iter, &delend_iter);
        }
    
        /*TODO: insert child anchor here; anchors don't work at the moment */
        if (test_line [i] == '#')
        {
            GtkTextIter anchor_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &anchor_iter, i);
            gtk_text_buffer_create_child_anchor(buffer, &anchor_iter);
        }
    }
    
    /* hack to add 0xFFFC to str */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (str, "$", 0);
    str = g_strjoinv (outbuf, splitted_str);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    if (INVISIBLE_START_POS >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_start, 
                                            INVISIBLE_START_POS);
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_end, 
                                            INVISIBLE_END_POS);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                    "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                                   &invisible_start, &invisible_end);
    }
    */
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_backward_search (&iter, str, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_backward_search (&iter, str, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_backward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    /* this 'if' is to avoid segving if res != CORRECT_RESULT */
    if (res == CORRECT_RESULT)
    {
        if (CORRECT_MATCH_START_OFFSET >= 0)
        {
            match_start_offset = gtk_text_iter_get_offset (&match_start);
            if (match_start_offset != CORRECT_MATCH_START_OFFSET)
            {
                TEST_FAIL ("match_start_offset is %d, should be %d", 
                           match_start_offset, CORRECT_MATCH_START_OFFSET);
            }
            
            match_end_offset = gtk_text_iter_get_offset (&match_end);
            if (match_end_offset != CORRECT_MATCH_END_OFFSET)
            {
                TEST_FAIL ("match_end_offset is %d, should be %d", 
                           match_end_offset, CORRECT_MATCH_END_OFFSET);
            }
        }
    
        if (CORRECT_0XFFFC_POS >= 0)
        {
            GtkTextIter fffc_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &fffc_iter, 
                                                CORRECT_0XFFFC_POS);
            
            if (gtk_text_iter_get_char(&fffc_iter) != 0xFFFC)
            {
                TEST_FAIL ("symbol at the pos %d should be 0xFFFC", 
                           CORRECT_0XFFFC_POS);
            }
        }
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef INVISIBLE_START_POS
    #undef INVISIBLE_END_POS
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    #undef CORRECT_0XFFFC_POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Same as gtk_text_iter_forward_search(), but moves backward.
 * Params Values: const GtkTextIter *iter, "abcde", GTK_TEXT_SEARCH_TEXT_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: TRUE  
 */
static void test_purpose_885()
{
    #define TEST_LINE  "abcdefabcdef"
    #define OFFSET 12
    #define STR "abcde"
    #define FLAGS GTK_TEXT_SEARCH_TEXT_ONLY
    #define LIMIT_OFFSET -1
    #define INVISIBLE_START_POS 2
    #define INVISIBLE_END_POS 7
    #define CORRECT_RESULT TRUE
    #define CORRECT_MATCH_START_OFFSET 6
    #define CORRECT_MATCH_END_OFFSET 11
    #define CORRECT_0XFFFC_POS -1
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    GtkTextTag *invisible_tag;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    char* test_line = TEST_LINE;
    gchar* str = STR;
    int i;
    gchar** splitted_str;
    char* outbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, test_line, strlen(test_line));
    
    /*  hack for adding pixbufs and child widgets */
    for (i = 0; i < strlen (test_line); i++)
    {
        if (test_line [i] == '@')
        {
            GtkTextIter pixbuf_iter;
            GtkTextIter delstart_iter;
            GtkTextIter delend_iter;
            GdkPixbuf* pixbuf;
    
            pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 
                                                8, 10, 10);
            gtk_text_buffer_get_iter_at_offset (buffer, &pixbuf_iter, i);
            gtk_text_buffer_insert_pixbuf (buffer, &pixbuf_iter, pixbuf);
    
            gtk_text_buffer_get_iter_at_offset (buffer, &delstart_iter, i + 1);
            gtk_text_buffer_get_iter_at_offset (buffer, &delend_iter, i + 2);
            gtk_text_buffer_delete (buffer, &delstart_iter, &delend_iter);
        }
    
        /*TODO: insert child anchor here; anchors don't work at the moment */
        if (test_line [i] == '#')
        {
            GtkTextIter anchor_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &anchor_iter, i);
            gtk_text_buffer_create_child_anchor(buffer, &anchor_iter);
        }
    }
    
    /* hack to add 0xFFFC to str */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (str, "$", 0);
    str = g_strjoinv (outbuf, splitted_str);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    if (INVISIBLE_START_POS >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_start, 
                                            INVISIBLE_START_POS);
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_end, 
                                            INVISIBLE_END_POS);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                    "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                                   &invisible_start, &invisible_end);
    }
    */
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_backward_search (&iter, str, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_backward_search (&iter, str, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_backward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    /* this 'if' is to avoid segving if res != CORRECT_RESULT */
    if (res == CORRECT_RESULT)
    {
        if (CORRECT_MATCH_START_OFFSET >= 0)
        {
            match_start_offset = gtk_text_iter_get_offset (&match_start);
            if (match_start_offset != CORRECT_MATCH_START_OFFSET)
            {
                TEST_FAIL ("match_start_offset is %d, should be %d", 
                           match_start_offset, CORRECT_MATCH_START_OFFSET);
            }
            
            match_end_offset = gtk_text_iter_get_offset (&match_end);
            if (match_end_offset != CORRECT_MATCH_END_OFFSET)
            {
                TEST_FAIL ("match_end_offset is %d, should be %d", 
                           match_end_offset, CORRECT_MATCH_END_OFFSET);
            }
        }
    
        if (CORRECT_0XFFFC_POS >= 0)
        {
            GtkTextIter fffc_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &fffc_iter, 
                                                CORRECT_0XFFFC_POS);
            
            if (gtk_text_iter_get_char(&fffc_iter) != 0xFFFC)
            {
                TEST_FAIL ("symbol at the pos %d should be 0xFFFC", 
                           CORRECT_0XFFFC_POS);
            }
        }
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef INVISIBLE_START_POS
    #undef INVISIBLE_END_POS
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    #undef CORRECT_0XFFFC_POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Same as gtk_text_iter_forward_search(), but moves backward.
 * Params Values: const GtkTextIter *iter, "abc$e", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: TRUE  
 */
static void test_purpose_886()
{
    #define TEST_LINE  "abc@efabcdef"
    #define OFFSET 13
    #define STR "abc$e"
    #define FLAGS GTK_TEXT_SEARCH_VISIBLE_ONLY
    #define LIMIT_OFFSET -1
    #define INVISIBLE_START_POS -1
    #define INVISIBLE_END_POS -1
    #define CORRECT_RESULT TRUE
    #define CORRECT_MATCH_START_OFFSET 0
    #define CORRECT_MATCH_END_OFFSET 5
    #define CORRECT_0XFFFC_POS 3
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    GtkTextTag *invisible_tag;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    char* test_line = TEST_LINE;
    gchar* str = STR;
    int i;
    gchar** splitted_str;
    char* outbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, test_line, strlen(test_line));
    
    /*  hack for adding pixbufs and child widgets */
    for (i = 0; i < strlen (test_line); i++)
    {
        if (test_line [i] == '@')
        {
            GtkTextIter pixbuf_iter;
            GtkTextIter delstart_iter;
            GtkTextIter delend_iter;
            GdkPixbuf* pixbuf;
    
            pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 
                                                8, 10, 10);
            gtk_text_buffer_get_iter_at_offset (buffer, &pixbuf_iter, i);
            gtk_text_buffer_insert_pixbuf (buffer, &pixbuf_iter, pixbuf);
    
            gtk_text_buffer_get_iter_at_offset (buffer, &delstart_iter, i + 1);
            gtk_text_buffer_get_iter_at_offset (buffer, &delend_iter, i + 2);
            gtk_text_buffer_delete (buffer, &delstart_iter, &delend_iter);
        }
    
        /*TODO: insert child anchor here; anchors don't work at the moment */
        if (test_line [i] == '#')
        {
            GtkTextIter anchor_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &anchor_iter, i);
            gtk_text_buffer_create_child_anchor(buffer, &anchor_iter);
        }
    }
    
    /* hack to add 0xFFFC to str */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (str, "$", 0);
    str = g_strjoinv (outbuf, splitted_str);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    if (INVISIBLE_START_POS >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_start, 
                                            INVISIBLE_START_POS);
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_end, 
                                            INVISIBLE_END_POS);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                    "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                                   &invisible_start, &invisible_end);
    }
    */
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_backward_search (&iter, str, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_backward_search (&iter, str, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_backward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    /* this 'if' is to avoid segving if res != CORRECT_RESULT */
    if (res == CORRECT_RESULT)
    {
        if (CORRECT_MATCH_START_OFFSET >= 0)
        {
            match_start_offset = gtk_text_iter_get_offset (&match_start);
            if (match_start_offset != CORRECT_MATCH_START_OFFSET)
            {
                TEST_FAIL ("match_start_offset is %d, should be %d", 
                           match_start_offset, CORRECT_MATCH_START_OFFSET);
            }
            
            match_end_offset = gtk_text_iter_get_offset (&match_end);
            if (match_end_offset != CORRECT_MATCH_END_OFFSET)
            {
                TEST_FAIL ("match_end_offset is %d, should be %d", 
                           match_end_offset, CORRECT_MATCH_END_OFFSET);
            }
        }
    
        if (CORRECT_0XFFFC_POS >= 0)
        {
            GtkTextIter fffc_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &fffc_iter, 
                                                CORRECT_0XFFFC_POS);
            
            if (gtk_text_iter_get_char(&fffc_iter) != 0xFFFC)
            {
                TEST_FAIL ("symbol at the pos %d should be 0xFFFC", 
                           CORRECT_0XFFFC_POS);
            }
        }
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef INVISIBLE_START_POS
    #undef INVISIBLE_END_POS
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    #undef CORRECT_0XFFFC_POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Same as gtk_text_iter_forward_search(), but moves backward.
 * Params Values: const GtkTextIter *iter, "abc$\n", GTK_TEXT_SEARCH_TEXT_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: FALSE  
 */
static void test_purpose_887()
{
    #define TEST_LINE  "abc@"
    #define OFFSET 5
    #define STR "abc$\n"
    #define FLAGS GTK_TEXT_SEARCH_TEXT_ONLY
    #define LIMIT_OFFSET -1
    #define INVISIBLE_START_POS -1
    #define INVISIBLE_END_POS -1
    #define CORRECT_RESULT FALSE
    #define CORRECT_MATCH_START_OFFSET -1
    #define CORRECT_MATCH_END_OFFSET -1
    #define CORRECT_0XFFFC_POS 3
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    GtkTextTag *invisible_tag;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    char* test_line = TEST_LINE;
    gchar* str = STR;
    int i;
    gchar** splitted_str;
    char* outbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, test_line, strlen(test_line));
    
    /*  hack for adding pixbufs and child widgets */
    for (i = 0; i < strlen (test_line); i++)
    {
        if (test_line [i] == '@')
        {
            GtkTextIter pixbuf_iter;
            GtkTextIter delstart_iter;
            GtkTextIter delend_iter;
            GdkPixbuf* pixbuf;
    
            pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 
                                                8, 10, 10);
            gtk_text_buffer_get_iter_at_offset (buffer, &pixbuf_iter, i);
            gtk_text_buffer_insert_pixbuf (buffer, &pixbuf_iter, pixbuf);
    
            gtk_text_buffer_get_iter_at_offset (buffer, &delstart_iter, i + 1);
            gtk_text_buffer_get_iter_at_offset (buffer, &delend_iter, i + 2);
            gtk_text_buffer_delete (buffer, &delstart_iter, &delend_iter);
        }
    
        /*TODO: insert child anchor here; anchors don't work at the moment */
        if (test_line [i] == '#')
        {
            GtkTextIter anchor_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &anchor_iter, i);
            gtk_text_buffer_create_child_anchor(buffer, &anchor_iter);
        }
    }
    
    /* hack to add 0xFFFC to str */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (str, "$", 0);
    str = g_strjoinv (outbuf, splitted_str);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    if (INVISIBLE_START_POS >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_start, 
                                            INVISIBLE_START_POS);
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_end, 
                                            INVISIBLE_END_POS);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                    "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                                   &invisible_start, &invisible_end);
    }
    */
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_backward_search (&iter, str, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_backward_search (&iter, str, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_backward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    /* this 'if' is to avoid segving if res != CORRECT_RESULT */
    if (res == CORRECT_RESULT)
    {
        if (CORRECT_MATCH_START_OFFSET >= 0)
        {
            match_start_offset = gtk_text_iter_get_offset (&match_start);
            if (match_start_offset != CORRECT_MATCH_START_OFFSET)
            {
                TEST_FAIL ("match_start_offset is %d, should be %d", 
                           match_start_offset, CORRECT_MATCH_START_OFFSET);
            }
            
            match_end_offset = gtk_text_iter_get_offset (&match_end);
            if (match_end_offset != CORRECT_MATCH_END_OFFSET)
            {
                TEST_FAIL ("match_end_offset is %d, should be %d", 
                           match_end_offset, CORRECT_MATCH_END_OFFSET);
            }
        }
    
        if (CORRECT_0XFFFC_POS >= 0)
        {
            GtkTextIter fffc_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &fffc_iter, 
                                                CORRECT_0XFFFC_POS);
            
            if (gtk_text_iter_get_char(&fffc_iter) != 0xFFFC)
            {
                TEST_FAIL ("symbol at the pos %d should be 0xFFFC", 
                           CORRECT_0XFFFC_POS);
            }
        }
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef INVISIBLE_START_POS
    #undef INVISIBLE_END_POS
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    #undef CORRECT_0XFFFC_POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_text_iter_backward_search
 * Params: const GtkTextIter *iter, const gchar *str, GtkTextSearchFlags flags, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Returns: gboolean
 * Assertion: Same as gtk_text_iter_forward_search(), but moves backward.
 * Params Values: const GtkTextIter *iter, "abc$$\n", GTK_TEXT_SEARCH_VISIBLE_ONLY, GtkTextIter *match_start, GtkTextIter *match_end, const GtkTextIter *limit
 * Expected: TRUE  
 */
static void test_purpose_888()
{
    #define TEST_LINE  "abc@@\n"
    #define OFFSET 6
    #define STR "abc$$\n"
    #define FLAGS GTK_TEXT_SEARCH_VISIBLE_ONLY
    #define LIMIT_OFFSET -1
    #define INVISIBLE_START_POS -1
    #define INVISIBLE_END_POS -1
    #define CORRECT_RESULT TRUE
    #define CORRECT_MATCH_START_OFFSET 0
    #define CORRECT_MATCH_END_OFFSET 6
    #define CORRECT_0XFFFC_POS 3
    
    GtkTextIter iter;
    GtkTextIter match_start;
    GtkTextIter match_end;
    GtkTextIter invisible_start;
    GtkTextIter invisible_end;
    GtkTextTag *invisible_tag;
    GtkTextBuffer* buffer;
    gboolean res;
    GtkTextIter limit;
    gint match_start_offset;
    gint match_end_offset;
    char* test_line = TEST_LINE;
    gchar* str = STR;
    int i;
    gchar** splitted_str;
    char* outbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, test_line, strlen(test_line));
    
    /*  hack for adding pixbufs and child widgets */
    for (i = 0; i < strlen (test_line); i++)
    {
        if (test_line [i] == '@')
        {
            GtkTextIter pixbuf_iter;
            GtkTextIter delstart_iter;
            GtkTextIter delend_iter;
            GdkPixbuf* pixbuf;
    
            pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 
                                                8, 10, 10);
            gtk_text_buffer_get_iter_at_offset (buffer, &pixbuf_iter, i);
            gtk_text_buffer_insert_pixbuf (buffer, &pixbuf_iter, pixbuf);
    
            gtk_text_buffer_get_iter_at_offset (buffer, &delstart_iter, i + 1);
            gtk_text_buffer_get_iter_at_offset (buffer, &delend_iter, i + 2);
            gtk_text_buffer_delete (buffer, &delstart_iter, &delend_iter);
        }
    
        /*TODO: insert child anchor here; anchors don't work at the moment */
        if (test_line [i] == '#')
        {
            GtkTextIter anchor_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &anchor_iter, i);
            gtk_text_buffer_create_child_anchor(buffer, &anchor_iter);
        }
    }
    
    /* hack to add 0xFFFC to str */
    outbuf = (char*) calloc (sizeof (char), 6);
    g_unichar_to_utf8 (0xFFFC, outbuf);
    splitted_str = g_strsplit (str, "$", 0);
    str = g_strjoinv (outbuf, splitted_str);
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    if (LIMIT_OFFSET >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &limit, LIMIT_OFFSET);
    }
    
    /*
      #66194 bug "invisible" property on GtkTextTag is not supported for GTK 2.0
    
    if (INVISIBLE_START_POS >= 0)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_start, 
                                            INVISIBLE_START_POS);
        gtk_text_buffer_get_iter_at_offset (buffer, &invisible_end, 
                                            INVISIBLE_END_POS);
        invisible_tag = gtk_text_buffer_create_tag (buffer, "invisible-tag", 
                                                    "invisible", TRUE, NULL);
        gtk_text_buffer_apply_tag (buffer, invisible_tag, 
                                   &invisible_start, &invisible_end);
    }
    */
    
    if (LIMIT_OFFSET >= 0)
    {
        res = gtk_text_iter_backward_search (&iter, str, FLAGS, &match_start, &match_end, &limit);
    } else {
        res = gtk_text_iter_backward_search (&iter, str, FLAGS, &match_start, &match_end, NULL);
    }
    
    if (res != CORRECT_RESULT)
    {
        TEST_FAIL ("gtk_text_iter_backward_search() returned %d, should return %d", res, CORRECT_RESULT);
    }
    
    /* this 'if' is to avoid segving if res != CORRECT_RESULT */
    if (res == CORRECT_RESULT)
    {
        if (CORRECT_MATCH_START_OFFSET >= 0)
        {
            match_start_offset = gtk_text_iter_get_offset (&match_start);
            if (match_start_offset != CORRECT_MATCH_START_OFFSET)
            {
                TEST_FAIL ("match_start_offset is %d, should be %d", 
                           match_start_offset, CORRECT_MATCH_START_OFFSET);
            }
            
            match_end_offset = gtk_text_iter_get_offset (&match_end);
            if (match_end_offset != CORRECT_MATCH_END_OFFSET)
            {
                TEST_FAIL ("match_end_offset is %d, should be %d", 
                           match_end_offset, CORRECT_MATCH_END_OFFSET);
            }
        }
    
        if (CORRECT_0XFFFC_POS >= 0)
        {
            GtkTextIter fffc_iter;
            gtk_text_buffer_get_iter_at_offset (buffer, &fffc_iter, 
                                                CORRECT_0XFFFC_POS);
            
            if (gtk_text_iter_get_char(&fffc_iter) != 0xFFFC)
            {
                TEST_FAIL ("symbol at the pos %d should be 0xFFFC", 
                           CORRECT_0XFFFC_POS);
            }
        }
    }
    
    #undef TEST_LINE
    #undef OFFSET
    #undef STR
    #undef FLAGS
    #undef LIMIT_OFFSET
    #undef INVISIBLE_START_POS
    #undef INVISIBLE_END_POS
    #undef CORRECT_RESULT
    #undef CORRECT_MATCH_START_OFFSET
    #undef CORRECT_MATCH_END_OFFSET
    #undef CORRECT_0XFFFC_POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_889()
{
    #define TEST_LINE  "Sentence 1"
    #define LINE  0
    #define OFFS  3
    #define LINE1 0
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_890()
{
    #define TEST_LINE  "Sentence 1. Sentence2"
    #define LINE  0
    #define OFFS  0
    #define LINE1 0
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_891()
{
    #define TEST_LINE  "Sentence 1. Sentence2"
    #define LINE  1
    #define OFFS  3
    #define LINE1 1
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_892()
{
    #define TEST_LINE  "Sentence 1.\nSentence2"
    #define LINE  1
    #define OFFS  8
    #define LINE1 1
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_893()
{
    #define TEST_LINE  "Sentence 1 Sentence2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_894()
{
    #define TEST_LINE  "Sentence 1.Sentence2"
    #define LINE  0
    #define OFFS  15
    #define LINE1 0
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_895()
{
    #define TEST_LINE  "Sentence 1;Sentence2"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_896()
{
    #define TEST_LINE  "Sentence 1-Sentence2"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_897()
{
    #define TEST_LINE  "Sentence 1:Sentence2"
    #define LINE  0
    #define OFFS  15
    #define LINE1 0
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_898()
{
    #define TEST_LINE  "Sentence 1\"Sentence2"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_899()
{
    #define TEST_LINE  "Sentence 1,Sentence2"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_900()
{
    #define TEST_LINE  "Sentence 1! Sentence2"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 12
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_901()
{
    #define TEST_LINE  "Sentence 1!\nSentence2"
    #define LINE  1
    #define OFFS  5
    #define LINE1 1
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_902()
{
    #define TEST_LINE  "Sentence 1!Sentence2! "
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 11
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_903()
{
    #define TEST_LINE  "Sentence 1!Sentence2!\n"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 11
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_904()
{
    #define TEST_LINE  "Sentence 1!Sentence2!"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 11
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_905()
{
    #define TEST_LINE  "Sentence 1... Sentence2"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 14
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_906()
{
    #define TEST_LINE  "Sentence 1...\nSentence2"
    #define LINE  1
    #define OFFS  5
    #define LINE1 1
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_907()
{
    #define TEST_LINE  "Sentence 1... Sentence2"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 14
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_908()
{
    #define TEST_LINE  "Sentence 1? Sentence2"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 12
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_909()
{
    #define TEST_LINE  "Sentence 1?! Sentence2"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 13
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_910()
{
    #define TEST_LINE  "Sentence \none!"
    #define LINE  0
    #define OFFS  5
    #define LINE1 0
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous sentence start; if iter is already at the start of a sentence, moves backward to the next one
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_911()
{
    #define TEST_LINE  "Sentence\n one!"
    #define LINE  1
    #define OFFS  5
    #define LINE1 1
    #define OFFS1 1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_sentence_start() up to count times, or until it returns FALSE
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward instead of backward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_912()
{
    #define TEST_LINE  "Sentence 1. Sentence2. Sentence3"
    #define LINE  0
    #define OFFS  30
    #define LINE1 0
    #define OFFS1 12
    #define COUNT 2
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_sentence_start() up to count times, or until it returns FALSE
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward instead of backward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_913()
{
    #define TEST_LINE  "Sentence 1, Sentence2?! Sentence3"
    #define LINE  0
    #define OFFS  30
    #define LINE1 0
    #define OFFS1 24
    #define COUNT 1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_sentence_start() up to count times, or until it returns FALSE
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward instead of backward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_914()
{
    #define TEST_LINE  "Sentence 1; Sentence2! Sentence3"
    #define LINE  0
    #define OFFS  30
    #define LINE1 0
    #define OFFS1 23
    #define COUNT 1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_sentence_start() up to count times, or until it returns FALSE
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward instead of backward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_915()
{
    #define TEST_LINE  "Sentence 1? Sentence2! Sentence3"
    #define LINE  0
    #define OFFS  0
    #define LINE1 0
    #define OFFS1 11
    #define COUNT -1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_sentence_start() up to count times, or until it returns FALSE
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward instead of backward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_916()
{
    #define TEST_LINE  "Sentence 1. Sentence2. Sentence3"
    #define LINE  0
    #define OFFS  0
    #define LINE1 0
    #define OFFS1 22
    #define COUNT -2
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_sentence_start() up to count times, or until it returns FALSE
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward instead of backward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_917()
{
    #define TEST_LINE  "Sentence 1.\nSentence2"
    #define LINE  0
    #define OFFS  0
    #define LINE1 0
    #define OFFS1 11
    #define COUNT -1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_sentence_start() up to count times, or until it returns FALSE
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward instead of backward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_918()
{
    #define TEST_LINE  "Sentence 1 Sentence2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 0
    #define COUNT 1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_sentence_start() up to count times, or until it returns FALSE
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_sentence_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves forward instead of backward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_919()
{
    #define TEST_LINE  "Sentence 1.Sentence2"
    #define LINE  0
    #define OFFS  15
    #define LINE1 0
    #define OFFS1 0
    #define COUNT 1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_sentence_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_sentence_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_920()
{
    #define TEST_LINE  "Sentence 1"
    #define LINE  0
    #define OFFS  3
    #define LINE1 0
    #define OFFS1 10
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_921()
{
    #define TEST_LINE  "Sentence 1. Sentence2"
    #define LINE  0
    #define OFFS  0
    #define LINE1 0
    #define OFFS1 11
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_922()
{
    #define TEST_LINE  "Sentence 1.\nSentence2"
    #define LINE  1
    #define OFFS  8
    #define LINE1 1
    #define OFFS1 9
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_923()
{
    #define TEST_LINE  "Sentence 1 Sentence2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 20
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_924()
{
    #define TEST_LINE  "Sentence 1.Sentence2"
    #define LINE  0
    #define OFFS  15
    #define LINE1 0
    #define OFFS1 20
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_925()
{
    #define TEST_LINE  "Sentence 1;Sentence2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 20
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_926()
{
    #define TEST_LINE  "Sentence 1-Sentence2"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 20
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_927()
{
    #define TEST_LINE  "Sentence 1:Sentence2"
    #define LINE  0
    #define OFFS  15
    #define LINE1 0
    #define OFFS1 20
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_928()
{
    #define TEST_LINE  "Sentence 1\"Sentence2"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 20
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_929()
{
    #define TEST_LINE  "Sentence 1,Sentence2"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 20
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_930()
{
    #define TEST_LINE  "Sentence 1! Sentence2"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 21
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_931()
{
    #define TEST_LINE  "Sentence 1!\nSentence2"
    #define LINE  1
    #define OFFS  5
    #define LINE1 1
    #define OFFS1 9
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_932()
{
    #define TEST_LINE  "Sentence 1!Sentence2! "
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 21
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_933()
{
    #define TEST_LINE  "Sentence 1!Sentence2!\n"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 21
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_934()
{
    #define TEST_LINE  "Sentence 1!Sentence2!"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 21
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_935()
{
    #define TEST_LINE  "Sentence 1... Sentence2"
    #define LINE  0
    #define OFFS  0
    #define LINE1 0
    #define OFFS1 13
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_936()
{
    #define TEST_LINE  "Sentence 1...\nSentence2"
    #define LINE  1
    #define OFFS  5
    #define LINE1 1
    #define OFFS1 9
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_937()
{
    #define TEST_LINE  "Sentence 1... Sentence2"
    #define LINE  0
    #define OFFS  20
    #define LINE1 0
    #define OFFS1 23
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_938()
{
    #define TEST_LINE  "Sentence 1? Sentence2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 11
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_939()
{
    #define TEST_LINE  "Sentence 1?! Sentence2"
    #define LINE  0
    #define OFFS  11
    #define LINE1 0
    #define OFFS1 12
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_940()
{
    #define TEST_LINE  "Sentence \none!"
    #define LINE  0
    #define OFFS  5
    #define LINE1 0
    #define OFFS1 9
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is at the end of a sentence, moves to the next end of sentence.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next sentence end
 * 
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_941()
{
    #define TEST_LINE  "Sentence\n one!"
    #define LINE  1
    #define OFFS  5
    #define LINE1 1
    #define OFFS1 5
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_sentence_end() count times (or until gtk_text_iter_forward_sentence_end() returns FALSE)
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves backward instead of forward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_942()
{
    #define TEST_LINE  "Sentence 1. Sentence2. Sentence3"
    #define LINE  0
    #define OFFS  30
    #define LINE1 0
    #define OFFS1 12
    #define COUNT -2
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_sentence_end() count times (or until gtk_text_iter_forward_sentence_end() returns FALSE)
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves backward instead of forward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_943()
{
    #define TEST_LINE  "Sentence 1, Sentence2?! Sentence3"
    #define LINE  0
    #define OFFS  30
    #define LINE1 0
    #define OFFS1 24
    #define COUNT -1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_sentence_end() count times (or until gtk_text_iter_forward_sentence_end() returns FALSE)
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves backward instead of forward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_944()
{
    #define TEST_LINE  "Sentence 1; Sentence2! Sentence3"
    #define LINE  0
    #define OFFS  30
    #define LINE1 0
    #define OFFS1 23
    #define COUNT -1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_sentence_end() count times (or until gtk_text_iter_forward_sentence_end() returns FALSE)
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves backward instead of forward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_945()
{
    #define TEST_LINE  "Sentence 1? Sentence2! Sentence3"
    #define LINE  0
    #define OFFS  0
    #define LINE1 0
    #define OFFS1 11
    #define COUNT 1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_sentence_end() count times (or until gtk_text_iter_forward_sentence_end() returns FALSE)
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves backward instead of forward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_946()
{
    #define TEST_LINE  "Sentence 1. Sentence2. Sentence3"
    #define LINE  0
    #define OFFS  0
    #define LINE1 0
    #define OFFS1 22
    #define COUNT 2
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_sentence_end() count times (or until gtk_text_iter_forward_sentence_end() returns FALSE)
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves backward instead of forward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_947()
{
    #define TEST_LINE  "Sentence 1.\nSentence2"
    #define LINE  0
    #define OFFS  0
    #define LINE1 0
    #define OFFS1 11
    #define COUNT 1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_sentence_end() count times (or until gtk_text_iter_forward_sentence_end() returns FALSE)
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves backward instead of forward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_948()
{
    #define TEST_LINE  "Sentence 1 Sentence2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 0
    #define COUNT -1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_sentence_end() count times (or until gtk_text_iter_forward_sentence_end() returns FALSE)
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_sentence_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: If count is negative, moves backward instead of forward
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_949()
{
    #define TEST_LINE  "Sentence1.Sentence2"
    #define LINE  0
    #define OFFS  15
    #define LINE1 0
    #define OFFS1 0
    #define COUNT -1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_sentence_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_sentence_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_950()
{
    #define TEST_LINE  "Word1 Word2"
    #define LINE  0
    #define OFFS  8
    #define LINE1 0
    #define OFFS1 6
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_951()
{
    #define TEST_LINE  "Word1 Word2"
    #define LINE  0
    #define OFFS  5
    #define LINE1 0
    #define OFFS1 4
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_952()
{
    #define TEST_LINE  "Word1. Word2"
    #define LINE  0
    #define OFFS  0
    #define LINE1 0
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_953()
{
    #define TEST_LINE  "Word1. Word2"
    #define LINE  0
    #define OFFS  4
    #define LINE1 0
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_954()
{
    #define TEST_LINE  "Word1.\nWord2"
    #define LINE  1
    #define OFFS  4
    #define LINE1 1
    #define OFFS1 0
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_955()
{
    #define TEST_LINE  "Word 1 Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 7
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_956()
{
    #define TEST_LINE  "Word 1.Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 7
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_957()
{
    #define TEST_LINE  "Word 1;Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 7
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_958()
{
    #define TEST_LINE  "Word 1-Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 7
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_959()
{
    #define TEST_LINE  "Word 1:Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 7
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_960()
{
    #define TEST_LINE  "Word 1!Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 7
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_961()
{
    #define TEST_LINE  "Word 1\"Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 7
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_962()
{
    #define TEST_LINE  "Word 1! Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 8
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_963()
{
    #define TEST_LINE  "Word 1!\nWord2"
    #define LINE  1
    #define OFFS  5
    #define LINE1 1
    #define OFFS1 4
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word start, moves backward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_backward_word_start
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves backward to the previous word start
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_964()
{
    #define TEST_LINE  "Word 1!Word2! "
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 7
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_start (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_start' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_word_start() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_965()
{
    #define TEST_LINE  "Word. Word. Word"
    #define LINE  0
    #define OFFS  15
    #define LINE1 0
    #define OFFS1 6
    #define COUNT 2
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_word_start() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_966()
{
    #define TEST_LINE  "Word. Word. Word"
    #define LINE  0
    #define OFFS  15
    #define LINE1 0
    #define OFFS1 0
    #define COUNT 3
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_word_start() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_967()
{
    #define TEST_LINE  "Word, Word?! Word"
    #define LINE  0
    #define OFFS  5
    #define LINE1 0
    #define OFFS1 0
    #define COUNT 1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_word_start() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_968()
{
    #define TEST_LINE  "Word 1; Word2! Word3"
    #define LINE  0
    #define OFFS  18
    #define LINE1 0
    #define OFFS1 12
    #define COUNT 2
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_word_start() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_969()
{
    #define TEST_LINE  "Word 1?\n Word2!\n Word3"
    #define LINE  2
    #define OFFS  1
    #define LINE1 1
    #define OFFS1 5
    #define COUNT 1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_word_start() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_970()
{
    #define TEST_LINE  "Word 1?\n Word2!\n Word3"
    #define LINE  2
    #define OFFS  1
    #define LINE1 1
    #define OFFS1 1
    #define COUNT 2
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_backward_word_starts
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_backward_word_start() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_971()
{
    #define TEST_LINE  "Word 1?\n Word2!\n Word3"
    #define LINE  2
    #define OFFS  1
    #define LINE1 0
    #define OFFS1 5
    #define COUNT 3
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_backward_word_starts (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_backward_word_starts' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_972()
{
    #define TEST_LINE  "Word 1"
    #define LINE  0
    #define OFFS  3
    #define LINE1 0
    #define OFFS1 4
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_973()
{
    #define TEST_LINE  "Word 1. Word2"
    #define LINE  0
    #define OFFS  0
    #define LINE1 0
    #define OFFS1 4
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_974()
{
    #define TEST_LINE  "Word 1.\nWord2"
    #define LINE  1
    #define OFFS  0
    #define LINE1 1
    #define OFFS1 4
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_975()
{
    #define TEST_LINE  "Word 1 Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 11
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_976()
{
    #define TEST_LINE  "Word 1.Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 11
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_977()
{
    #define TEST_LINE  "Word 1-Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 11
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_978()
{
    #define TEST_LINE  "Word 1:Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 11
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_979()
{
    #define TEST_LINE  "Word 1\"Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 11
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_980()
{
    #define TEST_LINE  "Word 1,Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 11
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_981()
{
    #define TEST_LINE  "Word 1! Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 12
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_982()
{
    #define TEST_LINE  "Word 1!\nWord2"
    #define LINE  0
    #define OFFS  5
    #define LINE1 0
    #define OFFS1 6
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_983()
{
    #define TEST_LINE  "Word 1!Word2! "
    #define LINE  0
    #define OFFS  5
    #define LINE1 0
    #define OFFS1 6
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_984()
{
    #define TEST_LINE  "Word 1!Word2! "
    #define LINE  0
    #define OFFS  6
    #define LINE1 0
    #define OFFS1 11
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_985()
{
    #define TEST_LINE  "Word 1... Word2"
    #define LINE  0
    #define OFFS  5
    #define LINE1 0
    #define OFFS1 6
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_986()
{
    #define TEST_LINE  "Word 1...\nWord2"
    #define LINE  1
    #define OFFS  4
    #define LINE1 1
    #define OFFS1 5
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_987()
{
    #define TEST_LINE  "Word 1?! Word2"
    #define LINE  0
    #define OFFS  5
    #define LINE1 0
    #define OFFS1 6
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_988()
{
    #define TEST_LINE  "Word \none!"
    #define LINE  0
    #define OFFS  5
    #define LINE1 1
    #define OFFS1 3
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: Moves forward to the next word end
 * Params Values: GtkTextIter* iter
 * Expected: gboolean
 * 
 * Name: gtk_text_iter_forward_word_end
 * Params: GtkTextIter* iter
 * Returns: gboolean
 * Assertion: (If iter is currently on a word end, moves forward to the next one after that.)
 * Params Values: GtkTextIter* iter
 * Expected: gboolean  
 */
static void test_purpose_989()
{
    #define TEST_LINE  "Word\n one!"
    #define LINE  1
    #define OFFS  4
    #define LINE1 1
    #define OFFS1 5
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_end (&iter);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_end' moved iterator incorrectly\n'%s'\niter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_word_end() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_990()
{
    #define TEST_LINE  "Word 1. Word2. Word3"
    #define LINE  0
    #define OFFS  0
    #define LINE1 0
    #define OFFS1 6
    #define COUNT 2
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_word_end() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_991()
{
    #define TEST_LINE  "Word 1, Word2?! Word3"
    #define LINE  0
    #define OFFS  0
    #define LINE1 0
    #define OFFS1 20
    #define COUNT 5
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_word_end() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_992()
{
    #define TEST_LINE  "Word 1; Word2! Word3"
    #define LINE  0
    #define OFFS  5
    #define LINE1 0
    #define OFFS1 6
    #define COUNT 1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_word_end() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_993()
{
    #define TEST_LINE  "Word 1? Word2! Word3"
    #define LINE  0
    #define OFFS  5
    #define LINE1 0
    #define OFFS1 6
    #define COUNT 1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_word_end() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_994()
{
    #define TEST_LINE  "Word 1. Word2. Word3"
    #define LINE  0
    #define OFFS  0
    #define LINE1 0
    #define OFFS1 20
    #define COUNT 6
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_word_end() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_995()
{
    #define TEST_LINE  "Word 1.\nWord2"
    #define LINE  0
    #define OFFS  0
    #define LINE1 1
    #define OFFS1 4
    #define COUNT 3
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_word_end() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_996()
{
    #define TEST_LINE  "Word 1 Word2"
    #define LINE  0
    #define OFFS  10
    #define LINE1 0
    #define OFFS1 11
    #define COUNT 1
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_iter_forward_word_ends
 * Params: GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Calls gtk_text_iter_forward_word_end() up to count times
 * Params Values: GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_997()
{
    #define TEST_LINE  "Word1.Word2"
    #define LINE  0
    #define OFFS  3
    #define LINE1 0
    #define OFFS1 5
    #define COUNT 2
    
    GtkTextIter iter;
    GtkTextIter iter1;
    GtkTextBuffer* buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter, LINE, OFFS);
    gtk_text_buffer_get_iter_at_line_offset(buffer, &iter1, LINE1, OFFS1);
    
    gtk_text_iter_forward_word_ends (&iter, COUNT);
    if (gtk_text_iter_compare (&iter, &iter1))
    {
        TEST_FAIL ("'gtk_text_iter_forward_word_ends' moved iterator incorrectly\n'%s'\ncount = %i, iter = (%i, %i), should be (%i, %i)", 
                   TEST_LINE, COUNT,
                   gtk_text_iter_get_line (&iter), gtk_text_iter_get_line_offset (&iter),
                   gtk_text_iter_get_line (&iter1), gtk_text_iter_get_line_offset (&iter1) );
    }
    
    #undef TEST_LINE
    #undef LINE
    #undef OFFS
    #undef LINE1
    #undef OFFS1
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkTextIter ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {test_purpose_101, 1},
    {test_purpose_102, 1},
    {test_purpose_103, 1},
    {test_purpose_104, 1},
    {test_purpose_105, 1},
    {test_purpose_106, 1},
    {test_purpose_107, 1},
    {test_purpose_108, 1},
    {test_purpose_109, 1},
    {test_purpose_110, 1},
    {test_purpose_111, 1},
    {test_purpose_112, 1},
    {test_purpose_113, 1},
    {test_purpose_114, 1},
    {test_purpose_115, 1},
    {test_purpose_116, 1},
    {test_purpose_117, 1},
    {test_purpose_118, 1},
    {test_purpose_119, 1},
    {test_purpose_120, 1},
    {test_purpose_121, 1},
    {test_purpose_122, 1},
    {test_purpose_123, 1},
    {test_purpose_124, 1},
    {test_purpose_125, 1},
    {test_purpose_126, 1},
    {test_purpose_127, 1},
    {test_purpose_128, 1},
    {test_purpose_129, 1},
    {test_purpose_130, 1},
    {test_purpose_131, 1},
    {test_purpose_132, 1},
    {test_purpose_133, 1},
    {test_purpose_134, 1},
    {test_purpose_135, 1},
    {test_purpose_136, 1},
    {test_purpose_137, 1},
    {test_purpose_138, 1},
    {test_purpose_139, 1},
    {test_purpose_140, 1},
    {test_purpose_141, 1},
    {test_purpose_142, 1},
    {test_purpose_143, 1},
    {test_purpose_144, 1},
    {test_purpose_145, 1},
    {test_purpose_146, 1},
    {test_purpose_147, 1},
    {test_purpose_148, 1},
    {test_purpose_149, 1},
    {test_purpose_150, 1},
    {test_purpose_151, 1},
    {test_purpose_152, 1},
    {test_purpose_153, 1},
    {test_purpose_154, 1},
    {test_purpose_155, 1},
    {test_purpose_156, 1},
    {test_purpose_157, 1},
    {test_purpose_158, 1},
    {test_purpose_159, 1},
    {test_purpose_160, 1},
    {test_purpose_161, 1},
    {test_purpose_162, 1},
    {test_purpose_163, 1},
    {test_purpose_164, 1},
    {test_purpose_165, 1},
    {test_purpose_166, 1},
    {test_purpose_167, 1},
    {test_purpose_168, 1},
    {test_purpose_169, 1},
    {test_purpose_170, 1},
    {test_purpose_171, 1},
    {test_purpose_172, 1},
    {test_purpose_173, 1},
    {test_purpose_174, 1},
    {test_purpose_175, 1},
    {test_purpose_176, 1},
    {test_purpose_177, 1},
    {test_purpose_178, 1},
    {test_purpose_179, 1},
    {test_purpose_180, 1},
    {test_purpose_181, 1},
    {test_purpose_182, 1},
    {test_purpose_183, 1},
    {test_purpose_184, 1},
    {test_purpose_185, 1},
    {test_purpose_186, 1},
    {test_purpose_187, 1},
    {test_purpose_188, 1},
    {test_purpose_189, 1},
    {test_purpose_190, 1},
    {test_purpose_191, 1},
    {test_purpose_192, 1},
    {test_purpose_193, 1},
    {test_purpose_194, 1},
    {test_purpose_195, 1},
    {test_purpose_196, 1},
    {test_purpose_197, 1},
    {test_purpose_198, 1},
    {test_purpose_199, 1},
    {test_purpose_200, 1},
    {test_purpose_201, 1},
    {test_purpose_202, 1},
    {test_purpose_203, 1},
    {test_purpose_204, 1},
    {test_purpose_205, 1},
    {test_purpose_206, 1},
    {test_purpose_207, 1},
    {test_purpose_208, 1},
    {test_purpose_209, 1},
    {test_purpose_210, 1},
    {test_purpose_211, 1},
    {test_purpose_212, 1},
    {test_purpose_213, 1},
    {test_purpose_214, 1},
    {test_purpose_215, 1},
    {test_purpose_216, 1},
    {test_purpose_217, 1},
    {test_purpose_218, 1},
    {test_purpose_219, 1},
    {test_purpose_220, 1},
    {test_purpose_221, 1},
    {test_purpose_222, 1},
    {test_purpose_223, 1},
    {test_purpose_224, 1},
    {test_purpose_225, 1},
    {test_purpose_226, 1},
    {test_purpose_227, 1},
    {test_purpose_228, 1},
    {test_purpose_229, 1},
    {test_purpose_230, 1},
    {test_purpose_231, 1},
    {test_purpose_232, 1},
    {test_purpose_233, 1},
    {test_purpose_234, 1},
    {test_purpose_235, 1},
    {test_purpose_236, 1},
    {test_purpose_237, 1},
    {test_purpose_238, 1},
    {test_purpose_239, 1},
    {test_purpose_240, 1},
    {test_purpose_241, 1},
    {test_purpose_242, 1},
    {test_purpose_243, 1},
    {test_purpose_244, 1},
    {test_purpose_245, 1},
    {test_purpose_246, 1},
    {test_purpose_247, 1},
    {test_purpose_248, 1},
    {test_purpose_249, 1},
    {test_purpose_250, 1},
    {test_purpose_251, 1},
    {test_purpose_252, 1},
    {test_purpose_253, 1},
    {test_purpose_254, 1},
    {test_purpose_255, 1},
    {test_purpose_256, 1},
    {test_purpose_257, 1},
    {test_purpose_258, 1},
    {test_purpose_259, 1},
    {test_purpose_260, 1},
    {test_purpose_261, 1},
    {test_purpose_262, 1},
    {test_purpose_263, 1},
    {test_purpose_264, 1},
    {test_purpose_265, 1},
    {test_purpose_266, 1},
    {test_purpose_267, 1},
    {test_purpose_268, 1},
    {test_purpose_269, 1},
    {test_purpose_270, 1},
    {test_purpose_271, 1},
    {test_purpose_272, 1},
    {test_purpose_273, 1},
    {test_purpose_274, 1},
    {test_purpose_275, 1},
    {test_purpose_276, 1},
    {test_purpose_277, 1},
    {test_purpose_278, 1},
    {test_purpose_279, 1},
    {test_purpose_280, 1},
    {test_purpose_281, 1},
    {test_purpose_282, 1},
    {test_purpose_283, 1},
    {test_purpose_284, 1},
    {test_purpose_285, 1},
    {test_purpose_286, 1},
    {test_purpose_287, 1},
    {test_purpose_288, 1},
    {test_purpose_289, 1},
    {test_purpose_290, 1},
    {test_purpose_291, 1},
    {test_purpose_292, 1},
    {test_purpose_293, 1},
    {test_purpose_294, 1},
    {test_purpose_295, 1},
    {test_purpose_296, 1},
    {test_purpose_297, 1},
    {test_purpose_298, 1},
    {test_purpose_299, 1},
    {test_purpose_300, 1},
    {test_purpose_301, 1},
    {test_purpose_302, 1},
    {test_purpose_303, 1},
    {test_purpose_304, 1},
    {test_purpose_305, 1},
    {test_purpose_306, 1},
    {test_purpose_307, 1},
    {test_purpose_308, 1},
    {test_purpose_309, 1},
    {test_purpose_310, 1},
    {test_purpose_311, 1},
    {test_purpose_312, 1},
    {test_purpose_313, 1},
    {test_purpose_314, 1},
    {test_purpose_315, 1},
    {test_purpose_316, 1},
    {test_purpose_317, 1},
    {test_purpose_318, 1},
    {test_purpose_319, 1},
    {test_purpose_320, 1},
    {test_purpose_321, 1},
    {test_purpose_322, 1},
    {test_purpose_323, 1},
    {test_purpose_324, 1},
    {test_purpose_325, 1},
    {test_purpose_326, 1},
    {test_purpose_327, 1},
    {test_purpose_328, 1},
    {test_purpose_329, 1},
    {test_purpose_330, 1},
    {test_purpose_331, 1},
    {test_purpose_332, 1},
    {test_purpose_333, 1},
    {test_purpose_334, 1},
    {test_purpose_335, 1},
    {test_purpose_336, 1},
    {test_purpose_337, 1},
    {test_purpose_338, 1},
    {test_purpose_339, 1},
    {test_purpose_340, 1},
    {test_purpose_341, 1},
    {test_purpose_342, 1},
    {test_purpose_343, 1},
    {test_purpose_344, 1},
    {test_purpose_345, 1},
    {test_purpose_346, 1},
    {test_purpose_347, 1},
    {test_purpose_348, 1},
    {test_purpose_349, 1},
    {test_purpose_350, 1},
    {test_purpose_351, 1},
    {test_purpose_352, 1},
    {test_purpose_353, 1},
    {test_purpose_354, 1},
    {test_purpose_355, 1},
    {test_purpose_356, 1},
    {test_purpose_357, 1},
    {test_purpose_358, 1},
    {test_purpose_359, 1},
    {test_purpose_360, 1},
    {test_purpose_361, 1},
    {test_purpose_362, 1},
    {test_purpose_363, 1},
    {test_purpose_364, 1},
    {test_purpose_365, 1},
    {test_purpose_366, 1},
    {test_purpose_367, 1},
    {test_purpose_368, 1},
    {test_purpose_369, 1},
    {test_purpose_370, 1},
    {test_purpose_371, 1},
    {test_purpose_372, 1},
    {test_purpose_373, 1},
    {test_purpose_374, 1},
    {test_purpose_375, 1},
    {test_purpose_376, 1},
    {test_purpose_377, 1},
    {test_purpose_378, 1},
    {test_purpose_379, 1},
    {test_purpose_380, 1},
    {test_purpose_381, 1},
    {test_purpose_382, 1},
    {test_purpose_383, 1},
    {test_purpose_384, 1},
    {test_purpose_385, 1},
    {test_purpose_386, 1},
    {test_purpose_387, 1},
    {test_purpose_388, 1},
    {test_purpose_389, 1},
    {test_purpose_390, 1},
    {test_purpose_391, 1},
    {test_purpose_392, 1},
    {test_purpose_393, 1},
    {test_purpose_394, 1},
    {test_purpose_395, 1},
    {test_purpose_396, 1},
    {test_purpose_397, 1},
    {test_purpose_398, 1},
    {test_purpose_399, 1},
    {test_purpose_400, 1},
    {test_purpose_401, 1},
    {test_purpose_402, 1},
    {test_purpose_403, 1},
    {test_purpose_404, 1},
    {test_purpose_405, 1},
    {test_purpose_406, 1},
    {test_purpose_407, 1},
    {test_purpose_408, 1},
    {test_purpose_409, 1},
    {test_purpose_410, 1},
    {test_purpose_411, 1},
    {test_purpose_412, 1},
    {test_purpose_413, 1},
    {test_purpose_414, 1},
    {test_purpose_415, 1},
    {test_purpose_416, 1},
    {test_purpose_417, 1},
    {test_purpose_418, 1},
    {test_purpose_419, 1},
    {test_purpose_420, 1},
    {test_purpose_421, 1},
    {test_purpose_422, 1},
    {test_purpose_423, 1},
    {test_purpose_424, 1},
    {test_purpose_425, 1},
    {test_purpose_426, 1},
    {test_purpose_427, 1},
    {test_purpose_428, 1},
    {test_purpose_429, 1},
    {test_purpose_430, 1},
    {test_purpose_431, 1},
    {test_purpose_432, 1},
    {test_purpose_433, 1},
    {test_purpose_434, 1},
    {test_purpose_435, 1},
    {test_purpose_436, 1},
    {test_purpose_437, 1},
    {test_purpose_438, 1},
    {test_purpose_439, 1},
    {test_purpose_440, 1},
    {test_purpose_441, 1},
    {test_purpose_442, 1},
    {test_purpose_443, 1},
    {test_purpose_444, 1},
    {test_purpose_445, 1},
    {test_purpose_446, 1},
    {test_purpose_447, 1},
    {test_purpose_448, 1},
    {test_purpose_449, 1},
    {test_purpose_450, 1},
    {test_purpose_451, 1},
    {test_purpose_452, 1},
    {test_purpose_453, 1},
    {test_purpose_454, 1},
    {test_purpose_455, 1},
    {test_purpose_456, 1},
    {test_purpose_457, 1},
    {test_purpose_458, 1},
    {test_purpose_459, 1},
    {test_purpose_460, 1},
    {test_purpose_461, 1},
    {test_purpose_462, 1},
    {test_purpose_463, 1},
    {test_purpose_464, 1},
    {test_purpose_465, 1},
    {test_purpose_466, 1},
    {test_purpose_467, 1},
    {test_purpose_468, 1},
    {test_purpose_469, 1},
    {test_purpose_470, 1},
    {test_purpose_471, 1},
    {test_purpose_472, 1},
    {test_purpose_473, 1},
    {test_purpose_474, 1},
    {test_purpose_475, 1},
    {test_purpose_476, 1},
    {test_purpose_477, 1},
    {test_purpose_478, 1},
    {test_purpose_479, 1},
    {test_purpose_480, 1},
    {test_purpose_481, 1},
    {test_purpose_482, 1},
    {test_purpose_483, 1},
    {test_purpose_484, 1},
    {test_purpose_485, 1},
    {test_purpose_486, 1},
    {test_purpose_487, 1},
    {test_purpose_488, 1},
    {test_purpose_489, 1},
    {test_purpose_490, 1},
    {test_purpose_491, 1},
    {test_purpose_492, 1},
    {test_purpose_493, 1},
    {test_purpose_494, 1},
    {test_purpose_495, 1},
    {test_purpose_496, 1},
    {test_purpose_497, 1},
    {test_purpose_498, 1},
    {test_purpose_499, 1},
    {test_purpose_500, 1},
    {test_purpose_501, 1},
    {test_purpose_502, 1},
    {test_purpose_503, 1},
    {test_purpose_504, 1},
    {test_purpose_505, 1},
    {test_purpose_506, 1},
    {test_purpose_507, 1},
    {test_purpose_508, 1},
    {test_purpose_509, 1},
    {test_purpose_510, 1},
    {test_purpose_511, 1},
    {test_purpose_512, 1},
    {test_purpose_513, 1},
    {test_purpose_514, 1},
    {test_purpose_515, 1},
    {test_purpose_516, 1},
    {test_purpose_517, 1},
    {test_purpose_518, 1},
    {test_purpose_519, 1},
    {test_purpose_520, 1},
    {test_purpose_521, 1},
    {test_purpose_522, 1},
    {test_purpose_523, 1},
    {test_purpose_524, 1},
    {test_purpose_525, 1},
    {test_purpose_526, 1},
    {test_purpose_527, 1},
    {test_purpose_528, 1},
    {test_purpose_529, 1},
    {test_purpose_530, 1},
    {test_purpose_531, 1},
    {test_purpose_532, 1},
    {test_purpose_533, 1},
    {test_purpose_534, 1},
    {test_purpose_535, 1},
    {test_purpose_536, 1},
    {test_purpose_537, 1},
    {test_purpose_538, 1},
    {test_purpose_539, 1},
    {test_purpose_540, 1},
    {test_purpose_541, 1},
    {test_purpose_542, 1},
    {test_purpose_543, 1},
    {test_purpose_544, 1},
    {test_purpose_545, 1},
    {test_purpose_546, 1},
    {test_purpose_547, 1},
    {test_purpose_548, 1},
    {test_purpose_549, 1},
    {test_purpose_550, 1},
    {test_purpose_551, 1},
    {test_purpose_552, 1},
    {test_purpose_553, 1},
    {test_purpose_554, 1},
    {test_purpose_555, 1},
    {test_purpose_556, 1},
    {test_purpose_557, 1},
    {test_purpose_558, 1},
    {test_purpose_559, 1},
    {test_purpose_560, 1},
    {test_purpose_561, 1},
    {test_purpose_562, 1},
    {test_purpose_563, 1},
    {test_purpose_564, 1},
    {test_purpose_565, 1},
    {test_purpose_566, 1},
    {test_purpose_567, 1},
    {test_purpose_568, 1},
    {test_purpose_569, 1},
    {test_purpose_570, 1},
    {test_purpose_571, 1},
    {test_purpose_572, 1},
    {test_purpose_573, 1},
    {test_purpose_574, 1},
    {test_purpose_575, 1},
    {test_purpose_576, 1},
    {test_purpose_577, 1},
    {test_purpose_578, 1},
    {test_purpose_579, 1},
    {test_purpose_580, 1},
    {test_purpose_581, 1},
    {test_purpose_582, 1},
    {test_purpose_583, 1},
    {test_purpose_584, 1},
    {test_purpose_585, 1},
    {test_purpose_586, 1},
    {test_purpose_587, 1},
    {test_purpose_588, 1},
    {test_purpose_589, 1},
    {test_purpose_590, 1},
    {test_purpose_591, 1},
    {test_purpose_592, 1},
    {test_purpose_593, 1},
    {test_purpose_594, 1},
    {test_purpose_595, 1},
    {test_purpose_596, 1},
    {test_purpose_597, 1},
    {test_purpose_598, 1},
    {test_purpose_599, 1},
    {test_purpose_600, 1},
    {test_purpose_601, 1},
    {test_purpose_602, 1},
    {test_purpose_603, 1},
    {test_purpose_604, 1},
    {test_purpose_605, 1},
    {test_purpose_606, 1},
    {test_purpose_607, 1},
    {test_purpose_608, 1},
    {test_purpose_609, 1},
    {test_purpose_610, 1},
    {test_purpose_611, 1},
    {test_purpose_612, 1},
    {test_purpose_613, 1},
    {test_purpose_614, 1},
    {test_purpose_615, 1},
    {test_purpose_616, 1},
    {test_purpose_617, 1},
    {test_purpose_618, 1},
    {test_purpose_619, 1},
    {test_purpose_620, 1},
    {test_purpose_621, 1},
    {test_purpose_622, 1},
    {test_purpose_623, 1},
    {test_purpose_624, 1},
    {test_purpose_625, 1},
    {test_purpose_626, 1},
    {test_purpose_627, 1},
    {test_purpose_628, 1},
    {test_purpose_629, 1},
    {test_purpose_630, 1},
    {test_purpose_631, 1},
    {test_purpose_632, 1},
    {test_purpose_633, 1},
    {test_purpose_634, 1},
    {test_purpose_635, 1},
    {test_purpose_636, 1},
    {test_purpose_637, 1},
    {test_purpose_638, 1},
    {test_purpose_639, 1},
    {test_purpose_640, 1},
    {test_purpose_641, 1},
    {test_purpose_642, 1},
    {test_purpose_643, 1},
    {test_purpose_644, 1},
    {test_purpose_645, 1},
    {test_purpose_646, 1},
    {test_purpose_647, 1},
    {test_purpose_648, 1},
    {test_purpose_649, 1},
    {test_purpose_650, 1},
    {test_purpose_651, 1},
    {test_purpose_652, 1},
    {test_purpose_653, 1},
    {test_purpose_654, 1},
    {test_purpose_655, 1},
    {test_purpose_656, 1},
    {test_purpose_657, 1},
    {test_purpose_658, 1},
    {test_purpose_659, 1},
    {test_purpose_660, 1},
    {test_purpose_661, 1},
    {test_purpose_662, 1},
    {test_purpose_663, 1},
    {test_purpose_664, 1},
    {test_purpose_665, 1},
    {test_purpose_666, 1},
    {test_purpose_667, 1},
    {test_purpose_668, 1},
    {test_purpose_669, 1},
    {test_purpose_670, 1},
    {test_purpose_671, 1},
    {test_purpose_672, 1},
    {test_purpose_673, 1},
    {test_purpose_674, 1},
    {test_purpose_675, 1},
    {test_purpose_676, 1},
    {test_purpose_677, 1},
    {test_purpose_678, 1},
    {test_purpose_679, 1},
    {test_purpose_680, 1},
    {test_purpose_681, 1},
    {test_purpose_682, 1},
    {test_purpose_683, 1},
    {test_purpose_684, 1},
    {test_purpose_685, 1},
    {test_purpose_686, 1},
    {test_purpose_687, 1},
    {test_purpose_688, 1},
    {test_purpose_689, 1},
    {test_purpose_690, 1},
    {test_purpose_691, 1},
    {test_purpose_692, 1},
    {test_purpose_693, 1},
    {test_purpose_694, 1},
    {test_purpose_695, 1},
    {test_purpose_696, 1},
    {test_purpose_697, 1},
    {test_purpose_698, 1},
    {test_purpose_699, 1},
    {test_purpose_700, 1},
    {test_purpose_701, 1},
    {test_purpose_702, 1},
    {test_purpose_703, 1},
    {test_purpose_704, 1},
    {test_purpose_705, 1},
    {test_purpose_706, 1},
    {test_purpose_707, 1},
    {test_purpose_708, 1},
    {test_purpose_709, 1},
    {test_purpose_710, 1},
    {test_purpose_711, 1},
    {test_purpose_712, 1},
    {test_purpose_713, 1},
    {test_purpose_714, 1},
    {test_purpose_715, 1},
    {test_purpose_716, 1},
    {test_purpose_717, 1},
    {test_purpose_718, 1},
    {test_purpose_719, 1},
    {test_purpose_720, 1},
    {test_purpose_721, 1},
    {test_purpose_722, 1},
    {test_purpose_723, 1},
    {test_purpose_724, 1},
    {test_purpose_725, 1},
    {test_purpose_726, 1},
    {test_purpose_727, 1},
    {test_purpose_728, 1},
    {test_purpose_729, 1},
    {test_purpose_730, 1},
    {test_purpose_731, 1},
    {test_purpose_732, 1},
    {test_purpose_733, 1},
    {test_purpose_734, 1},
    {test_purpose_735, 1},
    {test_purpose_736, 1},
    {test_purpose_737, 1},
    {test_purpose_738, 1},
    {test_purpose_739, 1},
    {test_purpose_740, 1},
    {test_purpose_741, 1},
    {test_purpose_742, 1},
    {test_purpose_743, 1},
    {test_purpose_744, 1},
    {test_purpose_745, 1},
    {test_purpose_746, 1},
    {test_purpose_747, 1},
    {test_purpose_748, 1},
    {test_purpose_749, 1},
    {test_purpose_750, 1},
    {test_purpose_751, 1},
    {test_purpose_752, 1},
    {test_purpose_753, 1},
    {test_purpose_754, 1},
    {test_purpose_755, 1},
    {test_purpose_756, 1},
    {test_purpose_757, 1},
    {test_purpose_758, 1},
    {test_purpose_759, 1},
    {test_purpose_760, 1},
    {test_purpose_761, 1},
    {test_purpose_762, 1},
    {test_purpose_763, 1},
    {test_purpose_764, 1},
    {test_purpose_765, 1},
    {test_purpose_766, 1},
    {test_purpose_767, 1},
    {test_purpose_768, 1},
    {test_purpose_769, 1},
    {test_purpose_770, 1},
    {test_purpose_771, 1},
    {test_purpose_772, 1},
    {test_purpose_773, 1},
    {test_purpose_774, 1},
    {test_purpose_775, 1},
    {test_purpose_776, 1},
    {test_purpose_777, 1},
    {test_purpose_778, 1},
    {test_purpose_779, 1},
    {test_purpose_780, 1},
    {test_purpose_781, 1},
    {test_purpose_782, 1},
    {test_purpose_783, 1},
    {test_purpose_784, 1},
    {test_purpose_785, 1},
    {test_purpose_786, 1},
    {test_purpose_787, 1},
    {test_purpose_788, 1},
    {test_purpose_789, 1},
    {test_purpose_790, 1},
    {test_purpose_791, 1},
    {test_purpose_792, 1},
    {test_purpose_793, 1},
    {test_purpose_794, 1},
    {test_purpose_795, 1},
    {test_purpose_796, 1},
    {test_purpose_797, 1},
    {test_purpose_798, 1},
    {test_purpose_799, 1},
    {test_purpose_800, 1},
    {test_purpose_801, 1},
    {test_purpose_802, 1},
    {test_purpose_803, 1},
    {test_purpose_804, 1},
    {test_purpose_805, 1},
    {test_purpose_806, 1},
    {test_purpose_807, 1},
    {test_purpose_808, 1},
    {test_purpose_809, 1},
    {test_purpose_810, 1},
    {test_purpose_811, 1},
    {test_purpose_812, 1},
    {test_purpose_813, 1},
    {test_purpose_814, 1},
    {test_purpose_815, 1},
    {test_purpose_816, 1},
    {test_purpose_817, 1},
    {test_purpose_818, 1},
    {test_purpose_819, 1},
    {test_purpose_820, 1},
    {test_purpose_821, 1},
    {test_purpose_822, 1},
    {test_purpose_823, 1},
    {test_purpose_824, 1},
    {test_purpose_825, 1},
    {test_purpose_826, 1},
    {test_purpose_827, 1},
    {test_purpose_828, 1},
    {test_purpose_829, 1},
    {test_purpose_830, 1},
    {test_purpose_831, 1},
    {test_purpose_832, 1},
    {test_purpose_833, 1},
    {test_purpose_834, 1},
    {test_purpose_835, 1},
    {test_purpose_836, 1},
    {test_purpose_837, 1},
    {test_purpose_838, 1},
    {test_purpose_839, 1},
    {test_purpose_840, 1},
    {test_purpose_841, 1},
    {test_purpose_842, 1},
    {test_purpose_843, 1},
    {test_purpose_844, 1},
    {test_purpose_845, 1},
    {test_purpose_846, 1},
    {test_purpose_847, 1},
    {test_purpose_848, 1},
    {test_purpose_849, 1},
    {test_purpose_850, 1},
    {test_purpose_851, 1},
    {test_purpose_852, 1},
    {test_purpose_853, 1},
    {test_purpose_854, 1},
    {test_purpose_855, 1},
    {test_purpose_856, 1},
    {test_purpose_857, 1},
    {test_purpose_858, 1},
    {test_purpose_859, 1},
    {test_purpose_860, 1},
    {test_purpose_861, 1},
    {test_purpose_862, 1},
    {test_purpose_863, 1},
    {test_purpose_864, 1},
    {test_purpose_865, 1},
    {test_purpose_866, 1},
    {test_purpose_867, 1},
    {test_purpose_868, 1},
    {test_purpose_869, 1},
    {test_purpose_870, 1},
    {test_purpose_871, 1},
    {test_purpose_872, 1},
    {test_purpose_873, 1},
    {test_purpose_874, 1},
    {test_purpose_875, 1},
    {test_purpose_876, 1},
    {test_purpose_877, 1},
    {test_purpose_878, 1},
    {test_purpose_879, 1},
    {test_purpose_880, 1},
    {test_purpose_881, 1},
    {test_purpose_882, 1},
    {test_purpose_883, 1},
    {test_purpose_884, 1},
    {test_purpose_885, 1},
    {test_purpose_886, 1},
    {test_purpose_887, 1},
    {test_purpose_888, 1},
    {test_purpose_889, 1},
    {test_purpose_890, 1},
    {test_purpose_891, 1},
    {test_purpose_892, 1},
    {test_purpose_893, 1},
    {test_purpose_894, 1},
    {test_purpose_895, 1},
    {test_purpose_896, 1},
    {test_purpose_897, 1},
    {test_purpose_898, 1},
    {test_purpose_899, 1},
    {test_purpose_900, 1},
    {test_purpose_901, 1},
    {test_purpose_902, 1},
    {test_purpose_903, 1},
    {test_purpose_904, 1},
    {test_purpose_905, 1},
    {test_purpose_906, 1},
    {test_purpose_907, 1},
    {test_purpose_908, 1},
    {test_purpose_909, 1},
    {test_purpose_910, 1},
    {test_purpose_911, 1},
    {test_purpose_912, 1},
    {test_purpose_913, 1},
    {test_purpose_914, 1},
    {test_purpose_915, 1},
    {test_purpose_916, 1},
    {test_purpose_917, 1},
    {test_purpose_918, 1},
    {test_purpose_919, 1},
    {test_purpose_920, 1},
    {test_purpose_921, 1},
    {test_purpose_922, 1},
    {test_purpose_923, 1},
    {test_purpose_924, 1},
    {test_purpose_925, 1},
    {test_purpose_926, 1},
    {test_purpose_927, 1},
    {test_purpose_928, 1},
    {test_purpose_929, 1},
    {test_purpose_930, 1},
    {test_purpose_931, 1},
    {test_purpose_932, 1},
    {test_purpose_933, 1},
    {test_purpose_934, 1},
    {test_purpose_935, 1},
    {test_purpose_936, 1},
    {test_purpose_937, 1},
    {test_purpose_938, 1},
    {test_purpose_939, 1},
    {test_purpose_940, 1},
    {test_purpose_941, 1},
    {test_purpose_942, 1},
    {test_purpose_943, 1},
    {test_purpose_944, 1},
    {test_purpose_945, 1},
    {test_purpose_946, 1},
    {test_purpose_947, 1},
    {test_purpose_948, 1},
    {test_purpose_949, 1},
    {test_purpose_950, 1},
    {test_purpose_951, 1},
    {test_purpose_952, 1},
    {test_purpose_953, 1},
    {test_purpose_954, 1},
    {test_purpose_955, 1},
    {test_purpose_956, 1},
    {test_purpose_957, 1},
    {test_purpose_958, 1},
    {test_purpose_959, 1},
    {test_purpose_960, 1},
    {test_purpose_961, 1},
    {test_purpose_962, 1},
    {test_purpose_963, 1},
    {test_purpose_964, 1},
    {test_purpose_965, 1},
    {test_purpose_966, 1},
    {test_purpose_967, 1},
    {test_purpose_968, 1},
    {test_purpose_969, 1},
    {test_purpose_970, 1},
    {test_purpose_971, 1},
    {test_purpose_972, 1},
    {test_purpose_973, 1},
    {test_purpose_974, 1},
    {test_purpose_975, 1},
    {test_purpose_976, 1},
    {test_purpose_977, 1},
    {test_purpose_978, 1},
    {test_purpose_979, 1},
    {test_purpose_980, 1},
    {test_purpose_981, 1},
    {test_purpose_982, 1},
    {test_purpose_983, 1},
    {test_purpose_984, 1},
    {test_purpose_985, 1},
    {test_purpose_986, 1},
    {test_purpose_987, 1},
    {test_purpose_988, 1},
    {test_purpose_989, 1},
    {test_purpose_990, 1},
    {test_purpose_991, 1},
    {test_purpose_992, 1},
    {test_purpose_993, 1},
    {test_purpose_994, 1},
    {test_purpose_995, 1},
    {test_purpose_996, 1},
    {test_purpose_997, 1},
    {NULL,0}
};
