/*
 * GtkWidget methods tests
 * Testing GtkWidget methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

static gboolean result;
static gint global_result;
va_list var_args;

void  
global_find (GtkWidget *widget, gpointer data)
{
    if (widget == data)
    {
        result = TRUE;
    }
}  


void  
global_show (GtkWidget *widget, gpointer data)
{
    result = TRUE;
}  


void  
global_realize_map (GtkWidget *widget, gpointer data)
{
    gboolean* res = data;
    *res = TRUE;
}  

void 
global_var_args_init (int prav_param, ...)
{
    va_start (var_args, prav_param);
}



void
global_set_result ()
{
    global_result++;
}  

void
global_accel_changed (GtkWidget *widget,gpointer user_data)
{
    global_result++;
}  


global_valist (GtkWidget* widget,const gchar* arg1, ...)
{
    va_list list;

    va_start (list, arg1);
    gtk_widget_style_get_valist (widget,arg1,list);
    va_end (list);
}


static unsigned char bits1[] = {
   0x01, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08};

static unsigned char bits2[] = {
   0x02, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08};

static unsigned char bits3[] = {
   0x03, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08};

static unsigned char bits4[] = {
   0x04, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08};



/*
 * Name:  gtk_widget_new
 * Params: GType type, const gchar *first_property_name, ...
 * Returns: GtkWidget*
 * Assertion: Equivalent to g_object_new(), but returns a widget so you don't have to cast the object yourself.'
 * Params Values: GTK_TYPE_LABEL, "label", "Hello World", "xalign", 0.0, NULL
 * Expected: GtkWidget*  
 */
static void test_purpose_1()
{
    #define    TYPE GTK_TYPE_LABEL
    #define    PROP "label", "Hello World", "xalign", 0.0, NULL
    
    GtkWidget* widget;
    gint x;
    gint y;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_widget_new (TYPE, PROP);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef  TYPE
    #undef  PROP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_new
 * Params: GType type, const gchar *first_property_name, ...
 * Returns: GtkWidget*
 * Assertion: Equivalent to g_object_new(), but returns a widget so you don't have to cast the object yourself.'
 * Params Values: GTK_TYPE_INVISIBLE, NULL
 * Expected: GtkWidget*  
 */
static void test_purpose_2()
{
    #define    TYPE GTK_TYPE_INVISIBLE
    #define    PROP NULL
    
    GtkWidget* widget;
    gint x;
    gint y;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_widget_new (TYPE, PROP);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef  TYPE
    #undef  PROP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_new
 * Params: GType type, const gchar *first_property_name, ...
 * Returns: GtkWidget*
 * Assertion: Equivalent to g_object_new(), but returns a widget so you don't have to cast the object yourself.'
 * Params Values: GTK_TYPE_CHECK_BUTTON, NULL
 * Expected: GtkWidget*  
 */
static void test_purpose_3()
{
    #define    TYPE GTK_TYPE_CHECK_BUTTON
    #define    PROP NULL
    
    GtkWidget* widget;
    gint x;
    gint y;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_widget_new (TYPE, PROP);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef  TYPE
    #undef  PROP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_new
 * Params: GType type, const gchar *first_property_name, ...
 * Returns: GtkWidget*
 * Assertion: For example you might write: gtk_widget_new (GTK_TYPE_LABEL, "label", "Hello World", "xalign", 0.0, NULL) to create a left-aligned label.
 * Params Values: GTK_TYPE_LABEL, "label", "Hello World", "xalign", 0.0, NULL
 * Expected: GtkWidget*  
 */
static void test_purpose_4()
{
    GtkWidget* widget;
    gfloat real_xalign;
    gfloat real_yalign;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_widget_new (GTK_TYPE_LABEL, "label", "Hello World", "xalign", 0.0, NULL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_LABEL (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_misc_get_alignment (GTK_MISC (widget), &real_xalign, &real_yalign);
    if (real_xalign != 0.0)
    {
        TEST_FAIL ("real_xalign = %f, should be %f", real_xalign, 0.0);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  TYPE
    #undef  PROP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_child_requisition 
 * Params: GtkWidget *widget, GtkRequisition *requisition
 * Returns: void
 * Assertion: Obtains widget->requisition, unless someone has forced a particular geometry on the widget (e.g. with gtk_widget_set_usize()), in which case it returns that geometry instead of the widget's requisition.'
 * Params Values: GtkWidget *widget, GtkRequisition *requisition
 * Expected: void  
 */
static void test_purpose_5()
{
    #define WIDGET gtk_vbox_new (TRUE, 10)
    #define CHILD gtk_button_new ()
    
    GtkWidget* widget;
    GtkWidget* window;
    GtkWidget* child;
    GtkRequisition requisition;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("toplevel window not created", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    gtk_widget_get_child_requisition (widget, &requisition);
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_child_requisition 
 * Params: GtkWidget *widget, GtkRequisition *requisition
 * Returns: void
 * Assertion: Obtains widget->requisition, unless someone has forced a particular geometry on the widget (e.g. with gtk_widget_set_usize()), in which case it returns that geometry instead of the widget's requisition.'
 * Params Values: GtkWidget *widget, GtkRequisition *requisition
 * Expected: void  
 */
static void test_purpose_6()
{
    #define WIDGET gtk_hbox_new (TRUE, 10)
    #define CHILD gtk_toggle_button_new ()
    
    GtkWidget* widget;
    GtkWidget* window;
    GtkWidget* child;
    GtkRequisition requisition;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("toplevel window not created", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    gtk_widget_get_child_requisition (widget, &requisition);
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_name
 * Params: GtkWidget *widget, const gchar *name
 * Returns: void
 * Assertion: Widgets can be named, which allows you to refer to them from a gtkrc file. 
 * Params Values: GtkWidget *widget,  "Text"
 * Expected: void  
 */
static void test_purpose_7()
{
    #define WIDGET gtk_button_new ()
    #define NAME "Text"
    
    GtkWidget* widget;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_name (widget, NAME);
    
    g_object_get (GTK_OBJECT (widget), "name", &name, NULL);
    
    if (NAME != NULL)
    {
        if (name == NULL)
        {
            TEST_FAIL ("name is NULL, should be", NAME);
    
        } else if (strcmp (name, (gchar*) NAME)) {
    
            TEST_FAIL ("name is %s, should be %s", name, NAME);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_name
 * Params: GtkWidget *widget, const gchar *name
 * Returns: void
 * Assertion: Widgets can be named, which allows you to refer to them from a gtkrc file. 
 * Params Values: GtkWidget *widget,  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void  
 */
static void test_purpose_8()
{
    #define WIDGET gtk_check_button_new ()
    #define NAME "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget* widget;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_name (widget, NAME);
    
    g_object_get (GTK_OBJECT (widget), "name", &name, NULL);
    
    if (NAME != NULL)
    {
        if (name == NULL)
        {
            TEST_FAIL ("name is NULL, should be", NAME);
    
        } else if (strcmp (name, (gchar*) NAME)) {
    
            TEST_FAIL ("name is %s, should be %s", name, NAME);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_name
 * Params: GtkWidget *widget, const gchar *name
 * Returns: void
 * Assertion: Widgets can be named, which allows you to refer to them from a gtkrc file. 
 * Params Values: GtkWidget *widget,  "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void  
 */
static void test_purpose_9()
{
    #define WIDGET gtk_button_new ()
    #define NAME "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget* widget;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_name (widget, NAME);
    
    g_object_get (GTK_OBJECT (widget), "name", &name, NULL);
    
    if (NAME != NULL)
    {
        if (name == NULL)
        {
            TEST_FAIL ("name is NULL, should be", NAME);
    
        } else if (strcmp (name, (gchar*) NAME)) {
    
            TEST_FAIL ("name is %s, should be %s", name, NAME);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_name
 * Params: GtkWidget *widget, const gchar *name
 * Returns: void
 * Assertion: Widgets can be named, which allows you to refer to them from a gtkrc file. 
 * Params Values: GtkWidget *widget,  "\b\n\t"
 * Expected: void  
 */
static void test_purpose_10()
{
    #define WIDGET gtk_entry_new ()
    #define NAME "\b\n\t"
    
    GtkWidget* widget;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_name (widget, NAME);
    
    g_object_get (GTK_OBJECT (widget), "name", &name, NULL);
    
    if (NAME != NULL)
    {
        if (name == NULL)
        {
            TEST_FAIL ("name is NULL, should be", NAME);
    
        } else if (strcmp (name, (gchar*) NAME)) {
    
            TEST_FAIL ("name is %s, should be %s", name, NAME);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_name
 * Params: GtkWidget *widget, const gchar *name
 * Returns: void
 * Assertion: Widgets can be named, which allows you to refer to them from a gtkrc file. 
 * Params Values: GtkWidget *widget,  ""
 * Expected: void  
 */
static void test_purpose_11()
{
    #define WIDGET gtk_button_new ()
    #define NAME ""
    
    GtkWidget* widget;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_name (widget, NAME);
    
    g_object_get (GTK_OBJECT (widget), "name", &name, NULL);
    
    if (NAME != NULL)
    {
        if (name == NULL)
        {
            TEST_FAIL ("name is NULL, should be", NAME);
    
        } else if (strcmp (name, (gchar*) NAME)) {
    
            TEST_FAIL ("name is %s, should be %s", name, NAME);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_name
 * Params: GtkWidget *widget, const gchar *name
 * Returns: void
 * Assertion: Widgets can be named, which allows you to refer to them from a gtkrc file. 
 * Params Values: GtkWidget *widget,  " "
 * Expected: void  
 */
static void test_purpose_12()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    #define NAME " "
    
    GtkWidget* widget;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_name (widget, NAME);
    
    g_object_get (GTK_OBJECT (widget), "name", &name, NULL);
    
    if (NAME != NULL)
    {
        if (name == NULL)
        {
            TEST_FAIL ("name is NULL, should be", NAME);
    
        } else if (strcmp (name, (gchar*) NAME)) {
    
            TEST_FAIL ("name is %s, should be %s", name, NAME);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_name
 * Params: GtkWidget *widget, const gchar *name
 * Returns: void
 * Assertion: Widgets can be named, which allows you to refer to them from a gtkrc file. 
 * Params Values: GtkWidget *widget,  NULL
 * Expected: void  
 */
static void test_purpose_13()
{
    #define WIDGET gtk_label_new ("Label")
    #define NAME NULL
    
    GtkWidget* widget;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_name (widget, NAME);
    
    g_object_get (GTK_OBJECT (widget), "name", &name, NULL);
    
    if (NAME != NULL)
    {
        if (name == NULL)
        {
            TEST_FAIL ("name is NULL, should be", NAME);
    
        } else if (strcmp (name, (gchar*) NAME)) {
    
            TEST_FAIL ("name is %s, should be %s", name, NAME);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_name
 * Params: GtkWidget *widget
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the name of a widget.
 * Params Values: GtkWidget* widget
 * Expected: "Text"  
 */
static void test_purpose_14()
{
    #define WIDGET gtk_button_new ()
    #define NAME "Text"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_set (GTK_OBJECT (widget), "name", NAME, NULL);
    
    name = gtk_widget_get_name (widget);
    
    if (NAME != NULL)
    {
        if (name == NULL)
        {
            TEST_FAIL ("name is NULL, should be", NAME);
    
        } else if (strcmp (name, (gchar*) NAME)) {
    
            TEST_FAIL ("name is '%s', should be %s", name, NAME);
        }
    
    } else {
    
        if ((name != NULL) && (name != gtk_widget_get_name (widget)))
        {
            TEST_FAIL ("name is %s, should be NULL", name);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_name
 * Params: GtkWidget *widget
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the name of a widget.
 * Params Values: GtkWidget* widget
 * Expected: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"  
 */
static void test_purpose_15()
{
    #define WIDGET gtk_check_button_new ()
    #define NAME "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_set (GTK_OBJECT (widget), "name", NAME, NULL);
    
    name = gtk_widget_get_name (widget);
    
    if (NAME != NULL)
    {
        if (name == NULL)
        {
            TEST_FAIL ("name is NULL, should be", NAME);
    
        } else if (strcmp (name, (gchar*) NAME)) {
    
            TEST_FAIL ("name is '%s', should be %s", name, NAME);
        }
    
    } else {
    
        if ((name != NULL) && (name != gtk_widget_get_name (widget)))
        {
            TEST_FAIL ("name is %s, should be NULL", name);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_name
 * Params: GtkWidget *widget
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the name of a widget.
 * Params Values: GtkWidget* widget
 * Expected: "!@#$%^&*()_+|~=\";:'?<>`/"  
 */
static void test_purpose_16()
{
    #define WIDGET gtk_button_new ()
    #define NAME "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_set (GTK_OBJECT (widget), "name", NAME, NULL);
    
    name = gtk_widget_get_name (widget);
    
    if (NAME != NULL)
    {
        if (name == NULL)
        {
            TEST_FAIL ("name is NULL, should be", NAME);
    
        } else if (strcmp (name, (gchar*) NAME)) {
    
            TEST_FAIL ("name is '%s', should be %s", name, NAME);
        }
    
    } else {
    
        if ((name != NULL) && (name != gtk_widget_get_name (widget)))
        {
            TEST_FAIL ("name is %s, should be NULL", name);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_name
 * Params: GtkWidget *widget
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the name of a widget.
 * Params Values: GtkWidget* widget
 * Expected: "\b\n\t"  
 */
static void test_purpose_17()
{
    #define WIDGET gtk_entry_new ()
    #define NAME "\b\n\t"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_set (GTK_OBJECT (widget), "name", NAME, NULL);
    
    name = gtk_widget_get_name (widget);
    
    if (NAME != NULL)
    {
        if (name == NULL)
        {
            TEST_FAIL ("name is NULL, should be", NAME);
    
        } else if (strcmp (name, (gchar*) NAME)) {
    
            TEST_FAIL ("name is '%s', should be %s", name, NAME);
        }
    
    } else {
    
        if ((name != NULL) && (name != gtk_widget_get_name (widget)))
        {
            TEST_FAIL ("name is %s, should be NULL", name);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_name
 * Params: GtkWidget *widget
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the name of a widget.
 * Params Values: GtkWidget* widget
 * Expected: ""  
 */
static void test_purpose_18()
{
    #define WIDGET gtk_button_new ()
    #define NAME ""
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_set (GTK_OBJECT (widget), "name", NAME, NULL);
    
    name = gtk_widget_get_name (widget);
    
    if (NAME != NULL)
    {
        if (name == NULL)
        {
            TEST_FAIL ("name is NULL, should be", NAME);
    
        } else if (strcmp (name, (gchar*) NAME)) {
    
            TEST_FAIL ("name is '%s', should be %s", name, NAME);
        }
    
    } else {
    
        if ((name != NULL) && (name != gtk_widget_get_name (widget)))
        {
            TEST_FAIL ("name is %s, should be NULL", name);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_name
 * Params: GtkWidget *widget
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the name of a widget.
 * Params Values: GtkWidget* widget
 * Expected: " "  
 */
static void test_purpose_19()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    #define NAME " "
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_set (GTK_OBJECT (widget), "name", NAME, NULL);
    
    name = gtk_widget_get_name (widget);
    
    if (NAME != NULL)
    {
        if (name == NULL)
        {
            TEST_FAIL ("name is NULL, should be", NAME);
    
        } else if (strcmp (name, (gchar*) NAME)) {
    
            TEST_FAIL ("name is '%s', should be %s", name, NAME);
        }
    
    } else {
    
        if ((name != NULL) && (name != gtk_widget_get_name (widget)))
        {
            TEST_FAIL ("name is %s, should be NULL", name);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_name
 * Params: GtkWidget *widget
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the name of a widget.
 * Params Values: GtkWidget* widget
 * Expected: NULL  
 */
static void test_purpose_20()
{
    #define WIDGET gtk_label_new ("Label")
    #define NAME NULL
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_set (GTK_OBJECT (widget), "name", NAME, NULL);
    
    name = gtk_widget_get_name (widget);
    
    if (NAME != NULL)
    {
        if (name == NULL)
        {
            TEST_FAIL ("name is NULL, should be", NAME);
    
        } else if (strcmp (name, (gchar*) NAME)) {
    
            TEST_FAIL ("name is '%s', should be %s", name, NAME);
        }
    
    } else {
    
        if ((name != NULL) && (name != gtk_widget_get_name (widget)))
        {
            TEST_FAIL ("name is %s, should be NULL", name);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_state
 * Params: GtkWidget *widget, GtkStateType state
 * Returns: void
 * Assertion: Sets the state of a widget (insensitive, prelighted, etc.)
 * Params Values: GtkWidget *widget, GTK_STATE_NORMAL 
 * Expected: void  
 */
static void test_purpose_21()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define STATE GTK_STATE_NORMAL 
    
    GtkWidget* widget;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_state (widget, STATE);
    
    if (!(GTK_WIDGET_STATE (widget) & STATE))
    {
        if (STATE != GTK_STATE_NORMAL)
        {
            TEST_FAIL ("state is wrong", NULL);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_state
 * Params: GtkWidget *widget, GtkStateType state
 * Returns: void
 * Assertion: Sets the state of a widget (insensitive, prelighted, etc.)
 * Params Values: GtkWidget *widget, GTK_STATE_ACTIVE
 * Expected: void  
 */
static void test_purpose_22()
{
    #define WIDGET gtk_button_new ()
    #define STATE GTK_STATE_ACTIVE
    
    GtkWidget* widget;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_state (widget, STATE);
    
    if (!(GTK_WIDGET_STATE (widget) & STATE))
    {
        if (STATE != GTK_STATE_NORMAL)
        {
            TEST_FAIL ("state is wrong", NULL);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_state
 * Params: GtkWidget *widget, GtkStateType state
 * Returns: void
 * Assertion: Sets the state of a widget (insensitive, prelighted, etc.)
 * Params Values: GtkWidget *widget, GTK_STATE_PRELIGHT 
 * Expected: void  
 */
static void test_purpose_23()
{
    #define WIDGET gtk_label_new ("Label")
    #define STATE GTK_STATE_PRELIGHT 
    
    GtkWidget* widget;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_state (widget, STATE);
    
    if (!(GTK_WIDGET_STATE (widget) & STATE))
    {
        if (STATE != GTK_STATE_NORMAL)
        {
            TEST_FAIL ("state is wrong", NULL);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_state
 * Params: GtkWidget *widget, GtkStateType state
 * Returns: void
 * Assertion: Sets the state of a widget (insensitive, prelighted, etc.)
 * Params Values: GtkWidget *widget, GTK_STATE_SELECTED 
 * Expected: void  
 */
static void test_purpose_24()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    #define STATE GTK_STATE_SELECTED 
    
    GtkWidget* widget;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_state (widget, STATE);
    
    if (!(GTK_WIDGET_STATE (widget) & STATE))
    {
        if (STATE != GTK_STATE_NORMAL)
        {
            TEST_FAIL ("state is wrong", NULL);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_state
 * Params: GtkWidget *widget, GtkStateType state
 * Returns: void
 * Assertion: Sets the state of a widget (insensitive, prelighted, etc.)
 * Params Values: GtkWidget *widget, GTK_STATE_INSENSITIVE 
 * Expected: void  
 */
static void test_purpose_25()
{
    #define WIDGET gtk_check_button_new ()
    #define STATE GTK_STATE_INSENSITIVE 
    
    GtkWidget* widget;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_state (widget, STATE);
    
    if (!(GTK_WIDGET_STATE (widget) & STATE))
    {
        if (STATE != GTK_STATE_NORMAL)
        {
            TEST_FAIL ("state is wrong", NULL);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_sensitive
 * Params: GtkWidget *widget, gboolean sensitive
 * Returns: void
 * Assertion: Sets the sensitivity of a widget.
 * Params Values: GtkWidget *widget, TRUE
 * Expected: void  
 */
static void test_purpose_26()
{
    #define WIDGET gtk_button_new ()
    #define SENSITIVE TRUE
    
    GtkWidget* widget;
    gboolean sensitive;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_sensitive (widget, SENSITIVE);
    
    g_object_get (GTK_OBJECT (widget), "sensitive", &sensitive, NULL);
    
    if (sensitive != SENSITIVE) 
    {
        TEST_FAIL ("sensitive is %s, should be %s", sensitive, SENSITIVE);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef SENSITIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_sensitive
 * Params: GtkWidget *widget, gboolean sensitive
 * Returns: void
 * Assertion: Sets the sensitivity of a widget.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void  
 */
static void test_purpose_27()
{
    #define WIDGET gtk_button_new ()
    #define SENSITIVE FALSE
    
    GtkWidget* widget;
    gboolean sensitive;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_sensitive (widget, SENSITIVE);
    
    g_object_get (GTK_OBJECT (widget), "sensitive", &sensitive, NULL);
    
    if (sensitive != SENSITIVE) 
    {
        TEST_FAIL ("sensitive is %s, should be %s", sensitive, SENSITIVE);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef SENSITIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_sensitive
 * Params: GtkWidget *widget, gboolean sensitive
 * Returns: void
 * Assertion: Sets the sensitivity of a widget.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void  
 */
static void test_purpose_28()
{
    #define WIDGET gtk_check_button_new ()
    #define SENSITIVE FALSE
    
    GtkWidget* widget;
    gboolean sensitive;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_sensitive (widget, SENSITIVE);
    
    g_object_get (GTK_OBJECT (widget), "sensitive", &sensitive, NULL);
    
    if (sensitive != SENSITIVE) 
    {
        TEST_FAIL ("sensitive is %s, should be %s", sensitive, SENSITIVE);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef SENSITIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_sensitive
 * Params: GtkWidget *widget, gboolean sensitive
 * Returns: void
 * Assertion: Sets the sensitivity of a widget.
 * Params Values: GtkWidget *widget, TRUE
 * Expected: void  
 */
static void test_purpose_29()
{
    #define WIDGET gtk_entry_new ()
    #define SENSITIVE TRUE
    
    GtkWidget* widget;
    gboolean sensitive;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_sensitive (widget, SENSITIVE);
    
    g_object_get (GTK_OBJECT (widget), "sensitive", &sensitive, NULL);
    
    if (sensitive != SENSITIVE) 
    {
        TEST_FAIL ("sensitive is %s, should be %s", sensitive, SENSITIVE);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef SENSITIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_sensitive
 * Params: GtkWidget *widget, gboolean sensitive
 * Returns: void
 * Assertion: Sets the sensitivity of a widget.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void  
 */
static void test_purpose_30()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    #define SENSITIVE FALSE
    
    GtkWidget* widget;
    gboolean sensitive;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_sensitive (widget, SENSITIVE);
    
    g_object_get (GTK_OBJECT (widget), "sensitive", &sensitive, NULL);
    
    if (sensitive != SENSITIVE) 
    {
        TEST_FAIL ("sensitive is %s, should be %s", sensitive, SENSITIVE);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef SENSITIVE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_parent
 * Params: GtkWidget *widget, GtkWidget *parent
 * Returns: void
 * Assertion: Sets the container as the parent of widget, and takes care of some details such as updating the state and style of the child to reflect its new location.
 * Params Values: gtk_window_new (GTK_WINDOW_TOPLEVEL),  gtk_button_new ()
 * Expected: void  
 */
static void test_purpose_31()
{
    #define PARENT gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkContainer* real_parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL);
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_parent (widget, parent);
    
    g_object_get (GTK_OBJECT (widget), "parent", &real_parent, NULL);
    
    if (real_parent != GTK_CONTAINER (parent)) 
    {
        TEST_FAIL ("parent differs from the one was set", NULL);
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_parent
 * Params: GtkWidget *widget, GtkWidget *parent
 * Returns: void
 * Assertion: Sets the container as the parent of widget, and takes care of some details such as updating the state and style of the child to reflect its new location.
 * Params Values: gtk_window_new (GTK_WINDOW_TOPLEVEL),  gtk_vbox_new (TRUE, 10)
 * Expected: void  
 */
static void test_purpose_32()
{
    #define PARENT gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define WIDGET gtk_vbox_new (TRUE, 10)
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkContainer* real_parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL);
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_parent (widget, parent);
    
    g_object_get (GTK_OBJECT (widget), "parent", &real_parent, NULL);
    
    if (real_parent != GTK_CONTAINER (parent)) 
    {
        TEST_FAIL ("parent differs from the one was set", NULL);
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_parent
 * Params: GtkWidget *widget, GtkWidget *parent
 * Returns: void
 * Assertion: Sets the container as the parent of widget, and takes care of some details such as updating the state and style of the child to reflect its new location.
 * Params Values: gtk_hbox_new (TRUE, 10),  gtk_spin_button_new_with_range (0, 100, 10)
 * Expected: void  
 */
static void test_purpose_33()
{
    #define PARENT gtk_hbox_new (TRUE, 10)
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkContainer* real_parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL);
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_parent (widget, parent);
    
    g_object_get (GTK_OBJECT (widget), "parent", &real_parent, NULL);
    
    if (real_parent != GTK_CONTAINER (parent)) 
    {
        TEST_FAIL ("parent differs from the one was set", NULL);
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_parent
 * Params: GtkWidget *widget, GtkWidget *parent
 * Returns: void
 * Assertion: Sets the container as the parent of widget, and takes care of some details such as updating the state and style of the child to reflect its new location.
 * Params Values: gtk_vbox_new (TRUE, 10),  gtk_hbox_new (TRUE, 10)
 * Expected: void  
 */
static void test_purpose_34()
{
    #define PARENT gtk_vbox_new (TRUE, 10)
    #define WIDGET gtk_hbox_new (TRUE, 10)
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkContainer* real_parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL);
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_parent (widget, parent);
    
    g_object_get (GTK_OBJECT (widget), "parent", &real_parent, NULL);
    
    if (real_parent != GTK_CONTAINER (parent)) 
    {
        TEST_FAIL ("parent differs from the one was set", NULL);
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_parent
 * Params: GtkWidget *widget
 * Returns: GtkWidget*
 * Assertion: Returns the parent container of widget.
 * Params Values: gtk_window_new (GTK_WINDOW_TOPLEVEL)
 * Expected: void  
 */
static void test_purpose_35()
{
    #define PARENT gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkContainer* real_parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL);
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_parent (widget, parent);
    
    if (parent != gtk_widget_get_parent (widget)) 
    {
        TEST_FAIL ("parent differs from the one was set", NULL);
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_parent
 * Params: GtkWidget *widget
 * Returns: GtkWidget*
 * Assertion: Returns the parent container of widget.
 * Params Values: gtk_window_new (GTK_WINDOW_TOPLEVEL)
 * Expected: void  
 */
static void test_purpose_36()
{
    #define PARENT gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define WIDGET gtk_vbox_new (TRUE, 10)
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkContainer* real_parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL);
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_parent (widget, parent);
    
    if (parent != gtk_widget_get_parent (widget)) 
    {
        TEST_FAIL ("parent differs from the one was set", NULL);
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_parent
 * Params: GtkWidget *widget
 * Returns: GtkWidget*
 * Assertion: Returns the parent container of widget.
 * Params Values: gtk_hbox_new (TRUE, 10)
 * Expected: void  
 */
static void test_purpose_37()
{
    #define PARENT gtk_hbox_new (TRUE, 10)
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkContainer* real_parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL);
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_parent (widget, parent);
    
    if (parent != gtk_widget_get_parent (widget)) 
    {
        TEST_FAIL ("parent differs from the one was set", NULL);
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_parent
 * Params: GtkWidget *widget
 * Returns: GtkWidget*
 * Assertion: Returns the parent container of widget.
 * Params Values: gtk_vbox_new (TRUE, 10)
 * Expected: void  
 */
static void test_purpose_38()
{
    #define PARENT gtk_vbox_new (TRUE, 10)
    #define WIDGET gtk_hbox_new (TRUE, 10)
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkContainer* real_parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL);
        return;
    }
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_parent (widget, parent);
    
    if (parent != gtk_widget_get_parent (widget)) 
    {
        TEST_FAIL ("parent differs from the one was set", NULL);
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_parent_window
 * Params: GtkWidget *widget, GdkWindow *parent_window
 * Returns: void
 * Assertion: Sets a non default parent window for widget.
 * Params Values: GtkWidget *widget, GdkWindow *parent_window
 * Expected: void
 * 
 * Name:  gtk_widget_get_parent_window
 * Params: GtkWidget *widget
 * Returns: GdkWindow*
 * Assertion: Gets widget's parent window.'
 * Params Values: GtkWidget *widget
 * Expected: GdkWindow*  
 */
static void test_purpose_39()
{
    #define WIDGET gtk_vbox_new (TRUE, 10)
    
    GtkWidget* widget;
    GdkWindow* parent;
    GdkWindowAttr attributes;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    parent = gdk_window_new (NULL, &attributes, attributes_mask);
    
    gtk_widget_set_parent (widget, gtk_button_new());
    gtk_widget_set_parent_window (widget, parent);
    
    if (parent != gtk_widget_get_parent_window (widget)) 
    {
        TEST_FAIL ("parent window differs from the one was set", NULL);
    }
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_parent_window
 * Params: GtkWidget *widget, GdkWindow *parent_window
 * Returns: void
 * Assertion: Sets a non default parent window for widget.
 * Params Values: GtkWidget *widget, GdkWindow *parent_window
 * Expected: void
 * 
 * Name:  gtk_widget_get_parent_window
 * Params: GtkWidget *widget
 * Returns: GdkWindow*
 * Assertion: Gets widget's parent window.'
 * Params Values: GtkWidget *widget
 * Expected: GdkWindow*  
 */
static void test_purpose_40()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    GdkWindow* parent;
    GdkWindowAttr attributes;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    parent = gdk_window_new (NULL, &attributes, attributes_mask);
    
    gtk_widget_set_parent (widget, gtk_button_new());
    gtk_widget_set_parent_window (widget, parent);
    
    if (parent != gtk_widget_get_parent_window (widget)) 
    {
        TEST_FAIL ("parent window differs from the one was set", NULL);
    }
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_parent_window
 * Params: GtkWidget *widget, GdkWindow *parent_window
 * Returns: void
 * Assertion: Sets a non default parent window for widget.
 * Params Values: GtkWidget *widget, GdkWindow *parent_window
 * Expected: void
 * 
 * Name:  gtk_widget_get_parent_window
 * Params: GtkWidget *widget
 * Returns: GdkWindow*
 * Assertion: Gets widget's parent window.'
 * Params Values: GtkWidget *widget
 * Expected: GdkWindow*  
 */
static void test_purpose_41()
{
    #define WIDGET gtk_label_new ("Label")
    
    GtkWidget* widget;
    GdkWindow* parent;
    GdkWindowAttr attributes;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    parent = gdk_window_new (NULL, &attributes, attributes_mask);
    
    gtk_widget_set_parent (widget, gtk_button_new());
    gtk_widget_set_parent_window (widget, parent);
    
    if (parent != gtk_widget_get_parent_window (widget)) 
    {
        TEST_FAIL ("parent window differs from the one was set", NULL);
    }
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_parent_window
 * Params: GtkWidget *widget, GdkWindow *parent_window
 * Returns: void
 * Assertion: Sets a non default parent window for widget.
 * Params Values: GtkWidget *widget, GdkWindow *parent_window
 * Expected: void
 * 
 * Name:  gtk_widget_get_parent_window
 * Params: GtkWidget *widget
 * Returns: GdkWindow*
 * Assertion: Gets widget's parent window.'
 * Params Values: GtkWidget *widget
 * Expected: GdkWindow*  
 */
static void test_purpose_42()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    
    GtkWidget* widget;
    GdkWindow* parent;
    GdkWindowAttr attributes;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    parent = gdk_window_new (NULL, &attributes, attributes_mask);
    
    gtk_widget_set_parent (widget, gtk_button_new());
    gtk_widget_set_parent_window (widget, parent);
    
    if (parent != gtk_widget_get_parent_window (widget)) 
    {
        TEST_FAIL ("parent window differs from the one was set", NULL);
    }
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_events
 * Params: GtkWidget *widget, gint events
 * Returns: void
 * Assertion: Sets the event mask (see GdkEventMask) for a widget.
 * Params Values: GtkWidget *widget,  GDK_ALL_EVENTS_MASK
 * Expected: void
 * 
 * Name:  gtk_widget_get_events
 * Params: GtkWidget *widget
 * Returns: gint
 * Assertion: Returns the event mask for the widget (a bitfield containing flags from the GdkEventMask enumeration).
 * Params Values:  GtkWidget *widget
 * Expected: GDK_ALL_EVENTS_MASK  
 */
static void test_purpose_43()
{
    #define WIDGET gtk_button_new ()
    #define EVENTS GDK_ALL_EVENTS_MASK
    
    GtkWidget* widget;
    gint events;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_events (widget, (gint) EVENTS);
    
    events = gtk_widget_get_events (widget);
    
    if (events != (gint) EVENTS) 
    {
        TEST_FAIL ("events is %x, should be %x", events, EVENTS);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef EVENTS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_events
 * Params: GtkWidget *widget, gint events
 * Returns: void
 * Assertion: Sets the event mask (see GdkEventMask) for a widget.
 * Params Values: GtkWidget *widget,  GDK_ENTER_NOTIFY_MASK
 * Expected: void
 * 
 * Name:  gtk_widget_get_events
 * Params: GtkWidget *widget
 * Returns: gint
 * Assertion: Returns the event mask for the widget (a bitfield containing flags from the GdkEventMask enumeration).
 * Params Values:  GtkWidget *widget
 * Expected: GDK_ENTER_NOTIFY_MASK  
 */
static void test_purpose_44()
{
    #define WIDGET gtk_button_new ()
    #define EVENTS GDK_ENTER_NOTIFY_MASK
    
    GtkWidget* widget;
    gint events;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_events (widget, (gint) EVENTS);
    
    events = gtk_widget_get_events (widget);
    
    if (events != (gint) EVENTS) 
    {
        TEST_FAIL ("events is %x, should be %x", events, EVENTS);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef EVENTS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_events
 * Params: GtkWidget *widget, gint events
 * Returns: void
 * Assertion: Sets the event mask (see GdkEventMask) for a widget.
 * Params Values: GtkWidget *widget,  GDK_EXPOSURE_MASK
 * Expected: void
 * 
 * Name:  gtk_widget_get_events
 * Params: GtkWidget *widget
 * Returns: gint
 * Assertion: Returns the event mask for the widget (a bitfield containing flags from the GdkEventMask enumeration).
 * Params Values:  GtkWidget *widget
 * Expected: GDK_EXPOSURE_MASK  
 */
static void test_purpose_45()
{
    #define WIDGET gtk_toggle_button_new ()
    #define EVENTS GDK_EXPOSURE_MASK
    
    GtkWidget* widget;
    gint events;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_events (widget, (gint) EVENTS);
    
    events = gtk_widget_get_events (widget);
    
    if (events != (gint) EVENTS) 
    {
        TEST_FAIL ("events is %x, should be %x", events, EVENTS);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef EVENTS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_events
 * Params: GtkWidget *widget, gint events
 * Returns: void
 * Assertion: Sets the event mask (see GdkEventMask) for a widget.
 * Params Values: GtkWidget *widget,  GDK_BUTTON_MOTION_MASK
 * Expected: void
 * 
 * Name:  gtk_widget_get_events
 * Params: GtkWidget *widget
 * Returns: gint
 * Assertion: Returns the event mask for the widget (a bitfield containing flags from the GdkEventMask enumeration).
 * Params Values:  GtkWidget *widget
 * Expected: GDK_BUTTON_MOTION_MASK  
 */
static void test_purpose_46()
{
    #define WIDGET gtk_entry_new ()
    #define EVENTS GDK_BUTTON_MOTION_MASK
    
    GtkWidget* widget;
    gint events;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_events (widget, (gint) EVENTS);
    
    events = gtk_widget_get_events (widget);
    
    if (events != (gint) EVENTS) 
    {
        TEST_FAIL ("events is %x, should be %x", events, EVENTS);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef EVENTS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_events
 * Params: GtkWidget *widget, gint events
 * Returns: void
 * Assertion: Sets the event mask (see GdkEventMask) for a widget.
 * Params Values: GtkWidget *widget,  GDK_KEY_PRESS_MASK
 * Expected: void
 * 
 * Name:  gtk_widget_get_events
 * Params: GtkWidget *widget
 * Returns: gint
 * Assertion: Returns the event mask for the widget (a bitfield containing flags from the GdkEventMask enumeration).
 * Params Values:  GtkWidget *widget
 * Expected: GDK_KEY_PRESS_MASK  
 */
static void test_purpose_47()
{
    #define WIDGET gtk_entry_new ()
    #define EVENTS GDK_KEY_PRESS_MASK
    
    GtkWidget* widget;
    gint events;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_events (widget, (gint) EVENTS);
    
    events = gtk_widget_get_events (widget);
    
    if (events != (gint) EVENTS) 
    {
        TEST_FAIL ("events is %x, should be %x", events, EVENTS);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef EVENTS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_events
 * Params: GtkWidget *widget, gint events
 * Returns: void
 * Assertion: Sets the event mask (see GdkEventMask) for a widget.
 * Params Values: GtkWidget *widget,  GDK_POINTER_MOTION_MASK
 * Expected: void
 * 
 * Name:  gtk_widget_get_events
 * Params: GtkWidget *widget
 * Returns: gint
 * Assertion: Returns the event mask for the widget (a bitfield containing flags from the GdkEventMask enumeration).
 * Params Values:  GtkWidget *widget
 * Expected: GDK_POINTER_MOTION_MASK  
 */
static void test_purpose_48()
{
    #define WIDGET gtk_entry_new ()
    #define EVENTS GDK_POINTER_MOTION_MASK
    
    GtkWidget* widget;
    gint events;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_events (widget, (gint) EVENTS);
    
    events = gtk_widget_get_events (widget);
    
    if (events != (gint) EVENTS) 
    {
        TEST_FAIL ("events is %x, should be %x", events, EVENTS);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef EVENTS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_events
 * Params: GtkWidget *widget, gint events
 * Returns: void
 * Assertion: Sets the event mask (see GdkEventMask) for a widget.
 * Params Values: GtkWidget *widget,  GDK_BUTTON1_MOTION_MASK
 * Expected: void
 * 
 * Name:  gtk_widget_get_events
 * Params: GtkWidget *widget
 * Returns: gint
 * Assertion: Returns the event mask for the widget (a bitfield containing flags from the GdkEventMask enumeration).
 * Params Values:  GtkWidget *widget
 * Expected: GDK_BUTTON1_MOTION_MASK  
 */
static void test_purpose_49()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    #define EVENTS GDK_BUTTON1_MOTION_MASK
    
    GtkWidget* widget;
    gint events;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_events (widget, (gint) EVENTS);
    
    events = gtk_widget_get_events (widget);
    
    if (events != (gint) EVENTS) 
    {
        TEST_FAIL ("events is %x, should be %x", events, EVENTS);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef EVENTS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_extension_events
 * Params: GtkWidget *widget, GdkExtensionMode mode
 * Returns: void
 * Assertion: Sets the extension events mask to mode.
 * Params Values: GtkWidget *widget,  GDK_EXTENSION_EVENTS_NONE
 * Expected: void
 * 
 * Name:  gtk_widget_get_extension_events
 * Params: GtkWidget *widget
 * Returns: GdkExtensionMode mode
 * Assertion: Retrieves the extension events the widget will receive; see gdk_input_set_extension_events().
 * Params Values: GtkWidget *widget
 * Expected: GDK_EXTENSION_EVENTS_NONE  
 */
static void test_purpose_50()
{
    #define WIDGET gtk_button_new ()
    #define MODE GDK_EXTENSION_EVENTS_NONE
    
    GtkWidget* widget;
    GdkExtensionMode mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_extension_events (widget, MODE);
    
    mode = gtk_widget_get_extension_events (widget);
    
    if (mode != MODE) 
    {
        TEST_FAIL ("mode is %d, should be %d", mode, MODE);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_extension_events
 * Params: GtkWidget *widget, GdkExtensionMode mode
 * Returns: void
 * Assertion: Sets the extension events mask to mode.
 * Params Values: GtkWidget *widget,  GDK_EXTENSION_EVENTS_ALL
 * Expected: void
 * 
 * Name:  gtk_widget_get_extension_events
 * Params: GtkWidget *widget
 * Returns: GdkExtensionMode mode
 * Assertion: Retrieves the extension events the widget will receive; see gdk_input_set_extension_events().
 * Params Values: GtkWidget *widget
 * Expected: GDK_EXTENSION_EVENTS_ALL  
 */
static void test_purpose_51()
{
    #define WIDGET gtk_entry_new ()
    #define MODE GDK_EXTENSION_EVENTS_ALL
    
    GtkWidget* widget;
    GdkExtensionMode mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_extension_events (widget, MODE);
    
    mode = gtk_widget_get_extension_events (widget);
    
    if (mode != MODE) 
    {
        TEST_FAIL ("mode is %d, should be %d", mode, MODE);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_extension_events
 * Params: GtkWidget *widget, GdkExtensionMode mode
 * Returns: void
 * Assertion: Sets the extension events mask to mode.
 * Params Values: GtkWidget *widget,  GDK_EXTENSION_EVENTS_CURSOR
 * Expected: void
 * 
 * Name:  gtk_widget_get_extension_events
 * Params: GtkWidget *widget
 * Returns: GdkExtensionMode mode
 * Assertion: Retrieves the extension events the widget will receive; see gdk_input_set_extension_events().
 * Params Values: GtkWidget *widget
 * Expected: GDK_EXTENSION_EVENTS_CURSOR  
 */
static void test_purpose_52()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    #define MODE GDK_EXTENSION_EVENTS_CURSOR
    
    GtkWidget* widget;
    GdkExtensionMode mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_extension_events (widget, MODE);
    
    mode = gtk_widget_get_extension_events (widget);
    
    if (mode != MODE) 
    {
        TEST_FAIL ("mode is %d, should be %d", mode, MODE);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: This function returns the topmost widget in the container hierarchy widget is a part of.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: If widget has no parent widgets, it will be returned as the topmost widget. 
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: No reference will be added to the returned widget; it should not be unreferenced.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_53()
{
    #define PARENT NULL
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkWidget* toplevel;
    
    gint ref_c1 = -1;
    gint ref_c2 = -1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (parent)
    {
        gtk_widget_set_parent (widget, parent);
    } else {
        parent = widget;  
    }
    ref_c1 = G_OBJECT (parent)->ref_count;
    
    toplevel = gtk_widget_get_toplevel (widget);
    ref_c2 = G_OBJECT (toplevel)->ref_count;
    
    if (toplevel != parent)
    {
        TEST_FAIL ("Incorrect toplevel", NULL);
    }
    
    if (ref_c1 != ref_c2)
    {
        TEST_FAIL ("ref_c1 = %d, ref_c2 = %d, they should be equal", 
                   ref_c1, ref_c2);
    }
    gtk_widget_destroy (parent);
    
    #undef PARENT
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: This function returns the topmost widget in the container hierarchy widget is a part of.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: If widget has no parent widgets, it will be returned as the topmost widget. 
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: No reference will be added to the returned widget; it should not be unreferenced.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_54()
{
    #define PARENT gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkWidget* toplevel;
    
    gint ref_c1 = -1;
    gint ref_c2 = -1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (parent)
    {
        gtk_widget_set_parent (widget, parent);
    } else {
        parent = widget;  
    }
    ref_c1 = G_OBJECT (parent)->ref_count;
    
    toplevel = gtk_widget_get_toplevel (widget);
    ref_c2 = G_OBJECT (toplevel)->ref_count;
    
    if (toplevel != parent)
    {
        TEST_FAIL ("Incorrect toplevel", NULL);
    }
    
    if (ref_c1 != ref_c2)
    {
        TEST_FAIL ("ref_c1 = %d, ref_c2 = %d, they should be equal", 
                   ref_c1, ref_c2);
    }
    gtk_widget_destroy (parent);
    
    #undef PARENT
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: This function returns the topmost widget in the container hierarchy widget is a part of.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: If widget has no parent widgets, it will be returned as the topmost widget. 
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: No reference will be added to the returned widget; it should not be unreferenced.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_55()
{
    #define PARENT gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define WIDGET gtk_vbox_new (TRUE, 10)
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkWidget* toplevel;
    
    gint ref_c1 = -1;
    gint ref_c2 = -1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (parent)
    {
        gtk_widget_set_parent (widget, parent);
    } else {
        parent = widget;  
    }
    ref_c1 = G_OBJECT (parent)->ref_count;
    
    toplevel = gtk_widget_get_toplevel (widget);
    ref_c2 = G_OBJECT (toplevel)->ref_count;
    
    if (toplevel != parent)
    {
        TEST_FAIL ("Incorrect toplevel", NULL);
    }
    
    if (ref_c1 != ref_c2)
    {
        TEST_FAIL ("ref_c1 = %d, ref_c2 = %d, they should be equal", 
                   ref_c1, ref_c2);
    }
    gtk_widget_destroy (parent);
    
    #undef PARENT
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: This function returns the topmost widget in the container hierarchy widget is a part of.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: If widget has no parent widgets, it will be returned as the topmost widget. 
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: No reference will be added to the returned widget; it should not be unreferenced.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_56()
{
    #define PARENT gtk_hbox_new (TRUE, 10)
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkWidget* toplevel;
    
    gint ref_c1 = -1;
    gint ref_c2 = -1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (parent)
    {
        gtk_widget_set_parent (widget, parent);
    } else {
        parent = widget;  
    }
    ref_c1 = G_OBJECT (parent)->ref_count;
    
    toplevel = gtk_widget_get_toplevel (widget);
    ref_c2 = G_OBJECT (toplevel)->ref_count;
    
    if (toplevel != parent)
    {
        TEST_FAIL ("Incorrect toplevel", NULL);
    }
    
    if (ref_c1 != ref_c2)
    {
        TEST_FAIL ("ref_c1 = %d, ref_c2 = %d, they should be equal", 
                   ref_c1, ref_c2);
    }
    gtk_widget_destroy (parent);
    
    #undef PARENT
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: This function returns the topmost widget in the container hierarchy widget is a part of.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: If widget has no parent widgets, it will be returned as the topmost widget. 
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: No reference will be added to the returned widget; it should not be unreferenced.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_57()
{
    #define PARENT gtk_vbox_new (TRUE, 10)
    #define WIDGET gtk_hbox_new (TRUE, 10)
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkWidget* toplevel;
    
    gint ref_c1 = -1;
    gint ref_c2 = -1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (parent)
    {
        gtk_widget_set_parent (widget, parent);
    } else {
        parent = widget;  
    }
    ref_c1 = G_OBJECT (parent)->ref_count;
    
    toplevel = gtk_widget_get_toplevel (widget);
    ref_c2 = G_OBJECT (toplevel)->ref_count;
    
    if (toplevel != parent)
    {
        TEST_FAIL ("Incorrect toplevel", NULL);
    }
    
    if (ref_c1 != ref_c2)
    {
        TEST_FAIL ("ref_c1 = %d, ref_c2 = %d, they should be equal", 
                   ref_c1, ref_c2);
    }
    gtk_widget_destroy (parent);
    
    #undef PARENT
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_toplevel
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Note the difference in behavior vs. gtk_widget_get_ancestor(); gtk_widget_get_ancestor (widget, GTK_TYPE_WINDOW) would return NULL if widget wasn't inside a toplevel window, and if the window was inside a GtkWindow-derived widget which was in turn inside the toplevel GtkWindow.'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_58()
{
    GtkWidget* widget;
    GtkWidget* parent;
    GtkWidget* ancestor;
    
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new ();
    parent = gtk_vbox_new (TRUE, 10);
    gtk_container_add (GTK_CONTAINER (parent), widget);
    
    ancestor = gtk_widget_get_ancestor (widget, GTK_TYPE_WINDOW);
    if (ancestor != NULL)
    {
        TEST_FAIL ("widget was not inside a toplevel window, so ancestor should be NULL but it is not", NULL);
    }
    
    if (parent != gtk_widget_get_toplevel (widget))
    {
        TEST_FAIL ("widget wasn't inside a GtkWindow-derived widget, so gtk_widget_get_toplevel(widget) should return parent", NULL);
    }
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), parent);
    
    ancestor = gtk_widget_get_ancestor (widget, GTK_TYPE_WINDOW);
    if (ancestor != window)
    {
        TEST_FAIL ("widget was inside a GtkWindow-derived widget which was in turn inside the toplevel GtkWindow, so ancestor should be NULL but it is not", NULL);
    }
    
    if (window != gtk_widget_get_toplevel (widget))
    {
        TEST_FAIL ("widget was inside a GtkWindow-derived widget which was in turn inside the toplevel GtkWindow", NULL);
    }
    
    gtk_widget_destroy (window);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_ancestor
 * Params: GtkWidget *widget, GType widget_type
 * Returns: void
 * Assertion: Gets the first ancestor of widget with type widget_type. 
 * Params Values: GtkWidget *widget 
 * Expected: void
 * 
 * Name: gtk_widget_get_ancestor
 * Params: GtkWidget *widget, GType widget_type
 * Returns: void
 * Assertion: No reference will be added to the returned widget; it should not be unreferenced.
 * Params Values: GtkWidget *widget 
 * Expected: void  
 */
static void test_purpose_59()
{
    #define PARENT NULL
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkWidget* ancestor;
    gint ref_c1 = -1;
    gint ref_c2 = -1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (parent)
    {
        gtk_widget_set_parent (widget, parent);
        ref_c1 = G_OBJECT(parent)->ref_count;
    }
    
    if (parent)
    {
        ancestor = gtk_widget_get_ancestor (widget, GTK_WIDGET_TYPE (parent));
        ref_c2 = G_OBJECT(ancestor)->ref_count;
    } else {
    
        ancestor = gtk_widget_get_ancestor (widget, GTK_TYPE_WINDOW);
    }
    
    if (ancestor != parent)
    {
        TEST_FAIL ("Incorrect ancestor \n%p\n%p\n%p", parent, widget, ancestor);
    }
    
    if (ref_c1 != ref_c2)
    {
        TEST_FAIL ("ref_c1 = %d, ref_c2 = %d, they should be equal", 
                   ref_c1, ref_c2);
    }
    
    #undef PARENT
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_ancestor
 * Params: GtkWidget *widget, GType widget_type
 * Returns: void
 * Assertion: Gets the first ancestor of widget with type widget_type. 
 * Params Values: GtkWidget *widget 
 * Expected: void
 * 
 * Name: gtk_widget_get_ancestor
 * Params: GtkWidget *widget, GType widget_type
 * Returns: void
 * Assertion: No reference will be added to the returned widget; it should not be unreferenced.
 * Params Values: GtkWidget *widget 
 * Expected: void  
 */
static void test_purpose_60()
{
    #define PARENT gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkWidget* ancestor;
    gint ref_c1 = -1;
    gint ref_c2 = -1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (parent)
    {
        gtk_widget_set_parent (widget, parent);
        ref_c1 = G_OBJECT(parent)->ref_count;
    }
    
    if (parent)
    {
        ancestor = gtk_widget_get_ancestor (widget, GTK_WIDGET_TYPE (parent));
        ref_c2 = G_OBJECT(ancestor)->ref_count;
    } else {
    
        ancestor = gtk_widget_get_ancestor (widget, GTK_TYPE_WINDOW);
    }
    
    if (ancestor != parent)
    {
        TEST_FAIL ("Incorrect ancestor \n%p\n%p\n%p", parent, widget, ancestor);
    }
    
    if (ref_c1 != ref_c2)
    {
        TEST_FAIL ("ref_c1 = %d, ref_c2 = %d, they should be equal", 
                   ref_c1, ref_c2);
    }
    
    #undef PARENT
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_ancestor
 * Params: GtkWidget *widget, GType widget_type
 * Returns: void
 * Assertion: Gets the first ancestor of widget with type widget_type. 
 * Params Values: GtkWidget *widget 
 * Expected: void
 * 
 * Name: gtk_widget_get_ancestor
 * Params: GtkWidget *widget, GType widget_type
 * Returns: void
 * Assertion: No reference will be added to the returned widget; it should not be unreferenced.
 * Params Values: GtkWidget *widget 
 * Expected: void  
 */
static void test_purpose_61()
{
    #define PARENT gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define WIDGET gtk_vbox_new (TRUE, 10)
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkWidget* ancestor;
    gint ref_c1 = -1;
    gint ref_c2 = -1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (parent)
    {
        gtk_widget_set_parent (widget, parent);
        ref_c1 = G_OBJECT(parent)->ref_count;
    }
    
    if (parent)
    {
        ancestor = gtk_widget_get_ancestor (widget, GTK_WIDGET_TYPE (parent));
        ref_c2 = G_OBJECT(ancestor)->ref_count;
    } else {
    
        ancestor = gtk_widget_get_ancestor (widget, GTK_TYPE_WINDOW);
    }
    
    if (ancestor != parent)
    {
        TEST_FAIL ("Incorrect ancestor \n%p\n%p\n%p", parent, widget, ancestor);
    }
    
    if (ref_c1 != ref_c2)
    {
        TEST_FAIL ("ref_c1 = %d, ref_c2 = %d, they should be equal", 
                   ref_c1, ref_c2);
    }
    
    #undef PARENT
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_ancestor
 * Params: GtkWidget *widget, GType widget_type
 * Returns: void
 * Assertion: Gets the first ancestor of widget with type widget_type. 
 * Params Values: GtkWidget *widget 
 * Expected: void
 * 
 * Name: gtk_widget_get_ancestor
 * Params: GtkWidget *widget, GType widget_type
 * Returns: void
 * Assertion: No reference will be added to the returned widget; it should not be unreferenced.
 * Params Values: GtkWidget *widget 
 * Expected: void  
 */
static void test_purpose_62()
{
    #define PARENT gtk_hbox_new (TRUE, 10)
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkWidget* ancestor;
    gint ref_c1 = -1;
    gint ref_c2 = -1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (parent)
    {
        gtk_widget_set_parent (widget, parent);
        ref_c1 = G_OBJECT(parent)->ref_count;
    }
    
    if (parent)
    {
        ancestor = gtk_widget_get_ancestor (widget, GTK_WIDGET_TYPE (parent));
        ref_c2 = G_OBJECT(ancestor)->ref_count;
    } else {
    
        ancestor = gtk_widget_get_ancestor (widget, GTK_TYPE_WINDOW);
    }
    
    if (ancestor != parent)
    {
        TEST_FAIL ("Incorrect ancestor \n%p\n%p\n%p", parent, widget, ancestor);
    }
    
    if (ref_c1 != ref_c2)
    {
        TEST_FAIL ("ref_c1 = %d, ref_c2 = %d, they should be equal", 
                   ref_c1, ref_c2);
    }
    
    #undef PARENT
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_ancestor
 * Params: GtkWidget *widget, GType widget_type
 * Returns: void
 * Assertion: Gets the first ancestor of widget with type widget_type. 
 * Params Values: GtkWidget *widget 
 * Expected: void
 * 
 * Name: gtk_widget_get_ancestor
 * Params: GtkWidget *widget, GType widget_type
 * Returns: void
 * Assertion: No reference will be added to the returned widget; it should not be unreferenced.
 * Params Values: GtkWidget *widget 
 * Expected: void  
 */
static void test_purpose_63()
{
    #define PARENT gtk_vbox_new (TRUE, 10)
    #define WIDGET gtk_hbox_new (TRUE, 10)
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkWidget* ancestor;
    gint ref_c1 = -1;
    gint ref_c2 = -1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (parent)
    {
        gtk_widget_set_parent (widget, parent);
        ref_c1 = G_OBJECT(parent)->ref_count;
    }
    
    if (parent)
    {
        ancestor = gtk_widget_get_ancestor (widget, GTK_WIDGET_TYPE (parent));
        ref_c2 = G_OBJECT(ancestor)->ref_count;
    } else {
    
        ancestor = gtk_widget_get_ancestor (widget, GTK_TYPE_WINDOW);
    }
    
    if (ancestor != parent)
    {
        TEST_FAIL ("Incorrect ancestor \n%p\n%p\n%p", parent, widget, ancestor);
    }
    
    if (ref_c1 != ref_c2)
    {
        TEST_FAIL ("ref_c1 = %d, ref_c2 = %d, they should be equal", 
                   ref_c1, ref_c2);
    }
    
    #undef PARENT
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_colormap
 * Params: GtkWidget *widget, GdkColormap *colormap
 * Returns: void
 * Assertion: Gets the colormap that will be used to render widget.
 * Params Values: GtkWidget *widget, GdkColormap *colormap
 * Expected: void
 * 
 * Name:  gtk_widget_set_colormap
 * Params: GtkWidget *widget
 * Returns: GdkColormap *colormap
 * Assertion: Sets the colormap for the widget to the given value.
 * Params Values: GtkWidget *widget  
 * Expected: GdkColormap*  
 */
static void test_purpose_64()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    GdkColormap* map;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    map = gdk_colormap_new (gdk_visual_get_best(), TRUE);
    
    gtk_widget_set_colormap (widget, map);
    
    if (map != gtk_widget_get_colormap (widget)) 
    {
        TEST_FAIL ("map is different than the one was set", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_colormap
 * Params: GtkWidget *widget, GdkColormap *colormap
 * Returns: void
 * Assertion: Gets the colormap that will be used to render widget.
 * Params Values: GtkWidget *widget, GdkColormap *colormap
 * Expected: void
 * 
 * Name:  gtk_widget_set_colormap
 * Params: GtkWidget *widget
 * Returns: GdkColormap *colormap
 * Assertion: Sets the colormap for the widget to the given value.
 * Params Values: GtkWidget *widget  
 * Expected: GdkColormap*  
 */
static void test_purpose_65()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    GdkColormap* map;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    map = gdk_colormap_new (gdk_visual_get_best(), TRUE);
    
    gtk_widget_set_colormap (widget, map);
    
    if (map != gtk_widget_get_colormap (widget)) 
    {
        TEST_FAIL ("map is different than the one was set", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_colormap
 * Params: GtkWidget *widget, GdkColormap *colormap
 * Returns: void
 * Assertion: Gets the colormap that will be used to render widget.
 * Params Values: GtkWidget *widget, GdkColormap *colormap
 * Expected: void
 * 
 * Name:  gtk_widget_set_colormap
 * Params: GtkWidget *widget
 * Returns: GdkColormap *colormap
 * Assertion: Sets the colormap for the widget to the given value.
 * Params Values: GtkWidget *widget  
 * Expected: GdkColormap*  
 */
static void test_purpose_66()
{
    #define WIDGET gtk_toggle_button_new ()
    
    GtkWidget* widget;
    GdkColormap* map;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    map = gdk_colormap_new (gdk_visual_get_best(), TRUE);
    
    gtk_widget_set_colormap (widget, map);
    
    if (map != gtk_widget_get_colormap (widget)) 
    {
        TEST_FAIL ("map is different than the one was set", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_colormap
 * Params: GtkWidget *widget, GdkColormap *colormap
 * Returns: void
 * Assertion: Gets the colormap that will be used to render widget.
 * Params Values: GtkWidget *widget, GdkColormap *colormap
 * Expected: void
 * 
 * Name:  gtk_widget_set_colormap
 * Params: GtkWidget *widget
 * Returns: GdkColormap *colormap
 * Assertion: Sets the colormap for the widget to the given value.
 * Params Values: GtkWidget *widget  
 * Expected: GdkColormap*  
 */
static void test_purpose_67()
{
    #define WIDGET gtk_entry_new ()
    
    GtkWidget* widget;
    GdkColormap* map;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    map = gdk_colormap_new (gdk_visual_get_best(), TRUE);
    
    gtk_widget_set_colormap (widget, map);
    
    if (map != gtk_widget_get_colormap (widget)) 
    {
        TEST_FAIL ("map is different than the one was set", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_colormap
 * Params: GtkWidget *widget, GdkColormap *colormap
 * Returns: void
 * Assertion: Gets the colormap that will be used to render widget.
 * Params Values: GtkWidget *widget, GdkColormap *colormap
 * Expected: void
 * 
 * Name:  gtk_widget_set_colormap
 * Params: GtkWidget *widget
 * Returns: GdkColormap *colormap
 * Assertion: Sets the colormap for the widget to the given value.
 * Params Values: GtkWidget *widget  
 * Expected: GdkColormap*  
 */
static void test_purpose_68()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    
    GtkWidget* widget;
    GdkColormap* map;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    map = gdk_colormap_new (gdk_visual_get_best(), TRUE);
    
    gtk_widget_set_colormap (widget, map);
    
    if (map != gtk_widget_get_colormap (widget)) 
    {
        TEST_FAIL ("map is different than the one was set", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_visual
 * Params: GtkWidget *widget
 * Returns: GdkVisual*
 * Assertion: Gets the visual that will be used to render widget.
 * Params Values: a newly created GtkWidget*
 * Expected: GdkVisual*  
 */
static void test_purpose_69()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    GdkVisual* visual;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    visual = gtk_widget_get_visual (widget);
    if (!visual)
    {
        TEST_FAIL ("visual is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_visual
 * Params: GtkWidget *widget
 * Returns: GdkVisual*
 * Assertion: Gets the visual that will be used to render widget.
 * Params Values: a newly created GtkWidget*
 * Expected: GdkVisual*  
 */
static void test_purpose_70()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    GdkVisual* visual;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    visual = gtk_widget_get_visual (widget);
    if (!visual)
    {
        TEST_FAIL ("visual is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_visual
 * Params: GtkWidget *widget
 * Returns: GdkVisual*
 * Assertion: Gets the visual that will be used to render widget.
 * Params Values: a newly created GtkWidget*
 * Expected: GdkVisual*  
 */
static void test_purpose_71()
{
    #define WIDGET gtk_toggle_button_new ()
    
    GtkWidget* widget;
    GdkVisual* visual;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    visual = gtk_widget_get_visual (widget);
    if (!visual)
    {
        TEST_FAIL ("visual is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_visual
 * Params: GtkWidget *widget
 * Returns: GdkVisual*
 * Assertion: Gets the visual that will be used to render widget.
 * Params Values: a newly created GtkWidget*
 * Expected: GdkVisual*  
 */
static void test_purpose_72()
{
    #define WIDGET gtk_entry_new ()
    
    GtkWidget* widget;
    GdkVisual* visual;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    visual = gtk_widget_get_visual (widget);
    if (!visual)
    {
        TEST_FAIL ("visual is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_visual
 * Params: GtkWidget *widget
 * Returns: GdkVisual*
 * Assertion: Gets the visual that will be used to render widget.
 * Params Values: a newly created GtkWidget*
 * Expected: GdkVisual*  
 */
static void test_purpose_73()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    
    GtkWidget* widget;
    GdkVisual* visual;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    visual = gtk_widget_get_visual (widget);
    if (!visual)
    {
        TEST_FAIL ("visual is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_pointer
 * Params: GtkWidget *widget, gint *x, gint *y
 * Returns: void
 * Assertion: Obtains the location of the mouse pointer in widget coordinates.
 * Params Values: GtkWidget* widget, gint *x, gint *y
 * Expected: void  
 */
static void test_purpose_74()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_get_pointer (widget, &x, &y);
    if (x != -1)
    {
        TEST_FAIL ("x is %d, should be %d", -1);
    }
    
    if (y != -1)
    {
        TEST_FAIL ("y is %d, should be %d", -1);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_pointer
 * Params: GtkWidget *widget, gint *x, gint *y
 * Returns: void
 * Assertion: Obtains the location of the mouse pointer in widget coordinates.
 * Params Values: GtkWidget* widget, gint *x, gint *y
 * Expected: void  
 */
static void test_purpose_75()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_get_pointer (widget, &x, &y);
    if (x != -1)
    {
        TEST_FAIL ("x is %d, should be %d", -1);
    }
    
    if (y != -1)
    {
        TEST_FAIL ("y is %d, should be %d", -1);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_pointer
 * Params: GtkWidget *widget, gint *x, gint *y
 * Returns: void
 * Assertion: Obtains the location of the mouse pointer in widget coordinates.
 * Params Values: GtkWidget* widget, gint *x, gint *y
 * Expected: void  
 */
static void test_purpose_76()
{
    #define WIDGET gtk_toggle_button_new ()
    
    GtkWidget* widget;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_get_pointer (widget, &x, &y);
    if (x != -1)
    {
        TEST_FAIL ("x is %d, should be %d", -1);
    }
    
    if (y != -1)
    {
        TEST_FAIL ("y is %d, should be %d", -1);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_pointer
 * Params: GtkWidget *widget, gint *x, gint *y
 * Returns: void
 * Assertion: Obtains the location of the mouse pointer in widget coordinates.
 * Params Values: GtkWidget* widget, gint *x, gint *y
 * Expected: void  
 */
static void test_purpose_77()
{
    #define WIDGET gtk_entry_new ()
    
    GtkWidget* widget;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_get_pointer (widget, &x, &y);
    if (x != -1)
    {
        TEST_FAIL ("x is %d, should be %d", -1);
    }
    
    if (y != -1)
    {
        TEST_FAIL ("y is %d, should be %d", -1);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_pointer
 * Params: GtkWidget *widget, gint *x, gint *y
 * Returns: void
 * Assertion: Obtains the location of the mouse pointer in widget coordinates.
 * Params Values: GtkWidget* widget, gint *x, gint *y
 * Expected: void  
 */
static void test_purpose_78()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    
    GtkWidget* widget;
    gint x;
    gint y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_get_pointer (widget, &x, &y);
    if (x != -1)
    {
        TEST_FAIL ("x is %d, should be %d", -1);
    }
    
    if (y != -1)
    {
        TEST_FAIL ("y is %d, should be %d", -1);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_style
 * Params: GtkWidget *widget, GtkStyle *style
 * Returns: void
 * Assertion: Sets the GtkStyle for a widget (widget->style).
 * Params Values: GtkWidget *widget, GtkStyle *style;
 * Expected: void
 * 
 * Name:  gtk_widget_get_style
 * Params: GtkWidget *widget
 * Returns: GtkStyle *style
 * Assertion: Simply an accessor function that returns widget->style.
 * Params Values: GtkWidget *widget
 * Expected: GtkStyle*  
 */
static void test_purpose_79()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    GtkStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_style_new ();
    gtk_widget_set_style (widget, style);
    
    if (gtk_widget_get_style (widget) != style) 
    {
        TEST_FAIL ("style differs from the one was set", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_style
 * Params: GtkWidget *widget, GtkStyle *style
 * Returns: void
 * Assertion: Sets the GtkStyle for a widget (widget->style).
 * Params Values: GtkWidget *widget, GtkStyle *style;
 * Expected: void
 * 
 * Name:  gtk_widget_get_style
 * Params: GtkWidget *widget
 * Returns: GtkStyle *style
 * Assertion: Simply an accessor function that returns widget->style.
 * Params Values: GtkWidget *widget
 * Expected: GtkStyle*  
 */
static void test_purpose_80()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    GtkStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_style_new ();
    gtk_widget_set_style (widget, style);
    
    if (gtk_widget_get_style (widget) != style) 
    {
        TEST_FAIL ("style differs from the one was set", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_style
 * Params: GtkWidget *widget, GtkStyle *style
 * Returns: void
 * Assertion: Sets the GtkStyle for a widget (widget->style).
 * Params Values: GtkWidget *widget, GtkStyle *style;
 * Expected: void
 * 
 * Name:  gtk_widget_get_style
 * Params: GtkWidget *widget
 * Returns: GtkStyle *style
 * Assertion: Simply an accessor function that returns widget->style.
 * Params Values: GtkWidget *widget
 * Expected: GtkStyle*  
 */
static void test_purpose_81()
{
    #define WIDGET gtk_toggle_button_new ()
    
    GtkWidget* widget;
    GtkStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_style_new ();
    gtk_widget_set_style (widget, style);
    
    if (gtk_widget_get_style (widget) != style) 
    {
        TEST_FAIL ("style differs from the one was set", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_style
 * Params: GtkWidget *widget, GtkStyle *style
 * Returns: void
 * Assertion: Sets the GtkStyle for a widget (widget->style).
 * Params Values: GtkWidget *widget, GtkStyle *style;
 * Expected: void
 * 
 * Name:  gtk_widget_get_style
 * Params: GtkWidget *widget
 * Returns: GtkStyle *style
 * Assertion: Simply an accessor function that returns widget->style.
 * Params Values: GtkWidget *widget
 * Expected: GtkStyle*  
 */
static void test_purpose_82()
{
    #define WIDGET gtk_entry_new ()
    
    GtkWidget* widget;
    GtkStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_style_new ();
    gtk_widget_set_style (widget, style);
    
    if (gtk_widget_get_style (widget) != style) 
    {
        TEST_FAIL ("style differs from the one was set", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_style
 * Params: GtkWidget *widget, GtkStyle *style
 * Returns: void
 * Assertion: Sets the GtkStyle for a widget (widget->style).
 * Params Values: GtkWidget *widget, GtkStyle *style;
 * Expected: void
 * 
 * Name:  gtk_widget_get_style
 * Params: GtkWidget *widget
 * Returns: GtkStyle *style
 * Assertion: Simply an accessor function that returns widget->style.
 * Params Values: GtkWidget *widget
 * Expected: GtkStyle*  
 */
static void test_purpose_83()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    
    GtkWidget* widget;
    GtkStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_style_new ();
    gtk_widget_set_style (widget, style);
    
    if (gtk_widget_get_style (widget) != style) 
    {
        TEST_FAIL ("style differs from the one was set", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_default_style
 * Params: void
 * Returns: GtkStyle *style
 * Assertion: Returns the default style used by all widgets initially.
 * Params Values: void
 * Expected: a newly created GtkStyle*  
 */
static void test_purpose_84()
{
    GtkStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_widget_get_default_style ();
    if (!style) 
    {
        TEST_FAIL ("style is NULL", NULL);
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_default_colormap
 * Params: GdkColormap *colormap
 * Returns: void
 * Assertion:Sets the default colormap to use when creating widgets.
 * Params Values: a newly created GdkColormap*
 * Expected: void
 * 
 * Name:  gtk_widget_get_default_colormap
 * Params: void
 * Returns: GdkColormap *colormap
 * Assertion: Obtains the default colormap used to create widgets.
 * Params Values: void
 * Expected: GdkColormap*  
 */
static void test_purpose_85()
{
    GdkColormap* map;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    map = gdk_colormap_new (gdk_visual_get_best(), TRUE);
    if (!map)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_default_colormap (map);
    if (map != gtk_widget_get_default_colormap ())
     {
        TEST_FAIL ("map is different than the one was set", NULL);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_default_visual
 * Params: void
 * Returns: GdkVisual*
 * Assertion: Obtains the visual of the default colormap.
 * Params Values: void
 * Expected: GdkVisual*  
 */
static void test_purpose_86()
{
    GdkVisual* visual;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    visual = gtk_widget_get_default_visual ();
    if (!visual)
    {
        TEST_FAIL ("visual is NULL but shouldn't be", NULL);
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_direction
 * Params: GtkWidget *widget, GtkTextDirection dir
 * Returns: void
 * Assertion: Sets the reading direction on a particular widget. 
 * Params Values: GtkWidget *widget,  GTK_TEXT_DIR_NONE
 * Expected: void
 * 
 * Name:  gtk_widget_set_direction
 * Params: GtkWidget *widget, GtkTextDirection dir
 * Returns: void
 * Assertion: If the direction is set to GTK_TEXT_DIR_NONE, then the value set by gtk_widget_set_default_direction() will be used.
 * Params Values: GtkWidget *widget,  GTK_TEXT_DIR_NONE
 * Expected: void
 * 
 * Name:  gtk_widget_get_direction
 * Params: GtkWidget *widget, 
 * Returns: GtkTextDirection
 * Assertion: Gets the reading direction for a particular widget.
 * Params Values: GtkWidget *widget
 * Expected: GTK_TEXT_DIR_NONE  
 */
static void test_purpose_87()
{
    #define WIDGET gtk_entry_new ()
    #define DIRECTION GTK_TEXT_DIR_NONE
    
    GtkWidget* widget;
    GtkTextDirection direction;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_default_direction (GTK_TEXT_DIR_RTL);
    gtk_widget_set_direction (widget, DIRECTION);
    
    direction = gtk_widget_get_direction (widget);
    
    if (DIRECTION != GTK_TEXT_DIR_NONE)
    {
        if (direction != DIRECTION) 
        {
            TEST_FAIL ("direction is %d should be %d", direction, DIRECTION);
        }
    
    } else {
        if (direction != GTK_TEXT_DIR_RTL) 
        {
            TEST_FAIL ("direction is %d should be %d", direction, GTK_TEXT_DIR_RTL);
        }
    }
        
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_direction
 * Params: GtkWidget *widget, GtkTextDirection dir
 * Returns: void
 * Assertion: Sets the reading direction on a particular widget. 
 * Params Values: GtkWidget *widget,  GTK_TEXT_DIR_LTR
 * Expected: void
 * 
 * Name:  gtk_widget_set_direction
 * Params: GtkWidget *widget, GtkTextDirection dir
 * Returns: void
 * Assertion: If the direction is set to GTK_TEXT_DIR_NONE, then the value set by gtk_widget_set_default_direction() will be used.
 * Params Values: GtkWidget *widget,  GTK_TEXT_DIR_LTR
 * Expected: void
 * 
 * Name:  gtk_widget_get_direction
 * Params: GtkWidget *widget, 
 * Returns: GtkTextDirection
 * Assertion: Gets the reading direction for a particular widget.
 * Params Values: GtkWidget *widget
 * Expected: GTK_TEXT_DIR_LTR  
 */
static void test_purpose_88()
{
    #define WIDGET gtk_entry_new ()
    #define DIRECTION GTK_TEXT_DIR_LTR
    
    GtkWidget* widget;
    GtkTextDirection direction;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_default_direction (GTK_TEXT_DIR_RTL);
    gtk_widget_set_direction (widget, DIRECTION);
    
    direction = gtk_widget_get_direction (widget);
    
    if (DIRECTION != GTK_TEXT_DIR_NONE)
    {
        if (direction != DIRECTION) 
        {
            TEST_FAIL ("direction is %d should be %d", direction, DIRECTION);
        }
    
    } else {
        if (direction != GTK_TEXT_DIR_RTL) 
        {
            TEST_FAIL ("direction is %d should be %d", direction, GTK_TEXT_DIR_RTL);
        }
    }
        
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_direction
 * Params: GtkWidget *widget, GtkTextDirection dir
 * Returns: void
 * Assertion: Sets the reading direction on a particular widget. 
 * Params Values: GtkWidget *widget,  GTK_TEXT_DIR_LTR
 * Expected: void
 * 
 * Name:  gtk_widget_set_direction
 * Params: GtkWidget *widget, GtkTextDirection dir
 * Returns: void
 * Assertion: If the direction is set to GTK_TEXT_DIR_NONE, then the value set by gtk_widget_set_default_direction() will be used.
 * Params Values: GtkWidget *widget,  GTK_TEXT_DIR_LTR
 * Expected: void
 * 
 * Name:  gtk_widget_get_direction
 * Params: GtkWidget *widget, 
 * Returns: GtkTextDirection
 * Assertion: Gets the reading direction for a particular widget.
 * Params Values: GtkWidget *widget
 * Expected: GTK_TEXT_DIR_LTR  
 */
static void test_purpose_89()
{
    #define WIDGET gtk_hbox_new (TRUE, 10)
    #define DIRECTION GTK_TEXT_DIR_LTR
    
    GtkWidget* widget;
    GtkTextDirection direction;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_default_direction (GTK_TEXT_DIR_RTL);
    gtk_widget_set_direction (widget, DIRECTION);
    
    direction = gtk_widget_get_direction (widget);
    
    if (DIRECTION != GTK_TEXT_DIR_NONE)
    {
        if (direction != DIRECTION) 
        {
            TEST_FAIL ("direction is %d should be %d", direction, DIRECTION);
        }
    
    } else {
        if (direction != GTK_TEXT_DIR_RTL) 
        {
            TEST_FAIL ("direction is %d should be %d", direction, GTK_TEXT_DIR_RTL);
        }
    }
        
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_direction
 * Params: GtkWidget *widget, GtkTextDirection dir
 * Returns: void
 * Assertion: Sets the reading direction on a particular widget. 
 * Params Values: GtkWidget *widget,  GTK_TEXT_DIR_RTL
 * Expected: void
 * 
 * Name:  gtk_widget_set_direction
 * Params: GtkWidget *widget, GtkTextDirection dir
 * Returns: void
 * Assertion: If the direction is set to GTK_TEXT_DIR_NONE, then the value set by gtk_widget_set_default_direction() will be used.
 * Params Values: GtkWidget *widget,  GTK_TEXT_DIR_RTL
 * Expected: void
 * 
 * Name:  gtk_widget_get_direction
 * Params: GtkWidget *widget, 
 * Returns: GtkTextDirection
 * Assertion: Gets the reading direction for a particular widget.
 * Params Values: GtkWidget *widget
 * Expected: GTK_TEXT_DIR_RTL  
 */
static void test_purpose_90()
{
    #define WIDGET gtk_button_new ()
    #define DIRECTION GTK_TEXT_DIR_RTL
    
    GtkWidget* widget;
    GtkTextDirection direction;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_default_direction (GTK_TEXT_DIR_RTL);
    gtk_widget_set_direction (widget, DIRECTION);
    
    direction = gtk_widget_get_direction (widget);
    
    if (DIRECTION != GTK_TEXT_DIR_NONE)
    {
        if (direction != DIRECTION) 
        {
            TEST_FAIL ("direction is %d should be %d", direction, DIRECTION);
        }
    
    } else {
        if (direction != GTK_TEXT_DIR_RTL) 
        {
            TEST_FAIL ("direction is %d should be %d", direction, GTK_TEXT_DIR_RTL);
        }
    }
        
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_default_direction
 * Params: GtkTextDirection dir
 * Returns: void
 * Assertion: Sets the default reading direction for widgets where the direction has not been explicitly set by gtk_widget_set_direction().
 * Params Values: GTK_TEXT_DIR_LTR
 * Expected: void
 * 
 * Name:  gtk_widget_get_default_direction
 * Params: void
 * Returns: GtkTextDirection
 * Assertion: Obtains the current default reading direction.
 * Params Values: void
 * Expected: GTK_TEXT_DIR_LTR  
 */
static void test_purpose_91()
{
    #define DIRECTION GTK_TEXT_DIR_LTR
    
    GtkTextDirection direction;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_widget_set_default_direction (DIRECTION);
    
    direction = gtk_widget_get_default_direction ();
    
    if (direction != DIRECTION) 
    {
        TEST_FAIL ("direction is %d should be %d", direction, DIRECTION);
    }
        
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_default_direction
 * Params: GtkTextDirection dir
 * Returns: void
 * Assertion: Sets the default reading direction for widgets where the direction has not been explicitly set by gtk_widget_set_direction().
 * Params Values: GTK_TEXT_DIR_RTL
 * Expected: void
 * 
 * Name:  gtk_widget_get_default_direction
 * Params: void
 * Returns: GtkTextDirection
 * Assertion: Obtains the current default reading direction.
 * Params Values: void
 * Expected: GTK_TEXT_DIR_RTL  
 */
static void test_purpose_92()
{
    #define DIRECTION GTK_TEXT_DIR_RTL
    
    GtkTextDirection direction;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gtk_widget_set_default_direction (DIRECTION);
    
    direction = gtk_widget_get_default_direction ();
    
    if (direction != DIRECTION) 
    {
        TEST_FAIL ("direction is %d should be %d", direction, DIRECTION);
    }
        
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_modifier_style
 * Params: GtkWidget* widget
 * Returns: GtkRcStyle*
 * Assertion: If no style has previously set, a new GtkRcStyle will be created with all values unset, and set as the modifier style for the widget.
 * Params Values: GtkWidget *widget
 * Expected: GtkRcStyle*  
 */
static void test_purpose_93()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    GtkRcStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_widget_get_modifier_style (widget);
    if (!style)
    {
        TEST_FAIL ("style is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_modifier_style
 * Params: GtkWidget* widget
 * Returns: GtkRcStyle*
 * Assertion: If no style has previously set, a new GtkRcStyle will be created with all values unset, and set as the modifier style for the widget.
 * Params Values: GtkWidget *widget
 * Expected: GtkRcStyle*  
 */
static void test_purpose_94()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    GtkRcStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_widget_get_modifier_style (widget);
    if (!style)
    {
        TEST_FAIL ("style is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_modifier_style
 * Params: GtkWidget* widget
 * Returns: GtkRcStyle*
 * Assertion: If no style has previously set, a new GtkRcStyle will be created with all values unset, and set as the modifier style for the widget.
 * Params Values: GtkWidget *widget
 * Expected: GtkRcStyle*  
 */
static void test_purpose_95()
{
    #define WIDGET gtk_toggle_button_new ()
    
    GtkWidget* widget;
    GtkRcStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_widget_get_modifier_style (widget);
    if (!style)
    {
        TEST_FAIL ("style is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_modifier_style
 * Params: GtkWidget* widget
 * Returns: GtkRcStyle*
 * Assertion: If no style has previously set, a new GtkRcStyle will be created with all values unset, and set as the modifier style for the widget.
 * Params Values: GtkWidget *widget
 * Expected: GtkRcStyle*  
 */
static void test_purpose_96()
{
    #define WIDGET gtk_entry_new ()
    
    GtkWidget* widget;
    GtkRcStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_widget_get_modifier_style (widget);
    if (!style)
    {
        TEST_FAIL ("style is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_modifier_style
 * Params: GtkWidget* widget
 * Returns: GtkRcStyle*
 * Assertion: If no style has previously set, a new GtkRcStyle will be created with all values unset, and set as the modifier style for the widget.
 * Params Values: GtkWidget *widget
 * Expected: GtkRcStyle*  
 */
static void test_purpose_97()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    
    GtkWidget* widget;
    GtkRcStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_widget_get_modifier_style (widget);
    if (!style)
    {
        TEST_FAIL ("style is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_pango_context
 * Params: GtkWidget* widget
 * Returns: PangoContext*
 * Assertion: Gets a PangoContext with the appropriate colormap, font description and base direction for this widget.
 * Params Values: a newly created GtkWidget*
 * Expected: PangoContext*, not NULL  
 */
static void test_purpose_98()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget *widget;
    PangoContext* context;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    context = gtk_widget_get_pango_context (widget);
    if (!context)
    {
        TEST_FAIL ("pango context is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_pango_context
 * Params: GtkWidget* widget
 * Returns: PangoContext*
 * Assertion: Gets a PangoContext with the appropriate colormap, font description and base direction for this widget.
 * Params Values: a newly created GtkWidget*
 * Expected: PangoContext*, not NULL  
 */
static void test_purpose_99()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget *widget;
    PangoContext* context;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    context = gtk_widget_get_pango_context (widget);
    if (!context)
    {
        TEST_FAIL ("pango context is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_pango_context
 * Params: GtkWidget* widget
 * Returns: PangoContext*
 * Assertion: Gets a PangoContext with the appropriate colormap, font description and base direction for this widget.
 * Params Values: a newly created GtkWidget*
 * Expected: PangoContext*, not NULL  
 */
static void test_purpose_100()
{
    #define WIDGET gtk_toggle_button_new ()
    
    GtkWidget *widget;
    PangoContext* context;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    context = gtk_widget_get_pango_context (widget);
    if (!context)
    {
        TEST_FAIL ("pango context is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_pango_context
 * Params: GtkWidget* widget
 * Returns: PangoContext*
 * Assertion: Gets a PangoContext with the appropriate colormap, font description and base direction for this widget.
 * Params Values: a newly created GtkWidget*
 * Expected: PangoContext*, not NULL  
 */
static void test_purpose_101()
{
    #define WIDGET gtk_entry_new ()
    
    GtkWidget *widget;
    PangoContext* context;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    context = gtk_widget_get_pango_context (widget);
    if (!context)
    {
        TEST_FAIL ("pango context is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_pango_context
 * Params: GtkWidget* widget
 * Returns: PangoContext*
 * Assertion: Gets a PangoContext with the appropriate colormap, font description and base direction for this widget.
 * Params Values: a newly created GtkWidget*
 * Expected: PangoContext*, not NULL  
 */
static void test_purpose_102()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    
    GtkWidget *widget;
    PangoContext* context;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    context = gtk_widget_get_pango_context (widget);
    if (!context)
    {
        TEST_FAIL ("pango context is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_double_buffered
 * Params: GtkWidget *widget, gboolean buffered
 * Returns: void
 * Assertion: Widgets are double buffered by default; you can use this function to turn off the buffering.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void  
 */
static void test_purpose_103()
{
    #define WIDGET gtk_button_new ()
    #define BUFFERED FALSE
    
    GtkWidget* widget;
    gboolean buffered;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_double_buffered (widget, BUFFERED);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef BUFFERED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_double_buffered
 * Params: GtkWidget *widget, gboolean buffered
 * Returns: void
 * Assertion: Widgets are double buffered by default; you can use this function to turn off the buffering.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void  
 */
static void test_purpose_104()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define BUFFERED FALSE
    
    GtkWidget* widget;
    gboolean buffered;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_double_buffered (widget, BUFFERED);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef BUFFERED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_double_buffered
 * Params: GtkWidget *widget, gboolean buffered
 * Returns: void
 * Assertion: Widgets are double buffered by default; you can use this function to turn off the buffering.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void  
 */
static void test_purpose_105()
{
    #define WIDGET gtk_toggle_button_new ()
    #define BUFFERED FALSE
    
    GtkWidget* widget;
    gboolean buffered;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_double_buffered (widget, BUFFERED);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef BUFFERED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_double_buffered
 * Params: GtkWidget *widget, gboolean buffered
 * Returns: void
 * Assertion: Widgets are double buffered by default; you can use this function to turn off the buffering.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void  
 */
static void test_purpose_106()
{
    #define WIDGET gtk_entry_new ()
    #define BUFFERED FALSE
    
    GtkWidget* widget;
    gboolean buffered;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_double_buffered (widget, BUFFERED);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef BUFFERED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_double_buffered
 * Params: GtkWidget *widget, gboolean buffered
 * Returns: void
 * Assertion: Widgets are double buffered by default; you can use this function to turn off the buffering.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void  
 */
static void test_purpose_107()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    #define BUFFERED FALSE
    
    GtkWidget* widget;
    gboolean buffered;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_double_buffered (widget, BUFFERED);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef BUFFERED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_composite_name
 * Params: GtkWidget *widget, const gchar *name
 * Returns: void
 * Assertion: Sets a widgets composite name.
 * Params Values: GtkWidget *widget, "Text"
 * Expected: void
 * 
 * Name:  gtk_widget_get_composite_name
 * Params: GtkWidget *widget, 
 * Returns: gchar*
 * Assertion: Obtains the composite name of a widget.
 * Params Values: GtkWidget *widget
 * Expected: "Text"  
 */
static void test_purpose_108()
{
    #define NAME "Text"
    
    GtkWidget* widget;
    GtkWidget* parent;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = gtk_dialog_new ();
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = gtk_dialog_add_button (GTK_DIALOG (parent), "Button", 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_WIDGET_COMPOSITE_CHILD (widget))
    {
        GTK_WIDGET_FLAGS (widget) |= GTK_COMPOSITE_CHILD;
    }
    
    gtk_widget_set_composite_name (widget, NAME);
    name = gtk_widget_get_composite_name (widget);
    
    if (!name)
    {
        TEST_FAIL ("composite name is NULL should be '%s'", NAME);
    
    } else if (strcmp (name, (gchar*) NAME)) {
    
        TEST_FAIL ("composite name is '%s' should be '%s'", name, NAME);
    }
    
    gtk_widget_destroy (parent); 
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_composite_name
 * Params: GtkWidget *widget, const gchar *name
 * Returns: void
 * Assertion: Sets a widgets composite name.
 * Params Values: GtkWidget *widget, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void
 * 
 * Name:  gtk_widget_get_composite_name
 * Params: GtkWidget *widget, 
 * Returns: gchar*
 * Assertion: Obtains the composite name of a widget.
 * Params Values: GtkWidget *widget
 * Expected: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"  
 */
static void test_purpose_109()
{
    #define NAME "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget* widget;
    GtkWidget* parent;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = gtk_dialog_new ();
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = gtk_dialog_add_button (GTK_DIALOG (parent), "Button", 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_WIDGET_COMPOSITE_CHILD (widget))
    {
        GTK_WIDGET_FLAGS (widget) |= GTK_COMPOSITE_CHILD;
    }
    
    gtk_widget_set_composite_name (widget, NAME);
    name = gtk_widget_get_composite_name (widget);
    
    if (!name)
    {
        TEST_FAIL ("composite name is NULL should be '%s'", NAME);
    
    } else if (strcmp (name, (gchar*) NAME)) {
    
        TEST_FAIL ("composite name is '%s' should be '%s'", name, NAME);
    }
    
    gtk_widget_destroy (parent); 
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_composite_name
 * Params: GtkWidget *widget, const gchar *name
 * Returns: void
 * Assertion: Sets a widgets composite name.
 * Params Values: GtkWidget *widget, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void
 * 
 * Name:  gtk_widget_get_composite_name
 * Params: GtkWidget *widget, 
 * Returns: gchar*
 * Assertion: Obtains the composite name of a widget.
 * Params Values: GtkWidget *widget
 * Expected: "!@#$%^&*()_+|~=\";:'?<>`/"  
 */
static void test_purpose_110()
{
    #define NAME "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkWidget* widget;
    GtkWidget* parent;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = gtk_dialog_new ();
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = gtk_dialog_add_button (GTK_DIALOG (parent), "Button", 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_WIDGET_COMPOSITE_CHILD (widget))
    {
        GTK_WIDGET_FLAGS (widget) |= GTK_COMPOSITE_CHILD;
    }
    
    gtk_widget_set_composite_name (widget, NAME);
    name = gtk_widget_get_composite_name (widget);
    
    if (!name)
    {
        TEST_FAIL ("composite name is NULL should be '%s'", NAME);
    
    } else if (strcmp (name, (gchar*) NAME)) {
    
        TEST_FAIL ("composite name is '%s' should be '%s'", name, NAME);
    }
    
    gtk_widget_destroy (parent); 
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_composite_name
 * Params: GtkWidget *widget, const gchar *name
 * Returns: void
 * Assertion: Sets a widgets composite name.
 * Params Values: GtkWidget *widget, "\b\n\t"
 * Expected: void
 * 
 * Name:  gtk_widget_get_composite_name
 * Params: GtkWidget *widget, 
 * Returns: gchar*
 * Assertion: Obtains the composite name of a widget.
 * Params Values: GtkWidget *widget
 * Expected: "\b\n\t"  
 */
static void test_purpose_111()
{
    #define NAME "\b\n\t"
    
    GtkWidget* widget;
    GtkWidget* parent;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = gtk_dialog_new ();
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = gtk_dialog_add_button (GTK_DIALOG (parent), "Button", 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_WIDGET_COMPOSITE_CHILD (widget))
    {
        GTK_WIDGET_FLAGS (widget) |= GTK_COMPOSITE_CHILD;
    }
    
    gtk_widget_set_composite_name (widget, NAME);
    name = gtk_widget_get_composite_name (widget);
    
    if (!name)
    {
        TEST_FAIL ("composite name is NULL should be '%s'", NAME);
    
    } else if (strcmp (name, (gchar*) NAME)) {
    
        TEST_FAIL ("composite name is '%s' should be '%s'", name, NAME);
    }
    
    gtk_widget_destroy (parent); 
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_composite_name
 * Params: GtkWidget *widget, const gchar *name
 * Returns: void
 * Assertion: Sets a widgets composite name.
 * Params Values: GtkWidget *widget, ""
 * Expected: void
 * 
 * Name:  gtk_widget_get_composite_name
 * Params: GtkWidget *widget, 
 * Returns: gchar*
 * Assertion: Obtains the composite name of a widget.
 * Params Values: GtkWidget *widget
 * Expected: ""  
 */
static void test_purpose_112()
{
    #define NAME ""
    
    GtkWidget* widget;
    GtkWidget* parent;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = gtk_dialog_new ();
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = gtk_dialog_add_button (GTK_DIALOG (parent), "Button", 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_WIDGET_COMPOSITE_CHILD (widget))
    {
        GTK_WIDGET_FLAGS (widget) |= GTK_COMPOSITE_CHILD;
    }
    
    gtk_widget_set_composite_name (widget, NAME);
    name = gtk_widget_get_composite_name (widget);
    
    if (!name)
    {
        TEST_FAIL ("composite name is NULL should be '%s'", NAME);
    
    } else if (strcmp (name, (gchar*) NAME)) {
    
        TEST_FAIL ("composite name is '%s' should be '%s'", name, NAME);
    }
    
    gtk_widget_destroy (parent); 
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_composite_name
 * Params: GtkWidget *widget, const gchar *name
 * Returns: void
 * Assertion: Sets a widgets composite name.
 * Params Values: GtkWidget *widget, " "
 * Expected: void
 * 
 * Name:  gtk_widget_get_composite_name
 * Params: GtkWidget *widget, 
 * Returns: gchar*
 * Assertion: Obtains the composite name of a widget.
 * Params Values: GtkWidget *widget
 * Expected: " "  
 */
static void test_purpose_113()
{
    #define NAME " "
    
    GtkWidget* widget;
    GtkWidget* parent;
    gchar* name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = gtk_dialog_new ();
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = gtk_dialog_add_button (GTK_DIALOG (parent), "Button", 1);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_WIDGET_COMPOSITE_CHILD (widget))
    {
        GTK_WIDGET_FLAGS (widget) |= GTK_COMPOSITE_CHILD;
    }
    
    gtk_widget_set_composite_name (widget, NAME);
    name = gtk_widget_get_composite_name (widget);
    
    if (!name)
    {
        TEST_FAIL ("composite name is NULL should be '%s'", NAME);
    
    } else if (strcmp (name, (gchar*) NAME)) {
    
        TEST_FAIL ("composite name is '%s' should be '%s'", name, NAME);
    }
    
    gtk_widget_destroy (parent); 
    
    #undef NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_scroll_adjustments
 * Params: GtkWidget *widget, GtkAdjustment *hadjustment, GtkAdjustment *vadjustment
 * Returns: gboolean
 * Assertion: For widgets that support scrolling, sets the scroll adjustments and returns TRUE. 
 * Params Values: gtk_viewport_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)), GTK_ADJUSTMENT (gtk_adjustment_new (5.0, 1.0, 10.0, 0.0, 0.0, 0.0))), gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0), NULL
 * Expected: TRUE  
 */
static void test_purpose_114()
{
    #define WIDGET gtk_viewport_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)), GTK_ADJUSTMENT (gtk_adjustment_new (5.0, 1.0, 10.0, 0.0, 0.0, 0.0)))
    #define HADJ gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
    #define VADJ NULL
    #define CORRECT_RESULT TRUE
    
    GtkWidget* widget;
    gboolean result;
    GtkAdjustment* hadj;
    GtkAdjustment* vadj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    hadj = (GtkAdjustment*)HADJ;
    vadj = (GtkAdjustment*)VADJ;
    
    result = gtk_widget_set_scroll_adjustments (widget, hadj, vadj);
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result is wrong %i %i", result, CORRECT_RESULT);
    }
    
    #undef WIDGET
    #undef HADJ
    #undef VADJ
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_scroll_adjustments
 * Params: GtkWidget *widget, GtkAdjustment *hadjustment, GtkAdjustment *vadjustment
 * Returns: gboolean
 * Assertion: For widgets that support scrolling, sets the scroll adjustments and returns TRUE. 
 * Params Values: gtk_viewport_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)), GTK_ADJUSTMENT (gtk_adjustment_new (5.0, 1.0, 10.0, 0.0, 0.0, 0.0))), NULL, gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
 * Expected: TRUE  
 */
static void test_purpose_115()
{
    #define WIDGET gtk_viewport_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)), GTK_ADJUSTMENT (gtk_adjustment_new (5.0, 1.0, 10.0, 0.0, 0.0, 0.0)))
    #define HADJ NULL
    #define VADJ gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
    #define CORRECT_RESULT TRUE
    
    GtkWidget* widget;
    gboolean result;
    GtkAdjustment* hadj;
    GtkAdjustment* vadj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    hadj = (GtkAdjustment*)HADJ;
    vadj = (GtkAdjustment*)VADJ;
    
    result = gtk_widget_set_scroll_adjustments (widget, hadj, vadj);
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result is wrong %i %i", result, CORRECT_RESULT);
    }
    
    #undef WIDGET
    #undef HADJ
    #undef VADJ
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_scroll_adjustments
 * Params: GtkWidget *widget, GtkAdjustment *hadjustment, GtkAdjustment *vadjustment
 * Returns: gboolean
 * Assertion: For widgets that support scrolling, sets the scroll adjustments and returns TRUE. 
 * Params Values: gtk_viewport_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)), GTK_ADJUSTMENT (gtk_adjustment_new (5.0, 1.0, 10.0, 0.0, 0.0, 0.0))), NULL, NULL
 * Expected: TRUE  
 */
static void test_purpose_116()
{
    #define WIDGET gtk_viewport_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0)), GTK_ADJUSTMENT (gtk_adjustment_new (5.0, 1.0, 10.0, 0.0, 0.0, 0.0)))
    #define HADJ NULL
    #define VADJ NULL
    #define CORRECT_RESULT TRUE
    
    GtkWidget* widget;
    gboolean result;
    GtkAdjustment* hadj;
    GtkAdjustment* vadj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    hadj = (GtkAdjustment*)HADJ;
    vadj = (GtkAdjustment*)VADJ;
    
    result = gtk_widget_set_scroll_adjustments (widget, hadj, vadj);
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result is wrong %i %i", result, CORRECT_RESULT);
    }
    
    #undef WIDGET
    #undef HADJ
    #undef VADJ
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_scroll_adjustments
 * Params: GtkWidget *widget, GtkAdjustment *hadjustment, GtkAdjustment *vadjustment
 * Returns: gboolean
 * Assertion: For widgets that support scrolling, sets the scroll adjustments and returns TRUE. 
 * Params Values: gtk_button_new ();, gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0), gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
 * Expected: FALSE  
 */
static void test_purpose_117()
{
    #define WIDGET gtk_button_new ();
    #define HADJ gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
    #define VADJ gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
    #define CORRECT_RESULT FALSE
    
    GtkWidget* widget;
    gboolean result;
    GtkAdjustment* hadj;
    GtkAdjustment* vadj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    hadj = (GtkAdjustment*)HADJ;
    vadj = (GtkAdjustment*)VADJ;
    
    result = gtk_widget_set_scroll_adjustments (widget, hadj, vadj);
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result is wrong %i %i", result, CORRECT_RESULT);
    }
    
    #undef WIDGET
    #undef HADJ
    #undef VADJ
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_scroll_adjustments
 * Params: GtkWidget *widget, GtkAdjustment *hadjustment, GtkAdjustment *vadjustment
 * Returns: gboolean
 * Assertion: For widgets that support scrolling, sets the scroll adjustments and returns TRUE. 
 * Params Values: gtk_button_new ();, NULL, gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
 * Expected: FALSE  
 */
static void test_purpose_118()
{
    #define WIDGET gtk_button_new ();
    #define HADJ NULL
    #define VADJ gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
    #define CORRECT_RESULT FALSE
    
    GtkWidget* widget;
    gboolean result;
    GtkAdjustment* hadj;
    GtkAdjustment* vadj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    hadj = (GtkAdjustment*)HADJ;
    vadj = (GtkAdjustment*)VADJ;
    
    result = gtk_widget_set_scroll_adjustments (widget, hadj, vadj);
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result is wrong %i %i", result, CORRECT_RESULT);
    }
    
    #undef WIDGET
    #undef HADJ
    #undef VADJ
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_scroll_adjustments
 * Params: GtkWidget *widget, GtkAdjustment *hadjustment, GtkAdjustment *vadjustment
 * Returns: gboolean
 * Assertion: For widgets that support scrolling, sets the scroll adjustments and returns TRUE. 
 * Params Values: gtk_button_new ();, gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0), NULL
 * Expected: FALSE  
 */
static void test_purpose_119()
{
    #define WIDGET gtk_button_new ();
    #define HADJ gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
    #define VADJ NULL
    #define CORRECT_RESULT FALSE
    
    GtkWidget* widget;
    gboolean result;
    GtkAdjustment* hadj;
    GtkAdjustment* vadj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    hadj = (GtkAdjustment*)HADJ;
    vadj = (GtkAdjustment*)VADJ;
    
    result = gtk_widget_set_scroll_adjustments (widget, hadj, vadj);
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result is wrong %i %i", result, CORRECT_RESULT);
    }
    
    #undef WIDGET
    #undef HADJ
    #undef VADJ
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_scroll_adjustments
 * Params: GtkWidget *widget, GtkAdjustment *hadjustment, GtkAdjustment *vadjustment
 * Returns: gboolean
 * Assertion: For widgets that support scrolling, sets the scroll adjustments and returns TRUE. 
 * Params Values: gtk_entry_new ();, NULL, NULL
 * Expected: FALSE  
 */
static void test_purpose_120()
{
    #define WIDGET gtk_entry_new ();
    #define HADJ NULL
    #define VADJ NULL
    #define CORRECT_RESULT FALSE
    
    GtkWidget* widget;
    gboolean result;
    GtkAdjustment* hadj;
    GtkAdjustment* vadj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    hadj = (GtkAdjustment*)HADJ;
    vadj = (GtkAdjustment*)VADJ;
    
    result = gtk_widget_set_scroll_adjustments (widget, hadj, vadj);
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result is wrong %i %i", result, CORRECT_RESULT);
    }
    
    #undef WIDGET
    #undef HADJ
    #undef VADJ
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_scroll_adjustments
 * Params: GtkWidget *widget, GtkAdjustment *hadjustment, GtkAdjustment *vadjustment
 * Returns: gboolean
 * Assertion: For widgets that don't support scrolling, does nothing and returns FALSE.'
 * Params Values: gtk_button_new ();, gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0), gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
 * Expected: FALSE  
 */
static void test_purpose_121()
{
    #define WIDGET gtk_button_new ();
    #define HADJ gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
    #define VADJ gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
    
    GtkWidget* widget;
    gboolean result;
    GtkAdjustment* hadj;
    GtkAdjustment* vadj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    hadj = (GtkAdjustment*)HADJ;
    vadj = (GtkAdjustment*)VADJ;
    
    result = gtk_widget_set_scroll_adjustments (widget, hadj, vadj);
    
    if (result)
    {
        TEST_FAIL ("result is wrong %i FALSE", result,NULL);
    }
    
    #undef WIDGET
    #undef HADJ
    #undef VADJ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_scroll_adjustments
 * Params: GtkWidget *widget, GtkAdjustment *hadjustment, GtkAdjustment *vadjustment
 * Returns: gboolean
 * Assertion: For widgets that don't support scrolling, does nothing and returns FALSE.'
 * Params Values: gtk_button_new ();, NULL, gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
 * Expected: FALSE  
 */
static void test_purpose_122()
{
    #define WIDGET gtk_button_new ();
    #define HADJ NULL
    #define VADJ gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
    
    GtkWidget* widget;
    gboolean result;
    GtkAdjustment* hadj;
    GtkAdjustment* vadj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    hadj = (GtkAdjustment*)HADJ;
    vadj = (GtkAdjustment*)VADJ;
    
    result = gtk_widget_set_scroll_adjustments (widget, hadj, vadj);
    
    if (result)
    {
        TEST_FAIL ("result is wrong %i FALSE", result,NULL);
    }
    
    #undef WIDGET
    #undef HADJ
    #undef VADJ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_scroll_adjustments
 * Params: GtkWidget *widget, GtkAdjustment *hadjustment, GtkAdjustment *vadjustment
 * Returns: gboolean
 * Assertion: For widgets that don't support scrolling, does nothing and returns FALSE.'
 * Params Values: gtk_button_new ();, gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0), NULL
 * Expected: FALSE  
 */
static void test_purpose_123()
{
    #define WIDGET gtk_button_new ();
    #define HADJ gtk_adjustment_new (1.0, 0.0, 5.0, 0.0, 0.0, 0.0)
    #define VADJ NULL
    
    GtkWidget* widget;
    gboolean result;
    GtkAdjustment* hadj;
    GtkAdjustment* vadj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    hadj = (GtkAdjustment*)HADJ;
    vadj = (GtkAdjustment*)VADJ;
    
    result = gtk_widget_set_scroll_adjustments (widget, hadj, vadj);
    
    if (result)
    {
        TEST_FAIL ("result is wrong %i FALSE", result,NULL);
    }
    
    #undef WIDGET
    #undef HADJ
    #undef VADJ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_scroll_adjustments
 * Params: GtkWidget *widget, GtkAdjustment *hadjustment, GtkAdjustment *vadjustment
 * Returns: gboolean
 * Assertion: For widgets that don't support scrolling, does nothing and returns FALSE.'
 * Params Values: gtk_entry_new ();, NULL, NULL
 * Expected: FALSE  
 */
static void test_purpose_124()
{
    #define WIDGET gtk_entry_new ();
    #define HADJ NULL
    #define VADJ NULL
    
    GtkWidget* widget;
    gboolean result;
    GtkAdjustment* hadj;
    GtkAdjustment* vadj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    hadj = (GtkAdjustment*)HADJ;
    vadj = (GtkAdjustment*)VADJ;
    
    result = gtk_widget_set_scroll_adjustments (widget, hadj, vadj);
    
    if (result)
    {
        TEST_FAIL ("result is wrong %i FALSE", result,NULL);
    }
    
    #undef WIDGET
    #undef HADJ
    #undef VADJ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_ref
 * Params: GtkWidget *widget
 * Returns: GtkWidget*
 * Assertion: Adds a reference to a widget. 
 * Params Values: GtkWidget *widget
 * Expected: GtkWidget*  
 */
static void test_purpose_125()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    gint ref_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    ref_count = G_OBJECT (widget)->ref_count;
    widget = gtk_widget_ref (widget);
    
    if (ref_count + 1 != G_OBJECT (widget)->ref_count)
    {
        TEST_FAIL ("G_OBJECT (widget)->ref_count should be %i", G_OBJECT (widget)->ref_count);
    }
    
    gtk_widget_unref (widget);
    gtk_widget_destroy (widget);
    
    #undef WIDGET 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_ref
 * Params: GtkWidget *widget
 * Returns: GtkWidget*
 * Assertion: Adds a reference to a widget. 
 * Params Values: GtkWidget *widget
 * Expected: GtkWidget*  
 */
static void test_purpose_126()
{
    #define WIDGET gtk_vbox_new (TRUE, 10);
    
    GtkWidget* widget;
    gint ref_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    ref_count = G_OBJECT (widget)->ref_count;
    widget = gtk_widget_ref (widget);
    
    if (ref_count + 1 != G_OBJECT (widget)->ref_count)
    {
        TEST_FAIL ("G_OBJECT (widget)->ref_count should be %i", G_OBJECT (widget)->ref_count);
    }
    
    gtk_widget_unref (widget);
    gtk_widget_destroy (widget);
    
    #undef WIDGET 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_ref
 * Params: GtkWidget *widget
 * Returns: GtkWidget*
 * Assertion: Adds a reference to a widget. 
 * Params Values: GtkWidget *widget
 * Expected: GtkWidget*  
 */
static void test_purpose_127()
{
    #define WIDGET gtk_notebook_new ();
    
    GtkWidget* widget;
    gint ref_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    ref_count = G_OBJECT (widget)->ref_count;
    widget = gtk_widget_ref (widget);
    
    if (ref_count + 1 != G_OBJECT (widget)->ref_count)
    {
        TEST_FAIL ("G_OBJECT (widget)->ref_count should be %i", G_OBJECT (widget)->ref_count);
    }
    
    gtk_widget_unref (widget);
    gtk_widget_destroy (widget);
    
    #undef WIDGET 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_unref
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Equivalent to g_object_unref()
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_128()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    gint ref_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = gtk_widget_ref (widget);
    ref_count = G_OBJECT (widget)->ref_count;
    gtk_widget_unref (widget);
    
    if (ref_count - 1 != G_OBJECT (widget)->ref_count)
    {
        TEST_FAIL ("G_OBJECT (widget)->ref_count should be %i", G_OBJECT (widget)->ref_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_unref
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Equivalent to g_object_unref()
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_129()
{
    #define WIDGET gtk_vbox_new (TRUE, 10);
    
    GtkWidget* widget;
    gint ref_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = gtk_widget_ref (widget);
    ref_count = G_OBJECT (widget)->ref_count;
    gtk_widget_unref (widget);
    
    if (ref_count - 1 != G_OBJECT (widget)->ref_count)
    {
        TEST_FAIL ("G_OBJECT (widget)->ref_count should be %i", G_OBJECT (widget)->ref_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_unref
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Equivalent to g_object_unref()
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_130()
{
    #define WIDGET gtk_notebook_new ();
    
    GtkWidget* widget;
    gint ref_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = gtk_widget_ref (widget);
    ref_count = G_OBJECT (widget)->ref_count;
    gtk_widget_unref (widget);
    
    if (ref_count - 1 != G_OBJECT (widget)->ref_count)
    {
        TEST_FAIL ("G_OBJECT (widget)->ref_count should be %i", G_OBJECT (widget)->ref_count);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_destroy
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Destroys a widget.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_destroy
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: If the widget is inside a container, the widget will be removed from the container.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_131()
{
    #define PARENT gtk_vbox_new (TRUE, 10)
    #define WIDGET gtk_button_new ()
    #define REF TRUE
    
    GtkWidget* parent;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("PARENT is not GTK_CONTAINER", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (REF)
    {
        gtk_widget_ref (widget);
    }
    
    gtk_container_add (GTK_CONTAINER (parent), gtk_label_new ("Label1"));
    gtk_container_add (GTK_CONTAINER (parent), gtk_label_new ("Label2"));
    
    gtk_container_add (GTK_CONTAINER (parent), widget);
    gtk_widget_destroy (widget);
    gtk_container_foreach (GTK_CONTAINER (parent), global_find, widget);
    
    if (result && !REF)
    {
        TEST_FAIL ("'widget' is not removed from 'parent'", NULL);
    }
    
    if (REF)
    {
        gtk_widget_unref (widget);
    }
    gtk_widget_destroy (parent);
    
    #undef PARENT 
    #undef WIDGET
    #undef REF
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_destroy
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Destroys a widget.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_destroy
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: If the widget is inside a container, the widget will be removed from the container.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_132()
{
    #define PARENT gtk_vbox_new (TRUE, 10)
    #define WIDGET gtk_button_new ()
    #define REF FALSE
    
    GtkWidget* parent;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("PARENT is not GTK_CONTAINER", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (REF)
    {
        gtk_widget_ref (widget);
    }
    
    gtk_container_add (GTK_CONTAINER (parent), gtk_label_new ("Label1"));
    gtk_container_add (GTK_CONTAINER (parent), gtk_label_new ("Label2"));
    
    gtk_container_add (GTK_CONTAINER (parent), widget);
    gtk_widget_destroy (widget);
    gtk_container_foreach (GTK_CONTAINER (parent), global_find, widget);
    
    if (result && !REF)
    {
        TEST_FAIL ("'widget' is not removed from 'parent'", NULL);
    }
    
    if (REF)
    {
        gtk_widget_unref (widget);
    }
    gtk_widget_destroy (parent);
    
    #undef PARENT 
    #undef WIDGET
    #undef REF
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_destroy
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: If the widget is a toplevel (derived from GtkWindow), it will be removed from the list of toplevels, and the reference GTK+ holds to it will be removed.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_destroy
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Removing a widget from its container or the list of toplevels results in the widget being finalized, unless you've added additional references to the widget with g_object_ref().'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_133()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define REF TRUE
    
    GtkWidget* widget;
    GList* list = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    if (REF)
    {
        gtk_widget_ref (widget);
    }
    
    gtk_widget_destroy (widget);
    
    list = gtk_window_list_toplevels ();
    
    if (!list)
    {
        TEST_FAIL ("gtk_window_list_toplevels () returns NULL", NULL);
        return;
    }
    
    g_list_foreach (list, (GFunc)g_object_ref, NULL);
    g_list_foreach (list, (GFunc)global_find, widget);
    
    if (result && !REF)
    {
        TEST_FAIL ("'widget' is not removed from toplist", NULL);
    }
    
    g_list_foreach (list, (GFunc)g_object_unref, NULL);
    g_list_free (list);
    
    if (REF)
    {
        gtk_widget_unref (widget);
    }
    
    #undef WIDGET
    #undef REF
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_destroy
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: If the widget is a toplevel (derived from GtkWindow), it will be removed from the list of toplevels, and the reference GTK+ holds to it will be removed.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_destroy
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Removing a widget from its container or the list of toplevels results in the widget being finalized, unless you've added additional references to the widget with g_object_ref().'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_134()
{
    #define WIDGET gtk_dialog_new ()
    #define REF FALSE
    
    GtkWidget* widget;
    GList* list = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    if (REF)
    {
        gtk_widget_ref (widget);
    }
    
    gtk_widget_destroy (widget);
    
    list = gtk_window_list_toplevels ();
    
    if (!list)
    {
        TEST_FAIL ("gtk_window_list_toplevels () returns NULL", NULL);
        return;
    }
    
    g_list_foreach (list, (GFunc)g_object_ref, NULL);
    g_list_foreach (list, (GFunc)global_find, widget);
    
    if (result && !REF)
    {
        TEST_FAIL ("'widget' is not removed from toplist", NULL);
    }
    
    g_list_foreach (list, (GFunc)g_object_unref, NULL);
    g_list_free (list);
    
    if (REF)
    {
        gtk_widget_unref (widget);
    }
    
    #undef WIDGET
    #undef REF
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_destroyed
 * Params: GtkWidget *widget, GtkWidget **widget_pointer
 * Returns: void
 * Assertion: This function sets *widget_pointer to NULL if widget_pointer != NULL.
 * Params Values: GtkWidget *widget, GtkWidget **widget_pointer
 * Expected: void  
 */
static void test_purpose_135()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    gint ref_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    g_signal_connect (G_OBJECT (widget), "destroy", GTK_SIGNAL_FUNC (gtk_widget_destroyed), &widget);
    
    gtk_widget_destroy (widget);
    
    if (widget)
    {
        TEST_FAIL ("'widget' should be NULL", NULL);
    }
    
    #undef WIDGET 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_destroyed
 * Params: GtkWidget *widget, GtkWidget **widget_pointer
 * Returns: void
 * Assertion: This function sets *widget_pointer to NULL if widget_pointer != NULL.
 * Params Values: GtkWidget *widget, GtkWidget **widget_pointer
 * Expected: void  
 */
static void test_purpose_136()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    gint ref_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    g_signal_connect (G_OBJECT (widget), "destroy", GTK_SIGNAL_FUNC (gtk_widget_destroyed), &widget);
    
    gtk_widget_destroy (widget);
    
    if (widget)
    {
        TEST_FAIL ("'widget' should be NULL", NULL);
    }
    
    #undef WIDGET 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_unparent
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Should be called by implementations of the remove method on GtkContainer, to dissociate a child from the container.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_destroy
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Removing a widget from its container or the list of toplevels results in the widget being finalized, unless you've added additional references to the widget with g_object_ref().'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_137()
{
    #define PARENT gtk_vbox_new (TRUE, 10)
    #define WIDGET gtk_button_new ()
    
    GtkWidget* parent;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("PARENT is not GTK_CONTAINER", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_container_add (GTK_CONTAINER (parent), gtk_label_new ("Label1"));
    gtk_container_add (GTK_CONTAINER (parent), gtk_label_new ("Label2"));
    
    gtk_widget_set_parent (widget, parent);
    gtk_widget_unparent (widget);
    gtk_container_foreach (GTK_CONTAINER (parent), global_find, widget);
    
    if (result)
    {
        TEST_FAIL ("'widget' is not removed from 'parent'", NULL);
    }
    
    gtk_widget_destroy (parent);
    
    #undef PARENT 
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_unparent
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Should be called by implementations of the remove method on GtkContainer, to dissociate a child from the container.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_destroy
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Removing a widget from its container or the list of toplevels results in the widget being finalized, unless you've added additional references to the widget with g_object_ref().'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_138()
{
    #define PARENT gtk_hbox_new (FALSE, 10)
    #define WIDGET gtk_label_new ("Label")
    
    GtkWidget* parent;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("PARENT is not GTK_CONTAINER", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_container_add (GTK_CONTAINER (parent), gtk_label_new ("Label1"));
    gtk_container_add (GTK_CONTAINER (parent), gtk_label_new ("Label2"));
    
    gtk_widget_set_parent (widget, parent);
    gtk_widget_unparent (widget);
    gtk_container_foreach (GTK_CONTAINER (parent), global_find, widget);
    
    if (result)
    {
        TEST_FAIL ("'widget' is not removed from 'parent'", NULL);
    }
    
    gtk_widget_destroy (parent);
    
    #undef PARENT 
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_unparent
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Should be called by implementations of the remove method on GtkContainer, to dissociate a child from the container.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_destroy
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Removing a widget from its container or the list of toplevels results in the widget being finalized, unless you've added additional references to the widget with g_object_ref().'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_139()
{
    #define PARENT gtk_hbox_new (FALSE, 10)
    #define WIDGET gtk_vbox_new (TRUE, 10)
    
    GtkWidget* parent;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("PARENT is not GTK_CONTAINER", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_container_add (GTK_CONTAINER (parent), gtk_label_new ("Label1"));
    gtk_container_add (GTK_CONTAINER (parent), gtk_label_new ("Label2"));
    
    gtk_widget_set_parent (widget, parent);
    gtk_widget_unparent (widget);
    gtk_container_foreach (GTK_CONTAINER (parent), global_find, widget);
    
    if (result)
    {
        TEST_FAIL ("'widget' is not removed from 'parent'", NULL);
    }
    
    gtk_widget_destroy (parent);
    
    #undef PARENT 
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_show
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Flags a widget to be displayed.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_show
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Any widget that isn't shown will not appear on the screen.'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_140()
{
    #define WIDGET gtk_button_new ()
    #define SHOW TRUE
    
    GtkWidget* widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "show", GTK_SIGNAL_FUNC (global_show), NULL);
    
    if (SHOW)
    {
        gtk_widget_show (widget);
    }
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    
    result &= visible;
    
    if (result && !SHOW)
    {
        TEST_FAIL ("'widget' is not shown", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef SHOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_show
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Flags a widget to be displayed.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_show
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Any widget that isn't shown will not appear on the screen.'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_141()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define SHOW TRUE
    
    GtkWidget* widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "show", GTK_SIGNAL_FUNC (global_show), NULL);
    
    if (SHOW)
    {
        gtk_widget_show (widget);
    }
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    
    result &= visible;
    
    if (result && !SHOW)
    {
        TEST_FAIL ("'widget' is not shown", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef SHOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_show
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Flags a widget to be displayed.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_show
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Any widget that isn't shown will not appear on the screen.'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_142()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define SHOW FALSE
    
    GtkWidget* widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "show", GTK_SIGNAL_FUNC (global_show), NULL);
    
    if (SHOW)
    {
        gtk_widget_show (widget);
    }
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    
    result &= visible;
    
    if (result && !SHOW)
    {
        TEST_FAIL ("'widget' is not shown", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef SHOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_show
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Flags a widget to be displayed.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_show
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Any widget that isn't shown will not appear on the screen.'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_143()
{
    #define WIDGET gtk_dialog_new ()
    #define SHOW FALSE
    
    GtkWidget* widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "show", GTK_SIGNAL_FUNC (global_show), NULL);
    
    if (SHOW)
    {
        gtk_widget_show (widget);
    }
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    
    result &= visible;
    
    if (result && !SHOW)
    {
        TEST_FAIL ("'widget' is not shown", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef SHOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_show
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: When a toplevel container is shown, it is immediately realized and mapped; other shown widgets are realized and mapped when their toplevel container is realized and mapped.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_144()
{
    #define WIDGET gtk_label_new ("Label")
    
    GtkWidget* parent;
    GtkWidget* widget;
    gboolean realized;
    gboolean mapped;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    realized = FALSE;
    mapped = FALSE;
    widget = WIDGET;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "realize", GTK_SIGNAL_FUNC (global_realize_map), &realized);
    g_signal_connect (G_OBJECT (widget), "map", GTK_SIGNAL_FUNC (global_realize_map), &mapped);
    g_signal_connect (G_OBJECT (widget), "show", GTK_SIGNAL_FUNC (global_show), NULL);
    
    if (GTK_WIDGET_TOPLEVEL (widget))
    {
        gtk_widget_show (widget);
        
    } else {
        
        parent = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        gtk_container_add (GTK_CONTAINER (parent), widget);
        gtk_widget_show (widget);
        gtk_widget_show (parent);
        widget = parent;
    }
    
    if (!(result && realized  && mapped))
    {
        TEST_FAIL ("'widget' is not realized = %i, mapped = %i or shown = %i ", realized, mapped, result);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_show
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: When a toplevel container is shown, it is immediately realized and mapped; other shown widgets are realized and mapped when their toplevel container is realized and mapped.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_145()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* parent;
    GtkWidget* widget;
    gboolean realized;
    gboolean mapped;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    realized = FALSE;
    mapped = FALSE;
    widget = WIDGET;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "realize", GTK_SIGNAL_FUNC (global_realize_map), &realized);
    g_signal_connect (G_OBJECT (widget), "map", GTK_SIGNAL_FUNC (global_realize_map), &mapped);
    g_signal_connect (G_OBJECT (widget), "show", GTK_SIGNAL_FUNC (global_show), NULL);
    
    if (GTK_WIDGET_TOPLEVEL (widget))
    {
        gtk_widget_show (widget);
        
    } else {
        
        parent = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        gtk_container_add (GTK_CONTAINER (parent), widget);
        gtk_widget_show (widget);
        gtk_widget_show (parent);
        widget = parent;
    }
    
    if (!(result && realized  && mapped))
    {
        TEST_FAIL ("'widget' is not realized = %i, mapped = %i or shown = %i ", realized, mapped, result);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_show
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: When a toplevel container is shown, it is immediately realized and mapped; other shown widgets are realized and mapped when their toplevel container is realized and mapped.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_146()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* parent;
    GtkWidget* widget;
    gboolean realized;
    gboolean mapped;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    realized = FALSE;
    mapped = FALSE;
    widget = WIDGET;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "realize", GTK_SIGNAL_FUNC (global_realize_map), &realized);
    g_signal_connect (G_OBJECT (widget), "map", GTK_SIGNAL_FUNC (global_realize_map), &mapped);
    g_signal_connect (G_OBJECT (widget), "show", GTK_SIGNAL_FUNC (global_show), NULL);
    
    if (GTK_WIDGET_TOPLEVEL (widget))
    {
        gtk_widget_show (widget);
        
    } else {
        
        parent = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        gtk_container_add (GTK_CONTAINER (parent), widget);
        gtk_widget_show (widget);
        gtk_widget_show (parent);
        widget = parent;
    }
    
    if (!(result && realized  && mapped))
    {
        TEST_FAIL ("'widget' is not realized = %i, mapped = %i or shown = %i ", realized, mapped, result);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_show
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: When a toplevel container is shown, it is immediately realized and mapped; other shown widgets are realized and mapped when their toplevel container is realized and mapped.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_147()
{
    #define WIDGET gtk_dialog_new ()
    
    GtkWidget* parent;
    GtkWidget* widget;
    gboolean realized;
    gboolean mapped;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    realized = FALSE;
    mapped = FALSE;
    widget = WIDGET;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "realize", GTK_SIGNAL_FUNC (global_realize_map), &realized);
    g_signal_connect (G_OBJECT (widget), "map", GTK_SIGNAL_FUNC (global_realize_map), &mapped);
    g_signal_connect (G_OBJECT (widget), "show", GTK_SIGNAL_FUNC (global_show), NULL);
    
    if (GTK_WIDGET_TOPLEVEL (widget))
    {
        gtk_widget_show (widget);
        
    } else {
        
        parent = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        gtk_container_add (GTK_CONTAINER (parent), widget);
        gtk_widget_show (widget);
        gtk_widget_show (parent);
        widget = parent;
    }
    
    if (!(result && realized  && mapped))
    {
        TEST_FAIL ("'widget' is not realized = %i, mapped = %i or shown = %i ", realized, mapped, result);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_show_now
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Shows a widget.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_show_now
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: If the widget is an unmapped toplevel widget (i.e. a GtkWindow that has not yet been shown), enter the main loop and wait for the window to actually be mapped. 
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_148()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "show", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_show_now (widget);
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    
    result &= visible;
    
    if (!result)
    {
        TEST_FAIL ("'widget' is not shown", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_show_now
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Shows a widget.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_show_now
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: If the widget is an unmapped toplevel widget (i.e. a GtkWindow that has not yet been shown), enter the main loop and wait for the window to actually be mapped. 
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_149()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "show", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_show_now (widget);
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    
    result &= visible;
    
    if (!result)
    {
        TEST_FAIL ("'widget' is not shown", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_show_now
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Shows a widget.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_show_now
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: If the widget is an unmapped toplevel widget (i.e. a GtkWindow that has not yet been shown), enter the main loop and wait for the window to actually be mapped. 
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_150()
{
    #define WIDGET gtk_dialog_new ()
    
    GtkWidget* widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "show", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_show_now (widget);
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    
    result &= visible;
    
    if (!result)
    {
        TEST_FAIL ("'widget' is not shown", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_hide
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Reverses the effects of gtk_widget_show(), causing the widget to be hidden (invisible to the user).
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_151()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "hide", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_show (widget);
    gtk_widget_hide (widget);
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    
    result &= !visible;
    
    if (!result)
    {
        TEST_FAIL ("'widget' is not hide", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_hide
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Reverses the effects of gtk_widget_show(), causing the widget to be hidden (invisible to the user).
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_152()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "hide", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_show (widget);
    gtk_widget_hide (widget);
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    
    result &= !visible;
    
    if (!result)
    {
        TEST_FAIL ("'widget' is not hide", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_hide
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Reverses the effects of gtk_widget_show(), causing the widget to be hidden (invisible to the user).
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_153()
{
    #define WIDGET gtk_dialog_new ()
    
    GtkWidget* widget;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "hide", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_show (widget);
    gtk_widget_hide (widget);
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    
    result &= !visible;
    
    if (!result)
    {
        TEST_FAIL ("'widget' is not hide", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_show_all
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Recursively shows a widget, and any child widgets (if the widget is a container).
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_154()
{
    #define WIDGET gtk_vbox_new (TRUE, 10)
    #define CHILD gtk_button_new ()
    
    GtkWidget* widget;
    GtkWidget* child;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    gtk_widget_hide_all (widget);
    
    gtk_widget_show_all (widget);
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    if (!visible)
    {
        TEST_FAIL ("'widget' is not visible", NULL);
    }
    
    g_object_get (GTK_OBJECT (child), "visible", &visible, NULL);
    if (!visible)
    {
        TEST_FAIL ("'child' is not visible", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_show_all
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Recursively shows a widget, and any child widgets (if the widget is a container).
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_155()
{
    #define WIDGET gtk_hbox_new (FALSE, 10)
    #define CHILD gtk_label_new ("Label")
    
    GtkWidget* widget;
    GtkWidget* child;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    gtk_widget_hide_all (widget);
    
    gtk_widget_show_all (widget);
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    if (!visible)
    {
        TEST_FAIL ("'widget' is not visible", NULL);
    }
    
    g_object_get (GTK_OBJECT (child), "visible", &visible, NULL);
    if (!visible)
    {
        TEST_FAIL ("'child' is not visible", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_show_all
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Recursively shows a widget, and any child widgets (if the widget is a container).
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_156()
{
    #define WIDGET gtk_vbox_new (TRUE, 10)
    #define CHILD gtk_hbox_new (TRUE, 10)
    
    GtkWidget* widget;
    GtkWidget* child;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    gtk_widget_hide_all (widget);
    
    gtk_widget_show_all (widget);
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    if (!visible)
    {
        TEST_FAIL ("'widget' is not visible", NULL);
    }
    
    g_object_get (GTK_OBJECT (child), "visible", &visible, NULL);
    if (!visible)
    {
        TEST_FAIL ("'child' is not visible", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_hide_all
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Recursively hides a widget and any child widgets.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_157()
{
    #define WIDGET gtk_vbox_new (TRUE, 10)
    #define CHILD gtk_button_new ()
    
    GtkWidget* widget;
    GtkWidget* child;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    gtk_widget_show_all (widget);
    
    gtk_widget_hide_all (widget);
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    if (visible)
    {
        TEST_FAIL ("'widget' is not hide", NULL);
    }
    
    g_object_get (GTK_OBJECT (child), "visible", &visible, NULL);
    if (visible)
    {
        TEST_FAIL ("'child' is not hide", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_hide_all
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Recursively hides a widget and any child widgets.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_158()
{
    #define WIDGET gtk_hbox_new (FALSE, 10)
    #define CHILD gtk_label_new ("Label")
    
    GtkWidget* widget;
    GtkWidget* child;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    gtk_widget_show_all (widget);
    
    gtk_widget_hide_all (widget);
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    if (visible)
    {
        TEST_FAIL ("'widget' is not hide", NULL);
    }
    
    g_object_get (GTK_OBJECT (child), "visible", &visible, NULL);
    if (visible)
    {
        TEST_FAIL ("'child' is not hide", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_hide_all
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Recursively hides a widget and any child widgets.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_159()
{
    #define WIDGET gtk_hbox_new (TRUE, 10)
    #define CHILD gtk_vbox_new (TRUE, 10)
    
    GtkWidget* widget;
    GtkWidget* child;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    gtk_widget_show_all (widget);
    
    gtk_widget_hide_all (widget);
    
    g_object_get (GTK_OBJECT (widget), "visible", &visible, NULL);
    if (visible)
    {
        TEST_FAIL ("'widget' is not hide", NULL);
    }
    
    g_object_get (GTK_OBJECT (child), "visible", &visible, NULL);
    if (visible)
    {
        TEST_FAIL ("'child' is not hide", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_map
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Causes a widget to be mapped if it isn't already.'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_160()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "map", GTK_SIGNAL_FUNC (global_show), NULL);
    
    g_object_set (GTK_OBJECT (widget), "visible", TRUE, NULL);         // is it correct ?
    
    gtk_widget_map (widget);
    
    if (!result || !GTK_WIDGET_MAPPED (widget))
    {
        TEST_FAIL ("'widget' is not mapped", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_map
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Causes a widget to be mapped if it isn't already.'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_161()
{
    #define WIDGET gtk_dialog_new ()
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "map", GTK_SIGNAL_FUNC (global_show), NULL);
    
    g_object_set (GTK_OBJECT (widget), "visible", TRUE, NULL);         // is it correct ?
    
    gtk_widget_map (widget);
    
    if (!result || !GTK_WIDGET_MAPPED (widget))
    {
        TEST_FAIL ("'widget' is not mapped", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_unmap
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Causes a widget to be unmapped if it's currently mapped.'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_162()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "unmap", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_show (widget);
    gtk_widget_unmap (widget);
    
    if (!result || GTK_WIDGET_MAPPED (widget))
    {
        TEST_FAIL ("'widget' is not mapped", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_unmap
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Causes a widget to be unmapped if it's currently mapped.'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_163()
{
    #define WIDGET gtk_dialog_new ()
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "unmap", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_show (widget);
    gtk_widget_unmap (widget);
    
    if (!result || GTK_WIDGET_MAPPED (widget))
    {
        TEST_FAIL ("'widget' is not mapped", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_realize
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Creates the GDK (windowing system) resources associated with a widget.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_164()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "realize", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_realize (widget);
    
    if (!result)
    {
        TEST_FAIL ("'realize' signal not catched", NULL);
    }
    
    if (!widget->window)
    {
        TEST_FAIL ("widget->window is NULL", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_realize
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Creates the GDK (windowing system) resources associated with a widget.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_165()
{
    #define WIDGET gtk_dialog_new ()
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "realize", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_realize (widget);
    
    if (!result)
    {
        TEST_FAIL ("'realize' signal not catched", NULL);
    }
    
    if (!widget->window)
    {
        TEST_FAIL ("widget->window is NULL", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_realize
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Realizing a widget requires all the widget's parent widgets to be realized; calling gtk_widget_realize() realizes the widget's parents in addition to widget itself.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_166()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define CHILD gtk_button_new ()
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    g_signal_connect (G_OBJECT (widget), "realize", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_realize (child);
    
    if (!result)
    {
        TEST_FAIL ("'realize' signal not catched", NULL);
    }
    
    if (!widget->window)
    {
        TEST_FAIL ("widget->window is NULL", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_realize
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Realizing a widget requires all the widget's parent widgets to be realized; calling gtk_widget_realize() realizes the widget's parents in addition to widget itself.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_167()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define CHILD gtk_entry_new ()
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    g_signal_connect (G_OBJECT (widget), "realize", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_realize (child);
    
    if (!result)
    {
        TEST_FAIL ("'realize' signal not catched", NULL);
    }
    
    if (!widget->window)
    {
        TEST_FAIL ("widget->window is NULL", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_realize
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Realizing a widget requires all the widget's parent widgets to be realized; calling gtk_widget_realize() realizes the widget's parents in addition to widget itself.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_168()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define CHILD gtk_toggle_button_new ()
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    g_signal_connect (G_OBJECT (widget), "realize", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_realize (child);
    
    if (!result)
    {
        TEST_FAIL ("'realize' signal not catched", NULL);
    }
    
    if (!widget->window)
    {
        TEST_FAIL ("widget->window is NULL", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_realize
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Realizing a widget requires all the widget's parent widgets to be realized; calling gtk_widget_realize() realizes the widget's parents in addition to widget itself.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_169()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define CHILD gtk_label_new ("Label")
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    g_signal_connect (G_OBJECT (widget), "realize", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_realize (child);
    
    if (!result)
    {
        TEST_FAIL ("'realize' signal not catched", NULL);
    }
    
    if (!widget->window)
    {
        TEST_FAIL ("widget->window is NULL", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_unrealize
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Causes a widget to be unrealized (frees all GDK resources associated with the widget, such as widget->window).
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_170()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    g_signal_connect (G_OBJECT (widget), "unrealize", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_realize (widget);
    gtk_widget_unrealize (widget);
    
    if (!result)
    {
        TEST_FAIL ("'unrealize' signal not catched", NULL);
    }
    
    if (widget->window)
    {
        TEST_FAIL ("widget->window is not NULL", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_unrealize
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Causes a widget to be unrealized (frees all GDK resources associated with the widget, such as widget->window).
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_171()
{
    #define WIDGET gtk_dialog_new ()
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    g_signal_connect (G_OBJECT (widget), "unrealize", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_realize (widget);
    gtk_widget_unrealize (widget);
    
    if (!result)
    {
        TEST_FAIL ("'unrealize' signal not catched", NULL);
    }
    
    if (widget->window)
    {
        TEST_FAIL ("widget->window is not NULL", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_queue_draw
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Equivalent to calling gtk_widget_queue_draw_area() for the entire area of a widget.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_172()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_queue_draw (widget);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_queue_draw
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Equivalent to calling gtk_widget_queue_draw_area() for the entire area of a widget.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_173()
{
    #define WIDGET gtk_dialog_new ()
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_queue_draw (widget);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_queue_draw
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Equivalent to calling gtk_widget_queue_draw_area() for the entire area of a widget.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_174()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_queue_draw (widget);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_queue_draw
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Equivalent to calling gtk_widget_queue_draw_area() for the entire area of a widget.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_175()
{
    #define WIDGET gtk_label_new ("Label")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_queue_draw (widget);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_queue_resize
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Flags a widget to have its size renegotiated; should be called when a widget for some reason has a new size request.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_176()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_queue_resize (widget);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_queue_resize
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Flags a widget to have its size renegotiated; should be called when a widget for some reason has a new size request.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_177()
{
    #define WIDGET gtk_dialog_new ()
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_queue_resize (widget);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_queue_resize
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Flags a widget to have its size renegotiated; should be called when a widget for some reason has a new size request.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_178()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_queue_resize (widget);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_queue_resize
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Flags a widget to have its size renegotiated; should be called when a widget for some reason has a new size request.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_179()
{
    #define WIDGET gtk_label_new ("Label")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_queue_resize (widget);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_size_request
 * Params: GtkWidget *widget, GtkRequisition *requisition
 * Returns: void
 * Assertion: Obtains the preferred size of a widget. 
 * Params Values: GtkWidget *widget, GtkRequisition *requisition
 * Expected: void  
 */
static void test_purpose_180()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define WIDTH G_MAXINT
    #define HEIGHT 100
    
    GtkWidget* widget;
    GtkRequisition req;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_size_request (widget, WIDTH, HEIGHT);
    
    gtk_widget_size_request (widget, &req);
    
    if ((req.width != WIDTH) || (req.height != HEIGHT))
    {
        TEST_FAIL ("size not equal", NULL);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_size_request
 * Params: GtkWidget *widget, GtkRequisition *requisition
 * Returns: void
 * Assertion: Obtains the preferred size of a widget. 
 * Params Values: GtkWidget *widget, GtkRequisition *requisition
 * Expected: void  
 */
static void test_purpose_181()
{
    #define WIDGET gtk_button_new ()
    #define WIDTH 100
    #define HEIGHT 30
    
    GtkWidget* widget;
    GtkRequisition req;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_size_request (widget, WIDTH, HEIGHT);
    
    gtk_widget_size_request (widget, &req);
    
    if ((req.width != WIDTH) || (req.height != HEIGHT))
    {
        TEST_FAIL ("size not equal", NULL);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_size_allocate
 * Params: GtkWidget *widget, GtkAllocation *allocation
 * Returns: void
 * Assertion:This function is only used by GtkContainer subclasses, to assign a size and position to their child widgets.
 * Params Values: GtkWidget *widget, GtkAllocation *allocation
 * Expected: void  
 */
static void test_purpose_182()
{
    #define WIDGET gtk_vbox_new (TRUE, 10)
    #define CHILD gtk_button_new ()
    #define WIDTH G_MAXINT
    #define HEIGHT 100
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkAllocation all;
    GtkRequisition req;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_widget_set_size_request (child, WIDTH, HEIGHT);
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    all.x = 0;
    all.y = 0;
    all.width = WIDTH;
    all.height = HEIGHT;
    gtk_widget_size_allocate (widget, &all);
    
    gtk_widget_size_request (child, &req);
    
    if ((all.width != req.width) || (all.height != req.height))
    {
        TEST_FAIL ("size not equal (%i, %i, %i, %i) ,  (%i, %i)", all.x, all.y, all.width , all.height , req.width, req.height);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_size_allocate
 * Params: GtkWidget *widget, GtkAllocation *allocation
 * Returns: void
 * Assertion:This function is only used by GtkContainer subclasses, to assign a size and position to their child widgets.
 * Params Values: GtkWidget *widget, GtkAllocation *allocation
 * Expected: void  
 */
static void test_purpose_183()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define CHILD gtk_label_new ("Label")
    #define WIDTH 100
    #define HEIGHT 100
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkAllocation all;
    GtkRequisition req;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_widget_set_size_request (child, WIDTH, HEIGHT);
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    all.x = 0;
    all.y = 0;
    all.width = WIDTH;
    all.height = HEIGHT;
    gtk_widget_size_allocate (widget, &all);
    
    gtk_widget_size_request (child, &req);
    
    if ((all.width != req.width) || (all.height != req.height))
    {
        TEST_FAIL ("size not equal (%i, %i, %i, %i) ,  (%i, %i)", all.x, all.y, all.width , all.height , req.width, req.height);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_size_allocate
 * Params: GtkWidget *widget, GtkAllocation *allocation
 * Returns: void
 * Assertion:This function is only used by GtkContainer subclasses, to assign a size and position to their child widgets.
 * Params Values: GtkWidget *widget, GtkAllocation *allocation
 * Expected: void  
 */
static void test_purpose_184()
{
    #define WIDGET gtk_hbox_new (TRUE, 10)
    #define CHILD gtk_vbox_new (TRUE, 10)
    #define WIDTH 20
    #define HEIGHT 50
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkAllocation all;
    GtkRequisition req;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_widget_set_size_request (child, WIDTH, HEIGHT);
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    all.x = 0;
    all.y = 0;
    all.width = WIDTH;
    all.height = HEIGHT;
    gtk_widget_size_allocate (widget, &all);
    
    gtk_widget_size_request (child, &req);
    
    if ((all.width != req.width) || (all.height != req.height))
    {
        TEST_FAIL ("size not equal (%i, %i, %i, %i) ,  (%i, %i)", all.x, all.y, all.width , all.height , req.width, req.height);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_add_accelerator
 * Params: GtkWidget *widget, const gchar *accel_signal, GtkAccelGroup *accel_group, guint accel_key, guint accel_mods, GtkAccelFlags accel_flags
 * Returns: void
 * Assertion: Installs an accelerator for this widget in accel_group that causes accel_signal to be emitted if the accelerator is activated.
 * Params Values: GtkWidget *widget, const gchar *accel_signal, GtkAccelGroup *accel_group, guint accel_key, guint accel_mods, GtkAccelFlags accel_flags
 * Expected: void
 * 
 * Name: gtk_widget_remove_accelerator
 * Params: GtkWidget *widget, GtkAccelGroup *accel_group, guint accel_key, guint accel_mods
 * Returns: void
 * Assertion: Removes an accelerator from widget, previously installed with gtk_widget_add_accelerator().
 * Params Values: GtkWidget *widget, GtkAccelGroup *accel_group, guint accel_key, guint accel_mods
 * Expected: void  
 */
static void test_purpose_185()
{
    #define WIDGET gtk_menu_item_new ()
    #define SIGNAL "activate"
    #define KEY GDK_A
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* widget;
    GtkWidget* window;
    gboolean remove_res;
    GClosure* closure;
    GtkAccelGroup* accel_group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    accel_group = gtk_accel_group_new ();
    closure = g_cclosure_new ((GCallback) global_set_result, NULL, NULL);
    
    /*  g_signal_connect (G_OBJECT (widget), SIGNAL, GTK_SIGNAL_FUNC (global_show), NULL); */
    
    gtk_widget_add_accelerator (widget, SIGNAL, accel_group, KEY, MODS, FLAGS);
    remove_res = gtk_widget_remove_accelerator (widget, accel_group, KEY, MODS);
    
    if (!remove_res)
    {
        TEST_FAIL ("just added accelerator '%s' can't be removed", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef SIGNAL
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_add_accelerator
 * Params: GtkWidget *widget, const gchar *accel_signal, GtkAccelGroup *accel_group, guint accel_key, guint accel_mods, GtkAccelFlags accel_flags
 * Returns: void
 * Assertion: Installs an accelerator for this widget in accel_group that causes accel_signal to be emitted if the accelerator is activated.
 * Params Values: GtkWidget *widget, const gchar *accel_signal, GtkAccelGroup *accel_group, guint accel_key, guint accel_mods, GtkAccelFlags accel_flags
 * Expected: void
 * 
 * Name: gtk_widget_remove_accelerator
 * Params: GtkWidget *widget, GtkAccelGroup *accel_group, guint accel_key, guint accel_mods
 * Returns: void
 * Assertion: Removes an accelerator from widget, previously installed with gtk_widget_add_accelerator().
 * Params Values: GtkWidget *widget, GtkAccelGroup *accel_group, guint accel_key, guint accel_mods
 * Expected: void  
 */
static void test_purpose_186()
{
    #define WIDGET gtk_entry_new ()
    #define SIGNAL "activate"
    #define KEY GDK_B
    #define MODS 0
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* widget;
    GtkWidget* window;
    gboolean remove_res;
    GClosure* closure;
    GtkAccelGroup* accel_group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    accel_group = gtk_accel_group_new ();
    closure = g_cclosure_new ((GCallback) global_set_result, NULL, NULL);
    
    /*  g_signal_connect (G_OBJECT (widget), SIGNAL, GTK_SIGNAL_FUNC (global_show), NULL); */
    
    gtk_widget_add_accelerator (widget, SIGNAL, accel_group, KEY, MODS, FLAGS);
    remove_res = gtk_widget_remove_accelerator (widget, accel_group, KEY, MODS);
    
    if (!remove_res)
    {
        TEST_FAIL ("just added accelerator '%s' can't be removed", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef SIGNAL
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_add_accelerator
 * Params: GtkWidget *widget, const gchar *accel_signal, GtkAccelGroup *accel_group, guint accel_key, guint accel_mods, GtkAccelFlags accel_flags
 * Returns: void
 * Assertion: Installs an accelerator for this widget in accel_group that causes accel_signal to be emitted if the accelerator is activated.
 * Params Values: GtkWidget *widget, const gchar *accel_signal, GtkAccelGroup *accel_group, guint accel_key, guint accel_mods, GtkAccelFlags accel_flags
 * Expected: void
 * 
 * Name: gtk_widget_remove_accelerator
 * Params: GtkWidget *widget, GtkAccelGroup *accel_group, guint accel_key, guint accel_mods
 * Returns: void
 * Assertion: Removes an accelerator from widget, previously installed with gtk_widget_add_accelerator().
 * Params Values: GtkWidget *widget, GtkAccelGroup *accel_group, guint accel_key, guint accel_mods
 * Expected: void  
 */
static void test_purpose_187()
{
    #define WIDGET gtk_label_new ("label")
    #define SIGNAL "copy-clipboard"
    #define KEY GDK_A
    #define MODS GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK
    #define FLAGS GTK_ACCEL_VISIBLE
    
    GtkWidget* widget;
    GtkWidget* window;
    gboolean remove_res;
    GClosure* closure;
    GtkAccelGroup* accel_group;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    accel_group = gtk_accel_group_new ();
    closure = g_cclosure_new ((GCallback) global_set_result, NULL, NULL);
    
    /*  g_signal_connect (G_OBJECT (widget), SIGNAL, GTK_SIGNAL_FUNC (global_show), NULL); */
    
    gtk_widget_add_accelerator (widget, SIGNAL, accel_group, KEY, MODS, FLAGS);
    remove_res = gtk_widget_remove_accelerator (widget, accel_group, KEY, MODS);
    
    if (!remove_res)
    {
        TEST_FAIL ("just added accelerator '%s' can't be removed", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef SIGNAL
    #undef KEY
    #undef MODS
    #undef FLAGS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_activate
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: For widgets that can be "activated" (buttons, menu items, etc.) this function activates them.
 * Params Values: GtkWidget *widget
 * Expected: gboolean
 * 
 * Name:  gtk_widget_activate
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: If widget isn't activatable, the function returns FALSE.'
 * Params Values: GtkWidget *widget
 * Expected: gboolean  
 */
static void test_purpose_188()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define CORRECT_RES FALSE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_show (widget);
    
    if (GTK_WIDGET_GET_CLASS (widget)->activate_signal)
    {
        g_signal_connect (G_OBJECT (widget), "activate", GTK_SIGNAL_FUNC (global_show), NULL);
    } 
    
    result = gtk_widget_activate (widget);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("gtk_widget_activate () returned %d instead of %d", 
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_activate
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: For widgets that can be "activated" (buttons, menu items, etc.) this function activates them.
 * Params Values: GtkWidget *widget
 * Expected: gboolean
 * 
 * Name:  gtk_widget_activate
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: If widget isn't activatable, the function returns FALSE.'
 * Params Values: GtkWidget *widget
 * Expected: gboolean  
 */
static void test_purpose_189()
{
    #define WIDGET gtk_label_new ("Label")
    #define CORRECT_RES FALSE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_show (widget);
    
    if (GTK_WIDGET_GET_CLASS (widget)->activate_signal)
    {
        g_signal_connect (G_OBJECT (widget), "activate", GTK_SIGNAL_FUNC (global_show), NULL);
    } 
    
    result = gtk_widget_activate (widget);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("gtk_widget_activate () returned %d instead of %d", 
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_activate
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: For widgets that can be "activated" (buttons, menu items, etc.) this function activates them.
 * Params Values: GtkWidget *widget
 * Expected: gboolean
 * 
 * Name:  gtk_widget_activate
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: If widget isn't activatable, the function returns FALSE.'
 * Params Values: GtkWidget *widget
 * Expected: gboolean  
 */
static void test_purpose_190()
{
    #define WIDGET gtk_button_new ()
    #define CORRECT_RES TRUE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_show (widget);
    
    if (GTK_WIDGET_GET_CLASS (widget)->activate_signal)
    {
        g_signal_connect (G_OBJECT (widget), "activate", GTK_SIGNAL_FUNC (global_show), NULL);
    } 
    
    result = gtk_widget_activate (widget);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("gtk_widget_activate () returned %d instead of %d", 
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_activate
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: For widgets that can be "activated" (buttons, menu items, etc.) this function activates them.
 * Params Values: GtkWidget *widget
 * Expected: gboolean
 * 
 * Name:  gtk_widget_activate
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: If widget isn't activatable, the function returns FALSE.'
 * Params Values: GtkWidget *widget
 * Expected: gboolean  
 */
static void test_purpose_191()
{
    #define WIDGET gtk_toggle_button_new ()
    #define CORRECT_RES TRUE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_show (widget);
    
    if (GTK_WIDGET_GET_CLASS (widget)->activate_signal)
    {
        g_signal_connect (G_OBJECT (widget), "activate", GTK_SIGNAL_FUNC (global_show), NULL);
    } 
    
    result = gtk_widget_activate (widget);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("gtk_widget_activate () returned %d instead of %d", 
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_activate
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: For widgets that can be "activated" (buttons, menu items, etc.) this function activates them.
 * Params Values: GtkWidget *widget
 * Expected: gboolean
 * 
 * Name:  gtk_widget_activate
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: If widget isn't activatable, the function returns FALSE.'
 * Params Values: GtkWidget *widget
 * Expected: gboolean  
 */
static void test_purpose_192()
{
    #define WIDGET gtk_check_button_new ()
    #define CORRECT_RES TRUE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_show (widget);
    
    if (GTK_WIDGET_GET_CLASS (widget)->activate_signal)
    {
        g_signal_connect (G_OBJECT (widget), "activate", GTK_SIGNAL_FUNC (global_show), NULL);
    } 
    
    result = gtk_widget_activate (widget);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("gtk_widget_activate () returned %d instead of %d", 
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_reparent
 * Params: GtkWidget *widget, GtkWidget *new_parent
 * Returns: void
 * Assertion: Moves a widget from one GtkContainer to another, handling reference count issues to avoid destroying the widget. 
 * Params Values: GtkWidget *widget, GtkWidget *new_parent
 * Expected: void  
 */
static void test_purpose_193()
{
    #define WIDGET gtk_button_new ()
    #define PARENT gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkWidget* widget;
    GtkWidget* parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL ("'parent' is NULL", NULL); 
        return;
    } 
    
    gtk_container_add (GTK_CONTAINER (gtk_vbox_new (FALSE, 10)), widget);
    gtk_widget_reparent (widget, parent);
    
    if (widget->parent != parent)
    {
        TEST_FAIL ("'parent' not changed", NULL);
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_reparent
 * Params: GtkWidget *widget, GtkWidget *new_parent
 * Returns: void
 * Assertion: Moves a widget from one GtkContainer to another, handling reference count issues to avoid destroying the widget. 
 * Params Values: GtkWidget *widget, GtkWidget *new_parent
 * Expected: void  
 */
static void test_purpose_194()
{
    #define WIDGET gtk_button_new ()
    #define PARENT gtk_vbox_new (TRUE, 10)
    
    GtkWidget* widget;
    GtkWidget* parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL ("'parent' is NULL", NULL); 
        return;
    } 
    
    gtk_container_add (GTK_CONTAINER (gtk_vbox_new (FALSE, 10)), widget);
    gtk_widget_reparent (widget, parent);
    
    if (widget->parent != parent)
    {
        TEST_FAIL ("'parent' not changed", NULL);
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_reparent
 * Params: GtkWidget *widget, GtkWidget *new_parent
 * Returns: void
 * Assertion: Moves a widget from one GtkContainer to another, handling reference count issues to avoid destroying the widget. 
 * Params Values: GtkWidget *widget, GtkWidget *new_parent
 * Expected: void  
 */
static void test_purpose_195()
{
    #define WIDGET gtk_toggle_button_new ()
    #define PARENT gtk_hbox_new (FALSE, 10)
    
    GtkWidget* widget;
    GtkWidget* parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL ("'parent' is NULL", NULL); 
        return;
    } 
    
    gtk_container_add (GTK_CONTAINER (gtk_vbox_new (FALSE, 10)), widget);
    gtk_widget_reparent (widget, parent);
    
    if (widget->parent != parent)
    {
        TEST_FAIL ("'parent' not changed", NULL);
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_intersect
 * Params: GtkWidget *widget,  GdkRectangle *area, GdkRectangle *intersection
 * Returns: gboolean
 * Assertion: Computes the intersection of a widget's area and area, storing the intersection in intersection, and returns TRUE if there was an intersection.'
 * Params Values: GtkWidget *widget, GdkRectangle *area, GdkRectangle *intersection
 * Expected: TRUE  
 */
static void test_purpose_196()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define RECT 0, 0, 10, 10
    #define AREA 0, 0, 10, 10
    #define INTER 0, 0, 10, 10
    #define RESULT TRUE
    
    GdkRectangle rect = {RECT};
    GdkRectangle area = {AREA};
    GdkRectangle inter = {INTER};
    
    GtkWidget* widget;
    GdkRectangle res = {0,0,0,0};
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_realize (widget);
    obj = (GdkWindowObject*)widget->window;
    obj->x = rect.x;
    obj->y = rect.y;
    gtk_widget_set_size_request (widget, rect.width, rect.height);
    gtk_widget_show_all (widget);
    
    if (RESULT != gtk_widget_intersect (widget, &area, &res))
    {
        TEST_FAIL ("results not equal", NULL); 
        return;
    }
    
    if ((inter.x != res.x) || (inter.y != res.y) || (inter.width != res.width) || (inter.height != res.height) )
    {
        TEST_FAIL ("rectangles not equal: res = (%i, %i, %i, %i) intersection = (%i, %i, %i, %i)", 
                   res.x, res.y, res.width, res.height,
                   inter.x, inter.y, inter.width, inter.height
                  );
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef RECT
    #undef AREA
    #undef INTER
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_intersect
 * Params: GtkWidget *widget,  GdkRectangle *area, GdkRectangle *intersection
 * Returns: gboolean
 * Assertion: Computes the intersection of a widget's area and area, storing the intersection in intersection, and returns TRUE if there was an intersection.'
 * Params Values: GtkWidget *widget, GdkRectangle *area, GdkRectangle *intersection
 * Expected: FALSE  
 */
static void test_purpose_197()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define RECT 0, 0, 10, 10
    #define AREA 10, 10, 10, 10
    #define INTER 0, 0, 0, 0
    #define RESULT FALSE
    
    GdkRectangle rect = {RECT};
    GdkRectangle area = {AREA};
    GdkRectangle inter = {INTER};
    
    GtkWidget* widget;
    GdkRectangle res = {0,0,0,0};
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_realize (widget);
    obj = (GdkWindowObject*)widget->window;
    obj->x = rect.x;
    obj->y = rect.y;
    gtk_widget_set_size_request (widget, rect.width, rect.height);
    gtk_widget_show_all (widget);
    
    if (RESULT != gtk_widget_intersect (widget, &area, &res))
    {
        TEST_FAIL ("results not equal", NULL); 
        return;
    }
    
    if ((inter.x != res.x) || (inter.y != res.y) || (inter.width != res.width) || (inter.height != res.height) )
    {
        TEST_FAIL ("rectangles not equal: res = (%i, %i, %i, %i) intersection = (%i, %i, %i, %i)", 
                   res.x, res.y, res.width, res.height,
                   inter.x, inter.y, inter.width, inter.height
                  );
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef RECT
    #undef AREA
    #undef INTER
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_intersect
 * Params: GtkWidget *widget,  GdkRectangle *area, GdkRectangle *intersection
 * Returns: gboolean
 * Assertion: Computes the intersection of a widget's area and area, storing the intersection in intersection, and returns TRUE if there was an intersection.'
 * Params Values: GtkWidget *widget, GdkRectangle *area, GdkRectangle *intersection
 * Expected: TRUE  
 */
static void test_purpose_198()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define RECT 0, 0, 10, 10
    #define AREA 2, 2, 10, 10
    #define INTER 2, 2, 8, 8
    #define RESULT TRUE
    
    GdkRectangle rect = {RECT};
    GdkRectangle area = {AREA};
    GdkRectangle inter = {INTER};
    
    GtkWidget* widget;
    GdkRectangle res = {0,0,0,0};
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_realize (widget);
    obj = (GdkWindowObject*)widget->window;
    obj->x = rect.x;
    obj->y = rect.y;
    gtk_widget_set_size_request (widget, rect.width, rect.height);
    gtk_widget_show_all (widget);
    
    if (RESULT != gtk_widget_intersect (widget, &area, &res))
    {
        TEST_FAIL ("results not equal", NULL); 
        return;
    }
    
    if ((inter.x != res.x) || (inter.y != res.y) || (inter.width != res.width) || (inter.height != res.height) )
    {
        TEST_FAIL ("rectangles not equal: res = (%i, %i, %i, %i) intersection = (%i, %i, %i, %i)", 
                   res.x, res.y, res.width, res.height,
                   inter.x, inter.y, inter.width, inter.height
                  );
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef RECT
    #undef AREA
    #undef INTER
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_intersect
 * Params: GtkWidget *widget,  GdkRectangle *area, GdkRectangle *intersection
 * Returns: gboolean
 * Assertion: Computes the intersection of a widget's area and area, storing the intersection in intersection, and returns TRUE if there was an intersection.'
 * Params Values: GtkWidget *widget, GdkRectangle *area, GdkRectangle *intersection
 * Expected: FALSE  
 */
static void test_purpose_199()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define RECT 0, 0, 10, 10
    #define AREA 100, 100, 100, 100
    #define INTER 0, 0, 0, 0
    #define RESULT FALSE
    
    GdkRectangle rect = {RECT};
    GdkRectangle area = {AREA};
    GdkRectangle inter = {INTER};
    
    GtkWidget* widget;
    GdkRectangle res = {0,0,0,0};
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_realize (widget);
    obj = (GdkWindowObject*)widget->window;
    obj->x = rect.x;
    obj->y = rect.y;
    gtk_widget_set_size_request (widget, rect.width, rect.height);
    gtk_widget_show_all (widget);
    
    if (RESULT != gtk_widget_intersect (widget, &area, &res))
    {
        TEST_FAIL ("results not equal", NULL); 
        return;
    }
    
    if ((inter.x != res.x) || (inter.y != res.y) || (inter.width != res.width) || (inter.height != res.height) )
    {
        TEST_FAIL ("rectangles not equal: res = (%i, %i, %i, %i) intersection = (%i, %i, %i, %i)", 
                   res.x, res.y, res.width, res.height,
                   inter.x, inter.y, inter.width, inter.height
                  );
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef RECT
    #undef AREA
    #undef INTER
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_is_focus
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: Determines if the widget is the focus widget within its toplevel.  
 * Params Values: GtkWidget *widget
 * Expected: TRUE  
 */
static void test_purpose_200()
{
    #define WIDGET gtk_entry_new ()
    #define RESULT TRUE
    
    GtkWidget* window;
    GtkWidget* widget;
    GtkWidget* vbox;
    GtkWidget* test_button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    vbox = gtk_vbox_new (10, TRUE);
    test_button = gtk_button_new_with_label ("test button");
    gtk_container_add (GTK_CONTAINER (vbox), test_button);
    gtk_container_add (GTK_CONTAINER (vbox), widget);
    
    /******* VISUALISATION *******/
    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        gtk_container_add (GTK_CONTAINER (window), vbox);
        gtk_widget_show_all (window);
    }
    /******* -------------  *******/  
    
    gtk_widget_grab_focus (test_button);
    if (RESULT)
    {
        gtk_widget_grab_focus (widget);
    }
    
    if (RESULT != gtk_widget_is_focus (widget))
    {
        TEST_FAIL ("results are not equal", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_is_focus
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: Determines if the widget is the focus widget within its toplevel.  
 * Params Values: GtkWidget *widget
 * Expected: FALSE  
 */
static void test_purpose_201()
{
    #define WIDGET gtk_button_new_with_label ("button")
    #define RESULT FALSE
    
    GtkWidget* window;
    GtkWidget* widget;
    GtkWidget* vbox;
    GtkWidget* test_button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    vbox = gtk_vbox_new (10, TRUE);
    test_button = gtk_button_new_with_label ("test button");
    gtk_container_add (GTK_CONTAINER (vbox), test_button);
    gtk_container_add (GTK_CONTAINER (vbox), widget);
    
    /******* VISUALISATION *******/
    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        gtk_container_add (GTK_CONTAINER (window), vbox);
        gtk_widget_show_all (window);
    }
    /******* -------------  *******/  
    
    gtk_widget_grab_focus (test_button);
    if (RESULT)
    {
        gtk_widget_grab_focus (widget);
    }
    
    if (RESULT != gtk_widget_is_focus (widget))
    {
        TEST_FAIL ("results are not equal", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_is_focus
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: Determines if the widget is the focus widget within its toplevel.  
 * Params Values: GtkWidget *widget
 * Expected: TRUE  
 */
static void test_purpose_202()
{
    #define WIDGET gtk_button_new_with_label ("button")
    #define RESULT TRUE
    
    GtkWidget* window;
    GtkWidget* widget;
    GtkWidget* vbox;
    GtkWidget* test_button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    vbox = gtk_vbox_new (10, TRUE);
    test_button = gtk_button_new_with_label ("test button");
    gtk_container_add (GTK_CONTAINER (vbox), test_button);
    gtk_container_add (GTK_CONTAINER (vbox), widget);
    
    /******* VISUALISATION *******/
    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        gtk_container_add (GTK_CONTAINER (window), vbox);
        gtk_widget_show_all (window);
    }
    /******* -------------  *******/  
    
    gtk_widget_grab_focus (test_button);
    if (RESULT)
    {
        gtk_widget_grab_focus (widget);
    }
    
    if (RESULT != gtk_widget_is_focus (widget))
    {
        TEST_FAIL ("results are not equal", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_is_focus
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: Determines if the widget is the focus widget within its toplevel.  
 * Params Values: GtkWidget *widget
 * Expected: TRUE  
 */
static void test_purpose_203()
{
    #define WIDGET gtk_check_button_new_with_label ("cb")
    #define RESULT TRUE
    
    GtkWidget* window;
    GtkWidget* widget;
    GtkWidget* vbox;
    GtkWidget* test_button;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    vbox = gtk_vbox_new (10, TRUE);
    test_button = gtk_button_new_with_label ("test button");
    gtk_container_add (GTK_CONTAINER (vbox), test_button);
    gtk_container_add (GTK_CONTAINER (vbox), widget);
    
    /******* VISUALISATION *******/
    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        gtk_container_add (GTK_CONTAINER (window), vbox);
        gtk_widget_show_all (window);
    }
    /******* -------------  *******/  
    
    gtk_widget_grab_focus (test_button);
    if (RESULT)
    {
        gtk_widget_grab_focus (widget);
    }
    
    if (RESULT != gtk_widget_is_focus (widget))
    {
        TEST_FAIL ("results are not equal", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_grab_focus
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Causes widget to have the keyboard focus for the GtkWindow it's inside.'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_204()
{
    #define WIDGET gtk_entry_new ()
    #define KEY GDK_A
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("parent window is NULL", NULL); 
        return;
    } 
    
    if (!GTK_WIDGET_CAN_FOCUS (widget))
    {
        TEST_FAIL ("widget '%s' can't have focus", WIDGET); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "key-press-event", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    gtk_widget_grab_focus (widget);
    
    robot_key_press_event (window, KEY, 0);
    
    if (!result)
    {
        TEST_FAIL ("'key-press-event' not catched", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_grab_focus
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Causes widget to have the keyboard focus for the GtkWindow it's inside.'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_205()
{
    #define WIDGET gtk_button_new ()
    #define KEY GDK_Return
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("parent window is NULL", NULL); 
        return;
    } 
    
    if (!GTK_WIDGET_CAN_FOCUS (widget))
    {
        TEST_FAIL ("widget '%s' can't have focus", WIDGET); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "key-press-event", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    gtk_widget_grab_focus (widget);
    
    robot_key_press_event (window, KEY, 0);
    
    if (!result)
    {
        TEST_FAIL ("'key-press-event' not catched", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_grab_focus
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Causes widget to have the keyboard focus for the GtkWindow it's inside.'
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_206()
{
    #define WIDGET gtk_toggle_button_new ()
    #define KEY GDK_Return
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("parent window is NULL", NULL); 
        return;
    } 
    
    if (!GTK_WIDGET_CAN_FOCUS (widget))
    {
        TEST_FAIL ("widget '%s' can't have focus", WIDGET); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "key-press-event", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    gtk_widget_grab_focus (widget);
    
    robot_key_press_event (window, KEY, 0);
    
    if (!result)
    {
        TEST_FAIL ("'key-press-event' not catched", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef KEY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_grab_default
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Causes widget to become the default widget.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_grab_default
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The default widget is activated when the user presses Enter in a window.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_207()
{
    #define WIDGET gtk_entry_new ()
    
    GtkWidget* window;
    GtkWidget* vbox;
    GtkWidget* test_button;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("parent window is NULL", NULL); 
        return;
    } 
    
    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
    
    if (!GTK_WIDGET_CAN_DEFAULT (widget))
    {
        TEST_FAIL ("widget '%s' can't be default", WIDGET); 
        return;
    } 
    
    
    vbox = gtk_vbox_new (10, TRUE);
    test_button = gtk_button_new_with_label ("test button");
    gtk_container_add (GTK_CONTAINER (vbox), gtk_label_new ("label"));
    gtk_container_add (GTK_CONTAINER (vbox), test_button);
    gtk_container_add (GTK_CONTAINER (vbox), widget);
    
    gtk_container_add (GTK_CONTAINER (window), vbox);
    gtk_widget_show_all (window);
    gtk_window_set_focus (GTK_WINDOW (window), NULL);
    
    gtk_widget_grab_default (widget);
    gtk_widget_grab_focus (window);
    
    if (!(GTK_WIDGET_GET_CLASS (widget)->activate_signal))
    {
        TEST_FAIL ("bad test: widget doesn't have \"activate\" signal", NULL);
        return;
    } else {
        g_signal_connect (G_OBJECT (widget), "activate", GTK_SIGNAL_FUNC (global_show), NULL);
    }
    
    robot_key_press_event (window, GDK_Return, 0);
    
    if (result == FALSE)
    {
        TEST_FAIL ("'activate' event not catched", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_grab_default
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Causes widget to become the default widget.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_grab_default
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The default widget is activated when the user presses Enter in a window.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_208()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* window;
    GtkWidget* vbox;
    GtkWidget* test_button;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("parent window is NULL", NULL); 
        return;
    } 
    
    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
    
    if (!GTK_WIDGET_CAN_DEFAULT (widget))
    {
        TEST_FAIL ("widget '%s' can't be default", WIDGET); 
        return;
    } 
    
    
    vbox = gtk_vbox_new (10, TRUE);
    test_button = gtk_button_new_with_label ("test button");
    gtk_container_add (GTK_CONTAINER (vbox), gtk_label_new ("label"));
    gtk_container_add (GTK_CONTAINER (vbox), test_button);
    gtk_container_add (GTK_CONTAINER (vbox), widget);
    
    gtk_container_add (GTK_CONTAINER (window), vbox);
    gtk_widget_show_all (window);
    gtk_window_set_focus (GTK_WINDOW (window), NULL);
    
    gtk_widget_grab_default (widget);
    gtk_widget_grab_focus (window);
    
    if (!(GTK_WIDGET_GET_CLASS (widget)->activate_signal))
    {
        TEST_FAIL ("bad test: widget doesn't have \"activate\" signal", NULL);
        return;
    } else {
        g_signal_connect (G_OBJECT (widget), "activate", GTK_SIGNAL_FUNC (global_show), NULL);
    }
    
    robot_key_press_event (window, GDK_Return, 0);
    
    if (result == FALSE)
    {
        TEST_FAIL ("'activate' event not catched", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_grab_default
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Causes widget to become the default widget.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_grab_default
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The default widget is activated when the user presses Enter in a window.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_209()
{
    #define WIDGET gtk_toggle_button_new ()
    
    GtkWidget* window;
    GtkWidget* vbox;
    GtkWidget* test_button;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("parent window is NULL", NULL); 
        return;
    } 
    
    GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
    
    if (!GTK_WIDGET_CAN_DEFAULT (widget))
    {
        TEST_FAIL ("widget '%s' can't be default", WIDGET); 
        return;
    } 
    
    
    vbox = gtk_vbox_new (10, TRUE);
    test_button = gtk_button_new_with_label ("test button");
    gtk_container_add (GTK_CONTAINER (vbox), gtk_label_new ("label"));
    gtk_container_add (GTK_CONTAINER (vbox), test_button);
    gtk_container_add (GTK_CONTAINER (vbox), widget);
    
    gtk_container_add (GTK_CONTAINER (window), vbox);
    gtk_widget_show_all (window);
    gtk_window_set_focus (GTK_WINDOW (window), NULL);
    
    gtk_widget_grab_default (widget);
    gtk_widget_grab_focus (window);
    
    if (!(GTK_WIDGET_GET_CLASS (widget)->activate_signal))
    {
        TEST_FAIL ("bad test: widget doesn't have \"activate\" signal", NULL);
        return;
    } else {
        g_signal_connect (G_OBJECT (widget), "activate", GTK_SIGNAL_FUNC (global_show), NULL);
    }
    
    robot_key_press_event (window, GDK_Return, 0);
    
    if (result == FALSE)
    {
        TEST_FAIL ("'activate' event not catched", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_add_events
 * Params: GtkWidget *widget, gint events
 * Returns: void
 * Assertion: Adds the events in the bitfield events to the event mask for widget.
 * Params Values: GtkWidget *widget, gint events
 * Expected: void  
 */
static void test_purpose_210()
{
    #define WIDGET gtk_entry_new ()
    #define EVENTS GDK_KEY_PRESS_MASK 
    
    GtkWidget* widget;
    gint *eventp;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_add_events (widget, EVENTS);
    
    if (!(gtk_widget_get_events (widget) & EVENTS))
    {
        TEST_FAIL ("event not added", NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef EVENTS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_add_events
 * Params: GtkWidget *widget, gint events
 * Returns: void
 * Assertion: Adds the events in the bitfield events to the event mask for widget.
 * Params Values: GtkWidget *widget, gint events
 * Expected: void  
 */
static void test_purpose_211()
{
    #define WIDGET gtk_entry_new ()
    #define EVENTS GDK_KEY_RELEASE_MASK
    
    GtkWidget* widget;
    gint *eventp;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_add_events (widget, EVENTS);
    
    if (!(gtk_widget_get_events (widget) & EVENTS))
    {
        TEST_FAIL ("event not added", NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef EVENTS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_add_events
 * Params: GtkWidget *widget, gint events
 * Returns: void
 * Assertion: Adds the events in the bitfield events to the event mask for widget.
 * Params Values: GtkWidget *widget, gint events
 * Expected: void  
 */
static void test_purpose_212()
{
    #define WIDGET gtk_entry_new ()
    #define EVENTS GDK_FOCUS_CHANGE_MASK
    
    GtkWidget* widget;
    gint *eventp;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_add_events (widget, EVENTS);
    
    if (!(gtk_widget_get_events (widget) & EVENTS))
    {
        TEST_FAIL ("event not added", NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef EVENTS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_add_events
 * Params: GtkWidget *widget, gint events
 * Returns: void
 * Assertion: Adds the events in the bitfield events to the event mask for widget.
 * Params Values: GtkWidget *widget, gint events
 * Expected: void  
 */
static void test_purpose_213()
{
    #define WIDGET gtk_entry_new ()
    #define EVENTS GDK_SCROLL_MASK
    
    GtkWidget* widget;
    gint *eventp;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_add_events (widget, EVENTS);
    
    if (!(gtk_widget_get_events (widget) & EVENTS))
    {
        TEST_FAIL ("event not added", NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef EVENTS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_add_events
 * Params: GtkWidget *widget, gint events
 * Returns: void
 * Assertion: Adds the events in the bitfield events to the event mask for widget.
 * Params Values: GtkWidget *widget, gint events
 * Expected: void  
 */
static void test_purpose_214()
{
    #define WIDGET gtk_button_new ()
    #define EVENTS GDK_KEY_RELEASE_MASK
    
    GtkWidget* widget;
    gint *eventp;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_add_events (widget, EVENTS);
    
    if (!(gtk_widget_get_events (widget) & EVENTS))
    {
        TEST_FAIL ("event not added", NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef EVENTS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_add_events
 * Params: GtkWidget *widget, gint events
 * Returns: void
 * Assertion: Adds the events in the bitfield events to the event mask for widget.
 * Params Values: GtkWidget *widget, gint events
 * Expected: void  
 */
static void test_purpose_215()
{
    #define WIDGET gtk_toggle_button_new ()
    #define EVENTS GDK_ALL_EVENTS_MASK
    
    GtkWidget* widget;
    gint *eventp;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_add_events (widget, EVENTS);
    
    if (!(gtk_widget_get_events (widget) & EVENTS))
    {
        TEST_FAIL ("event not added", NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef EVENTS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_is_ancestor
 * Params: GtkWidget *widget, GtkWidget *ancestor
 * Returns: gboolean
 * Assertion: Determines whether widget is somewhere inside ancestor, possibly with intermediate containers.
 * Params Values: GtkWidget *widget, GtkWidget *ancestor
 * Expected: gtk_vbox_new (TRUE, 10)  
 */
static void test_purpose_216()
{
    #define WIDGET gtk_entry_new ()
    #define PARENT gtk_vbox_new (TRUE, 10)
    #define RESULT TRUE
    
    GtkWidget* parent;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL ("'parent' is NULL", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL); 
        return;
    }
    
    if (RESULT)
    {
        gtk_container_add (GTK_CONTAINER (parent), widget);
    }
    
    if (RESULT != gtk_widget_is_ancestor (widget, parent))
    {
        TEST_FAIL ("results not equal", NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PARENT
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_is_ancestor
 * Params: GtkWidget *widget, GtkWidget *ancestor
 * Returns: gboolean
 * Assertion: Determines whether widget is somewhere inside ancestor, possibly with intermediate containers.
 * Params Values: GtkWidget *widget, GtkWidget *ancestor
 * Expected: gtk_vbox_new (TRUE, 10)  
 */
static void test_purpose_217()
{
    #define WIDGET gtk_button_new ()
    #define PARENT gtk_vbox_new (TRUE, 10)
    #define RESULT FALSE
    
    GtkWidget* parent;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL ("'parent' is NULL", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL); 
        return;
    }
    
    if (RESULT)
    {
        gtk_container_add (GTK_CONTAINER (parent), widget);
    }
    
    if (RESULT != gtk_widget_is_ancestor (widget, parent))
    {
        TEST_FAIL ("results not equal", NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PARENT
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_is_ancestor
 * Params: GtkWidget *widget, GtkWidget *ancestor
 * Returns: gboolean
 * Assertion: Determines whether widget is somewhere inside ancestor, possibly with intermediate containers.
 * Params Values: GtkWidget *widget, GtkWidget *ancestor
 * Expected: gtk_window_new (GTK_WINDOW_TOPLEVEL);  
 */
static void test_purpose_218()
{
    #define WIDGET gtk_button_new ()
    #define PARENT gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define RESULT TRUE
    
    GtkWidget* parent;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL ("'parent' is NULL", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL); 
        return;
    }
    
    if (RESULT)
    {
        gtk_container_add (GTK_CONTAINER (parent), widget);
    }
    
    if (RESULT != gtk_widget_is_ancestor (widget, parent))
    {
        TEST_FAIL ("results not equal", NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PARENT
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_is_ancestor
 * Params: GtkWidget *widget, GtkWidget *ancestor
 * Returns: gboolean
 * Assertion: Determines whether widget is somewhere inside ancestor, possibly with intermediate containers.
 * Params Values: GtkWidget *widget, GtkWidget *ancestor
 * Expected: gtk_window_new (GTK_WINDOW_TOPLEVEL);  
 */
static void test_purpose_219()
{
    #define WIDGET gtk_check_button_new ()
    #define PARENT gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define RESULT TRUE
    
    GtkWidget* parent;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL ("'parent' is NULL", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL); 
        return;
    }
    
    if (RESULT)
    {
        gtk_container_add (GTK_CONTAINER (parent), widget);
    }
    
    if (RESULT != gtk_widget_is_ancestor (widget, parent))
    {
        TEST_FAIL ("results not equal", NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PARENT
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_is_ancestor
 * Params: GtkWidget *widget, GtkWidget *ancestor
 * Returns: gboolean
 * Assertion: Determines whether widget is somewhere inside ancestor, possibly with intermediate containers.
 * Params Values: GtkWidget *widget, GtkWidget *ancestor
 * Expected: gtk_window_new (GTK_WINDOW_TOPLEVEL);  
 */
static void test_purpose_220()
{
    #define WIDGET gtk_check_button_new ()
    #define PARENT gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define RESULT FALSE
    
    GtkWidget* parent;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL ("'parent' is NULL", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL); 
        return;
    }
    
    if (RESULT)
    {
        gtk_container_add (GTK_CONTAINER (parent), widget);
    }
    
    if (RESULT != gtk_widget_is_ancestor (widget, parent))
    {
        TEST_FAIL ("results not equal", NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PARENT
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_hide_on_delete
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The function calls gtk_widget_hide() on its argument, then returns TRUE.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_hide_on_delete
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: If connected to "delete_event", the result is that clicking the close button for a window (on the window frame, top right corner usually) will hide but not destroy the window.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_221()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "delete-event", GTK_SIGNAL_FUNC (gtk_widget_hide_on_delete), NULL);
    g_signal_connect (G_OBJECT (widget), "hide", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_show (widget);
    robot_delete_event (widget);
    
    if (!result)
    {
        TEST_FAIL ("'hide' signal not catched", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_hide_on_delete
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The function calls gtk_widget_hide() on its argument, then returns TRUE.
 * Params Values: GtkWidget *widget
 * Expected: void
 * 
 * Name:  gtk_widget_hide_on_delete
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: If connected to "delete_event", the result is that clicking the close button for a window (on the window frame, top right corner usually) will hide but not destroy the window.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_222()
{
    #define WIDGET gtk_dialog_new ();
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_signal_connect (G_OBJECT (widget), "delete-event", GTK_SIGNAL_FUNC (gtk_widget_hide_on_delete), NULL);
    g_signal_connect (G_OBJECT (widget), "hide", GTK_SIGNAL_FUNC (global_show), NULL);
    
    gtk_widget_show (widget);
    robot_delete_event (widget);
    
    if (!result)
    {
        TEST_FAIL ("'hide' signal not catched", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_ensure_style
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Ensures that widget has a style (widget->style).
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_223()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_ensure_style (widget);
    
    if (!gtk_widget_get_style (widget))
    {
        TEST_FAIL ("'style' is NULL", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_ensure_style
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Ensures that widget has a style (widget->style).
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_224()
{
    #define WIDGET gtk_dialog_new ();
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_ensure_style (widget);
    
    if (!gtk_widget_get_style (widget))
    {
        TEST_FAIL ("'style' is NULL", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_ensure_style
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Ensures that widget has a style (widget->style).
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_225()
{
    #define WIDGET gtk_vbox_new (TRUE, 10)
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_ensure_style (widget);
    
    if (!gtk_widget_get_style (widget))
    {
        TEST_FAIL ("'style' is NULL", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_ensure_style
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Ensures that widget has a style (widget->style).
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_226()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_ensure_style (widget);
    
    if (!gtk_widget_get_style (widget))
    {
        TEST_FAIL ("'style' is NULL", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_ensure_style
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Ensures that widget has a style (widget->style).
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_227()
{
    #define WIDGET gtk_check_button_new ()
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_ensure_style (widget);
    
    if (!gtk_widget_get_style (widget))
    {
        TEST_FAIL ("'style' is NULL", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_push_colormap
 * Params: GdkColormap *cmap
 * Returns: void
 * Assertion: Pushes cmap onto a global stack of colormaps; the topmost colormap on the stack will be used to create all widgets.
 * Params Values: GdkColormap *cmap
 * Expected: void  
 */
static void test_purpose_228()
{
    GdkColormap *cmap;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cmap = gdk_colormap_new (gdk_visual_get_system (), TRUE);
    if (!cmap)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_push_colormap (cmap);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_pop_colormap
 * Params: void
 * Returns: void
 * Assertion: Removes a colormap pushed with gtk_widget_push_colormap().
 * Params Values: void
 * Expected: void  
 */
static void test_purpose_229()
{
    GdkColormap *cmap;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    cmap = gdk_colormap_new (gdk_visual_get_system (), TRUE);
    
    if (!cmap)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_push_colormap (cmap);
    gtk_widget_pop_colormap ();
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_path
 * Returns: void
 * Assertion: Obtains the full path to widget.
 * Params Values: GtkWidget *widget, guint *path_length, gchar **path, gchar **path_reversed
 * Expected: void  
 */
static void test_purpose_230()
{
    #define WIDGET gtk_button_new ();
    #define PARENT gtk_hbox_new (TRUE, 10);
    #define PATH "GtkHBox.GtkButton"
    #define PATH_REV "nottuBktG.xoBHktG"
    
    GtkWidget* widget;
    GtkWidget* parent;
    gchar* path;
    gchar* path_rev;
    guint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL ("'parent' is NULL", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (parent), widget);
    
    path = calloc (strlen (PATH)+1, sizeof (char));
    path_rev = calloc (strlen  (PATH_REV)+1, sizeof (char));
    
    gtk_widget_path (widget, &len, &path, &path_rev);
    
    if (strcmp (path, PATH))
    {
        TEST_FAIL ("'path' is wrong", NULL); 
    }
    
    if (strcmp (path_rev, PATH_REV))
    {
        TEST_FAIL ("'path' is wrong", NULL); 
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    #undef PATH
    #undef PATH_REV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_path
 * Returns: void
 * Assertion: Obtains the full path to widget.
 * Params Values: GtkWidget *widget, guint *path_length, gchar **path, gchar **path_reversed
 * Expected: void  
 */
static void test_purpose_231()
{
    #define WIDGET gtk_label_new ("Label");
    #define PARENT gtk_hbox_new (TRUE, 10);
    #define PATH "GtkHBox.GtkLabel"
    #define PATH_REV "lebaLktG.xoBHktG"
    
    GtkWidget* widget;
    GtkWidget* parent;
    gchar* path;
    gchar* path_rev;
    guint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL ("'parent' is NULL", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (parent), widget);
    
    path = calloc (strlen (PATH)+1, sizeof (char));
    path_rev = calloc (strlen  (PATH_REV)+1, sizeof (char));
    
    gtk_widget_path (widget, &len, &path, &path_rev);
    
    if (strcmp (path, PATH))
    {
        TEST_FAIL ("'path' is wrong", NULL); 
    }
    
    if (strcmp (path_rev, PATH_REV))
    {
        TEST_FAIL ("'path' is wrong", NULL); 
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    #undef PATH
    #undef PATH_REV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_path
 * Returns: void
 * Assertion: Obtains the full path to widget.
 * Params Values: GtkWidget *widget, guint *path_length, gchar **path, gchar **path_reversed
 * Expected: void  
 */
static void test_purpose_232()
{
    #define WIDGET gtk_check_button_new ()
    #define PARENT gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define PATH "GtkWindow.GtkCheckButton"
    #define PATH_REV "nottuBkcehCktG.wodniWktG"
    
    GtkWidget* widget;
    GtkWidget* parent;
    gchar* path;
    gchar* path_rev;
    guint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL ("'parent' is NULL", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (parent), widget);
    
    path = calloc (strlen (PATH)+1, sizeof (char));
    path_rev = calloc (strlen  (PATH_REV)+1, sizeof (char));
    
    gtk_widget_path (widget, &len, &path, &path_rev);
    
    if (strcmp (path, PATH))
    {
        TEST_FAIL ("'path' is wrong", NULL); 
    }
    
    if (strcmp (path_rev, PATH_REV))
    {
        TEST_FAIL ("'path' is wrong", NULL); 
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    #undef PATH
    #undef PATH_REV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_class_path
 * Params: GtkWidget *widget, guint *path_length, gchar **path, gchar **path_reversed 
 * Returns: void
 * Assertion: Same as gtk_widget_path(), but always uses the name of a widget's type, never uses a custom name set with gtk_widget_set_name().'
 * Params Values: GtkWidget *widget, guint *path_length, gchar **path, gchar **path_reversed
 * Expected: void  
 */
static void test_purpose_233()
{
    #define WIDGET gtk_button_new ();
    #define PARENT gtk_hbox_new (TRUE, 10);
    #define PATH "GtkHBox.GtkButton"
    #define PATH_REV "nottuBktG.xoBHktG"
    
    GtkWidget* widget;
    GtkWidget* parent;
    gchar* path;
    gchar* path_rev;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL ("'parent' is NULL", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (parent), widget);
    
    path = calloc (strlen(PATH)+1, sizeof (char));
    path_rev = calloc (strlen(PATH_REV)+1, sizeof (char));
    
    gtk_widget_set_name (widget, "MyName");
    
    gtk_widget_class_path (widget, &len, &path, &path_rev);
    
    if (strcmp (path, PATH))
    {
        TEST_FAIL ("'path' is wrong", NULL); 
    }
    
    if (strcmp (path_rev, PATH_REV))
    {
        TEST_FAIL ("'path' is wrong", NULL); 
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    #undef PATH
    #undef PATH_REV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_class_path
 * Params: GtkWidget *widget, guint *path_length, gchar **path, gchar **path_reversed 
 * Returns: void
 * Assertion: Same as gtk_widget_path(), but always uses the name of a widget's type, never uses a custom name set with gtk_widget_set_name().'
 * Params Values: GtkWidget *widget, guint *path_length, gchar **path, gchar **path_reversed
 * Expected: void  
 */
static void test_purpose_234()
{
    #define WIDGET gtk_label_new ("Label");
    #define PARENT gtk_hbox_new (TRUE, 10);
    #define PATH "GtkHBox.GtkLabel"
    #define PATH_REV "lebaLktG.xoBHktG"
    
    GtkWidget* widget;
    GtkWidget* parent;
    gchar* path;
    gchar* path_rev;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL ("'parent' is NULL", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (parent), widget);
    
    path = calloc (strlen(PATH)+1, sizeof (char));
    path_rev = calloc (strlen(PATH_REV)+1, sizeof (char));
    
    gtk_widget_set_name (widget, "MyName");
    
    gtk_widget_class_path (widget, &len, &path, &path_rev);
    
    if (strcmp (path, PATH))
    {
        TEST_FAIL ("'path' is wrong", NULL); 
    }
    
    if (strcmp (path_rev, PATH_REV))
    {
        TEST_FAIL ("'path' is wrong", NULL); 
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    #undef PATH
    #undef PATH_REV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_class_path
 * Params: GtkWidget *widget, guint *path_length, gchar **path, gchar **path_reversed 
 * Returns: void
 * Assertion: Same as gtk_widget_path(), but always uses the name of a widget's type, never uses a custom name set with gtk_widget_set_name().'
 * Params Values: GtkWidget *widget, guint *path_length, gchar **path, gchar **path_reversed
 * Expected: void  
 */
static void test_purpose_235()
{
    #define WIDGET gtk_check_button_new ()
    #define PARENT gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define PATH "GtkWindow.GtkCheckButton"
    #define PATH_REV "nottuBkcehCktG.wodniWktG"
    
    GtkWidget* widget;
    GtkWidget* parent;
    gchar* path;
    gchar* path_rev;
    gint len;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    parent = PARENT;
    if (!parent)
    {
        TEST_FAIL ("'parent' is NULL", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (parent))
    {
        TEST_FAIL ("'parent' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (parent), widget);
    
    path = calloc (strlen(PATH)+1, sizeof (char));
    path_rev = calloc (strlen(PATH_REV)+1, sizeof (char));
    
    gtk_widget_set_name (widget, "MyName");
    
    gtk_widget_class_path (widget, &len, &path, &path_rev);
    
    if (strcmp (path, PATH))
    {
        TEST_FAIL ("'path' is wrong", NULL); 
    }
    
    if (strcmp (path_rev, PATH_REV))
    {
        TEST_FAIL ("'path' is wrong", NULL); 
    }
    
    gtk_widget_destroy (parent);
    
    #undef WIDGET
    #undef PARENT
    #undef PATH
    #undef PATH_REV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_style
 * Params: GtkWidget *widget, GtkRcStyle *style
 * Returns: void
 * Assertion: Modifies style values on the widget.
 * Params Values: GtkWidget *widget, GtkRcStyle *style
 * Expected: void
 * 
 * Name: gtk_widget_modify_style
 * Params: GtkWidget *widget, GtkRcStyle *style
 * Returns: void
 * Assertion: Modifications made using this technique take precedence over style values set via an RC file, however, they will be overriden if a style is explicitely set on the widget using gtk_widget_set_style().
 * Params Values: GtkWidget *widget, GtkRcStyle *style
 * Expected: void
 * 
 * Name: gtk_widget_modify_style
 * Params: GtkWidget *widget, GtkRcStyle *style
 * Returns: void
 * Assertion: Note that modifications made with this function are not cumulative with previous calls to gtk_widget_modify_style() or with such functions as gtk_widget_modify_fg().
 * Params Values: GtkWidget *widget, GtkRcStyle *style
 * Expected: void
 * 
 * Name:  gtk_widget_get_modifier_style
 * Params: GtkWidget* widget
 * Returns: GtkRcStyle*
 * Assertion: Returns the current modifier style for the widget. 
 * Params Values: GtkWidget *widget
 * Expected: GtkRcStyle*  
 */
static void test_purpose_236()
{
    #define WIDGET gtk_button_new ();
    
    GtkWidget* widget;
    GtkRcStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_style (widget, style);
    
    if (memcmp (style, gtk_widget_get_modifier_style (widget), sizeof (GtkRcStyle)))
    {
        TEST_FAIL ("styles are not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_style
 * Params: GtkWidget *widget, GtkRcStyle *style
 * Returns: void
 * Assertion: Modifies style values on the widget.
 * Params Values: GtkWidget *widget, GtkRcStyle *style
 * Expected: void
 * 
 * Name: gtk_widget_modify_style
 * Params: GtkWidget *widget, GtkRcStyle *style
 * Returns: void
 * Assertion: Modifications made using this technique take precedence over style values set via an RC file, however, they will be overriden if a style is explicitely set on the widget using gtk_widget_set_style().
 * Params Values: GtkWidget *widget, GtkRcStyle *style
 * Expected: void
 * 
 * Name: gtk_widget_modify_style
 * Params: GtkWidget *widget, GtkRcStyle *style
 * Returns: void
 * Assertion: Note that modifications made with this function are not cumulative with previous calls to gtk_widget_modify_style() or with such functions as gtk_widget_modify_fg().
 * Params Values: GtkWidget *widget, GtkRcStyle *style
 * Expected: void
 * 
 * Name:  gtk_widget_get_modifier_style
 * Params: GtkWidget* widget
 * Returns: GtkRcStyle*
 * Assertion: Returns the current modifier style for the widget. 
 * Params Values: GtkWidget *widget
 * Expected: GtkRcStyle*  
 */
static void test_purpose_237()
{
    #define WIDGET gtk_hbox_new (TRUE, 10);
    
    GtkWidget* widget;
    GtkRcStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_style (widget, style);
    
    if (memcmp (style, gtk_widget_get_modifier_style (widget), sizeof (GtkRcStyle)))
    {
        TEST_FAIL ("styles are not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_style
 * Params: GtkWidget *widget, GtkRcStyle *style
 * Returns: void
 * Assertion: Modifies style values on the widget.
 * Params Values: GtkWidget *widget, GtkRcStyle *style
 * Expected: void
 * 
 * Name: gtk_widget_modify_style
 * Params: GtkWidget *widget, GtkRcStyle *style
 * Returns: void
 * Assertion: Modifications made using this technique take precedence over style values set via an RC file, however, they will be overriden if a style is explicitely set on the widget using gtk_widget_set_style().
 * Params Values: GtkWidget *widget, GtkRcStyle *style
 * Expected: void
 * 
 * Name: gtk_widget_modify_style
 * Params: GtkWidget *widget, GtkRcStyle *style
 * Returns: void
 * Assertion: Note that modifications made with this function are not cumulative with previous calls to gtk_widget_modify_style() or with such functions as gtk_widget_modify_fg().
 * Params Values: GtkWidget *widget, GtkRcStyle *style
 * Expected: void
 * 
 * Name:  gtk_widget_get_modifier_style
 * Params: GtkWidget* widget
 * Returns: GtkRcStyle*
 * Assertion: Returns the current modifier style for the widget. 
 * Params Values: GtkWidget *widget
 * Expected: GtkRcStyle*  
 */
static void test_purpose_238()
{
    #define WIDGET gtk_label_new ("Label");
    
    GtkWidget* widget;
    GtkRcStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_style (widget, style);
    
    if (memcmp (style, gtk_widget_get_modifier_style (widget), sizeof (GtkRcStyle)))
    {
        TEST_FAIL ("styles are not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_style
 * Params: GtkWidget *widget, GtkRcStyle *style
 * Returns: void
 * Assertion: Modifies style values on the widget.
 * Params Values: GtkWidget *widget, GtkRcStyle *style
 * Expected: void
 * 
 * Name: gtk_widget_modify_style
 * Params: GtkWidget *widget, GtkRcStyle *style
 * Returns: void
 * Assertion: Modifications made using this technique take precedence over style values set via an RC file, however, they will be overriden if a style is explicitely set on the widget using gtk_widget_set_style().
 * Params Values: GtkWidget *widget, GtkRcStyle *style
 * Expected: void
 * 
 * Name: gtk_widget_modify_style
 * Params: GtkWidget *widget, GtkRcStyle *style
 * Returns: void
 * Assertion: Note that modifications made with this function are not cumulative with previous calls to gtk_widget_modify_style() or with such functions as gtk_widget_modify_fg().
 * Params Values: GtkWidget *widget, GtkRcStyle *style
 * Expected: void
 * 
 * Name:  gtk_widget_get_modifier_style
 * Params: GtkWidget* widget
 * Returns: GtkRcStyle*
 * Assertion: Returns the current modifier style for the widget. 
 * Params Values: GtkWidget *widget
 * Expected: GtkRcStyle*  
 */
static void test_purpose_239()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    GtkWidget* widget;
    GtkRcStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_style (widget, style);
    
    if (memcmp (style, gtk_widget_get_modifier_style (widget), sizeof (GtkRcStyle)))
    {
        TEST_FAIL ("styles are not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_fg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the foreground color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_NORMAL, GdkColor {100, 65535, 100}
 * Expected: void
 * 
 * Name: gtk_widget_modify_fg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_NORMAL, GdkColor {100, 65535, 100}
 * Expected: void  
 */
static void test_purpose_240()
{
    #define WIDGET gtk_button_new ();
    #define STATE GTK_STATE_NORMAL
    #define COLOR 100, 65535, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_fg (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->fg[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_fg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the foreground color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_ACTIVE, GdkColor {100, 100, 65535}
 * Expected: void
 * 
 * Name: gtk_widget_modify_fg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_ACTIVE, GdkColor {100, 100, 65535}
 * Expected: void  
 */
static void test_purpose_241()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define STATE GTK_STATE_ACTIVE
    #define COLOR 100, 100, 65535
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_fg (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->fg[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_fg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the foreground color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_PRELIGHT, GdkColor {100, 100, 100}
 * Expected: void
 * 
 * Name: gtk_widget_modify_fg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_PRELIGHT, GdkColor {100, 100, 100}
 * Expected: void  
 */
static void test_purpose_242()
{
    #define WIDGET gtk_label_new ("Label");
    #define STATE GTK_STATE_PRELIGHT
    #define COLOR 100, 100, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_fg (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->fg[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_fg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the foreground color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_SELECTED, GdkColor {0, 100, 100}
 * Expected: void
 * 
 * Name: gtk_widget_modify_fg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_SELECTED, GdkColor {0, 100, 100}
 * Expected: void  
 */
static void test_purpose_243()
{
    #define WIDGET gtk_entry_new ();
    #define STATE GTK_STATE_SELECTED
    #define COLOR 0, 100, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_fg (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->fg[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_fg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the foreground color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_INSENSITIVE, GdkColor {100, 0, 100}
 * Expected: void
 * 
 * Name: gtk_widget_modify_fg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_INSENSITIVE, GdkColor {100, 0, 100}
 * Expected: void  
 */
static void test_purpose_244()
{
    #define WIDGET gtk_check_button_new ();
    #define STATE GTK_STATE_INSENSITIVE
    #define COLOR 100, 0, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_fg (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->fg[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_bg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion:Sets the background color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_NORMAL, GdkColor {100, 65535, 100}
 * Expected: void
 * 
 * Name: gtk_widget_modify_bg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_NORMAL, GdkColor {100, 65535, 100}
 * Expected: void  
 */
static void test_purpose_245()
{
    #define WIDGET gtk_button_new ();
    #define STATE GTK_STATE_NORMAL
    #define COLOR 100, 65535, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_bg (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->bg[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_bg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion:Sets the background color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_ACTIVE, GdkColor {100, 100, 65535}
 * Expected: void
 * 
 * Name: gtk_widget_modify_bg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_ACTIVE, GdkColor {100, 100, 65535}
 * Expected: void  
 */
static void test_purpose_246()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define STATE GTK_STATE_ACTIVE
    #define COLOR 100, 100, 65535
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_bg (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->bg[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_bg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion:Sets the background color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_PRELIGHT, GdkColor {100, 100, 100}
 * Expected: void
 * 
 * Name: gtk_widget_modify_bg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_PRELIGHT, GdkColor {100, 100, 100}
 * Expected: void  
 */
static void test_purpose_247()
{
    #define WIDGET gtk_label_new ("Label");
    #define STATE GTK_STATE_PRELIGHT
    #define COLOR 100, 100, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_bg (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->bg[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_bg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion:Sets the background color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_SELECTED, GdkColor {0, 100, 100}
 * Expected: void
 * 
 * Name: gtk_widget_modify_bg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_SELECTED, GdkColor {0, 100, 100}
 * Expected: void  
 */
static void test_purpose_248()
{
    #define WIDGET gtk_entry_new ();
    #define STATE GTK_STATE_SELECTED
    #define COLOR 0, 100, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_bg (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->bg[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_bg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion:Sets the background color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_INSENSITIVE, GdkColor {100, 0, 100}
 * Expected: void
 * 
 * Name: gtk_widget_modify_bg
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_INSENSITIVE, GdkColor {100, 0, 100}
 * Expected: void  
 */
static void test_purpose_249()
{
    #define WIDGET gtk_check_button_new ();
    #define STATE GTK_STATE_INSENSITIVE
    #define COLOR 100, 0, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_bg (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->bg[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_text
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the text color for a widget in a particular state
 * Params Values: GtkWidget *widget, GTK_STATE_NORMAL, GdkColor {100, 65535, 100}
 * Expected: void  
 */
static void test_purpose_250()
{
    #define WIDGET gtk_button_new ();
    #define STATE GTK_STATE_NORMAL
    #define COLOR 100, 65535, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_text (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->text[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_text
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the text color for a widget in a particular state
 * Params Values: GtkWidget *widget, GTK_STATE_ACTIVE, GdkColor {100, 100, 65535}
 * Expected: void  
 */
static void test_purpose_251()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define STATE GTK_STATE_ACTIVE
    #define COLOR 100, 100, 65535
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_text (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->text[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_text
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the text color for a widget in a particular state
 * Params Values: GtkWidget *widget, GTK_STATE_PRELIGHT, GdkColor {100, 100, 100}
 * Expected: void  
 */
static void test_purpose_252()
{
    #define WIDGET gtk_label_new ("Label");
    #define STATE GTK_STATE_PRELIGHT
    #define COLOR 100, 100, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_text (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->text[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_text
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the text color for a widget in a particular state
 * Params Values: GtkWidget *widget, GTK_STATE_SELECTED, GdkColor {0, 100, 100}
 * Expected: void  
 */
static void test_purpose_253()
{
    #define WIDGET gtk_entry_new ();
    #define STATE GTK_STATE_SELECTED
    #define COLOR 0, 100, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_text (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->text[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_text
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the text color for a widget in a particular state
 * Params Values: GtkWidget *widget, GTK_STATE_INSENSITIVE, GdkColor {100, 0, 100}
 * Expected: void  
 */
static void test_purpose_254()
{
    #define WIDGET gtk_check_button_new ();
    #define STATE GTK_STATE_INSENSITIVE
    #define COLOR 100, 0, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_text (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->text[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_base
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the base color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_NORMAL, GdkColor {100, 65535, 100}
 * Expected: void
 * 
 * Name: gtk_widget_modify_base
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_NORMAL, GdkColor {100, 65535, 100}
 * Expected: void  
 */
static void test_purpose_255()
{
    #define WIDGET gtk_button_new ();
    #define STATE GTK_STATE_NORMAL
    #define COLOR 100, 65535, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_base (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->base[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_base
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the base color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_ACTIVE, GdkColor {100, 100, 65535}
 * Expected: void
 * 
 * Name: gtk_widget_modify_base
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_ACTIVE, GdkColor {100, 100, 65535}
 * Expected: void  
 */
static void test_purpose_256()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define STATE GTK_STATE_ACTIVE
    #define COLOR 100, 100, 65535
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_base (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->base[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_base
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the base color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_PRELIGHT, GdkColor {100, 100, 100}
 * Expected: void
 * 
 * Name: gtk_widget_modify_base
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_PRELIGHT, GdkColor {100, 100, 100}
 * Expected: void  
 */
static void test_purpose_257()
{
    #define WIDGET gtk_label_new ("Label");
    #define STATE GTK_STATE_PRELIGHT
    #define COLOR 100, 100, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_base (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->base[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_base
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the base color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_SELECTED, GdkColor {0, 100, 100}
 * Expected: void
 * 
 * Name: gtk_widget_modify_base
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_SELECTED, GdkColor {0, 100, 100}
 * Expected: void  
 */
static void test_purpose_258()
{
    #define WIDGET gtk_entry_new ();
    #define STATE GTK_STATE_SELECTED
    #define COLOR 0, 100, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_base (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->base[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_base
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: Sets the base color for a widget in a particular state.
 * Params Values: GtkWidget *widget, GTK_STATE_INSENSITIVE, GdkColor {100, 0, 100}
 * Expected: void
 * 
 * Name: gtk_widget_modify_base
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, GTK_STATE_INSENSITIVE, GdkColor {100, 0, 100}
 * Expected: void  
 */
static void test_purpose_259()
{
    #define WIDGET gtk_check_button_new ();
    #define STATE GTK_STATE_INSENSITIVE
    #define COLOR 100, 0, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    gtk_widget_modify_base (widget, STATE, &color);
    
    style = gtk_widget_get_modifier_style (widget);
    
    for (i = 0; i < 5; i++)
    {
        if ((i == STATE) && (style->color_flags[i] == 0))
        {
            TEST_FAIL ("style->color_flags[%i] should be 1", i); 
        }
    
        if ((i != STATE) && (style->color_flags[i] == 1))
        {
            TEST_FAIL ("style->color_flags[%i] should be 0", i); 
        }
    }
    
    if (!gdk_color_equal (&color, &style->base[STATE]))
    {
        TEST_FAIL ("colors not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_font
 * Params: GtkWidget *widget, PangoFontDescription *font_desc
 * Returns: void
 * Assertion: Sets the font to use for a widget
 * Params Values: GtkWidget *widget, PangoFontDescription *font_desc
 * Expected: void
 * 
 * Name: gtk_widget_modify_font
 * Params: GtkWidget *widget, PangoFontDescription *font_desc
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, PangoFontDescription *font_desc
 * Expected: void  
 */
static void test_purpose_260()
{
    #define WIDGET gtk_button_new ();
    
    GtkWidget* widget;
    GtkRcStyle* style;
    PangoFontDescription* font_desc = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    font_desc = pango_font_description_new ();
    
    pango_font_description_set_family (font_desc, "Times");
    pango_font_description_set_style (font_desc, PANGO_STYLE_NORMAL);
    pango_font_description_set_variant (font_desc, PANGO_VARIANT_NORMAL);
    pango_font_description_set_weight (font_desc, PANGO_WEIGHT_BOLD);
    pango_font_description_set_stretch (font_desc, PANGO_STRETCH_NORMAL); 
    
    gtk_widget_modify_font (widget, font_desc);
    
    style = gtk_widget_get_modifier_style (widget);
    
    if (!pango_font_description_equal (font_desc, style->font_desc))
    {
        TEST_FAIL ("fonts not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_font
 * Params: GtkWidget *widget, PangoFontDescription *font_desc
 * Returns: void
 * Assertion: Sets the font to use for a widget
 * Params Values: GtkWidget *widget, PangoFontDescription *font_desc
 * Expected: void
 * 
 * Name: gtk_widget_modify_font
 * Params: GtkWidget *widget, PangoFontDescription *font_desc
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, PangoFontDescription *font_desc
 * Expected: void  
 */
static void test_purpose_261()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    GtkWidget* widget;
    GtkRcStyle* style;
    PangoFontDescription* font_desc = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    font_desc = pango_font_description_new ();
    
    pango_font_description_set_family (font_desc, "Times");
    pango_font_description_set_style (font_desc, PANGO_STYLE_NORMAL);
    pango_font_description_set_variant (font_desc, PANGO_VARIANT_NORMAL);
    pango_font_description_set_weight (font_desc, PANGO_WEIGHT_BOLD);
    pango_font_description_set_stretch (font_desc, PANGO_STRETCH_NORMAL); 
    
    gtk_widget_modify_font (widget, font_desc);
    
    style = gtk_widget_get_modifier_style (widget);
    
    if (!pango_font_description_equal (font_desc, style->font_desc))
    {
        TEST_FAIL ("fonts not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_font
 * Params: GtkWidget *widget, PangoFontDescription *font_desc
 * Returns: void
 * Assertion: Sets the font to use for a widget
 * Params Values: GtkWidget *widget, PangoFontDescription *font_desc
 * Expected: void
 * 
 * Name: gtk_widget_modify_font
 * Params: GtkWidget *widget, PangoFontDescription *font_desc
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, PangoFontDescription *font_desc
 * Expected: void  
 */
static void test_purpose_262()
{
    #define WIDGET gtk_label_new ("Label");
    
    GtkWidget* widget;
    GtkRcStyle* style;
    PangoFontDescription* font_desc = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    font_desc = pango_font_description_new ();
    
    pango_font_description_set_family (font_desc, "Times");
    pango_font_description_set_style (font_desc, PANGO_STYLE_NORMAL);
    pango_font_description_set_variant (font_desc, PANGO_VARIANT_NORMAL);
    pango_font_description_set_weight (font_desc, PANGO_WEIGHT_BOLD);
    pango_font_description_set_stretch (font_desc, PANGO_STRETCH_NORMAL); 
    
    gtk_widget_modify_font (widget, font_desc);
    
    style = gtk_widget_get_modifier_style (widget);
    
    if (!pango_font_description_equal (font_desc, style->font_desc))
    {
        TEST_FAIL ("fonts not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_font
 * Params: GtkWidget *widget, PangoFontDescription *font_desc
 * Returns: void
 * Assertion: Sets the font to use for a widget
 * Params Values: GtkWidget *widget, PangoFontDescription *font_desc
 * Expected: void
 * 
 * Name: gtk_widget_modify_font
 * Params: GtkWidget *widget, PangoFontDescription *font_desc
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, PangoFontDescription *font_desc
 * Expected: void  
 */
static void test_purpose_263()
{
    #define WIDGET gtk_entry_new ();
    
    GtkWidget* widget;
    GtkRcStyle* style;
    PangoFontDescription* font_desc = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    font_desc = pango_font_description_new ();
    
    pango_font_description_set_family (font_desc, "Times");
    pango_font_description_set_style (font_desc, PANGO_STYLE_NORMAL);
    pango_font_description_set_variant (font_desc, PANGO_VARIANT_NORMAL);
    pango_font_description_set_weight (font_desc, PANGO_WEIGHT_BOLD);
    pango_font_description_set_stretch (font_desc, PANGO_STRETCH_NORMAL); 
    
    gtk_widget_modify_font (widget, font_desc);
    
    style = gtk_widget_get_modifier_style (widget);
    
    if (!pango_font_description_equal (font_desc, style->font_desc))
    {
        TEST_FAIL ("fonts not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_font
 * Params: GtkWidget *widget, PangoFontDescription *font_desc
 * Returns: void
 * Assertion: Sets the font to use for a widget
 * Params Values: GtkWidget *widget, PangoFontDescription *font_desc
 * Expected: void
 * 
 * Name: gtk_widget_modify_font
 * Params: GtkWidget *widget, PangoFontDescription *font_desc
 * Returns: void
 * Assertion: All other style values are left untouched.
 * Params Values: GtkWidget *widget, PangoFontDescription *font_desc
 * Expected: void  
 */
static void test_purpose_264()
{
    #define WIDGET gtk_check_button_new ();
    
    GtkWidget* widget;
    GtkRcStyle* style;
    PangoFontDescription* font_desc = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    font_desc = pango_font_description_new ();
    
    pango_font_description_set_family (font_desc, "Times");
    pango_font_description_set_style (font_desc, PANGO_STYLE_NORMAL);
    pango_font_description_set_variant (font_desc, PANGO_VARIANT_NORMAL);
    pango_font_description_set_weight (font_desc, PANGO_WEIGHT_BOLD);
    pango_font_description_set_stretch (font_desc, PANGO_STRETCH_NORMAL); 
    
    gtk_widget_modify_font (widget, font_desc);
    
    style = gtk_widget_get_modifier_style (widget);
    
    if (!pango_font_description_equal (font_desc, style->font_desc))
    {
        TEST_FAIL ("fonts not equal", NULL); 
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_create_pango_context
 * Params: GtkWidget* widget
 * Returns: PangoContext*
 * Assertion: Creates a new PangoContext with the appropriate colormap, font description, and base direction for drawing text for this widget.
 * Params Values: GtkWidget* widget
 * Expected: PangoContext*  
 */
static void test_purpose_265()
{
    #define WIDGET gtk_button_new ();
    
    GtkWidget* widget;
    PangoContext* context;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    context = gtk_widget_create_pango_context (widget);
    if (!context)
    {
        TEST_FAIL ("pango context is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_create_pango_context
 * Params: GtkWidget* widget
 * Returns: PangoContext*
 * Assertion: Creates a new PangoContext with the appropriate colormap, font description, and base direction for drawing text for this widget.
 * Params Values: GtkWidget* widget
 * Expected: PangoContext*  
 */
static void test_purpose_266()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    GtkWidget* widget;
    PangoContext* context;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    context = gtk_widget_create_pango_context (widget);
    if (!context)
    {
        TEST_FAIL ("pango context is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_create_pango_context
 * Params: GtkWidget* widget
 * Returns: PangoContext*
 * Assertion: Creates a new PangoContext with the appropriate colormap, font description, and base direction for drawing text for this widget.
 * Params Values: GtkWidget* widget
 * Expected: PangoContext*  
 */
static void test_purpose_267()
{
    #define WIDGET gtk_label_new ("Label");
    
    GtkWidget* widget;
    PangoContext* context;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    context = gtk_widget_create_pango_context (widget);
    if (!context)
    {
        TEST_FAIL ("pango context is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_create_pango_context
 * Params: GtkWidget* widget
 * Returns: PangoContext*
 * Assertion: Creates a new PangoContext with the appropriate colormap, font description, and base direction for drawing text for this widget.
 * Params Values: GtkWidget* widget
 * Expected: PangoContext*  
 */
static void test_purpose_268()
{
    #define WIDGET gtk_entry_new ();
    
    GtkWidget* widget;
    PangoContext* context;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    context = gtk_widget_create_pango_context (widget);
    if (!context)
    {
        TEST_FAIL ("pango context is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_create_pango_context
 * Params: GtkWidget* widget
 * Returns: PangoContext*
 * Assertion: Creates a new PangoContext with the appropriate colormap, font description, and base direction for drawing text for this widget.
 * Params Values: GtkWidget* widget
 * Expected: PangoContext*  
 */
static void test_purpose_269()
{
    #define WIDGET gtk_check_button_new ();
    
    GtkWidget* widget;
    PangoContext* context;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    context = gtk_widget_create_pango_context (widget);
    if (!context)
    {
        TEST_FAIL ("pango context is NULL but shouldn't be", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_create_pango_layout
 * Params: GtkWidget* widget, const gchar *text
 * Returns: PangoLayout*
 * Assertion: Creates a new PangoLayout with the appropriate colormap, font description, and base direction for drawing text for this widget.
 * Params Values: GtkWidget* widget, const gchar *text
 * Expected: PangoLayout*  
 */
static void test_purpose_270()
{
    #define WIDGET gtk_button_new ();
    #define TEXT "Layout"
    
    GtkWidget* widget;
    PangoLayout* layout;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    layout = gtk_widget_create_pango_layout (widget, TEXT);
    if (!layout)
    {
        TEST_FAIL ("pango layout is NULL but shouldn't be", NULL);
        return;
    }
    
    if (strcmp (TEXT, pango_layout_get_text (layout)))
    {
        TEST_FAIL ("text should be %s", TEXT);
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_create_pango_layout
 * Params: GtkWidget* widget, const gchar *text
 * Returns: PangoLayout*
 * Assertion: Creates a new PangoLayout with the appropriate colormap, font description, and base direction for drawing text for this widget.
 * Params Values: GtkWidget* widget, const gchar *text
 * Expected: PangoLayout*  
 */
static void test_purpose_271()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define TEXT "Layout"
    
    GtkWidget* widget;
    PangoLayout* layout;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    layout = gtk_widget_create_pango_layout (widget, TEXT);
    if (!layout)
    {
        TEST_FAIL ("pango layout is NULL but shouldn't be", NULL);
        return;
    }
    
    if (strcmp (TEXT, pango_layout_get_text (layout)))
    {
        TEST_FAIL ("text should be %s", TEXT);
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_create_pango_layout
 * Params: GtkWidget* widget, const gchar *text
 * Returns: PangoLayout*
 * Assertion: Creates a new PangoLayout with the appropriate colormap, font description, and base direction for drawing text for this widget.
 * Params Values: GtkWidget* widget, const gchar *text
 * Expected: PangoLayout*  
 */
static void test_purpose_272()
{
    #define WIDGET gtk_label_new ("Label");
    #define TEXT "Layout"
    
    GtkWidget* widget;
    PangoLayout* layout;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    layout = gtk_widget_create_pango_layout (widget, TEXT);
    if (!layout)
    {
        TEST_FAIL ("pango layout is NULL but shouldn't be", NULL);
        return;
    }
    
    if (strcmp (TEXT, pango_layout_get_text (layout)))
    {
        TEST_FAIL ("text should be %s", TEXT);
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_create_pango_layout
 * Params: GtkWidget* widget, const gchar *text
 * Returns: PangoLayout*
 * Assertion: Creates a new PangoLayout with the appropriate colormap, font description, and base direction for drawing text for this widget.
 * Params Values: GtkWidget* widget, const gchar *text
 * Expected: PangoLayout*  
 */
static void test_purpose_273()
{
    #define WIDGET gtk_entry_new ();
    #define TEXT "Layout"
    
    GtkWidget* widget;
    PangoLayout* layout;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    layout = gtk_widget_create_pango_layout (widget, TEXT);
    if (!layout)
    {
        TEST_FAIL ("pango layout is NULL but shouldn't be", NULL);
        return;
    }
    
    if (strcmp (TEXT, pango_layout_get_text (layout)))
    {
        TEST_FAIL ("text should be %s", TEXT);
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_create_pango_layout
 * Params: GtkWidget* widget, const gchar *text
 * Returns: PangoLayout*
 * Assertion: Creates a new PangoLayout with the appropriate colormap, font description, and base direction for drawing text for this widget.
 * Params Values: GtkWidget* widget, const gchar *text
 * Expected: PangoLayout*  
 */
static void test_purpose_274()
{
    #define WIDGET gtk_check_button_new ();
    #define TEXT "Layout"
    
    GtkWidget* widget;
    PangoLayout* layout;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    layout = gtk_widget_create_pango_layout (widget, TEXT);
    if (!layout)
    {
        TEST_FAIL ("pango layout is NULL but shouldn't be", NULL);
        return;
    }
    
    if (strcmp (TEXT, pango_layout_get_text (layout)))
    {
        TEST_FAIL ("text should be %s", TEXT);
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_render_icon
 * Params: GtkWidget* widget, const gchar *stock_id, GtkIconSize size, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: A convenience function that uses the theme engine and RC file settings for widget to look up stock_id and render it to a pixbuf. 
 * Params Values: GtkWidget* widget,  const gchar *stock_id, GtkIconSize size, const gchar *detail
 * Expected: GdkPixbuf*  
 */
static void test_purpose_275()
{
    #define WIDGET gtk_button_new ()
    #define STOCK_ID GTK_STOCK_OPEN
    #define ICON_SIZE GTK_ICON_SIZE_MENU
    #define DETAIL "Button"
    
    GtkWidget* widget;
    GdkPixbuf* pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    pixbuf = gtk_widget_render_icon (widget, STOCK_ID, ICON_SIZE, DETAIL);
    if (!pixbuf)
    {
        TEST_FAIL ("gtk_widget_render_icon () returns NULL", NULL);
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STOCK_ID
    #undef ICON_SIZE
    #undef DETAIL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_render_icon
 * Params: GtkWidget* widget, const gchar *stock_id, GtkIconSize size, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: A convenience function that uses the theme engine and RC file settings for widget to look up stock_id and render it to a pixbuf. 
 * Params Values: GtkWidget* widget,  const gchar *stock_id, GtkIconSize size, const gchar *detail
 * Expected: GdkPixbuf*  
 */
static void test_purpose_276()
{
    #define WIDGET gtk_button_new ()
    #define STOCK_ID GTK_STOCK_OK
    #define ICON_SIZE GTK_ICON_SIZE_SMALL_TOOLBAR
    #define DETAIL "Button"
    
    GtkWidget* widget;
    GdkPixbuf* pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    pixbuf = gtk_widget_render_icon (widget, STOCK_ID, ICON_SIZE, DETAIL);
    if (!pixbuf)
    {
        TEST_FAIL ("gtk_widget_render_icon () returns NULL", NULL);
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STOCK_ID
    #undef ICON_SIZE
    #undef DETAIL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_render_icon
 * Params: GtkWidget* widget, const gchar *stock_id, GtkIconSize size, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: A convenience function that uses the theme engine and RC file settings for widget to look up stock_id and render it to a pixbuf. 
 * Params Values: GtkWidget* widget,  const gchar *stock_id, GtkIconSize size, const gchar *detail
 * Expected: GdkPixbuf*  
 */
static void test_purpose_277()
{
    #define WIDGET gtk_check_button_new ()
    #define STOCK_ID GTK_STOCK_OK
    #define ICON_SIZE GTK_ICON_SIZE_LARGE_TOOLBAR
    #define DETAIL "Check Button"
    
    GtkWidget* widget;
    GdkPixbuf* pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    pixbuf = gtk_widget_render_icon (widget, STOCK_ID, ICON_SIZE, DETAIL);
    if (!pixbuf)
    {
        TEST_FAIL ("gtk_widget_render_icon () returns NULL", NULL);
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STOCK_ID
    #undef ICON_SIZE
    #undef DETAIL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_render_icon
 * Params: GtkWidget* widget, const gchar *stock_id, GtkIconSize size, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: A convenience function that uses the theme engine and RC file settings for widget to look up stock_id and render it to a pixbuf. 
 * Params Values: GtkWidget* widget,  const gchar *stock_id, GtkIconSize size, const gchar *detail
 * Expected: GdkPixbuf*  
 */
static void test_purpose_278()
{
    #define WIDGET gtk_toggle_button_new ()
    #define STOCK_ID GTK_STOCK_OPEN
    #define ICON_SIZE GTK_ICON_SIZE_BUTTON
    #define DETAIL "Toggle Button"
    
    GtkWidget* widget;
    GdkPixbuf* pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    pixbuf = gtk_widget_render_icon (widget, STOCK_ID, ICON_SIZE, DETAIL);
    if (!pixbuf)
    {
        TEST_FAIL ("gtk_widget_render_icon () returns NULL", NULL);
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STOCK_ID
    #undef ICON_SIZE
    #undef DETAIL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_queue_draw_area 
 * Params: GtkWidget* widget, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Invalidates the rectangular area of widget defined by x, y, width and height by calling gdk_window_invalidate_rect() on the widget's window and all its child windows.'
 * Params Values: GtkWidget* widget, gint x, gint y, gint width, gint height
 * Expected: void  
 */
static void test_purpose_279()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define CHILD gtk_button_new ()
    #define BOTH TRUE
    
    GtkWidget* widget;
    GtkWidget* child;
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    gtk_widget_realize (widget);
    gtk_widget_realize (child);
    obj = (GdkWindowObject*)widget->window;
    obj->x = 0;
    obj->y = 0;
    
    gtk_widget_set_size_request (widget, 200, 200);
    gtk_widget_set_size_request (child, 30, 20);
    gtk_widget_show_all (widget);
    
    
    obj = (GdkWindowObject*)child->window;
    if (BOTH)
    {
        obj->x = 0;
        obj->y = 0;
        g_signal_connect (G_OBJECT (child), "expose-event", GTK_SIGNAL_FUNC (global_show), NULL);
    
    } else {
    
        obj->x = 100;
        obj->y = 100;
        g_signal_connect (G_OBJECT (widget), "expose-event", GTK_SIGNAL_FUNC (global_show), NULL);
    }
    
    gtk_widget_queue_draw_area (widget, 1, 1, 50, 50);
    gdk_window_process_all_updates() ;
    
    if (!result)
    {
        TEST_FAIL ("result is wrong", NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    #undef BOTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_queue_draw_area 
 * Params: GtkWidget* widget, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Invalidates the rectangular area of widget defined by x, y, width and height by calling gdk_window_invalidate_rect() on the widget's window and all its child windows.'
 * Params Values: GtkWidget* widget, gint x, gint y, gint width, gint height
 * Expected: void  
 */
static void test_purpose_280()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define CHILD gtk_button_new ()
    #define BOTH FALSE
    
    GtkWidget* widget;
    GtkWidget* child;
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    gtk_widget_realize (widget);
    gtk_widget_realize (child);
    obj = (GdkWindowObject*)widget->window;
    obj->x = 0;
    obj->y = 0;
    
    gtk_widget_set_size_request (widget, 200, 200);
    gtk_widget_set_size_request (child, 30, 20);
    gtk_widget_show_all (widget);
    
    
    obj = (GdkWindowObject*)child->window;
    if (BOTH)
    {
        obj->x = 0;
        obj->y = 0;
        g_signal_connect (G_OBJECT (child), "expose-event", GTK_SIGNAL_FUNC (global_show), NULL);
    
    } else {
    
        obj->x = 100;
        obj->y = 100;
        g_signal_connect (G_OBJECT (widget), "expose-event", GTK_SIGNAL_FUNC (global_show), NULL);
    }
    
    gtk_widget_queue_draw_area (widget, 1, 1, 50, 50);
    gdk_window_process_all_updates() ;
    
    if (!result)
    {
        TEST_FAIL ("result is wrong", NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    #undef BOTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_queue_draw_area 
 * Params: GtkWidget* widget, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Invalidates the rectangular area of widget defined by x, y, width and height by calling gdk_window_invalidate_rect() on the widget's window and all its child windows.'
 * Params Values: GtkWidget* widget, gint x, gint y, gint width, gint height
 * Expected: void  
 */
static void test_purpose_281()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define CHILD gtk_check_button_new ()
    #define BOTH TRUE
    
    GtkWidget* widget;
    GtkWidget* child;
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    gtk_widget_realize (widget);
    gtk_widget_realize (child);
    obj = (GdkWindowObject*)widget->window;
    obj->x = 0;
    obj->y = 0;
    
    gtk_widget_set_size_request (widget, 200, 200);
    gtk_widget_set_size_request (child, 30, 20);
    gtk_widget_show_all (widget);
    
    
    obj = (GdkWindowObject*)child->window;
    if (BOTH)
    {
        obj->x = 0;
        obj->y = 0;
        g_signal_connect (G_OBJECT (child), "expose-event", GTK_SIGNAL_FUNC (global_show), NULL);
    
    } else {
    
        obj->x = 100;
        obj->y = 100;
        g_signal_connect (G_OBJECT (widget), "expose-event", GTK_SIGNAL_FUNC (global_show), NULL);
    }
    
    gtk_widget_queue_draw_area (widget, 1, 1, 50, 50);
    gdk_window_process_all_updates() ;
    
    if (!result)
    {
        TEST_FAIL ("result is wrong", NULL); 
        return;
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    #undef BOTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_region_intersect
 * Params: GtkWidget *widget, GdkRegion *region
 * Returns: GdkRegion*
 * Assertion: Computes the intersection of a widget's area and region, returning the intersection.'
 * Params Values: GtkWidget *widget, GdkRegion *region
 * Expected: GdkRegion*  
 */
static void test_purpose_282()
{
    #define WIDGET gtk_dialog_new ()
    #define RECT 0, 0, 100, 100
    #define REGION 100, 100, 100, 100
    
    GtkWidget* widget;
    GdkRectangle region = {REGION};
    GdkRectangle rect = {RECT};
    GdkRectangle rect_res = {0,0,0,0};
    GdkRegion*   result;
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_realize (widget);
    obj = (GdkWindowObject*)widget->window;
    obj->x = rect.x;
    obj->y = rect.y;
    
    gtk_widget_set_size_request (widget, rect.width, rect.height);
    gtk_widget_show_all (widget);
    
    result = gtk_widget_region_intersect (widget, gdk_region_rectangle (&region));
    
    gdk_rectangle_intersect (&rect, &region, &rect_res);
    
    if (!gdk_region_equal(result, gdk_region_rectangle (&rect_res)))
    {
        TEST_FAIL ("rectangles not equal", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef RECT
    #undef REGION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_region_intersect
 * Params: GtkWidget *widget, GdkRegion *region
 * Returns: GdkRegion*
 * Assertion: Computes the intersection of a widget's area and region, returning the intersection.'
 * Params Values: GtkWidget *widget, GdkRegion *region
 * Expected: GdkRegion*  
 */
static void test_purpose_283()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define RECT 0, 0, 100, 100
    #define REGION 1, 1, 100, 100
    
    GtkWidget* widget;
    GdkRectangle region = {REGION};
    GdkRectangle rect = {RECT};
    GdkRectangle rect_res = {0,0,0,0};
    GdkRegion*   result;
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_realize (widget);
    obj = (GdkWindowObject*)widget->window;
    obj->x = rect.x;
    obj->y = rect.y;
    
    gtk_widget_set_size_request (widget, rect.width, rect.height);
    gtk_widget_show_all (widget);
    
    result = gtk_widget_region_intersect (widget, gdk_region_rectangle (&region));
    
    gdk_rectangle_intersect (&rect, &region, &rect_res);
    
    if (!gdk_region_equal(result, gdk_region_rectangle (&rect_res)))
    {
        TEST_FAIL ("rectangles not equal", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef RECT
    #undef REGION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_region_intersect
 * Params: GtkWidget *widget, GdkRegion *region
 * Returns: GdkRegion*
 * Assertion: Computes the intersection of a widget's area and region, returning the intersection.'
 * Params Values: GtkWidget *widget, GdkRegion *region
 * Expected: GdkRegion*  
 */
static void test_purpose_284()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define RECT 0, 0, 50, 50
    #define REGION 50, 0, 100, 20
    
    GtkWidget* widget;
    GdkRectangle region = {REGION};
    GdkRectangle rect = {RECT};
    GdkRectangle rect_res = {0,0,0,0};
    GdkRegion*   result;
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_realize (widget);
    obj = (GdkWindowObject*)widget->window;
    obj->x = rect.x;
    obj->y = rect.y;
    
    gtk_widget_set_size_request (widget, rect.width, rect.height);
    gtk_widget_show_all (widget);
    
    result = gtk_widget_region_intersect (widget, gdk_region_rectangle (&region));
    
    gdk_rectangle_intersect (&rect, &region, &rect_res);
    
    if (!gdk_region_equal(result, gdk_region_rectangle (&rect_res)))
    {
        TEST_FAIL ("rectangles not equal", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef RECT
    #undef REGION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_region_intersect
 * Params: GtkWidget *widget, GdkRegion *region
 * Returns: GdkRegion*
 * Assertion: Computes the intersection of a widget's area and region, returning the intersection.'
 * Params Values: GtkWidget *widget, GdkRegion *region
 * Expected: GdkRegion*  
 */
static void test_purpose_285()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define RECT 0, 0, 5, 50
    #define REGION 100, 100, 100, 20
    
    GtkWidget* widget;
    GdkRectangle region = {REGION};
    GdkRectangle rect = {RECT};
    GdkRectangle rect_res = {0,0,0,0};
    GdkRegion*   result;
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_realize (widget);
    obj = (GdkWindowObject*)widget->window;
    obj->x = rect.x;
    obj->y = rect.y;
    
    gtk_widget_set_size_request (widget, rect.width, rect.height);
    gtk_widget_show_all (widget);
    
    result = gtk_widget_region_intersect (widget, gdk_region_rectangle (&region));
    
    gdk_rectangle_intersect (&rect, &region, &rect_res);
    
    if (!gdk_region_equal(result, gdk_region_rectangle (&rect_res)))
    {
        TEST_FAIL ("rectangles not equal", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef RECT
    #undef REGION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_child_focus
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: gtk_widget_child_focus() is called by containers as the user moves around the window using keyboard shortcuts.
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean
 * 
 * Name:  gtk_widget_child_focus 
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: gtk_widget_child_focus() invokes the "focus" signal on GtkWidget; widgets override the default handler for this signal in order to implement appropriate focus behavior.
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean  
 */
static void test_purpose_286()
{
    #define WIDGET gtk_vbox_new (TRUE, 10)
    #define CHILD gtk_entry_new ()
    #define DIRECTION GTK_DIR_DOWN
    
    GtkWidget* widget;
    GtkWidget* window;
    GtkWidget* child;
    GList *list = NULL;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("toplevel window not created", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    for (i = 0; i < 3; i++)
    {
        child = CHILD;
        if (!child)
        {
            TEST_FAIL ("'child %i' widget not created", i); 
            return;
        } 
        gtk_container_add (GTK_CONTAINER (widget), child);
        list = g_list_append (list, child);
    }
    
    gtk_container_set_focus_chain (GTK_CONTAINER (widget), list);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    if ((DIRECTION == GTK_DIR_TAB_FORWARD) || (DIRECTION == GTK_DIR_DOWN) || (DIRECTION == GTK_DIR_RIGHT))
    {
        g_signal_connect (G_OBJECT ((GtkWidget*)g_list_nth_data (list, 2)), "focus", GTK_SIGNAL_FUNC (global_show), NULL);
    
    } else {
    
        g_signal_connect (G_OBJECT ((GtkWidget*)g_list_nth_data (list, 0)), "focus", GTK_SIGNAL_FUNC (global_show), NULL);
    }
    
    gtk_container_set_focus_child (GTK_CONTAINER (widget), (GtkWidget*)g_list_nth_data (list, 1));
    gtk_widget_grab_focus ((GtkWidget*)g_list_nth_data (list, 1));
    
    if (!gtk_widget_child_focus (widget, DIRECTION))
    {
        TEST_FAIL ("gtk_widget_child_focus () returns FALSE", NULL); 
    }
    
    if (!result)
    {
        TEST_FAIL ("result is wrong", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef CHILD
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_child_focus
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: gtk_widget_child_focus() is called by containers as the user moves around the window using keyboard shortcuts.
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean
 * 
 * Name:  gtk_widget_child_focus 
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: gtk_widget_child_focus() invokes the "focus" signal on GtkWidget; widgets override the default handler for this signal in order to implement appropriate focus behavior.
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean  
 */
static void test_purpose_287()
{
    #define WIDGET gtk_vbox_new (TRUE, 10)
    #define CHILD gtk_entry_new ()
    #define DIRECTION GTK_DIR_UP
    
    GtkWidget* widget;
    GtkWidget* window;
    GtkWidget* child;
    GList *list = NULL;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("toplevel window not created", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    for (i = 0; i < 3; i++)
    {
        child = CHILD;
        if (!child)
        {
            TEST_FAIL ("'child %i' widget not created", i); 
            return;
        } 
        gtk_container_add (GTK_CONTAINER (widget), child);
        list = g_list_append (list, child);
    }
    
    gtk_container_set_focus_chain (GTK_CONTAINER (widget), list);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    if ((DIRECTION == GTK_DIR_TAB_FORWARD) || (DIRECTION == GTK_DIR_DOWN) || (DIRECTION == GTK_DIR_RIGHT))
    {
        g_signal_connect (G_OBJECT ((GtkWidget*)g_list_nth_data (list, 2)), "focus", GTK_SIGNAL_FUNC (global_show), NULL);
    
    } else {
    
        g_signal_connect (G_OBJECT ((GtkWidget*)g_list_nth_data (list, 0)), "focus", GTK_SIGNAL_FUNC (global_show), NULL);
    }
    
    gtk_container_set_focus_child (GTK_CONTAINER (widget), (GtkWidget*)g_list_nth_data (list, 1));
    gtk_widget_grab_focus ((GtkWidget*)g_list_nth_data (list, 1));
    
    if (!gtk_widget_child_focus (widget, DIRECTION))
    {
        TEST_FAIL ("gtk_widget_child_focus () returns FALSE", NULL); 
    }
    
    if (!result)
    {
        TEST_FAIL ("result is wrong", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef CHILD
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_child_focus
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: gtk_widget_child_focus() is called by containers as the user moves around the window using keyboard shortcuts.
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean
 * 
 * Name:  gtk_widget_child_focus 
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: gtk_widget_child_focus() invokes the "focus" signal on GtkWidget; widgets override the default handler for this signal in order to implement appropriate focus behavior.
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean  
 */
static void test_purpose_288()
{
    #define WIDGET gtk_vbox_new (TRUE, 10)
    #define CHILD gtk_entry_new ()
    #define DIRECTION GTK_DIR_TAB_FORWARD
    
    GtkWidget* widget;
    GtkWidget* window;
    GtkWidget* child;
    GList *list = NULL;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("toplevel window not created", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    for (i = 0; i < 3; i++)
    {
        child = CHILD;
        if (!child)
        {
            TEST_FAIL ("'child %i' widget not created", i); 
            return;
        } 
        gtk_container_add (GTK_CONTAINER (widget), child);
        list = g_list_append (list, child);
    }
    
    gtk_container_set_focus_chain (GTK_CONTAINER (widget), list);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    if ((DIRECTION == GTK_DIR_TAB_FORWARD) || (DIRECTION == GTK_DIR_DOWN) || (DIRECTION == GTK_DIR_RIGHT))
    {
        g_signal_connect (G_OBJECT ((GtkWidget*)g_list_nth_data (list, 2)), "focus", GTK_SIGNAL_FUNC (global_show), NULL);
    
    } else {
    
        g_signal_connect (G_OBJECT ((GtkWidget*)g_list_nth_data (list, 0)), "focus", GTK_SIGNAL_FUNC (global_show), NULL);
    }
    
    gtk_container_set_focus_child (GTK_CONTAINER (widget), (GtkWidget*)g_list_nth_data (list, 1));
    gtk_widget_grab_focus ((GtkWidget*)g_list_nth_data (list, 1));
    
    if (!gtk_widget_child_focus (widget, DIRECTION))
    {
        TEST_FAIL ("gtk_widget_child_focus () returns FALSE", NULL); 
    }
    
    if (!result)
    {
        TEST_FAIL ("result is wrong", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef CHILD
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_child_focus
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: gtk_widget_child_focus() is called by containers as the user moves around the window using keyboard shortcuts.
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean
 * 
 * Name:  gtk_widget_child_focus 
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: gtk_widget_child_focus() invokes the "focus" signal on GtkWidget; widgets override the default handler for this signal in order to implement appropriate focus behavior.
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean  
 */
static void test_purpose_289()
{
    #define WIDGET gtk_hbox_new (TRUE, 10)
    #define CHILD gtk_entry_new ()
    #define DIRECTION GTK_DIR_TAB_FORWARD
    
    GtkWidget* widget;
    GtkWidget* window;
    GtkWidget* child;
    GList *list = NULL;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("toplevel window not created", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    for (i = 0; i < 3; i++)
    {
        child = CHILD;
        if (!child)
        {
            TEST_FAIL ("'child %i' widget not created", i); 
            return;
        } 
        gtk_container_add (GTK_CONTAINER (widget), child);
        list = g_list_append (list, child);
    }
    
    gtk_container_set_focus_chain (GTK_CONTAINER (widget), list);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    if ((DIRECTION == GTK_DIR_TAB_FORWARD) || (DIRECTION == GTK_DIR_DOWN) || (DIRECTION == GTK_DIR_RIGHT))
    {
        g_signal_connect (G_OBJECT ((GtkWidget*)g_list_nth_data (list, 2)), "focus", GTK_SIGNAL_FUNC (global_show), NULL);
    
    } else {
    
        g_signal_connect (G_OBJECT ((GtkWidget*)g_list_nth_data (list, 0)), "focus", GTK_SIGNAL_FUNC (global_show), NULL);
    }
    
    gtk_container_set_focus_child (GTK_CONTAINER (widget), (GtkWidget*)g_list_nth_data (list, 1));
    gtk_widget_grab_focus ((GtkWidget*)g_list_nth_data (list, 1));
    
    if (!gtk_widget_child_focus (widget, DIRECTION))
    {
        TEST_FAIL ("gtk_widget_child_focus () returns FALSE", NULL); 
    }
    
    if (!result)
    {
        TEST_FAIL ("result is wrong", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef CHILD
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_child_focus
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: gtk_widget_child_focus() is called by containers as the user moves around the window using keyboard shortcuts.
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean
 * 
 * Name:  gtk_widget_child_focus 
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: gtk_widget_child_focus() invokes the "focus" signal on GtkWidget; widgets override the default handler for this signal in order to implement appropriate focus behavior.
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean  
 */
static void test_purpose_290()
{
    #define WIDGET gtk_hbox_new (TRUE, 10)
    #define CHILD gtk_entry_new ()
    #define DIRECTION GTK_DIR_TAB_BACKWARD
    
    GtkWidget* widget;
    GtkWidget* window;
    GtkWidget* child;
    GList *list = NULL;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("toplevel window not created", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    for (i = 0; i < 3; i++)
    {
        child = CHILD;
        if (!child)
        {
            TEST_FAIL ("'child %i' widget not created", i); 
            return;
        } 
        gtk_container_add (GTK_CONTAINER (widget), child);
        list = g_list_append (list, child);
    }
    
    gtk_container_set_focus_chain (GTK_CONTAINER (widget), list);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    if ((DIRECTION == GTK_DIR_TAB_FORWARD) || (DIRECTION == GTK_DIR_DOWN) || (DIRECTION == GTK_DIR_RIGHT))
    {
        g_signal_connect (G_OBJECT ((GtkWidget*)g_list_nth_data (list, 2)), "focus", GTK_SIGNAL_FUNC (global_show), NULL);
    
    } else {
    
        g_signal_connect (G_OBJECT ((GtkWidget*)g_list_nth_data (list, 0)), "focus", GTK_SIGNAL_FUNC (global_show), NULL);
    }
    
    gtk_container_set_focus_child (GTK_CONTAINER (widget), (GtkWidget*)g_list_nth_data (list, 1));
    gtk_widget_grab_focus ((GtkWidget*)g_list_nth_data (list, 1));
    
    if (!gtk_widget_child_focus (widget, DIRECTION))
    {
        TEST_FAIL ("gtk_widget_child_focus () returns FALSE", NULL); 
    }
    
    if (!result)
    {
        TEST_FAIL ("result is wrong", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef CHILD
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_child_focus
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: gtk_widget_child_focus() is called by containers as the user moves around the window using keyboard shortcuts.
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean
 * 
 * Name:  gtk_widget_child_focus 
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: gtk_widget_child_focus() invokes the "focus" signal on GtkWidget; widgets override the default handler for this signal in order to implement appropriate focus behavior.
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean  
 */
static void test_purpose_291()
{
    #define WIDGET gtk_hbox_new (TRUE, 10)
    #define CHILD gtk_entry_new ()
    #define DIRECTION GTK_DIR_TAB_FORWARD
    
    GtkWidget* widget;
    GtkWidget* window;
    GtkWidget* child;
    GList *list = NULL;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("toplevel window not created", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    for (i = 0; i < 3; i++)
    {
        child = CHILD;
        if (!child)
        {
            TEST_FAIL ("'child %i' widget not created", i); 
            return;
        } 
        gtk_container_add (GTK_CONTAINER (widget), child);
        list = g_list_append (list, child);
    }
    
    gtk_container_set_focus_chain (GTK_CONTAINER (widget), list);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    if ((DIRECTION == GTK_DIR_TAB_FORWARD) || (DIRECTION == GTK_DIR_DOWN) || (DIRECTION == GTK_DIR_RIGHT))
    {
        g_signal_connect (G_OBJECT ((GtkWidget*)g_list_nth_data (list, 2)), "focus", GTK_SIGNAL_FUNC (global_show), NULL);
    
    } else {
    
        g_signal_connect (G_OBJECT ((GtkWidget*)g_list_nth_data (list, 0)), "focus", GTK_SIGNAL_FUNC (global_show), NULL);
    }
    
    gtk_container_set_focus_child (GTK_CONTAINER (widget), (GtkWidget*)g_list_nth_data (list, 1));
    gtk_widget_grab_focus ((GtkWidget*)g_list_nth_data (list, 1));
    
    if (!gtk_widget_child_focus (widget, DIRECTION))
    {
        TEST_FAIL ("gtk_widget_child_focus () returns FALSE", NULL); 
    }
    
    if (!result)
    {
        TEST_FAIL ("result is wrong", NULL); 
        return;
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef CHILD
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_child_focus 
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: The "focus" default handler for a widget should return TRUE if moving in direction left the focus on a focusable location inside that widget, and FALSE if moving in direction moved the focus outside the widget. 
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean
 * 
 * Name: gtk_widget_child_focus
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion:  gtk_widget_child_focus() returns FALSE if the widget is not currently in a focusable state, so there's no need for those checks.'
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean  
 */
static void test_purpose_292()
{
    #define WIDGET gtk_vbox_new (TRUE, 10)
    #define CHILD gtk_entry_new ()
    #define DIRECTION GTK_DIR_DOWN
    
    GtkWidget* widget;
    GtkWidget* window;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("toplevel window not created", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    gtk_container_set_focus_child (GTK_CONTAINER (widget), child);
    gtk_widget_grab_focus (child);
    
    if (gtk_widget_child_focus (widget, DIRECTION))
    {
        TEST_FAIL ("gtk_widget_child_focus () should return FALSE", NULL); 
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef CHILD
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_child_focus 
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: The "focus" default handler for a widget should return TRUE if moving in direction left the focus on a focusable location inside that widget, and FALSE if moving in direction moved the focus outside the widget. 
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean
 * 
 * Name: gtk_widget_child_focus
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion:  gtk_widget_child_focus() returns FALSE if the widget is not currently in a focusable state, so there's no need for those checks.'
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean  
 */
static void test_purpose_293()
{
    #define WIDGET gtk_vbox_new (TRUE, 10)
    #define CHILD gtk_entry_new ()
    #define DIRECTION GTK_DIR_UP
    
    GtkWidget* widget;
    GtkWidget* window;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("toplevel window not created", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    gtk_container_set_focus_child (GTK_CONTAINER (widget), child);
    gtk_widget_grab_focus (child);
    
    if (gtk_widget_child_focus (widget, DIRECTION))
    {
        TEST_FAIL ("gtk_widget_child_focus () should return FALSE", NULL); 
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef CHILD
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_child_focus 
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: The "focus" default handler for a widget should return TRUE if moving in direction left the focus on a focusable location inside that widget, and FALSE if moving in direction moved the focus outside the widget. 
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean
 * 
 * Name: gtk_widget_child_focus
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion:  gtk_widget_child_focus() returns FALSE if the widget is not currently in a focusable state, so there's no need for those checks.'
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean  
 */
static void test_purpose_294()
{
    #define WIDGET gtk_vbox_new (TRUE, 10)
    #define CHILD gtk_entry_new ()
    #define DIRECTION GTK_DIR_TAB_FORWARD
    
    GtkWidget* widget;
    GtkWidget* window;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("toplevel window not created", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    gtk_container_set_focus_child (GTK_CONTAINER (widget), child);
    gtk_widget_grab_focus (child);
    
    if (gtk_widget_child_focus (widget, DIRECTION))
    {
        TEST_FAIL ("gtk_widget_child_focus () should return FALSE", NULL); 
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef CHILD
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_child_focus 
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: The "focus" default handler for a widget should return TRUE if moving in direction left the focus on a focusable location inside that widget, and FALSE if moving in direction moved the focus outside the widget. 
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean
 * 
 * Name: gtk_widget_child_focus
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion:  gtk_widget_child_focus() returns FALSE if the widget is not currently in a focusable state, so there's no need for those checks.'
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean  
 */
static void test_purpose_295()
{
    #define WIDGET gtk_hbox_new (TRUE, 10)
    #define CHILD gtk_entry_new ()
    #define DIRECTION GTK_DIR_TAB_FORWARD
    
    GtkWidget* widget;
    GtkWidget* window;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("toplevel window not created", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    gtk_container_set_focus_child (GTK_CONTAINER (widget), child);
    gtk_widget_grab_focus (child);
    
    if (gtk_widget_child_focus (widget, DIRECTION))
    {
        TEST_FAIL ("gtk_widget_child_focus () should return FALSE", NULL); 
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef CHILD
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_child_focus 
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: The "focus" default handler for a widget should return TRUE if moving in direction left the focus on a focusable location inside that widget, and FALSE if moving in direction moved the focus outside the widget. 
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean
 * 
 * Name: gtk_widget_child_focus
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion:  gtk_widget_child_focus() returns FALSE if the widget is not currently in a focusable state, so there's no need for those checks.'
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean  
 */
static void test_purpose_296()
{
    #define WIDGET gtk_hbox_new (TRUE, 10)
    #define CHILD gtk_entry_new ()
    #define DIRECTION GTK_DIR_TAB_BACKWARD
    
    GtkWidget* widget;
    GtkWidget* window;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("toplevel window not created", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    gtk_container_set_focus_child (GTK_CONTAINER (widget), child);
    gtk_widget_grab_focus (child);
    
    if (gtk_widget_child_focus (widget, DIRECTION))
    {
        TEST_FAIL ("gtk_widget_child_focus () should return FALSE", NULL); 
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef CHILD
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_child_focus 
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion: The "focus" default handler for a widget should return TRUE if moving in direction left the focus on a focusable location inside that widget, and FALSE if moving in direction moved the focus outside the widget. 
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean
 * 
 * Name: gtk_widget_child_focus
 * Params: GtkWidget* widget,  GtkDirectionType direction
 * Returns: gboolean
 * Assertion:  gtk_widget_child_focus() returns FALSE if the widget is not currently in a focusable state, so there's no need for those checks.'
 * Params Values: GtkWidget* widget,  GtkDirectionType direction
 * Expected: gboolean  
 */
static void test_purpose_297()
{
    #define WIDGET gtk_hbox_new (TRUE, 10)
    #define CHILD gtk_entry_new ()
    #define DIRECTION GTK_DIR_TAB_FORWARD
    
    GtkWidget* widget;
    GtkWidget* window;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL ("toplevel window not created", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    gtk_container_set_focus_child (GTK_CONTAINER (widget), child);
    gtk_widget_grab_focus (child);
    
    if (gtk_widget_child_focus (widget, DIRECTION))
    {
        TEST_FAIL ("gtk_widget_child_focus () should return FALSE", NULL); 
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef CHILD
    #undef DIRECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_requisition_copy
 * Params: const GtkRequisition *requisition
 * Returns: GtkRequisition*
 * Assertion: Copies a GtkRequisition.
 * Params Values: const GtkRequisition *requisition
 * Expected: GtkRequisition*  
 */
static void test_purpose_298()
{
    #define REQ 10, 10
    
    GtkRequisition req = {REQ};
    GtkRequisition* res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    res = gtk_requisition_copy (&req);
    if (!res)
    {
        TEST_FAIL ("gtk_requisition_copy () returns NULL", NULL); 
        return;
    }
    
    if ((res->width != req.width) || (res->height != req.height))
    {
        TEST_FAIL ("gtk_widget_child_focus () should return FALSE", NULL); 
    }
    
    #undef REQ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_requisition_copy
 * Params: const GtkRequisition *requisition
 * Returns: GtkRequisition*
 * Assertion: Copies a GtkRequisition.
 * Params Values: const GtkRequisition *requisition
 * Expected: GtkRequisition*  
 */
static void test_purpose_299()
{
    #define REQ 10, G_MAXINT
    
    GtkRequisition req = {REQ};
    GtkRequisition* res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    res = gtk_requisition_copy (&req);
    if (!res)
    {
        TEST_FAIL ("gtk_requisition_copy () returns NULL", NULL); 
        return;
    }
    
    if ((res->width != req.width) || (res->height != req.height))
    {
        TEST_FAIL ("gtk_widget_child_focus () should return FALSE", NULL); 
    }
    
    #undef REQ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_requisition_copy
 * Params: const GtkRequisition *requisition
 * Returns: GtkRequisition*
 * Assertion: Copies a GtkRequisition.
 * Params Values: const GtkRequisition *requisition
 * Expected: GtkRequisition*  
 */
static void test_purpose_300()
{
    #define REQ 0, 0
    
    GtkRequisition req = {REQ};
    GtkRequisition* res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    res = gtk_requisition_copy (&req);
    if (!res)
    {
        TEST_FAIL ("gtk_requisition_copy () returns NULL", NULL); 
        return;
    }
    
    if ((res->width != req.width) || (res->height != req.height))
    {
        TEST_FAIL ("gtk_widget_child_focus () should return FALSE", NULL); 
    }
    
    #undef REQ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_requisition_free
 * Params: GtkRequisition *requisition
 * Returns: void
 * Assertion: Frees a GtkRequisition.
 * Params Values: GtkRequisition *requisition
 * Expected: void  
 */
static void test_purpose_301()
{
    #define REQ 10, 10
    
    GtkRequisition req = {REQ};
    GtkRequisition* res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    res = gtk_requisition_copy (&req);
    if (!res)
    {
        TEST_FAIL ("gtk_requisition_copy () returns NULL", NULL); 
        return;
    }
    
    gtk_requisition_free (res);
    
    #undef REQ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_requisition_free
 * Params: GtkRequisition *requisition
 * Returns: void
 * Assertion: Frees a GtkRequisition.
 * Params Values: GtkRequisition *requisition
 * Expected: void  
 */
static void test_purpose_302()
{
    #define REQ 10, G_MAXINT
    
    GtkRequisition req = {REQ};
    GtkRequisition* res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    res = gtk_requisition_copy (&req);
    if (!res)
    {
        TEST_FAIL ("gtk_requisition_copy () returns NULL", NULL); 
        return;
    }
    
    gtk_requisition_free (res);
    
    #undef REQ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_requisition_free
 * Params: GtkRequisition *requisition
 * Returns: void
 * Assertion: Frees a GtkRequisition.
 * Params Values: GtkRequisition *requisition
 * Expected: void  
 */
static void test_purpose_303()
{
    #define REQ 0, 0
    
    GtkRequisition req = {REQ};
    GtkRequisition* res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    res = gtk_requisition_copy (&req);
    if (!res)
    {
        TEST_FAIL ("gtk_requisition_copy () returns NULL", NULL); 
        return;
    }
    
    gtk_requisition_free (res);
    
    #undef REQ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_child_visible
 * Params: GtkWidget *widget, gboolean visible
 * Returns: void
 * Assertion: Sets whether widget should be mapped along with its when its parent is mapped and widget has been shown with gtk_widget_show().
 * Params Values: GtkWidget *widget,  TRUE
 * Expected: void
 * 
 * Name:  gtk_widget_get_child_visible
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: Gets the value set with gtk_widget_set_child_visible().
 * Params Values:  GtkWidget *widget
 * Expected: TRUE  
 */
static void test_purpose_304()
{
    #define WIDGET gtk_button_new ()
    #define VISIBLE TRUE
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_set_child_visible (widget, VISIBLE);
    
    if (VISIBLE != gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be %i", gtk_widget_get_child_visible (widget), VISIBLE);
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_child_visible
 * Params: GtkWidget *widget, gboolean visible
 * Returns: void
 * Assertion: Sets whether widget should be mapped along with its when its parent is mapped and widget has been shown with gtk_widget_show().
 * Params Values: GtkWidget *widget,  FALSE
 * Expected: void
 * 
 * Name:  gtk_widget_get_child_visible
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: Gets the value set with gtk_widget_set_child_visible().
 * Params Values:  GtkWidget *widget
 * Expected: FALSE  
 */
static void test_purpose_305()
{
    #define WIDGET gtk_check_button_new ()
    #define VISIBLE FALSE
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_set_child_visible (widget, VISIBLE);
    
    if (VISIBLE != gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be %i", gtk_widget_get_child_visible (widget), VISIBLE);
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_child_visible
 * Params: GtkWidget *widget, gboolean visible
 * Returns: void
 * Assertion: Sets whether widget should be mapped along with its when its parent is mapped and widget has been shown with gtk_widget_show().
 * Params Values: GtkWidget *widget,  TRUE
 * Expected: void
 * 
 * Name:  gtk_widget_get_child_visible
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: Gets the value set with gtk_widget_set_child_visible().
 * Params Values:  GtkWidget *widget
 * Expected: TRUE  
 */
static void test_purpose_306()
{
    #define WIDGET gtk_entry_new ()
    #define VISIBLE TRUE
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_set_child_visible (widget, VISIBLE);
    
    if (VISIBLE != gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be %i", gtk_widget_get_child_visible (widget), VISIBLE);
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_child_visible
 * Params: GtkWidget *widget, gboolean visible
 * Returns: void
 * Assertion: Sets whether widget should be mapped along with its when its parent is mapped and widget has been shown with gtk_widget_show().
 * Params Values: GtkWidget *widget,  FALSE
 * Expected: void
 * 
 * Name:  gtk_widget_get_child_visible
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: Gets the value set with gtk_widget_set_child_visible().
 * Params Values:  GtkWidget *widget
 * Expected: FALSE  
 */
static void test_purpose_307()
{
    #define WIDGET gtk_toggle_button_new ()
    #define VISIBLE FALSE
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_set_child_visible (widget, VISIBLE);
    
    if (VISIBLE != gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be %i", gtk_widget_get_child_visible (widget), VISIBLE);
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_settings
 * Params: GtkWidget *widget
 * Returns: GtkSettings*
 * Assertion: Gets the settings object holding the settings (global property settings, RC file information, etc) used for this widget.
 * Params Values:  GtkWidget *widget
 * Expected: GtkSettings*  
 */
static void test_purpose_308()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    if (!gtk_widget_get_settings (widget)) 
    {
        TEST_FAIL ("gtk_widget_get_settings returns NULL", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_settings
 * Params: GtkWidget *widget
 * Returns: GtkSettings*
 * Assertion: Gets the settings object holding the settings (global property settings, RC file information, etc) used for this widget.
 * Params Values:  GtkWidget *widget
 * Expected: GtkSettings*  
 */
static void test_purpose_309()
{
    #define WIDGET gtk_entry_new ()
    
    GtkWidget* widget;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    if (!gtk_widget_get_settings (widget)) 
    {
        TEST_FAIL ("gtk_widget_get_settings returns NULL", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_get_settings
 * Params: GtkWidget *widget
 * Returns: GtkSettings*
 * Assertion: Gets the settings object holding the settings (global property settings, RC file information, etc) used for this widget.
 * Params Values:  GtkWidget *widget
 * Expected: GtkSettings*  
 */
static void test_purpose_310()
{
    #define WIDGET gtk_toggle_button_new ()
    
    GtkWidget* widget;
    GtkWidget* window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_container_add (GTK_CONTAINER (window), widget);
    gtk_widget_show_all (window);
    
    if (!gtk_widget_get_settings (widget)) 
    {
        TEST_FAIL ("gtk_widget_get_settings returns NULL", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_size_request
 * Params: GtkWidget *widget, gint width, gint height
 * Returns: void
 * Assertion: Sets the minimum size of a widget; that is, the widget's size request will be width by height.'
 * Params Values: GtkWidget *widget, 40, 20
 * Expected: void
 * 
 * Name:  gtk_widget_set_size_request
 * Params: GtkWidget *widget, gint width, gint height
 * Returns: void
 * Assertion: Widgets can't actually be allocated a size less than 1 by 1, but you can pass 0,0 to this function to mean "as small as possible."'
 * Params Values: GtkWidget *widget, 40, 20
 * Expected: void
 * 
 * Name:  gtk_widget_get_size_request
 * Params: GtkWidget *widget, gint *width, gint *height
 * Returns: void
 * Assertion: Gets the size request that was explicitly set for the widget using gtk_widget_set_size_request(). 
 * Params Values:  GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_311()
{
    #define WIDGET gtk_button_new ()
    #define WIDTH 40
    #define HEIGHT 20
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_size_request (widget, WIDTH, HEIGHT);
    gtk_widget_get_size_request (widget, &width, &height);
    
    if ((width != WIDTH) || (height != HEIGHT)) 
    {
        if ((WIDTH > 0) && (HEIGHT > 0))
            TEST_FAIL ("size not equal (%i, %i), should be (%i, %i)", width, height, WIDTH, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_size_request
 * Params: GtkWidget *widget, gint width, gint height
 * Returns: void
 * Assertion: Sets the minimum size of a widget; that is, the widget's size request will be width by height.'
 * Params Values: GtkWidget *widget, 0, 0
 * Expected: void
 * 
 * Name:  gtk_widget_set_size_request
 * Params: GtkWidget *widget, gint width, gint height
 * Returns: void
 * Assertion: Widgets can't actually be allocated a size less than 1 by 1, but you can pass 0,0 to this function to mean "as small as possible."'
 * Params Values: GtkWidget *widget, 0, 0
 * Expected: void
 * 
 * Name:  gtk_widget_get_size_request
 * Params: GtkWidget *widget, gint *width, gint *height
 * Returns: void
 * Assertion: Gets the size request that was explicitly set for the widget using gtk_widget_set_size_request(). 
 * Params Values:  GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_312()
{
    #define WIDGET gtk_button_new ()
    #define WIDTH 0
    #define HEIGHT 0
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_size_request (widget, WIDTH, HEIGHT);
    gtk_widget_get_size_request (widget, &width, &height);
    
    if ((width != WIDTH) || (height != HEIGHT)) 
    {
        if ((WIDTH > 0) && (HEIGHT > 0))
            TEST_FAIL ("size not equal (%i, %i), should be (%i, %i)", width, height, WIDTH, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_size_request
 * Params: GtkWidget *widget, gint width, gint height
 * Returns: void
 * Assertion: Sets the minimum size of a widget; that is, the widget's size request will be width by height.'
 * Params Values: GtkWidget *widget, -1, -1
 * Expected: void
 * 
 * Name:  gtk_widget_set_size_request
 * Params: GtkWidget *widget, gint width, gint height
 * Returns: void
 * Assertion: Widgets can't actually be allocated a size less than 1 by 1, but you can pass 0,0 to this function to mean "as small as possible."'
 * Params Values: GtkWidget *widget, -1, -1
 * Expected: void
 * 
 * Name:  gtk_widget_get_size_request
 * Params: GtkWidget *widget, gint *width, gint *height
 * Returns: void
 * Assertion: Gets the size request that was explicitly set for the widget using gtk_widget_set_size_request(). 
 * Params Values:  GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_313()
{
    #define WIDGET gtk_button_new ()
    #define WIDTH -1
    #define HEIGHT -1
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_size_request (widget, WIDTH, HEIGHT);
    gtk_widget_get_size_request (widget, &width, &height);
    
    if ((width != WIDTH) || (height != HEIGHT)) 
    {
        if ((WIDTH > 0) && (HEIGHT > 0))
            TEST_FAIL ("size not equal (%i, %i), should be (%i, %i)", width, height, WIDTH, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_size_request
 * Params: GtkWidget *widget, gint width, gint height
 * Returns: void
 * Assertion: Sets the minimum size of a widget; that is, the widget's size request will be width by height.'
 * Params Values: GtkWidget *widget, 100, 30
 * Expected: void
 * 
 * Name:  gtk_widget_set_size_request
 * Params: GtkWidget *widget, gint width, gint height
 * Returns: void
 * Assertion: Widgets can't actually be allocated a size less than 1 by 1, but you can pass 0,0 to this function to mean "as small as possible."'
 * Params Values: GtkWidget *widget, 100, 30
 * Expected: void
 * 
 * Name:  gtk_widget_get_size_request
 * Params: GtkWidget *widget, gint *width, gint *height
 * Returns: void
 * Assertion: Gets the size request that was explicitly set for the widget using gtk_widget_set_size_request(). 
 * Params Values:  GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_314()
{
    #define WIDGET gtk_entry_new ()
    #define WIDTH 100
    #define HEIGHT 30
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_size_request (widget, WIDTH, HEIGHT);
    gtk_widget_get_size_request (widget, &width, &height);
    
    if ((width != WIDTH) || (height != HEIGHT)) 
    {
        if ((WIDTH > 0) && (HEIGHT > 0))
            TEST_FAIL ("size not equal (%i, %i), should be (%i, %i)", width, height, WIDTH, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_size_request
 * Params: GtkWidget *widget, gint width, gint height
 * Returns: void
 * Assertion: Sets the minimum size of a widget; that is, the widget's size request will be width by height.'
 * Params Values: GtkWidget *widget, 100, 30
 * Expected: void
 * 
 * Name:  gtk_widget_set_size_request
 * Params: GtkWidget *widget, gint width, gint height
 * Returns: void
 * Assertion: Widgets can't actually be allocated a size less than 1 by 1, but you can pass 0,0 to this function to mean "as small as possible."'
 * Params Values: GtkWidget *widget, 100, 30
 * Expected: void
 * 
 * Name:  gtk_widget_get_size_request
 * Params: GtkWidget *widget, gint *width, gint *height
 * Returns: void
 * Assertion: Gets the size request that was explicitly set for the widget using gtk_widget_set_size_request(). 
 * Params Values:  GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_315()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define WIDTH 100
    #define HEIGHT 30
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_size_request (widget, WIDTH, HEIGHT);
    gtk_widget_get_size_request (widget, &width, &height);
    
    if ((width != WIDTH) || (height != HEIGHT)) 
    {
        if ((WIDTH > 0) && (HEIGHT > 0))
            TEST_FAIL ("size not equal (%i, %i), should be (%i, %i)", width, height, WIDTH, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_redraw_on_allocate
 * Params: GtkWidget *widget, gboolean redraw_on_allocate
 * Returns: void
 * Assertion: Sets whether a when a widgets size allocation changes, the entire widget is queued for drawing.
 * Params Values: GtkWidget *widget, TRUE
 * Expected: void
 * 
 * Name:  gtk_widget_set_redraw_on_allocate
 * Params: GtkWidget *widget, gboolean redraw_on_allocate
 * Returns: void
 * Assertion: By default, this setting is TRUE and the entire widget is redrawn on every size change.
 * Params Values: GtkWidget *widget, TRUE
 * Expected: void  
 */
static void test_purpose_316()
{
    #define WIDGET gtk_button_new ()
    #define REDRAW_ON_ALLOCATE TRUE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_redraw_on_allocate (widget, REDRAW_ON_ALLOCATE);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef REDRAW_ON_ALLOCATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_redraw_on_allocate
 * Params: GtkWidget *widget, gboolean redraw_on_allocate
 * Returns: void
 * Assertion: Sets whether a when a widgets size allocation changes, the entire widget is queued for drawing.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void
 * 
 * Name:  gtk_widget_set_redraw_on_allocate
 * Params: GtkWidget *widget, gboolean redraw_on_allocate
 * Returns: void
 * Assertion: By default, this setting is TRUE and the entire widget is redrawn on every size change.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void  
 */
static void test_purpose_317()
{
    #define WIDGET gtk_button_new ()
    #define REDRAW_ON_ALLOCATE FALSE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_redraw_on_allocate (widget, REDRAW_ON_ALLOCATE);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef REDRAW_ON_ALLOCATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_redraw_on_allocate
 * Params: GtkWidget *widget, gboolean redraw_on_allocate
 * Returns: void
 * Assertion: Sets whether a when a widgets size allocation changes, the entire widget is queued for drawing.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void
 * 
 * Name:  gtk_widget_set_redraw_on_allocate
 * Params: GtkWidget *widget, gboolean redraw_on_allocate
 * Returns: void
 * Assertion: By default, this setting is TRUE and the entire widget is redrawn on every size change.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void  
 */
static void test_purpose_318()
{
    #define WIDGET gtk_check_button_new ()
    #define REDRAW_ON_ALLOCATE FALSE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_redraw_on_allocate (widget, REDRAW_ON_ALLOCATE);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef REDRAW_ON_ALLOCATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_redraw_on_allocate
 * Params: GtkWidget *widget, gboolean redraw_on_allocate
 * Returns: void
 * Assertion: Sets whether a when a widgets size allocation changes, the entire widget is queued for drawing.
 * Params Values: GtkWidget *widget, TRUE
 * Expected: void
 * 
 * Name:  gtk_widget_set_redraw_on_allocate
 * Params: GtkWidget *widget, gboolean redraw_on_allocate
 * Returns: void
 * Assertion: By default, this setting is TRUE and the entire widget is redrawn on every size change.
 * Params Values: GtkWidget *widget, TRUE
 * Expected: void  
 */
static void test_purpose_319()
{
    #define WIDGET gtk_entry_new ()
    #define REDRAW_ON_ALLOCATE TRUE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_redraw_on_allocate (widget, REDRAW_ON_ALLOCATE);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef REDRAW_ON_ALLOCATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_redraw_on_allocate
 * Params: GtkWidget *widget, gboolean redraw_on_allocate
 * Returns: void
 * Assertion: Sets whether a when a widgets size allocation changes, the entire widget is queued for drawing.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void
 * 
 * Name:  gtk_widget_set_redraw_on_allocate
 * Params: GtkWidget *widget, gboolean redraw_on_allocate
 * Returns: void
 * Assertion: By default, this setting is TRUE and the entire widget is redrawn on every size change.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void  
 */
static void test_purpose_320()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    #define REDRAW_ON_ALLOCATE FALSE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_redraw_on_allocate (widget, REDRAW_ON_ALLOCATE);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef REDRAW_ON_ALLOCATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_redraw_on_allocate
 * Params: GtkWidget *widget, gboolean redraw_on_allocate
 * Returns: void
 * Assertion: Sets whether a when a widgets size allocation changes, the entire widget is queued for drawing.
 * Params Values: GtkWidget *widget, TRUE
 * Expected: void
 * 
 * Name:  gtk_widget_set_redraw_on_allocate
 * Params: GtkWidget *widget, gboolean redraw_on_allocate
 * Returns: void
 * Assertion: By default, this setting is TRUE and the entire widget is redrawn on every size change.
 * Params Values: GtkWidget *widget, TRUE
 * Expected: void  
 */
static void test_purpose_321()
{
    #define WIDGET gtk_fixed_new ()
    #define REDRAW_ON_ALLOCATE TRUE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_redraw_on_allocate (widget, REDRAW_ON_ALLOCATE);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef REDRAW_ON_ALLOCATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_redraw_on_allocate
 * Params: GtkWidget *widget, gboolean redraw_on_allocate
 * Returns: void
 * Assertion: Sets whether a when a widgets size allocation changes, the entire widget is queued for drawing.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void
 * 
 * Name:  gtk_widget_set_redraw_on_allocate
 * Params: GtkWidget *widget, gboolean redraw_on_allocate
 * Returns: void
 * Assertion: By default, this setting is TRUE and the entire widget is redrawn on every size change.
 * Params Values: GtkWidget *widget, FALSE
 * Expected: void  
 */
static void test_purpose_322()
{
    #define WIDGET gtk_fixed_new ()
    #define REDRAW_ON_ALLOCATE FALSE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_set_redraw_on_allocate (widget, REDRAW_ON_ALLOCATE);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef REDRAW_ON_ALLOCATE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_translate_coordinates
 * Params: GtkWidget *src_widget, GtkWidget *dest_widget, gint src_x, gint src_y,gint *dest_x, gint *dest_y 
 * Returns: gboolean
 * Assertion: Translate coordinates relative to src_widget's allocation to coordinates relative to dest_widget's allocations.
 * Params Values: GtkWidget *widget, GtkWidget *dest_widget, 0, 0, gint *dest_x, gint *dest_y 
 * Expected: void  
 */
static void test_purpose_323()
{
    #define SRC_POS_X 0
    #define SRC_POS_Y 0
    #define DEST_POS_X 0
    #define DEST_POS_Y 0
    #define SRC_X 0
    #define SRC_Y 0
    #define CORRECT_DEST_X 0
    #define CORRECT_DEST_Y 0
    #define HAS_COMMON_ANCESTOR TRUE
    #define MUST_BE_REALIZED_SRC TRUE
    #define MUST_BE_REALIZED_DEST TRUE
     
    GtkWidget* window;
    GtkWidget* ancestor;
    GtkWidget* ancestor1;
    GtkWidget* src;
    GtkWidget* dest;
    gboolean res;
    gint dest_x;
    gint dest_y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    ancestor = gtk_fixed_new ();
    src = gtk_label_new ("src");
    dest = gtk_label_new ("dest");
    
    gtk_fixed_put (GTK_FIXED (ancestor), src, SRC_POS_X, SRC_POS_Y);
    gtk_container_add (GTK_CONTAINER (window), ancestor);
    
    if (HAS_COMMON_ANCESTOR == TRUE)
    {
        gtk_fixed_put (GTK_FIXED (ancestor), dest, DEST_POS_X, DEST_POS_Y);
    } else {
        ancestor1 = gtk_fixed_new ();
        gtk_fixed_put (GTK_FIXED (ancestor1), dest, DEST_POS_X, DEST_POS_Y);
    }
    
    if (MUST_BE_REALIZED_SRC)
    {
        gtk_widget_show (src);
    }
    if (MUST_BE_REALIZED_DEST)
    {
        gtk_widget_show (dest);
    }
    
    gtk_widget_show (ancestor);
    gtk_widget_show (window);
    
    res = gtk_widget_translate_coordinates (src, dest, SRC_X, SRC_Y, 
                                            &dest_x, &dest_y);
    
    if (HAS_COMMON_ANCESTOR == FALSE
        || MUST_BE_REALIZED_SRC == FALSE
        || MUST_BE_REALIZED_DEST == FALSE)
    {
        if (res == TRUE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = TRUE but should be FALSE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
    } else {
        if (res == FALSE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = FALSE but should be TRUE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
        
        if (dest_x != CORRECT_DEST_X)
        {
            TEST_FAIL ("dest_x = %d, should be %d", dest_x, CORRECT_DEST_X);
        }
    
        if (dest_y != CORRECT_DEST_Y)
        {
            TEST_FAIL ("dest_y = %d, should be %d", dest_y, CORRECT_DEST_Y);
        }
    }
    
    gtk_widget_destroy (src);
    gtk_widget_destroy (dest);
    gtk_widget_destroy (ancestor);
    
    if (ancestor1 && HAS_COMMON_ANCESTOR == FALSE)
    {
       gtk_widget_destroy (ancestor1);
    }
    
    gtk_widget_destroy (window);
    
    #undef SRC_POS_X
    #undef SRC_POS_Y
    #undef DEST_POS_X
    #undef DEST_POS_Y
    #undef SRC_X
    #undef SRC_Y
    #undef CORRECT_DEST_X
    #undef CORRECT_DEST_Y
    #undef HAS_COMMON_ANCESTOR
    #undef MUST_BE_REALIZED_SRC
    #undef MUST_BE_REALIZED_DEST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_translate_coordinates
 * Params: GtkWidget *src_widget, GtkWidget *dest_widget, gint src_x, gint src_y,gint *dest_x, gint *dest_y 
 * Returns: gboolean
 * Assertion: Translate coordinates relative to src_widget's allocation to coordinates relative to dest_widget's allocations.
 * Params Values: GtkWidget *widget, GtkWidget *dest_widget, 0, 0, gint *dest_x, gint *dest_y 
 * Expected: void  
 */
static void test_purpose_324()
{
    #define SRC_POS_X 0
    #define SRC_POS_Y 0
    #define DEST_POS_X 5
    #define DEST_POS_Y 5
    #define SRC_X 10
    #define SRC_Y 10
    #define CORRECT_DEST_X 5
    #define CORRECT_DEST_Y 5
    #define HAS_COMMON_ANCESTOR TRUE
    #define MUST_BE_REALIZED_SRC TRUE
    #define MUST_BE_REALIZED_DEST TRUE
     
    GtkWidget* window;
    GtkWidget* ancestor;
    GtkWidget* ancestor1;
    GtkWidget* src;
    GtkWidget* dest;
    gboolean res;
    gint dest_x;
    gint dest_y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    ancestor = gtk_fixed_new ();
    src = gtk_label_new ("src");
    dest = gtk_label_new ("dest");
    
    gtk_fixed_put (GTK_FIXED (ancestor), src, SRC_POS_X, SRC_POS_Y);
    gtk_container_add (GTK_CONTAINER (window), ancestor);
    
    if (HAS_COMMON_ANCESTOR == TRUE)
    {
        gtk_fixed_put (GTK_FIXED (ancestor), dest, DEST_POS_X, DEST_POS_Y);
    } else {
        ancestor1 = gtk_fixed_new ();
        gtk_fixed_put (GTK_FIXED (ancestor1), dest, DEST_POS_X, DEST_POS_Y);
    }
    
    if (MUST_BE_REALIZED_SRC)
    {
        gtk_widget_show (src);
    }
    if (MUST_BE_REALIZED_DEST)
    {
        gtk_widget_show (dest);
    }
    
    gtk_widget_show (ancestor);
    gtk_widget_show (window);
    
    res = gtk_widget_translate_coordinates (src, dest, SRC_X, SRC_Y, 
                                            &dest_x, &dest_y);
    
    if (HAS_COMMON_ANCESTOR == FALSE
        || MUST_BE_REALIZED_SRC == FALSE
        || MUST_BE_REALIZED_DEST == FALSE)
    {
        if (res == TRUE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = TRUE but should be FALSE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
    } else {
        if (res == FALSE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = FALSE but should be TRUE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
        
        if (dest_x != CORRECT_DEST_X)
        {
            TEST_FAIL ("dest_x = %d, should be %d", dest_x, CORRECT_DEST_X);
        }
    
        if (dest_y != CORRECT_DEST_Y)
        {
            TEST_FAIL ("dest_y = %d, should be %d", dest_y, CORRECT_DEST_Y);
        }
    }
    
    gtk_widget_destroy (src);
    gtk_widget_destroy (dest);
    gtk_widget_destroy (ancestor);
    
    if (ancestor1 && HAS_COMMON_ANCESTOR == FALSE)
    {
       gtk_widget_destroy (ancestor1);
    }
    
    gtk_widget_destroy (window);
    
    #undef SRC_POS_X
    #undef SRC_POS_Y
    #undef DEST_POS_X
    #undef DEST_POS_Y
    #undef SRC_X
    #undef SRC_Y
    #undef CORRECT_DEST_X
    #undef CORRECT_DEST_Y
    #undef HAS_COMMON_ANCESTOR
    #undef MUST_BE_REALIZED_SRC
    #undef MUST_BE_REALIZED_DEST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_translate_coordinates
 * Params: GtkWidget *src_widget, GtkWidget *dest_widget, gint src_x, gint src_y,gint *dest_x, gint *dest_y 
 * Returns: gboolean
 * Assertion: Translate coordinates relative to src_widget's allocation to coordinates relative to dest_widget's allocations.
 * Params Values: GtkWidget *widget, GtkWidget *dest_widget, 5, 10, gint *dest_x, gint *dest_y 
 * Expected: void  
 */
static void test_purpose_325()
{
    #define SRC_POS_X 5
    #define SRC_POS_Y 10
    #define DEST_POS_X 2
    #define DEST_POS_Y 3
    #define SRC_X 5
    #define SRC_Y 2
    #define CORRECT_DEST_X 8
    #define CORRECT_DEST_Y 9
    #define HAS_COMMON_ANCESTOR TRUE
    #define MUST_BE_REALIZED_SRC TRUE
    #define MUST_BE_REALIZED_DEST TRUE
     
    GtkWidget* window;
    GtkWidget* ancestor;
    GtkWidget* ancestor1;
    GtkWidget* src;
    GtkWidget* dest;
    gboolean res;
    gint dest_x;
    gint dest_y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    ancestor = gtk_fixed_new ();
    src = gtk_label_new ("src");
    dest = gtk_label_new ("dest");
    
    gtk_fixed_put (GTK_FIXED (ancestor), src, SRC_POS_X, SRC_POS_Y);
    gtk_container_add (GTK_CONTAINER (window), ancestor);
    
    if (HAS_COMMON_ANCESTOR == TRUE)
    {
        gtk_fixed_put (GTK_FIXED (ancestor), dest, DEST_POS_X, DEST_POS_Y);
    } else {
        ancestor1 = gtk_fixed_new ();
        gtk_fixed_put (GTK_FIXED (ancestor1), dest, DEST_POS_X, DEST_POS_Y);
    }
    
    if (MUST_BE_REALIZED_SRC)
    {
        gtk_widget_show (src);
    }
    if (MUST_BE_REALIZED_DEST)
    {
        gtk_widget_show (dest);
    }
    
    gtk_widget_show (ancestor);
    gtk_widget_show (window);
    
    res = gtk_widget_translate_coordinates (src, dest, SRC_X, SRC_Y, 
                                            &dest_x, &dest_y);
    
    if (HAS_COMMON_ANCESTOR == FALSE
        || MUST_BE_REALIZED_SRC == FALSE
        || MUST_BE_REALIZED_DEST == FALSE)
    {
        if (res == TRUE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = TRUE but should be FALSE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
    } else {
        if (res == FALSE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = FALSE but should be TRUE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
        
        if (dest_x != CORRECT_DEST_X)
        {
            TEST_FAIL ("dest_x = %d, should be %d", dest_x, CORRECT_DEST_X);
        }
    
        if (dest_y != CORRECT_DEST_Y)
        {
            TEST_FAIL ("dest_y = %d, should be %d", dest_y, CORRECT_DEST_Y);
        }
    }
    
    gtk_widget_destroy (src);
    gtk_widget_destroy (dest);
    gtk_widget_destroy (ancestor);
    
    if (ancestor1 && HAS_COMMON_ANCESTOR == FALSE)
    {
       gtk_widget_destroy (ancestor1);
    }
    
    gtk_widget_destroy (window);
    
    #undef SRC_POS_X
    #undef SRC_POS_Y
    #undef DEST_POS_X
    #undef DEST_POS_Y
    #undef SRC_X
    #undef SRC_Y
    #undef CORRECT_DEST_X
    #undef CORRECT_DEST_Y
    #undef HAS_COMMON_ANCESTOR
    #undef MUST_BE_REALIZED_SRC
    #undef MUST_BE_REALIZED_DEST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_translate_coordinates
 * Params: GtkWidget *src_widget, GtkWidget *dest_widget, gint src_x, gint src_y,gint *dest_x, gint *dest_y 
 * Returns: gboolean
 * Assertion: Translate coordinates relative to src_widget's allocation to coordinates relative to dest_widget's allocations.
 * Params Values: GtkWidget *widget, GtkWidget *dest_widget, 7, 45, gint *dest_x, gint *dest_y 
 * Expected: void  
 */
static void test_purpose_326()
{
    #define SRC_POS_X 7
    #define SRC_POS_Y 45
    #define DEST_POS_X 2
    #define DEST_POS_Y 3
    #define SRC_X 5
    #define SRC_Y 2
    #define CORRECT_DEST_X 2
    #define CORRECT_DEST_Y 43
    #define HAS_COMMON_ANCESTOR TRUE
    #define MUST_BE_REALIZED_SRC FALSE
    #define MUST_BE_REALIZED_DEST TRUE
     
    GtkWidget* window;
    GtkWidget* ancestor;
    GtkWidget* ancestor1;
    GtkWidget* src;
    GtkWidget* dest;
    gboolean res;
    gint dest_x;
    gint dest_y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    ancestor = gtk_fixed_new ();
    src = gtk_label_new ("src");
    dest = gtk_label_new ("dest");
    
    gtk_fixed_put (GTK_FIXED (ancestor), src, SRC_POS_X, SRC_POS_Y);
    gtk_container_add (GTK_CONTAINER (window), ancestor);
    
    if (HAS_COMMON_ANCESTOR == TRUE)
    {
        gtk_fixed_put (GTK_FIXED (ancestor), dest, DEST_POS_X, DEST_POS_Y);
    } else {
        ancestor1 = gtk_fixed_new ();
        gtk_fixed_put (GTK_FIXED (ancestor1), dest, DEST_POS_X, DEST_POS_Y);
    }
    
    if (MUST_BE_REALIZED_SRC)
    {
        gtk_widget_show (src);
    }
    if (MUST_BE_REALIZED_DEST)
    {
        gtk_widget_show (dest);
    }
    
    gtk_widget_show (ancestor);
    gtk_widget_show (window);
    
    res = gtk_widget_translate_coordinates (src, dest, SRC_X, SRC_Y, 
                                            &dest_x, &dest_y);
    
    if (HAS_COMMON_ANCESTOR == FALSE
        || MUST_BE_REALIZED_SRC == FALSE
        || MUST_BE_REALIZED_DEST == FALSE)
    {
        if (res == TRUE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = TRUE but should be FALSE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
    } else {
        if (res == FALSE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = FALSE but should be TRUE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
        
        if (dest_x != CORRECT_DEST_X)
        {
            TEST_FAIL ("dest_x = %d, should be %d", dest_x, CORRECT_DEST_X);
        }
    
        if (dest_y != CORRECT_DEST_Y)
        {
            TEST_FAIL ("dest_y = %d, should be %d", dest_y, CORRECT_DEST_Y);
        }
    }
    
    gtk_widget_destroy (src);
    gtk_widget_destroy (dest);
    gtk_widget_destroy (ancestor);
    
    if (ancestor1 && HAS_COMMON_ANCESTOR == FALSE)
    {
       gtk_widget_destroy (ancestor1);
    }
    
    gtk_widget_destroy (window);
    
    #undef SRC_POS_X
    #undef SRC_POS_Y
    #undef DEST_POS_X
    #undef DEST_POS_Y
    #undef SRC_X
    #undef SRC_Y
    #undef CORRECT_DEST_X
    #undef CORRECT_DEST_Y
    #undef HAS_COMMON_ANCESTOR
    #undef MUST_BE_REALIZED_SRC
    #undef MUST_BE_REALIZED_DEST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_translate_coordinates
 * Params: GtkWidget *src_widget, GtkWidget *dest_widget, gint src_x, gint src_y,gint *dest_x, gint *dest_y 
 * Returns: gboolean
 * Assertion: Translate coordinates relative to src_widget's allocation to coordinates relative to dest_widget's allocations.
 * Params Values: GtkWidget *widget, GtkWidget *dest_widget, 7, 45, gint *dest_x, gint *dest_y 
 * Expected: void  
 */
static void test_purpose_327()
{
    #define SRC_POS_X 7
    #define SRC_POS_Y 45
    #define DEST_POS_X 2
    #define DEST_POS_Y 3
    #define SRC_X 5
    #define SRC_Y 2
    #define CORRECT_DEST_X 2
    #define CORRECT_DEST_Y 43
    #define HAS_COMMON_ANCESTOR TRUE
    #define MUST_BE_REALIZED_SRC TRUE
    #define MUST_BE_REALIZED_DEST FALSE
     
    GtkWidget* window;
    GtkWidget* ancestor;
    GtkWidget* ancestor1;
    GtkWidget* src;
    GtkWidget* dest;
    gboolean res;
    gint dest_x;
    gint dest_y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    ancestor = gtk_fixed_new ();
    src = gtk_label_new ("src");
    dest = gtk_label_new ("dest");
    
    gtk_fixed_put (GTK_FIXED (ancestor), src, SRC_POS_X, SRC_POS_Y);
    gtk_container_add (GTK_CONTAINER (window), ancestor);
    
    if (HAS_COMMON_ANCESTOR == TRUE)
    {
        gtk_fixed_put (GTK_FIXED (ancestor), dest, DEST_POS_X, DEST_POS_Y);
    } else {
        ancestor1 = gtk_fixed_new ();
        gtk_fixed_put (GTK_FIXED (ancestor1), dest, DEST_POS_X, DEST_POS_Y);
    }
    
    if (MUST_BE_REALIZED_SRC)
    {
        gtk_widget_show (src);
    }
    if (MUST_BE_REALIZED_DEST)
    {
        gtk_widget_show (dest);
    }
    
    gtk_widget_show (ancestor);
    gtk_widget_show (window);
    
    res = gtk_widget_translate_coordinates (src, dest, SRC_X, SRC_Y, 
                                            &dest_x, &dest_y);
    
    if (HAS_COMMON_ANCESTOR == FALSE
        || MUST_BE_REALIZED_SRC == FALSE
        || MUST_BE_REALIZED_DEST == FALSE)
    {
        if (res == TRUE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = TRUE but should be FALSE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
    } else {
        if (res == FALSE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = FALSE but should be TRUE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
        
        if (dest_x != CORRECT_DEST_X)
        {
            TEST_FAIL ("dest_x = %d, should be %d", dest_x, CORRECT_DEST_X);
        }
    
        if (dest_y != CORRECT_DEST_Y)
        {
            TEST_FAIL ("dest_y = %d, should be %d", dest_y, CORRECT_DEST_Y);
        }
    }
    
    gtk_widget_destroy (src);
    gtk_widget_destroy (dest);
    gtk_widget_destroy (ancestor);
    
    if (ancestor1 && HAS_COMMON_ANCESTOR == FALSE)
    {
       gtk_widget_destroy (ancestor1);
    }
    
    gtk_widget_destroy (window);
    
    #undef SRC_POS_X
    #undef SRC_POS_Y
    #undef DEST_POS_X
    #undef DEST_POS_Y
    #undef SRC_X
    #undef SRC_Y
    #undef CORRECT_DEST_X
    #undef CORRECT_DEST_Y
    #undef HAS_COMMON_ANCESTOR
    #undef MUST_BE_REALIZED_SRC
    #undef MUST_BE_REALIZED_DEST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_translate_coordinates
 * Params: GtkWidget *src_widget, GtkWidget *dest_widget, gint src_x, gint src_y,gint *dest_x, gint *dest_y 
 * Returns: gboolean
 * Assertion: Translate coordinates relative to src_widget's allocation to coordinates relative to dest_widget's allocations.
 * Params Values: GtkWidget *widget, GtkWidget *dest_widget, 7, 45, gint *dest_x, gint *dest_y 
 * Expected: void  
 */
static void test_purpose_328()
{
    #define SRC_POS_X 7
    #define SRC_POS_Y 45
    #define DEST_POS_X 2
    #define DEST_POS_Y 3
    #define SRC_X 5
    #define SRC_Y 2
    #define CORRECT_DEST_X 2
    #define CORRECT_DEST_Y 43
    #define HAS_COMMON_ANCESTOR TRUE
    #define MUST_BE_REALIZED_SRC FALSE
    #define MUST_BE_REALIZED_DEST FALSE
     
    GtkWidget* window;
    GtkWidget* ancestor;
    GtkWidget* ancestor1;
    GtkWidget* src;
    GtkWidget* dest;
    gboolean res;
    gint dest_x;
    gint dest_y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    ancestor = gtk_fixed_new ();
    src = gtk_label_new ("src");
    dest = gtk_label_new ("dest");
    
    gtk_fixed_put (GTK_FIXED (ancestor), src, SRC_POS_X, SRC_POS_Y);
    gtk_container_add (GTK_CONTAINER (window), ancestor);
    
    if (HAS_COMMON_ANCESTOR == TRUE)
    {
        gtk_fixed_put (GTK_FIXED (ancestor), dest, DEST_POS_X, DEST_POS_Y);
    } else {
        ancestor1 = gtk_fixed_new ();
        gtk_fixed_put (GTK_FIXED (ancestor1), dest, DEST_POS_X, DEST_POS_Y);
    }
    
    if (MUST_BE_REALIZED_SRC)
    {
        gtk_widget_show (src);
    }
    if (MUST_BE_REALIZED_DEST)
    {
        gtk_widget_show (dest);
    }
    
    gtk_widget_show (ancestor);
    gtk_widget_show (window);
    
    res = gtk_widget_translate_coordinates (src, dest, SRC_X, SRC_Y, 
                                            &dest_x, &dest_y);
    
    if (HAS_COMMON_ANCESTOR == FALSE
        || MUST_BE_REALIZED_SRC == FALSE
        || MUST_BE_REALIZED_DEST == FALSE)
    {
        if (res == TRUE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = TRUE but should be FALSE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
    } else {
        if (res == FALSE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = FALSE but should be TRUE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
        
        if (dest_x != CORRECT_DEST_X)
        {
            TEST_FAIL ("dest_x = %d, should be %d", dest_x, CORRECT_DEST_X);
        }
    
        if (dest_y != CORRECT_DEST_Y)
        {
            TEST_FAIL ("dest_y = %d, should be %d", dest_y, CORRECT_DEST_Y);
        }
    }
    
    gtk_widget_destroy (src);
    gtk_widget_destroy (dest);
    gtk_widget_destroy (ancestor);
    
    if (ancestor1 && HAS_COMMON_ANCESTOR == FALSE)
    {
       gtk_widget_destroy (ancestor1);
    }
    
    gtk_widget_destroy (window);
    
    #undef SRC_POS_X
    #undef SRC_POS_Y
    #undef DEST_POS_X
    #undef DEST_POS_Y
    #undef SRC_X
    #undef SRC_Y
    #undef CORRECT_DEST_X
    #undef CORRECT_DEST_Y
    #undef HAS_COMMON_ANCESTOR
    #undef MUST_BE_REALIZED_SRC
    #undef MUST_BE_REALIZED_DEST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_translate_coordinates
 * Params: GtkWidget *src_widget, GtkWidget *dest_widget, gint src_x, gint src_y,gint *dest_x, gint *dest_y 
 * Returns: gboolean
 * Assertion: Translate coordinates relative to src_widget's allocation to coordinates relative to dest_widget's allocations.
 * Params Values: GtkWidget *widget, GtkWidget *dest_widget, 7, 45, gint *dest_x, gint *dest_y 
 * Expected: void  
 */
static void test_purpose_329()
{
    #define SRC_POS_X 7
    #define SRC_POS_Y 45
    #define DEST_POS_X 2
    #define DEST_POS_Y 3
    #define SRC_X 5
    #define SRC_Y 2
    #define CORRECT_DEST_X 2
    #define CORRECT_DEST_Y 43
    #define HAS_COMMON_ANCESTOR FALSE
    #define MUST_BE_REALIZED_SRC TRUE
    #define MUST_BE_REALIZED_DEST FALSE
     
    GtkWidget* window;
    GtkWidget* ancestor;
    GtkWidget* ancestor1;
    GtkWidget* src;
    GtkWidget* dest;
    gboolean res;
    gint dest_x;
    gint dest_y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    ancestor = gtk_fixed_new ();
    src = gtk_label_new ("src");
    dest = gtk_label_new ("dest");
    
    gtk_fixed_put (GTK_FIXED (ancestor), src, SRC_POS_X, SRC_POS_Y);
    gtk_container_add (GTK_CONTAINER (window), ancestor);
    
    if (HAS_COMMON_ANCESTOR == TRUE)
    {
        gtk_fixed_put (GTK_FIXED (ancestor), dest, DEST_POS_X, DEST_POS_Y);
    } else {
        ancestor1 = gtk_fixed_new ();
        gtk_fixed_put (GTK_FIXED (ancestor1), dest, DEST_POS_X, DEST_POS_Y);
    }
    
    if (MUST_BE_REALIZED_SRC)
    {
        gtk_widget_show (src);
    }
    if (MUST_BE_REALIZED_DEST)
    {
        gtk_widget_show (dest);
    }
    
    gtk_widget_show (ancestor);
    gtk_widget_show (window);
    
    res = gtk_widget_translate_coordinates (src, dest, SRC_X, SRC_Y, 
                                            &dest_x, &dest_y);
    
    if (HAS_COMMON_ANCESTOR == FALSE
        || MUST_BE_REALIZED_SRC == FALSE
        || MUST_BE_REALIZED_DEST == FALSE)
    {
        if (res == TRUE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = TRUE but should be FALSE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
    } else {
        if (res == FALSE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = FALSE but should be TRUE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
        
        if (dest_x != CORRECT_DEST_X)
        {
            TEST_FAIL ("dest_x = %d, should be %d", dest_x, CORRECT_DEST_X);
        }
    
        if (dest_y != CORRECT_DEST_Y)
        {
            TEST_FAIL ("dest_y = %d, should be %d", dest_y, CORRECT_DEST_Y);
        }
    }
    
    gtk_widget_destroy (src);
    gtk_widget_destroy (dest);
    gtk_widget_destroy (ancestor);
    
    if (ancestor1 && HAS_COMMON_ANCESTOR == FALSE)
    {
       gtk_widget_destroy (ancestor1);
    }
    
    gtk_widget_destroy (window);
    
    #undef SRC_POS_X
    #undef SRC_POS_Y
    #undef DEST_POS_X
    #undef DEST_POS_Y
    #undef SRC_X
    #undef SRC_Y
    #undef CORRECT_DEST_X
    #undef CORRECT_DEST_Y
    #undef HAS_COMMON_ANCESTOR
    #undef MUST_BE_REALIZED_SRC
    #undef MUST_BE_REALIZED_DEST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_translate_coordinates
 * Params: GtkWidget *src_widget, GtkWidget *dest_widget, gint src_x, gint src_y,gint *dest_x, gint *dest_y 
 * Returns: gboolean
 * Assertion: Translate coordinates relative to src_widget's allocation to coordinates relative to dest_widget's allocations.
 * Params Values: GtkWidget *widget, GtkWidget *dest_widget, 7, 45, gint *dest_x, gint *dest_y 
 * Expected: void  
 */
static void test_purpose_330()
{
    #define SRC_POS_X 7
    #define SRC_POS_Y 45
    #define DEST_POS_X 2
    #define DEST_POS_Y 3
    #define SRC_X 5
    #define SRC_Y 2
    #define CORRECT_DEST_X 2
    #define CORRECT_DEST_Y 43
    #define HAS_COMMON_ANCESTOR FALSE
    #define MUST_BE_REALIZED_SRC FALSE
    #define MUST_BE_REALIZED_DEST FALSE
     
    GtkWidget* window;
    GtkWidget* ancestor;
    GtkWidget* ancestor1;
    GtkWidget* src;
    GtkWidget* dest;
    gboolean res;
    gint dest_x;
    gint dest_y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    ancestor = gtk_fixed_new ();
    src = gtk_label_new ("src");
    dest = gtk_label_new ("dest");
    
    gtk_fixed_put (GTK_FIXED (ancestor), src, SRC_POS_X, SRC_POS_Y);
    gtk_container_add (GTK_CONTAINER (window), ancestor);
    
    if (HAS_COMMON_ANCESTOR == TRUE)
    {
        gtk_fixed_put (GTK_FIXED (ancestor), dest, DEST_POS_X, DEST_POS_Y);
    } else {
        ancestor1 = gtk_fixed_new ();
        gtk_fixed_put (GTK_FIXED (ancestor1), dest, DEST_POS_X, DEST_POS_Y);
    }
    
    if (MUST_BE_REALIZED_SRC)
    {
        gtk_widget_show (src);
    }
    if (MUST_BE_REALIZED_DEST)
    {
        gtk_widget_show (dest);
    }
    
    gtk_widget_show (ancestor);
    gtk_widget_show (window);
    
    res = gtk_widget_translate_coordinates (src, dest, SRC_X, SRC_Y, 
                                            &dest_x, &dest_y);
    
    if (HAS_COMMON_ANCESTOR == FALSE
        || MUST_BE_REALIZED_SRC == FALSE
        || MUST_BE_REALIZED_DEST == FALSE)
    {
        if (res == TRUE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = TRUE but should be FALSE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
    } else {
        if (res == FALSE)
        {
            TEST_FAIL ("HAS_COMMON_ANCESTOR = %d, MUST_BE_REALIZED_SRC = %d, MUST_BE_REALIZED_DEST = %d, res = FALSE but should be TRUE", HAS_COMMON_ANCESTOR, MUST_BE_REALIZED_SRC, MUST_BE_REALIZED_DEST);
        }
        
        if (dest_x != CORRECT_DEST_X)
        {
            TEST_FAIL ("dest_x = %d, should be %d", dest_x, CORRECT_DEST_X);
        }
    
        if (dest_y != CORRECT_DEST_Y)
        {
            TEST_FAIL ("dest_y = %d, should be %d", dest_y, CORRECT_DEST_Y);
        }
    }
    
    gtk_widget_destroy (src);
    gtk_widget_destroy (dest);
    gtk_widget_destroy (ancestor);
    
    if (ancestor1 && HAS_COMMON_ANCESTOR == FALSE)
    {
       gtk_widget_destroy (ancestor1);
    }
    
    gtk_widget_destroy (window);
    
    #undef SRC_POS_X
    #undef SRC_POS_Y
    #undef DEST_POS_X
    #undef DEST_POS_Y
    #undef SRC_X
    #undef SRC_Y
    #undef CORRECT_DEST_X
    #undef CORRECT_DEST_Y
    #undef HAS_COMMON_ANCESTOR
    #undef MUST_BE_REALIZED_SRC
    #undef MUST_BE_REALIZED_DEST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_push_composite_child
 * Params: void
 * Returns: void
 * Assertion: Makes all newly-created widgets as composite children until the corresponding gtk_widget_pop_composite_child() call.
 * Params Values: void
 * Expected: void
 * 
 * Name:  gtk_widget_pop_composite_child
 * Params: void
 * Returns: void
 * Assertion: Cancels the effect of a previous call to gtk_widget_push_composite_child().
 * Params Values: void
 * Expected: void  
 */
static void test_purpose_331()
{
    GtkWidget* window;
    GtkWidget* fixed;
    GtkWidget* child1;
    GtkWidget* child2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    fixed = gtk_fixed_new ();
    gtk_widget_push_composite_child();
    child1 = gtk_button_new_with_label ("button1");
    gtk_widget_set_composite_name (child1, "child_1");
    child2 = gtk_button_new_with_label ("button2");
    gtk_widget_set_composite_name (child2, "child_2");
    gtk_widget_pop_composite_child();
    
    gtk_fixed_put (GTK_FIXED (fixed), child1, 10, 10);
    
    gtk_fixed_put (GTK_FIXED (fixed), child2, 40, 40);
    
    gtk_container_add (GTK_CONTAINER (window), fixed);
    
    gtk_widget_destroy (child1);
    gtk_widget_destroy (child2);
    gtk_widget_destroy (fixed);
    gtk_widget_destroy (window);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_text
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched
 * Params Values: GtkWidget *widget, GTK_STATE_NORMAL, GdkColor {100, 65535, 100}
 * Expected: void  
 */
static void test_purpose_332()
{
    #define WIDGET gtk_button_new ();
    #define STATE GTK_STATE_NORMAL
    #define COLOR 100, 65535, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    gchar *name;
    gchar* bg_pixmap_name [5];
    gint xthickness;
    gint ythickness;
    PangoFontDescription *font_desc;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    name = style->name;
    for (i = 0; i <5; i++)
    {
        bg_pixmap_name [i] = style->bg_pixmap_name [i];
    }
    xthickness = style->xthickness;
    ythickness = style->ythickness;
    font_desc = style->font_desc;
    
    gtk_widget_modify_text (widget, STATE, &color);
    style = gtk_widget_get_modifier_style (widget);
    
    /*  if (strcmp (name,style->name)) */
    /*  { */
    /*      TEST_FAIL ("style->name should be untouched",NULL); */
    /*  } */
    /*  for (i = 0; i <5; i++) */
    /*  { */
    /*      if (strcmp (bg_pixmap_name [i],style->bg_pixmap_name [i])) */
    /*      { */
    /*          TEST_FAIL ("style->bg_pixmap_name should be untouched",NULL); */
    /*          break; */
    /*      } */
    /*  } */
    if (xthickness != style->xthickness)
    {
        TEST_FAIL ("style->xthickness should be untouched",NULL);
    }
    if (ythickness != style->ythickness)
    {
        TEST_FAIL ("style->ythickness should be untouched",NULL);
    }
    if (font_desc != style->font_desc)
    {
        TEST_FAIL ("style->font_desc should be untouched",NULL);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_text
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched
 * Params Values: GtkWidget *widget, GTK_STATE_ACTIVE, GdkColor {100, 100, 65535}
 * Expected: void  
 */
static void test_purpose_333()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    #define STATE GTK_STATE_ACTIVE
    #define COLOR 100, 100, 65535
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    gchar *name;
    gchar* bg_pixmap_name [5];
    gint xthickness;
    gint ythickness;
    PangoFontDescription *font_desc;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    name = style->name;
    for (i = 0; i <5; i++)
    {
        bg_pixmap_name [i] = style->bg_pixmap_name [i];
    }
    xthickness = style->xthickness;
    ythickness = style->ythickness;
    font_desc = style->font_desc;
    
    gtk_widget_modify_text (widget, STATE, &color);
    style = gtk_widget_get_modifier_style (widget);
    
    /*  if (strcmp (name,style->name)) */
    /*  { */
    /*      TEST_FAIL ("style->name should be untouched",NULL); */
    /*  } */
    /*  for (i = 0; i <5; i++) */
    /*  { */
    /*      if (strcmp (bg_pixmap_name [i],style->bg_pixmap_name [i])) */
    /*      { */
    /*          TEST_FAIL ("style->bg_pixmap_name should be untouched",NULL); */
    /*          break; */
    /*      } */
    /*  } */
    if (xthickness != style->xthickness)
    {
        TEST_FAIL ("style->xthickness should be untouched",NULL);
    }
    if (ythickness != style->ythickness)
    {
        TEST_FAIL ("style->ythickness should be untouched",NULL);
    }
    if (font_desc != style->font_desc)
    {
        TEST_FAIL ("style->font_desc should be untouched",NULL);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_text
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched
 * Params Values: GtkWidget *widget, GTK_STATE_PRELIGHT, GdkColor {100, 100, 100}
 * Expected: void  
 */
static void test_purpose_334()
{
    #define WIDGET gtk_label_new ("Label");
    #define STATE GTK_STATE_PRELIGHT
    #define COLOR 100, 100, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    gchar *name;
    gchar* bg_pixmap_name [5];
    gint xthickness;
    gint ythickness;
    PangoFontDescription *font_desc;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    name = style->name;
    for (i = 0; i <5; i++)
    {
        bg_pixmap_name [i] = style->bg_pixmap_name [i];
    }
    xthickness = style->xthickness;
    ythickness = style->ythickness;
    font_desc = style->font_desc;
    
    gtk_widget_modify_text (widget, STATE, &color);
    style = gtk_widget_get_modifier_style (widget);
    
    /*  if (strcmp (name,style->name)) */
    /*  { */
    /*      TEST_FAIL ("style->name should be untouched",NULL); */
    /*  } */
    /*  for (i = 0; i <5; i++) */
    /*  { */
    /*      if (strcmp (bg_pixmap_name [i],style->bg_pixmap_name [i])) */
    /*      { */
    /*          TEST_FAIL ("style->bg_pixmap_name should be untouched",NULL); */
    /*          break; */
    /*      } */
    /*  } */
    if (xthickness != style->xthickness)
    {
        TEST_FAIL ("style->xthickness should be untouched",NULL);
    }
    if (ythickness != style->ythickness)
    {
        TEST_FAIL ("style->ythickness should be untouched",NULL);
    }
    if (font_desc != style->font_desc)
    {
        TEST_FAIL ("style->font_desc should be untouched",NULL);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_text
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched
 * Params Values: GtkWidget *widget, GTK_STATE_SELECTED, GdkColor {0, 100, 100}
 * Expected: void  
 */
static void test_purpose_335()
{
    #define WIDGET gtk_entry_new ();
    #define STATE GTK_STATE_SELECTED
    #define COLOR 0, 100, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    gchar *name;
    gchar* bg_pixmap_name [5];
    gint xthickness;
    gint ythickness;
    PangoFontDescription *font_desc;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    name = style->name;
    for (i = 0; i <5; i++)
    {
        bg_pixmap_name [i] = style->bg_pixmap_name [i];
    }
    xthickness = style->xthickness;
    ythickness = style->ythickness;
    font_desc = style->font_desc;
    
    gtk_widget_modify_text (widget, STATE, &color);
    style = gtk_widget_get_modifier_style (widget);
    
    /*  if (strcmp (name,style->name)) */
    /*  { */
    /*      TEST_FAIL ("style->name should be untouched",NULL); */
    /*  } */
    /*  for (i = 0; i <5; i++) */
    /*  { */
    /*      if (strcmp (bg_pixmap_name [i],style->bg_pixmap_name [i])) */
    /*      { */
    /*          TEST_FAIL ("style->bg_pixmap_name should be untouched",NULL); */
    /*          break; */
    /*      } */
    /*  } */
    if (xthickness != style->xthickness)
    {
        TEST_FAIL ("style->xthickness should be untouched",NULL);
    }
    if (ythickness != style->ythickness)
    {
        TEST_FAIL ("style->ythickness should be untouched",NULL);
    }
    if (font_desc != style->font_desc)
    {
        TEST_FAIL ("style->font_desc should be untouched",NULL);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_modify_text
 * Params: GtkWidget *widget, GtkStateType state, GdkColor *color
 * Returns: void
 * Assertion: All other style values are left untouched
 * Params Values: GtkWidget *widget, GTK_STATE_INSENSITIVE, GdkColor {100, 0, 100}
 * Expected: void  
 */
static void test_purpose_336()
{
    #define WIDGET gtk_check_button_new ();
    #define STATE GTK_STATE_INSENSITIVE
    #define COLOR 100, 0, 100
    
    GtkWidget* widget;
    GtkRcStyle* style;
    GdkColor color = {0, COLOR};
    gint i;
    gchar *name;
    gchar* bg_pixmap_name [5];
    gint xthickness;
    gint ythickness;
    PangoFontDescription *font_desc;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    style = gtk_rc_style_new ();
    if (!style)
    {
        TEST_FAIL ("gtk_rc_style_new () return NULL", NULL); 
        return;
    } 
    
    name = style->name;
    for (i = 0; i <5; i++)
    {
        bg_pixmap_name [i] = style->bg_pixmap_name [i];
    }
    xthickness = style->xthickness;
    ythickness = style->ythickness;
    font_desc = style->font_desc;
    
    gtk_widget_modify_text (widget, STATE, &color);
    style = gtk_widget_get_modifier_style (widget);
    
    /*  if (strcmp (name,style->name)) */
    /*  { */
    /*      TEST_FAIL ("style->name should be untouched",NULL); */
    /*  } */
    /*  for (i = 0; i <5; i++) */
    /*  { */
    /*      if (strcmp (bg_pixmap_name [i],style->bg_pixmap_name [i])) */
    /*      { */
    /*          TEST_FAIL ("style->bg_pixmap_name should be untouched",NULL); */
    /*          break; */
    /*      } */
    /*  } */
    if (xthickness != style->xthickness)
    {
        TEST_FAIL ("style->xthickness should be untouched",NULL);
    }
    if (ythickness != style->ythickness)
    {
        TEST_FAIL ("style->ythickness should be untouched",NULL);
    }
    if (font_desc != style->font_desc)
    {
        TEST_FAIL ("style->font_desc should be untouched",NULL);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef STATE
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_reset_rc_styles 
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Reset the styles of widget and all descendents, so when they are looked up again, they get the correct values for the currently loaded RC file settings.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_337()
{
    #define WIDGET gtk_vbox_new (TRUE, 10)
    #define CHILD gtk_button_new ()
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkStyle* style;
    GtkStyle* real_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    style = gtk_style_new ();
    style->xthickness = 100;
    style->ythickness = 100;
    
    gtk_widget_set_style (widget,style);
    gtk_widget_set_style (child,style);
    
    style = gtk_widget_get_default_style ();
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    gtk_widget_reset_rc_styles (widget);
    
    real_style = gtk_widget_get_style (widget);
    if (real_style == style)
    {
        TEST_FAIL ("Widget's style  is not default style",NULL);
    }
    
    real_style = gtk_widget_get_style (child);
    if (real_style == style)
    {
        TEST_FAIL ("Widget's style  is not default style",NULL);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_reset_rc_styles 
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Reset the styles of widget and all descendents, so when they are looked up again, they get the correct values for the currently loaded RC file settings.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_338()
{
    #define WIDGET gtk_hbox_new (FALSE, 10)
    #define CHILD gtk_label_new ("Label")
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkStyle* style;
    GtkStyle* real_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    style = gtk_style_new ();
    style->xthickness = 100;
    style->ythickness = 100;
    
    gtk_widget_set_style (widget,style);
    gtk_widget_set_style (child,style);
    
    style = gtk_widget_get_default_style ();
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    gtk_widget_reset_rc_styles (widget);
    
    real_style = gtk_widget_get_style (widget);
    if (real_style == style)
    {
        TEST_FAIL ("Widget's style  is not default style",NULL);
    }
    
    real_style = gtk_widget_get_style (child);
    if (real_style == style)
    {
        TEST_FAIL ("Widget's style  is not default style",NULL);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_reset_rc_styles 
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Reset the styles of widget and all descendents, so when they are looked up again, they get the correct values for the currently loaded RC file settings.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_339()
{
    #define WIDGET gtk_hbox_new (TRUE, 10)
    #define CHILD gtk_vbox_new (TRUE, 10)
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkStyle* style;
    GtkStyle* real_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL ("'child' widget not created", NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (widget))
    {
        TEST_FAIL ("'widget' is not container", NULL); 
        return;
    }
    
    style = gtk_style_new ();
    style->xthickness = 100;
    style->ythickness = 100;
    
    gtk_widget_set_style (widget,style);
    gtk_widget_set_style (child,style);
    
    style = gtk_widget_get_default_style ();
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    gtk_widget_reset_rc_styles (widget);
    
    real_style = gtk_widget_get_style (widget);
    if (real_style == style)
    {
        TEST_FAIL ("Widget's style  is not default style",NULL);
    }
    
    real_style = gtk_widget_get_style (child);
    if (real_style == style)
    {
        TEST_FAIL ("Widget's style  is not default style",NULL);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_widget_shape_combine_mask
 * Params: GtkWidget *widget, GdkBitmap *shape_mask, gint offset_x, gint offset_y
 * Returns: void
 * Assertion:  Sets a shape for this widget's GDK window.'
 * Params Values: GtkWidget *widget, GdkBitmap *shape_mask, gint offset_x, gint offset_y
 * Expected: void  
 */
static void test_purpose_340()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    GtkWidget* widget;
    gchar data[8];
    GdkBitmap* map;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    map = gdk_bitmap_create_from_data (NULL, data, 8, 8);
    if (!map)
    {
        TEST_FAIL ("gdk_bitmap_create_from_data () return NULL",  NULL); 
        return;
    } 
    
    gtk_widget_shape_combine_mask (widget, map, 0, 0);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_widget_shape_combine_mask
 * Params: GtkWidget *widget, GdkBitmap *shape_mask, gint offset_x, gint offset_y
 * Returns: void
 * Assertion:  Sets a shape for this widget's GDK window.'
 * Params Values: GtkWidget *widget, GdkBitmap *shape_mask, gint offset_x, gint offset_y
 * Expected: void  
 */
static void test_purpose_341()
{
    #define WIDGET gtk_dialog_new ();
    
    GtkWidget* widget;
    gchar data[8];
    GdkBitmap* map;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    map = gdk_bitmap_create_from_data (NULL, data, 8, 8);
    if (!map)
    {
        TEST_FAIL ("gdk_bitmap_create_from_data () return NULL",  NULL); 
        return;
    } 
    
    gtk_widget_shape_combine_mask (widget, map, 0, 0);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_widget_reset_shapes 
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion:  Recursively resets the shape on this widget and its descendants.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_342()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    GtkWidget* widget;
    gchar data[8];
    GdkBitmap* map;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_realize (widget);
    gtk_widget_reset_shapes (widget);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   gtk_widget_reset_shapes 
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion:  Recursively resets the shape on this widget and its descendants.
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_343()
{
    #define WIDGET gtk_dialog_new ();
    
    GtkWidget* widget;
    gchar data[8];
    GdkBitmap* map;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_realize (widget);
    gtk_widget_reset_shapes (widget);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_child_visible
 * Params: GtkWidget *widget, gboolean visible
 * Returns: void
 * Assertion: However it will be reset to its default state of TRUE when the widget is removed from a container.
 * Params Values: GtkWidget *widget,  TRUE
 * Expected: void  
 */
static void test_purpose_344()
{
    #define WIDGET gtk_button_new ()
    #define VISIBLE TRUE
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_ref (G_OBJECT(widget));
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_set_child_visible (widget, VISIBLE);
    
    if (VISIBLE != gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be %i", gtk_widget_get_child_visible (widget), VISIBLE);
    }
    
    gtk_container_remove (GTK_CONTAINER (window), widget);
    if (!gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be TRUE", gtk_widget_get_child_visible (widget), NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_child_visible
 * Params: GtkWidget *widget, gboolean visible
 * Returns: void
 * Assertion: However it will be reset to its default state of TRUE when the widget is removed from a container.
 * Params Values: GtkWidget *widget,  FALSE
 * Expected: void  
 */
static void test_purpose_345()
{
    #define WIDGET gtk_button_new ()
    #define VISIBLE FALSE
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_ref (G_OBJECT(widget));
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_set_child_visible (widget, VISIBLE);
    
    if (VISIBLE != gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be %i", gtk_widget_get_child_visible (widget), VISIBLE);
    }
    
    gtk_container_remove (GTK_CONTAINER (window), widget);
    if (!gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be TRUE", gtk_widget_get_child_visible (widget), NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_child_visible
 * Params: GtkWidget *widget, gboolean visible
 * Returns: void
 * Assertion: However it will be reset to its default state of TRUE when the widget is removed from a container.
 * Params Values: GtkWidget *widget,  FALSE
 * Expected: void  
 */
static void test_purpose_346()
{
    #define WIDGET gtk_check_button_new ()
    #define VISIBLE FALSE
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_ref (G_OBJECT(widget));
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_set_child_visible (widget, VISIBLE);
    
    if (VISIBLE != gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be %i", gtk_widget_get_child_visible (widget), VISIBLE);
    }
    
    gtk_container_remove (GTK_CONTAINER (window), widget);
    if (!gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be TRUE", gtk_widget_get_child_visible (widget), NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_child_visible
 * Params: GtkWidget *widget, gboolean visible
 * Returns: void
 * Assertion: However it will be reset to its default state of TRUE when the widget is removed from a container.
 * Params Values: GtkWidget *widget,  TRUE
 * Expected: void  
 */
static void test_purpose_347()
{
    #define WIDGET gtk_entry_new ()
    #define VISIBLE TRUE
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_ref (G_OBJECT(widget));
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_set_child_visible (widget, VISIBLE);
    
    if (VISIBLE != gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be %i", gtk_widget_get_child_visible (widget), VISIBLE);
    }
    
    gtk_container_remove (GTK_CONTAINER (window), widget);
    if (!gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be TRUE", gtk_widget_get_child_visible (widget), NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_child_visible
 * Params: GtkWidget *widget, gboolean visible
 * Returns: void
 * Assertion: However it will be reset to its default state of TRUE when the widget is removed from a container.
 * Params Values: GtkWidget *widget,  FALSE
 * Expected: void  
 */
static void test_purpose_348()
{
    #define WIDGET gtk_entry_new ()
    #define VISIBLE FALSE
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_ref (G_OBJECT(widget));
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_set_child_visible (widget, VISIBLE);
    
    if (VISIBLE != gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be %i", gtk_widget_get_child_visible (widget), VISIBLE);
    }
    
    gtk_container_remove (GTK_CONTAINER (window), widget);
    if (!gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be TRUE", gtk_widget_get_child_visible (widget), NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_child_visible
 * Params: GtkWidget *widget, gboolean visible
 * Returns: void
 * Assertion: However it will be reset to its default state of TRUE when the widget is removed from a container.
 * Params Values: GtkWidget *widget,  FALSE
 * Expected: void  
 */
static void test_purpose_349()
{
    #define WIDGET gtk_toggle_button_new ()
    #define VISIBLE FALSE
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    g_object_ref (G_OBJECT(widget));
    gtk_container_add (GTK_CONTAINER (window), widget);
    
    gtk_widget_set_child_visible (widget, VISIBLE);
    
    if (VISIBLE != gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be %i", gtk_widget_get_child_visible (widget), VISIBLE);
    }
    
    gtk_container_remove (GTK_CONTAINER (window), widget);
    if (!gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be TRUE", gtk_widget_get_child_visible (widget), NULL);
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_child_visible
 * Params: GtkWidget *widget, gboolean visible
 * Returns: void
 * Assertion: The child visibility can be set for widget before it is added to a container with gtk_widget_set_parent(), to avoid mapping children unnecessary before immediately unmapping them.
 * Params Values: GtkWidget *widget,  TRUE
 * Expected: void  
 */
static void test_purpose_350()
{
    #define WIDGET gtk_button_new ()
    #define VISIBLE TRUE
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    
    gtk_widget_set_child_visible (widget, VISIBLE);
    
    gtk_widget_set_parent (widget,window);
    
    if (VISIBLE != gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be %i", gtk_widget_get_child_visible (widget), VISIBLE);
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_child_visible
 * Params: GtkWidget *widget, gboolean visible
 * Returns: void
 * Assertion: The child visibility can be set for widget before it is added to a container with gtk_widget_set_parent(), to avoid mapping children unnecessary before immediately unmapping them.
 * Params Values: GtkWidget *widget,  FALSE
 * Expected: void  
 */
static void test_purpose_351()
{
    #define WIDGET gtk_check_button_new ()
    #define VISIBLE FALSE
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    
    gtk_widget_set_child_visible (widget, VISIBLE);
    
    gtk_widget_set_parent (widget,window);
    
    if (VISIBLE != gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be %i", gtk_widget_get_child_visible (widget), VISIBLE);
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_child_visible
 * Params: GtkWidget *widget, gboolean visible
 * Returns: void
 * Assertion: The child visibility can be set for widget before it is added to a container with gtk_widget_set_parent(), to avoid mapping children unnecessary before immediately unmapping them.
 * Params Values: GtkWidget *widget,  TRUE
 * Expected: void  
 */
static void test_purpose_352()
{
    #define WIDGET gtk_entry_new ()
    #define VISIBLE TRUE
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    
    gtk_widget_set_child_visible (widget, VISIBLE);
    
    gtk_widget_set_parent (widget,window);
    
    if (VISIBLE != gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be %i", gtk_widget_get_child_visible (widget), VISIBLE);
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_child_visible
 * Params: GtkWidget *widget, gboolean visible
 * Returns: void
 * Assertion: The child visibility can be set for widget before it is added to a container with gtk_widget_set_parent(), to avoid mapping children unnecessary before immediately unmapping them.
 * Params Values: GtkWidget *widget,  FALSE
 * Expected: void  
 */
static void test_purpose_353()
{
    #define WIDGET gtk_toggle_button_new ()
    #define VISIBLE FALSE
    
    GtkWidget* window;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!window)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    
    gtk_widget_set_child_visible (widget, VISIBLE);
    
    gtk_widget_set_parent (widget,window);
    
    if (VISIBLE != gtk_widget_get_child_visible (widget)) 
    {
        TEST_FAIL ("visible = %i, should be %i", gtk_widget_get_child_visible (widget), VISIBLE);
    }
    
    gtk_widget_destroy (window);
    
    #undef WIDGET
    #undef VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_accel_path 
 * Params: GtkWidget *widget, const gchar *accel_path, GtkAccelGroup *accel_group 
 * Returns: void
 * Assertion: Given an accelerator group, accel_group, and an accelerator path, accel_path, sets up an accelerator in accel_group so whenever the key binding that is defined for accel_path is pressed, widget will be activated.
 * Params Values: GtkWidget *widget,  GDK_A
 * Expected: void  
 */
static void test_purpose_354()
{
    #define PATH "<test>/action_A"
    #define KEY GDK_A
    #define MODS GDK_SHIFT_MASK
    #define WIDGET gtk_menu_item_new ()
    
    GtkWidget* widget;
    GtkAccelGroup* group;
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_accel_group_new ();
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    gtk_accel_map_add_entry (PATH, KEY, MODS);
    gtk_widget_set_accel_path (widget, PATH, group);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
        return;
    }
    if (key.accel_key != KEY)
    {
        TEST_FAIL ("accel keys not equal", NULL);
        return;
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PATH
    #undef KEY
    #undef MODS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_accel_path 
 * Params: GtkWidget *widget, const gchar *accel_path, GtkAccelGroup *accel_group 
 * Returns: void
 * Assertion: Given an accelerator group, accel_group, and an accelerator path, accel_path, sets up an accelerator in accel_group so whenever the key binding that is defined for accel_path is pressed, widget will be activated.
 * Params Values: GtkWidget *widget,  GDK_B
 * Expected: void  
 */
static void test_purpose_355()
{
    #define PATH "<test>/action_B"
    #define KEY GDK_B
    #define MODS GDK_SHIFT_MASK
    #define WIDGET gtk_entry_new ()
    
    GtkWidget* widget;
    GtkAccelGroup* group;
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_accel_group_new ();
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    gtk_accel_map_add_entry (PATH, KEY, MODS);
    gtk_widget_set_accel_path (widget, PATH, group);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
        return;
    }
    if (key.accel_key != KEY)
    {
        TEST_FAIL ("accel keys not equal", NULL);
        return;
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PATH
    #undef KEY
    #undef MODS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_accel_path 
 * Params: GtkWidget *widget, const gchar *accel_path, GtkAccelGroup *accel_group 
 * Returns: void
 * Assertion: Given an accelerator group, accel_group, and an accelerator path, accel_path, sets up an accelerator in accel_group so whenever the key binding that is defined for accel_path is pressed, widget will be activated.
 * Params Values: GtkWidget *widget,  GDK_1
 * Expected: void  
 */
static void test_purpose_356()
{
    #define PATH "<test>/action_1"
    #define KEY GDK_1
    #define MODS 0
    #define WIDGET gtk_entry_new ()
    
    GtkWidget* widget;
    GtkAccelGroup* group;
    GtkAccelKey key;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_accel_group_new ();
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    gtk_accel_map_add_entry (PATH, KEY, MODS);
    gtk_widget_set_accel_path (widget, PATH, group);
    
    if (!gtk_accel_map_lookup_entry (PATH, &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
        return;
    }
    if (key.accel_key != KEY)
    {
        TEST_FAIL ("accel keys not equal", NULL);
        return;
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PATH
    #undef KEY
    #undef MODS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_accel_path 
 * Params: GtkWidget *widget, const gchar *accel_path, GtkAccelGroup *accel_group 
 * Returns: void
 * Assertion: This removes any accelerators (for any accelerator group) installed by previous calls to gtk_widget_set_accel_path(). 
 * Params Values: GtkWidget *widget,  GDK_A
 * Expected: void  
 */
static void test_purpose_357()
{
    #define PATH "<test>/action_A"
    #define KEY GDK_A
    #define MODS GDK_SHIFT_MASK
    #define WIDGET gtk_menu_item_new ()
    
    GtkWidget* widget;
    GtkAccelGroup* group;
    GtkAccelKey key;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_accel_group_new ();
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_accel_map_add_entry ("<test>/action_old", GDK_C, GDK_CONTROL_MASK);
    gtk_widget_set_accel_path (widget, "<test>/action_old", group);
    if (!gtk_accel_map_lookup_entry ("<test>/action_old", &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
        return;
    }
    if (key.accel_key != GDK_C)
    {
        TEST_FAIL ("accel keys not equal", NULL);
        return;
    }
    
    
    gtk_accel_map_add_entry (PATH, KEY, MODS);
    
    gtk_widget_set_accel_path (widget, PATH, group);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PATH
    #undef KEY
    #undef MODS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_accel_path 
 * Params: GtkWidget *widget, const gchar *accel_path, GtkAccelGroup *accel_group 
 * Returns: void
 * Assertion: This removes any accelerators (for any accelerator group) installed by previous calls to gtk_widget_set_accel_path(). 
 * Params Values: GtkWidget *widget,  GDK_B
 * Expected: void  
 */
static void test_purpose_358()
{
    #define PATH "<test>/action_B"
    #define KEY GDK_B
    #define MODS GDK_SHIFT_MASK
    #define WIDGET gtk_entry_new ()
    
    GtkWidget* widget;
    GtkAccelGroup* group;
    GtkAccelKey key;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_accel_group_new ();
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_accel_map_add_entry ("<test>/action_old", GDK_C, GDK_CONTROL_MASK);
    gtk_widget_set_accel_path (widget, "<test>/action_old", group);
    if (!gtk_accel_map_lookup_entry ("<test>/action_old", &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
        return;
    }
    if (key.accel_key != GDK_C)
    {
        TEST_FAIL ("accel keys not equal", NULL);
        return;
    }
    
    
    gtk_accel_map_add_entry (PATH, KEY, MODS);
    
    gtk_widget_set_accel_path (widget, PATH, group);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PATH
    #undef KEY
    #undef MODS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_set_accel_path 
 * Params: GtkWidget *widget, const gchar *accel_path, GtkAccelGroup *accel_group 
 * Returns: void
 * Assertion: This removes any accelerators (for any accelerator group) installed by previous calls to gtk_widget_set_accel_path(). 
 * Params Values: GtkWidget *widget,  GDK_1
 * Expected: void  
 */
static void test_purpose_359()
{
    #define PATH "<test>/action_1"
    #define KEY GDK_1
    #define MODS 0
    #define WIDGET gtk_entry_new ()
    
    GtkWidget* widget;
    GtkAccelGroup* group;
    GtkAccelKey key;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    group = gtk_accel_group_new ();
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_accel_map_add_entry ("<test>/action_old", GDK_C, GDK_CONTROL_MASK);
    gtk_widget_set_accel_path (widget, "<test>/action_old", group);
    if (!gtk_accel_map_lookup_entry ("<test>/action_old", &key))
    {
        TEST_FAIL ("'gtk_accel_map_lookup_entry' returns NULL", NULL);
        return;
    }
    if (key.accel_key != GDK_C)
    {
        TEST_FAIL ("accel keys not equal", NULL);
        return;
    }
    
    
    gtk_accel_map_add_entry (PATH, KEY, MODS);
    
    gtk_widget_set_accel_path (widget, PATH, group);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PATH
    #undef KEY
    #undef MODS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_style_get
 * Params: GtkWidget *widget, const gchar *first_property_name,...
 * Returns: void
 * Assertion: Gets the values of a multiple style properties of widget.
 * Params Values: GtkWidget *widget,  "interior_focus",&focus,"child_displacement_x",&x,"default_border",&border
 * Expected: void  
 */
static void test_purpose_360()
{
    #define WIDGET gtk_button_new ()
    #define PROP_AND_VALUES "interior_focus",&focus,"child_displacement_x",&x,"default_border",&border
    #define ARG1 gboolean focus; gint x; GtkBorder* border;
    
    
    GtkWidget* widget;
    ARG1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_style_get (widget,PROP_AND_VALUES,NULL);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PROP_AND_VALUES
    #undef ARG1
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_style_get
 * Params: GtkWidget *widget, const gchar *first_property_name,...
 * Returns: void
 * Assertion: Gets the values of a multiple style properties of widget.
 * Params Values: GtkWidget *widget,  "interior_focus",&focus,"indicator-size",&size,"indicator-spacing",&spacing
 * Expected: void  
 */
static void test_purpose_361()
{
    #define WIDGET gtk_check_button_new ()
    #define PROP_AND_VALUES "interior_focus",&focus,"indicator-size",&size,"indicator-spacing",&spacing
    #define ARG1 gboolean focus; gint size; gint spacing;
    
    
    GtkWidget* widget;
    ARG1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_style_get (widget,PROP_AND_VALUES,NULL);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PROP_AND_VALUES
    #undef ARG1
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_style_get_valist 
 * Params: GtkWidget *widget, const gchar *first_property_name,va_list var_args
 * Returns: void
 * Assertion: Non-vararg variant of gtk_widget_style_get(). 
 * Params Values: GtkWidget *widget,  "interior_focus"
 * Expected: void  
 */
static void test_purpose_362()
{
    #define WIDGET gtk_button_new ()
    #define ARG1 "interior_focus"
    #define DATA &focus,"child_displacement_x",&x,"default_border",&border,NULL
    #define ARG_DEF gint focus, x; GtkBorder *border;
    
    
    GtkWidget* widget;
    int prav_param = 1;
    
    ARG_DEF
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    global_valist (widget,ARG1,DATA);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef ARG1
    #undef DATA
    #undef ARG_DEF
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_style_get_valist 
 * Params: GtkWidget *widget, const gchar *first_property_name,va_list var_args
 * Returns: void
 * Assertion: Non-vararg variant of gtk_widget_style_get(). 
 * Params Values: GtkWidget *widget,  "interior_focus"
 * Expected: void  
 */
static void test_purpose_363()
{
    #define WIDGET gtk_check_button_new ()
    #define ARG1 "interior_focus"
    #define DATA &focus,"indicator-size",&size,"indicator-spacing",&spacing,NULL
    #define ARG_DEF gint focus, size, spacing;
    
    
    GtkWidget* widget;
    int prav_param = 1;
    
    ARG_DEF
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    global_valist (widget,ARG1,DATA);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef ARG1
    #undef DATA
    #undef ARG_DEF
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_style_get_property 
 * Params: GtkWidget *widget, const gchar *first_property_name,GValue *value
 * Returns: void
 * Assertion: Gets the value of a style property of widget.
 * Params Values: GtkWidget *widget,  "interior_focus"
 * Expected: void  
 */
static void test_purpose_364()
{
    #define WIDGET gtk_button_new ()
    #define PROP "interior_focus"
    #define VALUE 1
    #define ARG1 g_value_get_int (&val)
    
    
    GtkWidget* widget;
    GValue val = {0,};
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    g_value_init (&val, G_TYPE_INT);
    
    gtk_widget_style_get_property (widget,PROP,&val);
    if (ARG1 != VALUE)
    {
        TEST_FAIL ("Value is wrong",NULL);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PROP
    #undef VALUE
    #undef ARG1
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_style_get_property 
 * Params: GtkWidget *widget, const gchar *first_property_name,GValue *value
 * Returns: void
 * Assertion: Gets the value of a style property of widget.
 * Params Values: GtkWidget *widget,  "child_displacement_x"
 * Expected: void  
 */
static void test_purpose_365()
{
    #define WIDGET gtk_button_new ()
    #define PROP "child_displacement_x"
    #define VALUE 0
    #define ARG1 g_value_get_int (&val)
    
    
    GtkWidget* widget;
    GValue val = {0,};
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    g_value_init (&val, G_TYPE_INT);
    
    gtk_widget_style_get_property (widget,PROP,&val);
    if (ARG1 != VALUE)
    {
        TEST_FAIL ("Value is wrong",NULL);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PROP
    #undef VALUE
    #undef ARG1
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_style_get_property 
 * Params: GtkWidget *widget, const gchar *first_property_name,GValue *value
 * Returns: void
 * Assertion: Gets the value of a style property of widget.
 * Params Values: GtkWidget *widget,  "indicator-size"
 * Expected: void  
 */
static void test_purpose_366()
{
    #define WIDGET gtk_check_button_new ()
    #define PROP "indicator-size"
    #define VALUE 13
    #define ARG1 g_value_get_int (&val)
    
    
    GtkWidget* widget;
    GValue val = {0,};
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    g_value_init (&val, G_TYPE_INT);
    
    gtk_widget_style_get_property (widget,PROP,&val);
    if (ARG1 != VALUE)
    {
        TEST_FAIL ("Value is wrong",NULL);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef PROP
    #undef VALUE
    #undef ARG1
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_intersect
 * Params: GtkWidget *widget,  GdkRectangle *area, GdkRectangle *intersection
 * Returns: gboolean
 * Assertion: intersection may be NULL if you're only interested in whether there was an intersection.'
 * Params Values: GtkWidget *widget, GdkRectangle *area, GdkRectangle *intersection
 * Expected: <%4%>  
 */
static void test_purpose_367()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define RECT 0, 0, 10, 10
    #define AREA 0, 0, 10, 10
    #define RESULT TRUE
    
    GdkRectangle rect = {RECT};
    GdkRectangle area = {AREA};
    
    GtkWidget* widget;
    GdkRectangle res = {0,0,0,0};
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_realize (widget);
    obj = (GdkWindowObject*)widget->window;
    obj->x = rect.x;
    obj->y = rect.y;
    gtk_widget_set_size_request (widget, rect.width, rect.height);
    gtk_widget_show_all (widget);
    
    if (RESULT != gtk_widget_intersect (widget, &area, NULL))
    {
        TEST_FAIL ("results not equal", NULL); 
        return;
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef RECT
    #undef AREA
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_intersect
 * Params: GtkWidget *widget,  GdkRectangle *area, GdkRectangle *intersection
 * Returns: gboolean
 * Assertion: intersection may be NULL if you're only interested in whether there was an intersection.'
 * Params Values: GtkWidget *widget, GdkRectangle *area, GdkRectangle *intersection
 * Expected: <%4%>  
 */
static void test_purpose_368()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define RECT 0, 0, 10, 10
    #define AREA 10, 10, 10, 10
    #define RESULT FALSE
    
    GdkRectangle rect = {RECT};
    GdkRectangle area = {AREA};
    
    GtkWidget* widget;
    GdkRectangle res = {0,0,0,0};
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_realize (widget);
    obj = (GdkWindowObject*)widget->window;
    obj->x = rect.x;
    obj->y = rect.y;
    gtk_widget_set_size_request (widget, rect.width, rect.height);
    gtk_widget_show_all (widget);
    
    if (RESULT != gtk_widget_intersect (widget, &area, NULL))
    {
        TEST_FAIL ("results not equal", NULL); 
        return;
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef RECT
    #undef AREA
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_intersect
 * Params: GtkWidget *widget,  GdkRectangle *area, GdkRectangle *intersection
 * Returns: gboolean
 * Assertion: intersection may be NULL if you're only interested in whether there was an intersection.'
 * Params Values: GtkWidget *widget, GdkRectangle *area, GdkRectangle *intersection
 * Expected: <%4%>  
 */
static void test_purpose_369()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define RECT 0, 0, 10, 10
    #define AREA 2, 2, 10, 10
    #define RESULT TRUE
    
    GdkRectangle rect = {RECT};
    GdkRectangle area = {AREA};
    
    GtkWidget* widget;
    GdkRectangle res = {0,0,0,0};
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_realize (widget);
    obj = (GdkWindowObject*)widget->window;
    obj->x = rect.x;
    obj->y = rect.y;
    gtk_widget_set_size_request (widget, rect.width, rect.height);
    gtk_widget_show_all (widget);
    
    if (RESULT != gtk_widget_intersect (widget, &area, NULL))
    {
        TEST_FAIL ("results not equal", NULL); 
        return;
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef RECT
    #undef AREA
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_intersect
 * Params: GtkWidget *widget,  GdkRectangle *area, GdkRectangle *intersection
 * Returns: gboolean
 * Assertion: intersection may be NULL if you're only interested in whether there was an intersection.'
 * Params Values: GtkWidget *widget, GdkRectangle *area, GdkRectangle *intersection
 * Expected: <%4%>  
 */
static void test_purpose_370()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define RECT 0, 0, 10, 10
    #define AREA 100, 100, 100, 100
    #define RESULT FALSE
    
    GdkRectangle rect = {RECT};
    GdkRectangle area = {AREA};
    
    GtkWidget* widget;
    GdkRectangle res = {0,0,0,0};
    GdkWindowObject* obj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_realize (widget);
    obj = (GdkWindowObject*)widget->window;
    obj->x = rect.x;
    obj->y = rect.y;
    gtk_widget_set_size_request (widget, rect.width, rect.height);
    gtk_widget_show_all (widget);
    
    if (RESULT != gtk_widget_intersect (widget, &area, NULL))
    {
        TEST_FAIL ("results not equal", NULL); 
        return;
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    #undef RECT
    #undef AREA
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_thaw_child_notify
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Reverts the effect of a previous call to gtk_widget_freeze_child_notify().
 * Params Values: GtkWidget *widget
 * Expected: void  
 */
static void test_purpose_371()
{
    #define WIDGET gtk_button_new ()
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_widget_freeze_child_notify (widget);
    
    gtk_widget_thaw_child_notify (widget);
    
    gtk_widget_destroy (widget);
    
    #undef WIDGET
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_list_accel_closures  
 * Params: GtkWidget *widget
 * Returns: GList*
 * Assertion: Lists the closures used by widget for accelerator group connections with gtk_accel_group_connect_by_path() or gtk_accel_group_connect().
 * Params Values: GtkWidget *widget
 * Expected: GList*  
 */
static void test_purpose_372()
{
    #define NUM 1
    
    GtkWidget* widget;
    GtkAccelGroup* group;
    GtkWidget* window;
    GList* list;
    GtkWidget* button;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = gtk_accel_label_new ("Text");
    button = gtk_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    
    for (i = 0; i<NUM; i++)
    {
        gtk_widget_add_accelerator (button, "activate", group,
                                   GDK_1, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
    }
    
    list = gtk_widget_list_accel_closures (GTK_WIDGET (button));
    if (g_list_length (list) != NUM)
    {
        TEST_FAIL ("List's length is %d,should be %d",g_list_length (list),NUM);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef NUM
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_list_accel_closures  
 * Params: GtkWidget *widget
 * Returns: GList*
 * Assertion: Lists the closures used by widget for accelerator group connections with gtk_accel_group_connect_by_path() or gtk_accel_group_connect().
 * Params Values: GtkWidget *widget
 * Expected: GList*  
 */
static void test_purpose_373()
{
    #define NUM 5
    
    GtkWidget* widget;
    GtkAccelGroup* group;
    GtkWidget* window;
    GList* list;
    GtkWidget* button;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = gtk_accel_label_new ("Text");
    button = gtk_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    
    for (i = 0; i<NUM; i++)
    {
        gtk_widget_add_accelerator (button, "activate", group,
                                   GDK_1, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
    }
    
    list = gtk_widget_list_accel_closures (GTK_WIDGET (button));
    if (g_list_length (list) != NUM)
    {
        TEST_FAIL ("List's length is %d,should be %d",g_list_length (list),NUM);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef NUM
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_list_accel_closures  
 * Params: GtkWidget *widget
 * Returns: GList*
 * Assertion: Lists the closures used by widget for accelerator group connections with gtk_accel_group_connect_by_path() or gtk_accel_group_connect().
 * Params Values: GtkWidget *widget
 * Expected: GList*  
 */
static void test_purpose_374()
{
    #define NUM 10
    
    GtkWidget* widget;
    GtkAccelGroup* group;
    GtkWidget* window;
    GList* list;
    GtkWidget* button;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    widget = gtk_accel_label_new ("Text");
    button = gtk_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    
    for (i = 0; i<NUM; i++)
    {
        gtk_widget_add_accelerator (button, "activate", group,
                                   GDK_1, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
    }
    
    list = gtk_widget_list_accel_closures (GTK_WIDGET (button));
    if (g_list_length (list) != NUM)
    {
        TEST_FAIL ("List's length is %d,should be %d",g_list_length (list),NUM);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef NUM
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_widget_list_accel_closures  
 * Params: GtkWidget *widget
 * Returns: GList*
 * Assertion: The closures can be used to monitor accelerator changes on widget, by connecting to the ::accel_changed signal of the GtkAccelGroup of a closure which can be found out with gtk_accel_group_from_accel_closure().
 * Params Values: GtkWidget *widget
 * Expected: GList*  
 */
static void test_purpose_375()
{
    GtkWidget* widget;
    GtkAccelGroup* group;
    GtkWidget* window;
    GList* list;
    GtkWidget* button;
    gint i;
    GClosure* closure;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_result = 0;
    widget = gtk_accel_label_new ("Text");
    button = gtk_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    group = gtk_accel_group_new ();
    closure = g_cclosure_new ((GCallback)global_set_result, NULL, NULL);
    
    gtk_accel_group_connect (group, GDK_A, GDK_CONTROL_MASK,GTK_ACCEL_VISIBLE,closure);
    gtk_window_add_accel_group (GTK_WINDOW (window), group);
    
    
    g_signal_connect (G_OBJECT (group), "accel-changed", GTK_SIGNAL_FUNC (global_accel_changed), &group);
    
    gtk_widget_add_accelerator (button, "activate", group,
                                   GDK_1, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
    
    
    list = gtk_widget_list_accel_closures (GTK_WIDGET (button));
    
    group = gtk_accel_group_from_accel_closure (g_list_nth_data(list,0));
    
    gtk_accel_group_disconnect_key (group, GDK_1, GDK_CONTROL_MASK);
    
    
    if(!global_result)
    {
        TEST_FAIL ("Closure is changed",NULL);
    }
    
    gtk_widget_destroy (widget);
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_has_screen
 * Params: GtkWidget *widget
 * Returns: gboolean
 * Assertion: Checks whether there is a GdkScreen is associated with this widget.
 * Params Values: GtkWidget *widget
 * Expected: gboolean  
 */
static void test_purpose_376()
{
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
    
        if (gtk_widget_has_screen (hbox))
        {
            TEST_FAIL ("1: hbox has a screen", NULL);
        }
    
        if (gtk_widget_has_screen (child1))
        {
            TEST_FAIL ("1: child1 has doesn't have a screen", NULL);
        }
    
        if (gtk_widget_has_screen (child2))
        {
            TEST_FAIL ("1: child3 has a screen", NULL);
        }
    
        if (gtk_widget_has_screen (child3))
        {
            TEST_FAIL ("1: child3 has a screen", NULL);
        }
    
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_has_screen (hbox))
        {
            TEST_FAIL ("1: hbox doesn't have a screen", NULL);
        }
    
        if (!gtk_widget_has_screen (window))
        {
            TEST_FAIL ("1: window doesn't have a screen", NULL);
        }
    
        if (!gtk_widget_has_screen (child1))
        {
            TEST_FAIL ("1: child1 doesn't have a screen", NULL);
        }
    
        if (!gtk_widget_has_screen (child2))
        {
            TEST_FAIL ("1: child3 doesn't have a screen", NULL);
        }
    
        if (!gtk_widget_has_screen (child3))
        {
            TEST_FAIL ("1: child3 doesn't have a screen", NULL);
        }
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_root_window
 * Params: GtkWidget *widget
 * Returns: GdkWindow*
 * Assertion: Get the root window where this widget is located.
 * Params Values: GtkWidget *widget
 * Expected: GdkWindow*  
 */
static void test_purpose_377()
{
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_get_root_window (window))
        {
            TEST_FAIL ("window doesn't have a root window", NULL);
        }
    
        if (!gtk_widget_get_root_window (hbox))
        {
            TEST_FAIL ("hbox doesn't have a root window", NULL);
        }
    
        if (!gtk_widget_get_root_window (child1))
        {
            TEST_FAIL ("child1 doesn't have a root window", NULL);
        }
    
        if (!gtk_widget_get_root_window (child2))
        {
            TEST_FAIL ("child3 doesn't have a root window", NULL);
        }
    
        if (!gtk_widget_get_root_window (child3))
        {
            TEST_FAIL ("child3 doesn't have a root window", NULL);
        }
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_screen
 * Params: GtkWidget *widget
 * Returns: GdkScreen*
 * Assertion: Get the GdkScreen from the toplevel window associated with this widget.
 * Params Values: GtkWidget *widget
 * Expected: GdkScreen*  
 */
static void test_purpose_378()
{
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_get_screen (window))
        {
            TEST_FAIL ("window doesn't have a screen", NULL);
        }
    
        if (!gtk_widget_get_screen (hbox))
        {
            TEST_FAIL ("hbox doesn't have a screen", NULL);
        }
    
        if (!gtk_widget_get_screen (child1))
        {
            TEST_FAIL ("child1 doesn't have a screen", NULL);
        }
    
        if (!gtk_widget_get_screen (child2))
        {
            TEST_FAIL ("child3 doesn't have a screen", NULL);
        }
    
        if (!gtk_widget_get_screen (child3))
        {
            TEST_FAIL ("child3 doesn't have a screen", NULL);
        }
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_display
 * Params: GtkWidget *widget
 * Returns: GdkDisplay*
 * Assertion: Get the GdkDisplay for the toplevel window associated with this widget.
 * Params Values: GtkWidget *widget
 * Expected: GdkDisplay*  
 */
static void test_purpose_379()
{
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_get_display (window))
        {
            TEST_FAIL ("window doesn't have a display", NULL);
        }
    
        if (!gtk_widget_get_display (hbox))
        {
            TEST_FAIL ("hbox doesn't have a display", NULL);
        }
    
        if (!gtk_widget_get_display (child1))
        {
            TEST_FAIL ("child1 doesn't have a display", NULL);
        }
    
        if (!gtk_widget_get_display (child2))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
        }
    
        if (!gtk_widget_get_display (child3))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
        }
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_clipboard
 * Params: GtkWidget *widget, GdkAtom selection
 * Returns: GtkClipboard
 * Assertion: Returns the clipboard object for the given selection to be used with widget.
 * Params Values: GtkWidget *widget, GDK_SELECTION_PRIMARY
 * Expected: GdkClipboard*  
 */
static void test_purpose_380()
{
    #define SELECTION GDK_SELECTION_PRIMARY
    
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_get_display (window))
        {
            TEST_FAIL ("window doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (window, SELECTION))
            {
                TEST_FAIL ("window doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (hbox))
        {
            TEST_FAIL ("hbox doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (hbox, SELECTION))
            {
                TEST_FAIL ("hbox doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child1))
        {
            TEST_FAIL ("child1 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child1, SELECTION))
            {
                TEST_FAIL ("child1 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child2))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child2, SELECTION))
            {
                TEST_FAIL ("child2 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child3))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child3, SELECTION))
            {
                TEST_FAIL ("child3 doesn't have a clipboard", NULL);
            }
        }
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_clipboard
 * Params: GtkWidget *widget, GdkAtom selection
 * Returns: GtkClipboard
 * Assertion: Returns the clipboard object for the given selection to be used with widget.
 * Params Values: GtkWidget *widget, GDK_SELECTION_SECONDARY
 * Expected: GdkClipboard*  
 */
static void test_purpose_381()
{
    #define SELECTION GDK_SELECTION_SECONDARY
    
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_get_display (window))
        {
            TEST_FAIL ("window doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (window, SELECTION))
            {
                TEST_FAIL ("window doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (hbox))
        {
            TEST_FAIL ("hbox doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (hbox, SELECTION))
            {
                TEST_FAIL ("hbox doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child1))
        {
            TEST_FAIL ("child1 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child1, SELECTION))
            {
                TEST_FAIL ("child1 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child2))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child2, SELECTION))
            {
                TEST_FAIL ("child2 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child3))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child3, SELECTION))
            {
                TEST_FAIL ("child3 doesn't have a clipboard", NULL);
            }
        }
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_clipboard
 * Params: GtkWidget *widget, GdkAtom selection
 * Returns: GtkClipboard
 * Assertion: Returns the clipboard object for the given selection to be used with widget.
 * Params Values: GtkWidget *widget, GDK_SELECTION_CLIPBOARD
 * Expected: GdkClipboard*  
 */
static void test_purpose_382()
{
    #define SELECTION GDK_SELECTION_CLIPBOARD
    
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_get_display (window))
        {
            TEST_FAIL ("window doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (window, SELECTION))
            {
                TEST_FAIL ("window doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (hbox))
        {
            TEST_FAIL ("hbox doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (hbox, SELECTION))
            {
                TEST_FAIL ("hbox doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child1))
        {
            TEST_FAIL ("child1 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child1, SELECTION))
            {
                TEST_FAIL ("child1 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child2))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child2, SELECTION))
            {
                TEST_FAIL ("child2 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child3))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child3, SELECTION))
            {
                TEST_FAIL ("child3 doesn't have a clipboard", NULL);
            }
        }
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_clipboard
 * Params: GtkWidget *widget, GdkAtom selection
 * Returns: GtkClipboard
 * Assertion: Returns the clipboard object for the given selection to be used with widget.
 * Params Values: GtkWidget *widget, GDK_SELECTION_TYPE_ATOM
 * Expected: GdkClipboard*  
 */
static void test_purpose_383()
{
    #define SELECTION GDK_SELECTION_TYPE_ATOM
    
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_get_display (window))
        {
            TEST_FAIL ("window doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (window, SELECTION))
            {
                TEST_FAIL ("window doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (hbox))
        {
            TEST_FAIL ("hbox doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (hbox, SELECTION))
            {
                TEST_FAIL ("hbox doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child1))
        {
            TEST_FAIL ("child1 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child1, SELECTION))
            {
                TEST_FAIL ("child1 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child2))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child2, SELECTION))
            {
                TEST_FAIL ("child2 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child3))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child3, SELECTION))
            {
                TEST_FAIL ("child3 doesn't have a clipboard", NULL);
            }
        }
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_clipboard
 * Params: GtkWidget *widget, GdkAtom selection
 * Returns: GtkClipboard
 * Assertion: Returns the clipboard object for the given selection to be used with widget.
 * Params Values: GtkWidget *widget, GDK_SELECTION_TYPE_BITMAP
 * Expected: GdkClipboard*  
 */
static void test_purpose_384()
{
    #define SELECTION GDK_SELECTION_TYPE_BITMAP
    
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_get_display (window))
        {
            TEST_FAIL ("window doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (window, SELECTION))
            {
                TEST_FAIL ("window doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (hbox))
        {
            TEST_FAIL ("hbox doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (hbox, SELECTION))
            {
                TEST_FAIL ("hbox doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child1))
        {
            TEST_FAIL ("child1 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child1, SELECTION))
            {
                TEST_FAIL ("child1 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child2))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child2, SELECTION))
            {
                TEST_FAIL ("child2 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child3))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child3, SELECTION))
            {
                TEST_FAIL ("child3 doesn't have a clipboard", NULL);
            }
        }
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_clipboard
 * Params: GtkWidget *widget, GdkAtom selection
 * Returns: GtkClipboard
 * Assertion: Returns the clipboard object for the given selection to be used with widget.
 * Params Values: GtkWidget *widget, GDK_SELECTION_TYPE_COLORMAP
 * Expected: GdkClipboard*  
 */
static void test_purpose_385()
{
    #define SELECTION GDK_SELECTION_TYPE_COLORMAP
    
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_get_display (window))
        {
            TEST_FAIL ("window doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (window, SELECTION))
            {
                TEST_FAIL ("window doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (hbox))
        {
            TEST_FAIL ("hbox doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (hbox, SELECTION))
            {
                TEST_FAIL ("hbox doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child1))
        {
            TEST_FAIL ("child1 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child1, SELECTION))
            {
                TEST_FAIL ("child1 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child2))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child2, SELECTION))
            {
                TEST_FAIL ("child2 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child3))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child3, SELECTION))
            {
                TEST_FAIL ("child3 doesn't have a clipboard", NULL);
            }
        }
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_clipboard
 * Params: GtkWidget *widget, GdkAtom selection
 * Returns: GtkClipboard
 * Assertion: Returns the clipboard object for the given selection to be used with widget.
 * Params Values: GtkWidget *widget, GDK_SELECTION_TYPE_DRAWABLE
 * Expected: GdkClipboard*  
 */
static void test_purpose_386()
{
    #define SELECTION GDK_SELECTION_TYPE_DRAWABLE
    
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_get_display (window))
        {
            TEST_FAIL ("window doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (window, SELECTION))
            {
                TEST_FAIL ("window doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (hbox))
        {
            TEST_FAIL ("hbox doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (hbox, SELECTION))
            {
                TEST_FAIL ("hbox doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child1))
        {
            TEST_FAIL ("child1 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child1, SELECTION))
            {
                TEST_FAIL ("child1 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child2))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child2, SELECTION))
            {
                TEST_FAIL ("child2 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child3))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child3, SELECTION))
            {
                TEST_FAIL ("child3 doesn't have a clipboard", NULL);
            }
        }
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_clipboard
 * Params: GtkWidget *widget, GdkAtom selection
 * Returns: GtkClipboard
 * Assertion: Returns the clipboard object for the given selection to be used with widget.
 * Params Values: GtkWidget *widget, GDK_SELECTION_TYPE_INTEGER
 * Expected: GdkClipboard*  
 */
static void test_purpose_387()
{
    #define SELECTION GDK_SELECTION_TYPE_INTEGER
    
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_get_display (window))
        {
            TEST_FAIL ("window doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (window, SELECTION))
            {
                TEST_FAIL ("window doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (hbox))
        {
            TEST_FAIL ("hbox doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (hbox, SELECTION))
            {
                TEST_FAIL ("hbox doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child1))
        {
            TEST_FAIL ("child1 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child1, SELECTION))
            {
                TEST_FAIL ("child1 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child2))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child2, SELECTION))
            {
                TEST_FAIL ("child2 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child3))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child3, SELECTION))
            {
                TEST_FAIL ("child3 doesn't have a clipboard", NULL);
            }
        }
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_clipboard
 * Params: GtkWidget *widget, GdkAtom selection
 * Returns: GtkClipboard
 * Assertion: Returns the clipboard object for the given selection to be used with widget.
 * Params Values: GtkWidget *widget, GDK_SELECTION_TYPE_PIXMAP
 * Expected: GdkClipboard*  
 */
static void test_purpose_388()
{
    #define SELECTION GDK_SELECTION_TYPE_PIXMAP
    
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_get_display (window))
        {
            TEST_FAIL ("window doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (window, SELECTION))
            {
                TEST_FAIL ("window doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (hbox))
        {
            TEST_FAIL ("hbox doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (hbox, SELECTION))
            {
                TEST_FAIL ("hbox doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child1))
        {
            TEST_FAIL ("child1 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child1, SELECTION))
            {
                TEST_FAIL ("child1 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child2))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child2, SELECTION))
            {
                TEST_FAIL ("child2 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child3))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child3, SELECTION))
            {
                TEST_FAIL ("child3 doesn't have a clipboard", NULL);
            }
        }
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_clipboard
 * Params: GtkWidget *widget, GdkAtom selection
 * Returns: GtkClipboard
 * Assertion: Returns the clipboard object for the given selection to be used with widget.
 * Params Values: GtkWidget *widget, GDK_SELECTION_TYPE_WINDOW
 * Expected: GdkClipboard*  
 */
static void test_purpose_389()
{
    #define SELECTION GDK_SELECTION_TYPE_WINDOW
    
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_get_display (window))
        {
            TEST_FAIL ("window doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (window, SELECTION))
            {
                TEST_FAIL ("window doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (hbox))
        {
            TEST_FAIL ("hbox doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (hbox, SELECTION))
            {
                TEST_FAIL ("hbox doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child1))
        {
            TEST_FAIL ("child1 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child1, SELECTION))
            {
                TEST_FAIL ("child1 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child2))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child2, SELECTION))
            {
                TEST_FAIL ("child2 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child3))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child3, SELECTION))
            {
                TEST_FAIL ("child3 doesn't have a clipboard", NULL);
            }
        }
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_widget_get_clipboard
 * Params: GtkWidget *widget, GdkAtom selection
 * Returns: GtkClipboard
 * Assertion: Returns the clipboard object for the given selection to be used with widget.
 * Params Values: GtkWidget *widget, GDK_SELECTION_TYPE_STRING
 * Expected: GdkClipboard*  
 */
static void test_purpose_390()
{
    #define SELECTION GDK_SELECTION_TYPE_STRING
    
    GtkWidget* window;
    GtkWidget* hbox;
    GtkWidget* child1;
    GtkWidget* child2;
    GtkWidget* child3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    {
        window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
        hbox = gtk_hbox_new (TRUE, 10);
        child1 = gtk_button_new ();
        child2 = gtk_label_new ("label");
        child3 = gtk_progress_bar_new ();
        
        gtk_container_add (GTK_CONTAINER (hbox), child1);
        gtk_container_add (GTK_CONTAINER (hbox), child2);
        gtk_container_add (GTK_CONTAINER (hbox), child3);
        gtk_container_add (GTK_CONTAINER (window), hbox);
    
        gtk_widget_show_all (window);
    
        if (!gtk_widget_get_display (window))
        {
            TEST_FAIL ("window doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (window, SELECTION))
            {
                TEST_FAIL ("window doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (hbox))
        {
            TEST_FAIL ("hbox doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (hbox, SELECTION))
            {
                TEST_FAIL ("hbox doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child1))
        {
            TEST_FAIL ("child1 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child1, SELECTION))
            {
                TEST_FAIL ("child1 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child2))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child2, SELECTION))
            {
                TEST_FAIL ("child2 doesn't have a clipboard", NULL);
            }
        }
    
        if (!gtk_widget_get_display (child3))
        {
            TEST_FAIL ("child3 doesn't have a display", NULL);
            return;
        } else {
            if (!gtk_widget_get_clipboard (child3, SELECTION))
            {
                TEST_FAIL ("child3 doesn't have a clipboard", NULL);
            }
        }
    }
    
    #undef SELECTION
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkWidget ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {test_purpose_101, 1},
    {test_purpose_102, 1},
    {test_purpose_103, 1},
    {test_purpose_104, 1},
    {test_purpose_105, 1},
    {test_purpose_106, 1},
    {test_purpose_107, 1},
    {test_purpose_108, 1},
    {test_purpose_109, 1},
    {test_purpose_110, 1},
    {test_purpose_111, 1},
    {test_purpose_112, 1},
    {test_purpose_113, 1},
    {test_purpose_114, 1},
    {test_purpose_115, 1},
    {test_purpose_116, 1},
    {test_purpose_117, 1},
    {test_purpose_118, 1},
    {test_purpose_119, 1},
    {test_purpose_120, 1},
    {test_purpose_121, 1},
    {test_purpose_122, 1},
    {test_purpose_123, 1},
    {test_purpose_124, 1},
    {test_purpose_125, 1},
    {test_purpose_126, 1},
    {test_purpose_127, 1},
    {test_purpose_128, 1},
    {test_purpose_129, 1},
    {test_purpose_130, 1},
    {test_purpose_131, 1},
    {test_purpose_132, 1},
    {test_purpose_133, 1},
    {test_purpose_134, 1},
    {test_purpose_135, 1},
    {test_purpose_136, 1},
    {test_purpose_137, 1},
    {test_purpose_138, 1},
    {test_purpose_139, 1},
    {test_purpose_140, 1},
    {test_purpose_141, 1},
    {test_purpose_142, 1},
    {test_purpose_143, 1},
    {test_purpose_144, 1},
    {test_purpose_145, 1},
    {test_purpose_146, 1},
    {test_purpose_147, 1},
    {test_purpose_148, 1},
    {test_purpose_149, 1},
    {test_purpose_150, 1},
    {test_purpose_151, 1},
    {test_purpose_152, 1},
    {test_purpose_153, 1},
    {test_purpose_154, 1},
    {test_purpose_155, 1},
    {test_purpose_156, 1},
    {test_purpose_157, 1},
    {test_purpose_158, 1},
    {test_purpose_159, 1},
    {test_purpose_160, 1},
    {test_purpose_161, 1},
    {test_purpose_162, 1},
    {test_purpose_163, 1},
    {test_purpose_164, 1},
    {test_purpose_165, 1},
    {test_purpose_166, 1},
    {test_purpose_167, 1},
    {test_purpose_168, 1},
    {test_purpose_169, 1},
    {test_purpose_170, 1},
    {test_purpose_171, 1},
    {test_purpose_172, 1},
    {test_purpose_173, 1},
    {test_purpose_174, 1},
    {test_purpose_175, 1},
    {test_purpose_176, 1},
    {test_purpose_177, 1},
    {test_purpose_178, 1},
    {test_purpose_179, 1},
    {test_purpose_180, 1},
    {test_purpose_181, 1},
    {test_purpose_182, 1},
    {test_purpose_183, 1},
    {test_purpose_184, 1},
    {test_purpose_185, 1},
    {test_purpose_186, 1},
    {test_purpose_187, 1},
    {test_purpose_188, 1},
    {test_purpose_189, 1},
    {test_purpose_190, 1},
    {test_purpose_191, 1},
    {test_purpose_192, 1},
    {test_purpose_193, 1},
    {test_purpose_194, 1},
    {test_purpose_195, 1},
    {test_purpose_196, 1},
    {test_purpose_197, 1},
    {test_purpose_198, 1},
    {test_purpose_199, 1},
    {test_purpose_200, 1},
    {test_purpose_201, 1},
    {test_purpose_202, 1},
    {test_purpose_203, 1},
    {test_purpose_204, 1},
    {test_purpose_205, 1},
    {test_purpose_206, 1},
    {test_purpose_207, 1},
    {test_purpose_208, 1},
    {test_purpose_209, 1},
    {test_purpose_210, 1},
    {test_purpose_211, 1},
    {test_purpose_212, 1},
    {test_purpose_213, 1},
    {test_purpose_214, 1},
    {test_purpose_215, 1},
    {test_purpose_216, 1},
    {test_purpose_217, 1},
    {test_purpose_218, 1},
    {test_purpose_219, 1},
    {test_purpose_220, 1},
    {test_purpose_221, 1},
    {test_purpose_222, 1},
    {test_purpose_223, 1},
    {test_purpose_224, 1},
    {test_purpose_225, 1},
    {test_purpose_226, 1},
    {test_purpose_227, 1},
    {test_purpose_228, 1},
    {test_purpose_229, 1},
    {test_purpose_230, 1},
    {test_purpose_231, 1},
    {test_purpose_232, 1},
    {test_purpose_233, 1},
    {test_purpose_234, 1},
    {test_purpose_235, 1},
    {test_purpose_236, 1},
    {test_purpose_237, 1},
    {test_purpose_238, 1},
    {test_purpose_239, 1},
    {test_purpose_240, 1},
    {test_purpose_241, 1},
    {test_purpose_242, 1},
    {test_purpose_243, 1},
    {test_purpose_244, 1},
    {test_purpose_245, 1},
    {test_purpose_246, 1},
    {test_purpose_247, 1},
    {test_purpose_248, 1},
    {test_purpose_249, 1},
    {test_purpose_250, 1},
    {test_purpose_251, 1},
    {test_purpose_252, 1},
    {test_purpose_253, 1},
    {test_purpose_254, 1},
    {test_purpose_255, 1},
    {test_purpose_256, 1},
    {test_purpose_257, 1},
    {test_purpose_258, 1},
    {test_purpose_259, 1},
    {test_purpose_260, 1},
    {test_purpose_261, 1},
    {test_purpose_262, 1},
    {test_purpose_263, 1},
    {test_purpose_264, 1},
    {test_purpose_265, 1},
    {test_purpose_266, 1},
    {test_purpose_267, 1},
    {test_purpose_268, 1},
    {test_purpose_269, 1},
    {test_purpose_270, 1},
    {test_purpose_271, 1},
    {test_purpose_272, 1},
    {test_purpose_273, 1},
    {test_purpose_274, 1},
    {test_purpose_275, 1},
    {test_purpose_276, 1},
    {test_purpose_277, 1},
    {test_purpose_278, 1},
    {test_purpose_279, 1},
    {test_purpose_280, 1},
    {test_purpose_281, 1},
    {test_purpose_282, 1},
    {test_purpose_283, 1},
    {test_purpose_284, 1},
    {test_purpose_285, 1},
    {test_purpose_286, 1},
    {test_purpose_287, 1},
    {test_purpose_288, 1},
    {test_purpose_289, 1},
    {test_purpose_290, 1},
    {test_purpose_291, 1},
    {test_purpose_292, 1},
    {test_purpose_293, 1},
    {test_purpose_294, 1},
    {test_purpose_295, 1},
    {test_purpose_296, 1},
    {test_purpose_297, 1},
    {test_purpose_298, 1},
    {test_purpose_299, 1},
    {test_purpose_300, 1},
    {test_purpose_301, 1},
    {test_purpose_302, 1},
    {test_purpose_303, 1},
    {test_purpose_304, 1},
    {test_purpose_305, 1},
    {test_purpose_306, 1},
    {test_purpose_307, 1},
    {test_purpose_308, 1},
    {test_purpose_309, 1},
    {test_purpose_310, 1},
    {test_purpose_311, 1},
    {test_purpose_312, 1},
    {test_purpose_313, 1},
    {test_purpose_314, 1},
    {test_purpose_315, 1},
    {test_purpose_316, 1},
    {test_purpose_317, 1},
    {test_purpose_318, 1},
    {test_purpose_319, 1},
    {test_purpose_320, 1},
    {test_purpose_321, 1},
    {test_purpose_322, 1},
    {test_purpose_323, 1},
    {test_purpose_324, 1},
    {test_purpose_325, 1},
    {test_purpose_326, 1},
    {test_purpose_327, 1},
    {test_purpose_328, 1},
    {test_purpose_329, 1},
    {test_purpose_330, 1},
    {test_purpose_331, 1},
    {test_purpose_332, 1},
    {test_purpose_333, 1},
    {test_purpose_334, 1},
    {test_purpose_335, 1},
    {test_purpose_336, 1},
    {test_purpose_337, 1},
    {test_purpose_338, 1},
    {test_purpose_339, 1},
    {test_purpose_340, 1},
    {test_purpose_341, 1},
    {test_purpose_342, 1},
    {test_purpose_343, 1},
    {test_purpose_344, 1},
    {test_purpose_345, 1},
    {test_purpose_346, 1},
    {test_purpose_347, 1},
    {test_purpose_348, 1},
    {test_purpose_349, 1},
    {test_purpose_350, 1},
    {test_purpose_351, 1},
    {test_purpose_352, 1},
    {test_purpose_353, 1},
    {test_purpose_354, 1},
    {test_purpose_355, 1},
    {test_purpose_356, 1},
    {test_purpose_357, 1},
    {test_purpose_358, 1},
    {test_purpose_359, 1},
    {test_purpose_360, 1},
    {test_purpose_361, 1},
    {test_purpose_362, 1},
    {test_purpose_363, 1},
    {test_purpose_364, 1},
    {test_purpose_365, 1},
    {test_purpose_366, 1},
    {test_purpose_367, 1},
    {test_purpose_368, 1},
    {test_purpose_369, 1},
    {test_purpose_370, 1},
    {test_purpose_371, 1},
    {test_purpose_372, 1},
    {test_purpose_373, 1},
    {test_purpose_374, 1},
    {test_purpose_375, 1},
    {test_purpose_376, 1},
    {test_purpose_377, 1},
    {test_purpose_378, 1},
    {test_purpose_379, 1},
    {test_purpose_380, 1},
    {test_purpose_381, 1},
    {test_purpose_382, 1},
    {test_purpose_383, 1},
    {test_purpose_384, 1},
    {test_purpose_385, 1},
    {test_purpose_386, 1},
    {test_purpose_387, 1},
    {test_purpose_388, 1},
    {test_purpose_389, 1},
    {test_purpose_390, 1},
    {NULL,0}
};
