/*
 * Styles methods tests
 * Testing Styles methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name:  gtk_style_new
 * Params: void
 * Returns: GtkStyle*
 * Assertion: Creates a new GtkStyle. 
 * Params Values: void
 * Expected: a newly created GtkStyle*  
 */
static void test_purpose_1()
{
    GtkStyle* style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_style_attach
 * Params: void
 * Returns: GtkStyle *style, GdkWindow *window
 * Assertion: Attaches a style to a window; this process allocates the colors and creates the GC's for the style - it specializes it to a particular visual and colormap.' 
 * Params Values: GtkStyle *style, GdkWindow *window
 * Expected: GtkStyle*  
 */
static void test_purpose_2()
{
    #define WIDGET gtk_button_new ()
    
    GtkStyle* style;
    GtkStyle* ret_style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkWindowAttr attributes;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    
    if (!window)
    {
        TEST_FAIL ("window = NULL", NULL);
        return;
    }
    
    ret_style = gtk_style_attach (style, window);
    if (!ret_style)
    {
        TEST_FAIL ("gtk_style_attach() returned NULL", NULL);
    }
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_style_attach
 * Params: void
 * Returns: GtkStyle *style, GdkWindow *window
 * Assertion: Attaches a style to a window; this process allocates the colors and creates the GC's for the style - it specializes it to a particular visual and colormap.' 
 * Params Values: GtkStyle *style, GdkWindow *window
 * Expected: GtkStyle*  
 */
static void test_purpose_3()
{
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    
    GtkStyle* style;
    GtkStyle* ret_style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkWindowAttr attributes;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    
    if (!window)
    {
        TEST_FAIL ("window = NULL", NULL);
        return;
    }
    
    ret_style = gtk_style_attach (style, window);
    if (!ret_style)
    {
        TEST_FAIL ("gtk_style_attach() returned NULL", NULL);
    }
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_style_attach
 * Params: void
 * Returns: GtkStyle *style, GdkWindow *window
 * Assertion: Attaches a style to a window; this process allocates the colors and creates the GC's for the style - it specializes it to a particular visual and colormap.' 
 * Params Values: GtkStyle *style, GdkWindow *window
 * Expected: GtkStyle*  
 */
static void test_purpose_4()
{
    #define WIDGET gtk_toggle_button_new ()
    
    GtkStyle* style;
    GtkStyle* ret_style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkWindowAttr attributes;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    
    if (!window)
    {
        TEST_FAIL ("window = NULL", NULL);
        return;
    }
    
    ret_style = gtk_style_attach (style, window);
    if (!ret_style)
    {
        TEST_FAIL ("gtk_style_attach() returned NULL", NULL);
    }
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_style_attach
 * Params: void
 * Returns: GtkStyle *style, GdkWindow *window
 * Assertion: Attaches a style to a window; this process allocates the colors and creates the GC's for the style - it specializes it to a particular visual and colormap.' 
 * Params Values: GtkStyle *style, GdkWindow *window
 * Expected: GtkStyle*  
 */
static void test_purpose_5()
{
    #define WIDGET gtk_entry_new ()
    
    GtkStyle* style;
    GtkStyle* ret_style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkWindowAttr attributes;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    
    if (!window)
    {
        TEST_FAIL ("window = NULL", NULL);
        return;
    }
    
    ret_style = gtk_style_attach (style, window);
    if (!ret_style)
    {
        TEST_FAIL ("gtk_style_attach() returned NULL", NULL);
    }
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_style_attach
 * Params: void
 * Returns: GtkStyle *style, GdkWindow *window
 * Assertion: Attaches a style to a window; this process allocates the colors and creates the GC's for the style - it specializes it to a particular visual and colormap.' 
 * Params Values: GtkStyle *style, GdkWindow *window
 * Expected: GtkStyle*  
 */
static void test_purpose_6()
{
    #define WIDGET gtk_spin_button_new_with_range (0, 100, 10)
    
    GtkStyle* style;
    GtkStyle* ret_style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkWindowAttr attributes;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    
    if (!window)
    {
        TEST_FAIL ("window = NULL", NULL);
        return;
    }
    
    ret_style = gtk_style_attach (style, window);
    if (!ret_style)
    {
        TEST_FAIL ("gtk_style_attach() returned NULL", NULL);
    }
    
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_border_copy
 * Params: const GtkBorder *border
 * Returns: GtkBorder*
 * Assertion: Copies a GtkBorder structure.
 * Params Values: a newly created GtkBorder*
 * Expected: a copy of that newly created GtkBorder*  
 */
static void test_purpose_7()
{
    #define LEFT 0
    #define RIGHT 0
    #define TOP 0
    #define BOTTOM 0
    
    GtkBorder border;
    GtkBorder* border_copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    border.left = LEFT; 
    border.right = RIGHT; 
    border.top = TOP; 
    border.bottom = BOTTOM; 
    
    border_copy = gtk_border_copy (&border);
    
    if (!border_copy)
    {
        TEST_FAIL ("border_copy = NULL", NULL);
        return;
    }
    
    if (border_copy->left != border.left)
    {
        TEST_FAIL ("border.left = %d, border_copy.left = %d, they should be equal",
                   border.left, border_copy->left);
    }
    
    if (border_copy->right != border.right)
    {
        TEST_FAIL ("border.right = %d, border_copy.right = %d, they should be equal",
                   border.right, border_copy->right);
    }
    
    if (border_copy->top != border.top)
    {
        TEST_FAIL ("border.top = %d, border_copy.top = %d, they should be equal",
                   border.top, border_copy->top);
    }
    
    if (border_copy->bottom != border.bottom)
    {
        TEST_FAIL ("border.bottom = %d, border_copy.bottom = %d, they should be equal",
                   border.bottom, border_copy->bottom);
    }
    
    
    
    #undef LEFT
    #undef RIGHT
    #undef TOP
    #undef BOTTOM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_border_copy
 * Params: const GtkBorder *border
 * Returns: GtkBorder*
 * Assertion: Copies a GtkBorder structure.
 * Params Values: a newly created GtkBorder*
 * Expected: a copy of that newly created GtkBorder*  
 */
static void test_purpose_8()
{
    #define LEFT 0
    #define RIGHT 5
    #define TOP 0
    #define BOTTOM 5
    
    GtkBorder border;
    GtkBorder* border_copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    border.left = LEFT; 
    border.right = RIGHT; 
    border.top = TOP; 
    border.bottom = BOTTOM; 
    
    border_copy = gtk_border_copy (&border);
    
    if (!border_copy)
    {
        TEST_FAIL ("border_copy = NULL", NULL);
        return;
    }
    
    if (border_copy->left != border.left)
    {
        TEST_FAIL ("border.left = %d, border_copy.left = %d, they should be equal",
                   border.left, border_copy->left);
    }
    
    if (border_copy->right != border.right)
    {
        TEST_FAIL ("border.right = %d, border_copy.right = %d, they should be equal",
                   border.right, border_copy->right);
    }
    
    if (border_copy->top != border.top)
    {
        TEST_FAIL ("border.top = %d, border_copy.top = %d, they should be equal",
                   border.top, border_copy->top);
    }
    
    if (border_copy->bottom != border.bottom)
    {
        TEST_FAIL ("border.bottom = %d, border_copy.bottom = %d, they should be equal",
                   border.bottom, border_copy->bottom);
    }
    
    
    
    #undef LEFT
    #undef RIGHT
    #undef TOP
    #undef BOTTOM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_border_copy
 * Params: const GtkBorder *border
 * Returns: GtkBorder*
 * Assertion: Copies a GtkBorder structure.
 * Params Values: a newly created GtkBorder*
 * Expected: a copy of that newly created GtkBorder*  
 */
static void test_purpose_9()
{
    #define LEFT 2
    #define RIGHT 5
    #define TOP 2
    #define BOTTOM 5
    
    GtkBorder border;
    GtkBorder* border_copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    border.left = LEFT; 
    border.right = RIGHT; 
    border.top = TOP; 
    border.bottom = BOTTOM; 
    
    border_copy = gtk_border_copy (&border);
    
    if (!border_copy)
    {
        TEST_FAIL ("border_copy = NULL", NULL);
        return;
    }
    
    if (border_copy->left != border.left)
    {
        TEST_FAIL ("border.left = %d, border_copy.left = %d, they should be equal",
                   border.left, border_copy->left);
    }
    
    if (border_copy->right != border.right)
    {
        TEST_FAIL ("border.right = %d, border_copy.right = %d, they should be equal",
                   border.right, border_copy->right);
    }
    
    if (border_copy->top != border.top)
    {
        TEST_FAIL ("border.top = %d, border_copy.top = %d, they should be equal",
                   border.top, border_copy->top);
    }
    
    if (border_copy->bottom != border.bottom)
    {
        TEST_FAIL ("border.bottom = %d, border_copy.bottom = %d, they should be equal",
                   border.bottom, border_copy->bottom);
    }
    
    
    
    #undef LEFT
    #undef RIGHT
    #undef TOP
    #undef BOTTOM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_border_copy
 * Params: const GtkBorder *border
 * Returns: GtkBorder*
 * Assertion: Copies a GtkBorder structure.
 * Params Values: a newly created GtkBorder*
 * Expected: a copy of that newly created GtkBorder*  
 */
static void test_purpose_10()
{
    #define LEFT 102
    #define RIGHT 1055
    #define TOP 102
    #define BOTTOM 1455
    
    GtkBorder border;
    GtkBorder* border_copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    border.left = LEFT; 
    border.right = RIGHT; 
    border.top = TOP; 
    border.bottom = BOTTOM; 
    
    border_copy = gtk_border_copy (&border);
    
    if (!border_copy)
    {
        TEST_FAIL ("border_copy = NULL", NULL);
        return;
    }
    
    if (border_copy->left != border.left)
    {
        TEST_FAIL ("border.left = %d, border_copy.left = %d, they should be equal",
                   border.left, border_copy->left);
    }
    
    if (border_copy->right != border.right)
    {
        TEST_FAIL ("border.right = %d, border_copy.right = %d, they should be equal",
                   border.right, border_copy->right);
    }
    
    if (border_copy->top != border.top)
    {
        TEST_FAIL ("border.top = %d, border_copy.top = %d, they should be equal",
                   border.top, border_copy->top);
    }
    
    if (border_copy->bottom != border.bottom)
    {
        TEST_FAIL ("border.bottom = %d, border_copy.bottom = %d, they should be equal",
                   border.bottom, border_copy->bottom);
    }
    
    
    
    #undef LEFT
    #undef RIGHT
    #undef TOP
    #undef BOTTOM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_border_free
 * Params: const GtkBorder *border
 * Returns: void
 * Assertion: Frees a GtkBorder structure.
 * Params Values: a newly created GtkBorder*
 * Expected: void  
 */
static void test_purpose_11()
{
    #define LEFT 0
    #define RIGHT 0
    #define TOP 0
    #define BOTTOM 0
    
    GtkBorder border;
    GtkBorder* border_copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    border.left = LEFT; 
    border.right = RIGHT; 
    border.top = TOP; 
    border.bottom = BOTTOM; 
    
    border_copy = gtk_border_copy (&border);
    gtk_border_free (border_copy);
    
    #undef LEFT
    #undef RIGHT
    #undef TOP
    #undef BOTTOM
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_border_free
 * Params: const GtkBorder *border
 * Returns: void
 * Assertion: Frees a GtkBorder structure.
 * Params Values: a newly created GtkBorder*
 * Expected: void  
 */
static void test_purpose_12()
{
    #define LEFT 0
    #define RIGHT 5
    #define TOP 0
    #define BOTTOM 5
    
    GtkBorder border;
    GtkBorder* border_copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    border.left = LEFT; 
    border.right = RIGHT; 
    border.top = TOP; 
    border.bottom = BOTTOM; 
    
    border_copy = gtk_border_copy (&border);
    gtk_border_free (border_copy);
    
    #undef LEFT
    #undef RIGHT
    #undef TOP
    #undef BOTTOM
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_border_free
 * Params: const GtkBorder *border
 * Returns: void
 * Assertion: Frees a GtkBorder structure.
 * Params Values: a newly created GtkBorder*
 * Expected: void  
 */
static void test_purpose_13()
{
    #define LEFT 2
    #define RIGHT 5
    #define TOP 2
    #define BOTTOM 5
    
    GtkBorder border;
    GtkBorder* border_copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    border.left = LEFT; 
    border.right = RIGHT; 
    border.top = TOP; 
    border.bottom = BOTTOM; 
    
    border_copy = gtk_border_copy (&border);
    gtk_border_free (border_copy);
    
    #undef LEFT
    #undef RIGHT
    #undef TOP
    #undef BOTTOM
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_border_free
 * Params: const GtkBorder *border
 * Returns: void
 * Assertion: Frees a GtkBorder structure.
 * Params Values: a newly created GtkBorder*
 * Expected: void  
 */
static void test_purpose_14()
{
    #define LEFT 102
    #define RIGHT 1055
    #define TOP 102
    #define BOTTOM 1455
    
    GtkBorder border;
    GtkBorder* border_copy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    border.left = LEFT; 
    border.right = RIGHT; 
    border.top = TOP; 
    border.bottom = BOTTOM; 
    
    border_copy = gtk_border_copy (&border);
    gtk_border_free (border_copy);
    
    #undef LEFT
    #undef RIGHT
    #undef TOP
    #undef BOTTOM
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_set_background
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type
 * Returns: void
 * Assertion: Sets the background of window to the background color or pixmap specified by style for the given state.
 * Params Values: a newly created GtkStyle*, a newly created GdkWindow*, GTK_STATE_NORMAL
 * Expected: a newly created GtkStyle*  
 */
static void test_purpose_15()
{
    #define STATE_TYPE GTK_STATE_NORMAL
    
    GtkStyle* style;
    GdkWindow* window;
    GtkWidget* widget;
    GdkWindowAttr attributes;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = gtk_button_new ();
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    
    gtk_style_set_background (style, window, STATE_TYPE);
    
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_set_background
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type
 * Returns: void
 * Assertion: Sets the background of window to the background color or pixmap specified by style for the given state.
 * Params Values: a newly created GtkStyle*, a newly created GdkWindow*, GTK_STATE_ACTIVE
 * Expected: a newly created GtkStyle*  
 */
static void test_purpose_16()
{
    #define STATE_TYPE GTK_STATE_ACTIVE
    
    GtkStyle* style;
    GdkWindow* window;
    GtkWidget* widget;
    GdkWindowAttr attributes;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = gtk_button_new ();
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    
    gtk_style_set_background (style, window, STATE_TYPE);
    
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_set_background
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type
 * Returns: void
 * Assertion: Sets the background of window to the background color or pixmap specified by style for the given state.
 * Params Values: a newly created GtkStyle*, a newly created GdkWindow*, GTK_STATE_PRELIGHT
 * Expected: a newly created GtkStyle*  
 */
static void test_purpose_17()
{
    #define STATE_TYPE GTK_STATE_PRELIGHT
    
    GtkStyle* style;
    GdkWindow* window;
    GtkWidget* widget;
    GdkWindowAttr attributes;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = gtk_button_new ();
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    
    gtk_style_set_background (style, window, STATE_TYPE);
    
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_set_background
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type
 * Returns: void
 * Assertion: Sets the background of window to the background color or pixmap specified by style for the given state.
 * Params Values: a newly created GtkStyle*, a newly created GdkWindow*, GTK_STATE_SELECTED
 * Expected: a newly created GtkStyle*  
 */
static void test_purpose_18()
{
    #define STATE_TYPE GTK_STATE_SELECTED
    
    GtkStyle* style;
    GdkWindow* window;
    GtkWidget* widget;
    GdkWindowAttr attributes;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = gtk_button_new ();
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    
    gtk_style_set_background (style, window, STATE_TYPE);
    
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_set_background
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type
 * Returns: void
 * Assertion: Sets the background of window to the background color or pixmap specified by style for the given state.
 * Params Values: a newly created GtkStyle*, a newly created GdkWindow*, GTK_STATE_INSENSITIVE
 * Expected: a newly created GtkStyle*  
 */
static void test_purpose_19()
{
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    
    GtkStyle* style;
    GdkWindow* window;
    GtkWidget* widget;
    GdkWindowAttr attributes;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = gtk_button_new ();
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    
    gtk_style_set_background (style, window, STATE_TYPE);
    
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_render_icon
 * Params: GtkStyle *style, const GtkIconSource *source, GtkTextDirection direction, GtkStateType state, GtkIconSize size, GtkWidget *widget, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: Renders the icon specified by source at the given size according to the given parameters and returns the result in a pixbuf.
 * Params Values: a newly created GtkStyle*, a newly created GtkIconSource*, GTK_TEXT_DIR_NONE, GTK_STATE_NORMAL, GTK_ICON_SIZE_MENU, gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN), NULL
 * Expected: GdkPixbuf*  
 */
static void test_purpose_20()
{
    #define TEXT_DIRECTION GTK_TEXT_DIR_NONE
    #define STATE_TYPE GTK_STATE_NORMAL
    #define ICON_SIZE GTK_ICON_SIZE_MENU
    #define WIDGET gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN)
    
    GtkStyle* style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkPixbuf* res;
    GdkWindowAttr attributes;
    GtkIconSource* icon_source;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    gtk_style_attach (style, window);
    
    icon_source = gtk_icon_source_new();
    gtk_icon_source_set_pixbuf (icon_source, gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 5, 10));
    
    res = gtk_style_render_icon (style, icon_source, TEXT_DIRECTION,
                                 STATE_TYPE, ICON_SIZE, widget, NULL);
    
    if (!res)
    {
        TEST_FAIL ("gtk_style_render_icon() returned NULL", NULL);
    }
    
    #undef TEXT_DIRECTION
    #undef STATE_TYPE
    #undef ICON_SIZE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_render_icon
 * Params: GtkStyle *style, const GtkIconSource *source, GtkTextDirection direction, GtkStateType state, GtkIconSize size, GtkWidget *widget, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: Renders the icon specified by source at the given size according to the given parameters and returns the result in a pixbuf.
 * Params Values: a newly created GtkStyle*, a newly created GtkIconSource*, GTK_TEXT_DIR_LTR, GTK_STATE_NORMAL, GTK_ICON_SIZE_MENU, gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN), NULL
 * Expected: GdkPixbuf*  
 */
static void test_purpose_21()
{
    #define TEXT_DIRECTION GTK_TEXT_DIR_LTR
    #define STATE_TYPE GTK_STATE_NORMAL
    #define ICON_SIZE GTK_ICON_SIZE_MENU
    #define WIDGET gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN)
    
    GtkStyle* style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkPixbuf* res;
    GdkWindowAttr attributes;
    GtkIconSource* icon_source;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    gtk_style_attach (style, window);
    
    icon_source = gtk_icon_source_new();
    gtk_icon_source_set_pixbuf (icon_source, gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 5, 10));
    
    res = gtk_style_render_icon (style, icon_source, TEXT_DIRECTION,
                                 STATE_TYPE, ICON_SIZE, widget, NULL);
    
    if (!res)
    {
        TEST_FAIL ("gtk_style_render_icon() returned NULL", NULL);
    }
    
    #undef TEXT_DIRECTION
    #undef STATE_TYPE
    #undef ICON_SIZE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_render_icon
 * Params: GtkStyle *style, const GtkIconSource *source, GtkTextDirection direction, GtkStateType state, GtkIconSize size, GtkWidget *widget, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: Renders the icon specified by source at the given size according to the given parameters and returns the result in a pixbuf.
 * Params Values: a newly created GtkStyle*, a newly created GtkIconSource*, GTK_TEXT_DIR_RTL, GTK_STATE_NORMAL, GTK_ICON_SIZE_MENU, gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN), NULL
 * Expected: GdkPixbuf*  
 */
static void test_purpose_22()
{
    #define TEXT_DIRECTION GTK_TEXT_DIR_RTL
    #define STATE_TYPE GTK_STATE_NORMAL
    #define ICON_SIZE GTK_ICON_SIZE_MENU
    #define WIDGET gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN)
    
    GtkStyle* style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkPixbuf* res;
    GdkWindowAttr attributes;
    GtkIconSource* icon_source;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    gtk_style_attach (style, window);
    
    icon_source = gtk_icon_source_new();
    gtk_icon_source_set_pixbuf (icon_source, gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 5, 10));
    
    res = gtk_style_render_icon (style, icon_source, TEXT_DIRECTION,
                                 STATE_TYPE, ICON_SIZE, widget, NULL);
    
    if (!res)
    {
        TEST_FAIL ("gtk_style_render_icon() returned NULL", NULL);
    }
    
    #undef TEXT_DIRECTION
    #undef STATE_TYPE
    #undef ICON_SIZE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_render_icon
 * Params: GtkStyle *style, const GtkIconSource *source, GtkTextDirection direction, GtkStateType state, GtkIconSize size, GtkWidget *widget, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: Renders the icon specified by source at the given size according to the given parameters and returns the result in a pixbuf.
 * Params Values: a newly created GtkStyle*, a newly created GtkIconSource*, GTK_TEXT_DIR_LTR, GTK_STATE_ACTIVE, GTK_ICON_SIZE_MENU, gtk_button_new ();, NULL
 * Expected: GdkPixbuf*  
 */
static void test_purpose_23()
{
    #define TEXT_DIRECTION GTK_TEXT_DIR_LTR
    #define STATE_TYPE GTK_STATE_ACTIVE
    #define ICON_SIZE GTK_ICON_SIZE_MENU
    #define WIDGET gtk_button_new ();
    
    GtkStyle* style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkPixbuf* res;
    GdkWindowAttr attributes;
    GtkIconSource* icon_source;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    gtk_style_attach (style, window);
    
    icon_source = gtk_icon_source_new();
    gtk_icon_source_set_pixbuf (icon_source, gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 5, 10));
    
    res = gtk_style_render_icon (style, icon_source, TEXT_DIRECTION,
                                 STATE_TYPE, ICON_SIZE, widget, NULL);
    
    if (!res)
    {
        TEST_FAIL ("gtk_style_render_icon() returned NULL", NULL);
    }
    
    #undef TEXT_DIRECTION
    #undef STATE_TYPE
    #undef ICON_SIZE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_render_icon
 * Params: GtkStyle *style, const GtkIconSource *source, GtkTextDirection direction, GtkStateType state, GtkIconSize size, GtkWidget *widget, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: Renders the icon specified by source at the given size according to the given parameters and returns the result in a pixbuf.
 * Params Values: a newly created GtkStyle*, a newly created GtkIconSource*, GTK_TEXT_DIR_LTR, GTK_STATE_PRELIGHT, GTK_ICON_SIZE_MENU, gtk_button_new ();, NULL
 * Expected: GdkPixbuf*  
 */
static void test_purpose_24()
{
    #define TEXT_DIRECTION GTK_TEXT_DIR_LTR
    #define STATE_TYPE GTK_STATE_PRELIGHT
    #define ICON_SIZE GTK_ICON_SIZE_MENU
    #define WIDGET gtk_button_new ();
    
    GtkStyle* style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkPixbuf* res;
    GdkWindowAttr attributes;
    GtkIconSource* icon_source;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    gtk_style_attach (style, window);
    
    icon_source = gtk_icon_source_new();
    gtk_icon_source_set_pixbuf (icon_source, gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 5, 10));
    
    res = gtk_style_render_icon (style, icon_source, TEXT_DIRECTION,
                                 STATE_TYPE, ICON_SIZE, widget, NULL);
    
    if (!res)
    {
        TEST_FAIL ("gtk_style_render_icon() returned NULL", NULL);
    }
    
    #undef TEXT_DIRECTION
    #undef STATE_TYPE
    #undef ICON_SIZE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_render_icon
 * Params: GtkStyle *style, const GtkIconSource *source, GtkTextDirection direction, GtkStateType state, GtkIconSize size, GtkWidget *widget, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: Renders the icon specified by source at the given size according to the given parameters and returns the result in a pixbuf.
 * Params Values: a newly created GtkStyle*, a newly created GtkIconSource*, GTK_TEXT_DIR_LTR, GTK_STATE_SELECTED, GTK_ICON_SIZE_MENU, gtk_button_new ();, NULL
 * Expected: GdkPixbuf*  
 */
static void test_purpose_25()
{
    #define TEXT_DIRECTION GTK_TEXT_DIR_LTR
    #define STATE_TYPE GTK_STATE_SELECTED
    #define ICON_SIZE GTK_ICON_SIZE_MENU
    #define WIDGET gtk_button_new ();
    
    GtkStyle* style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkPixbuf* res;
    GdkWindowAttr attributes;
    GtkIconSource* icon_source;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    gtk_style_attach (style, window);
    
    icon_source = gtk_icon_source_new();
    gtk_icon_source_set_pixbuf (icon_source, gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 5, 10));
    
    res = gtk_style_render_icon (style, icon_source, TEXT_DIRECTION,
                                 STATE_TYPE, ICON_SIZE, widget, NULL);
    
    if (!res)
    {
        TEST_FAIL ("gtk_style_render_icon() returned NULL", NULL);
    }
    
    #undef TEXT_DIRECTION
    #undef STATE_TYPE
    #undef ICON_SIZE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_render_icon
 * Params: GtkStyle *style, const GtkIconSource *source, GtkTextDirection direction, GtkStateType state, GtkIconSize size, GtkWidget *widget, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: Renders the icon specified by source at the given size according to the given parameters and returns the result in a pixbuf.
 * Params Values: a newly created GtkStyle*, a newly created GtkIconSource*, GTK_TEXT_DIR_LTR, GTK_STATE_INSENSITIVE, GTK_ICON_SIZE_MENU, gtk_button_new ();, NULL
 * Expected: GdkPixbuf*  
 */
static void test_purpose_26()
{
    #define TEXT_DIRECTION GTK_TEXT_DIR_LTR
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define ICON_SIZE GTK_ICON_SIZE_MENU
    #define WIDGET gtk_button_new ();
    
    GtkStyle* style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkPixbuf* res;
    GdkWindowAttr attributes;
    GtkIconSource* icon_source;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    gtk_style_attach (style, window);
    
    icon_source = gtk_icon_source_new();
    gtk_icon_source_set_pixbuf (icon_source, gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 5, 10));
    
    res = gtk_style_render_icon (style, icon_source, TEXT_DIRECTION,
                                 STATE_TYPE, ICON_SIZE, widget, NULL);
    
    if (!res)
    {
        TEST_FAIL ("gtk_style_render_icon() returned NULL", NULL);
    }
    
    #undef TEXT_DIRECTION
    #undef STATE_TYPE
    #undef ICON_SIZE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_render_icon
 * Params: GtkStyle *style, const GtkIconSource *source, GtkTextDirection direction, GtkStateType state, GtkIconSize size, GtkWidget *widget, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: Renders the icon specified by source at the given size according to the given parameters and returns the result in a pixbuf.
 * Params Values: a newly created GtkStyle*, a newly created GtkIconSource*, GTK_TEXT_DIR_LTR, GTK_STATE_INSENSITIVE, GTK_ICON_SIZE_MENU, gtk_image_menu_item_new ();, NULL
 * Expected: GdkPixbuf*  
 */
static void test_purpose_27()
{
    #define TEXT_DIRECTION GTK_TEXT_DIR_LTR
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define ICON_SIZE GTK_ICON_SIZE_MENU
    #define WIDGET gtk_image_menu_item_new ();
    
    GtkStyle* style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkPixbuf* res;
    GdkWindowAttr attributes;
    GtkIconSource* icon_source;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    gtk_style_attach (style, window);
    
    icon_source = gtk_icon_source_new();
    gtk_icon_source_set_pixbuf (icon_source, gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 5, 10));
    
    res = gtk_style_render_icon (style, icon_source, TEXT_DIRECTION,
                                 STATE_TYPE, ICON_SIZE, widget, NULL);
    
    if (!res)
    {
        TEST_FAIL ("gtk_style_render_icon() returned NULL", NULL);
    }
    
    #undef TEXT_DIRECTION
    #undef STATE_TYPE
    #undef ICON_SIZE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_render_icon
 * Params: GtkStyle *style, const GtkIconSource *source, GtkTextDirection direction, GtkStateType state, GtkIconSize size, GtkWidget *widget, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: Renders the icon specified by source at the given size according to the given parameters and returns the result in a pixbuf.
 * Params Values: a newly created GtkStyle*, a newly created GtkIconSource*, GTK_TEXT_DIR_LTR, GTK_STATE_INSENSITIVE, GTK_ICON_SIZE_SMALL_TOOLBAR, gtk_image_menu_item_new ();, NULL
 * Expected: GdkPixbuf*  
 */
static void test_purpose_28()
{
    #define TEXT_DIRECTION GTK_TEXT_DIR_LTR
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define ICON_SIZE GTK_ICON_SIZE_SMALL_TOOLBAR
    #define WIDGET gtk_image_menu_item_new ();
    
    GtkStyle* style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkPixbuf* res;
    GdkWindowAttr attributes;
    GtkIconSource* icon_source;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    gtk_style_attach (style, window);
    
    icon_source = gtk_icon_source_new();
    gtk_icon_source_set_pixbuf (icon_source, gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 5, 10));
    
    res = gtk_style_render_icon (style, icon_source, TEXT_DIRECTION,
                                 STATE_TYPE, ICON_SIZE, widget, NULL);
    
    if (!res)
    {
        TEST_FAIL ("gtk_style_render_icon() returned NULL", NULL);
    }
    
    #undef TEXT_DIRECTION
    #undef STATE_TYPE
    #undef ICON_SIZE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_render_icon
 * Params: GtkStyle *style, const GtkIconSource *source, GtkTextDirection direction, GtkStateType state, GtkIconSize size, GtkWidget *widget, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: Renders the icon specified by source at the given size according to the given parameters and returns the result in a pixbuf.
 * Params Values: a newly created GtkStyle*, a newly created GtkIconSource*, GTK_TEXT_DIR_LTR, GTK_STATE_INSENSITIVE, GTK_ICON_SIZE_LARGE_TOOLBAR, gtk_image_menu_item_new ();, NULL
 * Expected: GdkPixbuf*  
 */
static void test_purpose_29()
{
    #define TEXT_DIRECTION GTK_TEXT_DIR_LTR
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define ICON_SIZE GTK_ICON_SIZE_LARGE_TOOLBAR
    #define WIDGET gtk_image_menu_item_new ();
    
    GtkStyle* style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkPixbuf* res;
    GdkWindowAttr attributes;
    GtkIconSource* icon_source;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    gtk_style_attach (style, window);
    
    icon_source = gtk_icon_source_new();
    gtk_icon_source_set_pixbuf (icon_source, gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 5, 10));
    
    res = gtk_style_render_icon (style, icon_source, TEXT_DIRECTION,
                                 STATE_TYPE, ICON_SIZE, widget, NULL);
    
    if (!res)
    {
        TEST_FAIL ("gtk_style_render_icon() returned NULL", NULL);
    }
    
    #undef TEXT_DIRECTION
    #undef STATE_TYPE
    #undef ICON_SIZE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_render_icon
 * Params: GtkStyle *style, const GtkIconSource *source, GtkTextDirection direction, GtkStateType state, GtkIconSize size, GtkWidget *widget, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: Renders the icon specified by source at the given size according to the given parameters and returns the result in a pixbuf.
 * Params Values: a newly created GtkStyle*, a newly created GtkIconSource*, GTK_TEXT_DIR_LTR, GTK_STATE_INSENSITIVE, GTK_ICON_SIZE_BUTTON, gtk_image_menu_item_new ();, NULL
 * Expected: GdkPixbuf*  
 */
static void test_purpose_30()
{
    #define TEXT_DIRECTION GTK_TEXT_DIR_LTR
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define ICON_SIZE GTK_ICON_SIZE_BUTTON
    #define WIDGET gtk_image_menu_item_new ();
    
    GtkStyle* style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkPixbuf* res;
    GdkWindowAttr attributes;
    GtkIconSource* icon_source;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    gtk_style_attach (style, window);
    
    icon_source = gtk_icon_source_new();
    gtk_icon_source_set_pixbuf (icon_source, gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 5, 10));
    
    res = gtk_style_render_icon (style, icon_source, TEXT_DIRECTION,
                                 STATE_TYPE, ICON_SIZE, widget, NULL);
    
    if (!res)
    {
        TEST_FAIL ("gtk_style_render_icon() returned NULL", NULL);
    }
    
    #undef TEXT_DIRECTION
    #undef STATE_TYPE
    #undef ICON_SIZE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_render_icon
 * Params: GtkStyle *style, const GtkIconSource *source, GtkTextDirection direction, GtkStateType state, GtkIconSize size, GtkWidget *widget, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: Renders the icon specified by source at the given size according to the given parameters and returns the result in a pixbuf.
 * Params Values: a newly created GtkStyle*, a newly created GtkIconSource*, GTK_TEXT_DIR_LTR, GTK_STATE_INSENSITIVE, GTK_ICON_SIZE_DND, gtk_image_menu_item_new ();, NULL
 * Expected: GdkPixbuf*  
 */
static void test_purpose_31()
{
    #define TEXT_DIRECTION GTK_TEXT_DIR_LTR
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define ICON_SIZE GTK_ICON_SIZE_DND
    #define WIDGET gtk_image_menu_item_new ();
    
    GtkStyle* style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkPixbuf* res;
    GdkWindowAttr attributes;
    GtkIconSource* icon_source;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    gtk_style_attach (style, window);
    
    icon_source = gtk_icon_source_new();
    gtk_icon_source_set_pixbuf (icon_source, gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 5, 10));
    
    res = gtk_style_render_icon (style, icon_source, TEXT_DIRECTION,
                                 STATE_TYPE, ICON_SIZE, widget, NULL);
    
    if (!res)
    {
        TEST_FAIL ("gtk_style_render_icon() returned NULL", NULL);
    }
    
    #undef TEXT_DIRECTION
    #undef STATE_TYPE
    #undef ICON_SIZE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_render_icon
 * Params: GtkStyle *style, const GtkIconSource *source, GtkTextDirection direction, GtkStateType state, GtkIconSize size, GtkWidget *widget, const gchar *detail
 * Returns: GdkPixbuf*
 * Assertion: Renders the icon specified by source at the given size according to the given parameters and returns the result in a pixbuf.
 * Params Values: a newly created GtkStyle*, a newly created GtkIconSource*, GTK_TEXT_DIR_LTR, GTK_STATE_INSENSITIVE, GTK_ICON_SIZE_DIALOG, gtk_image_menu_item_new ();, NULL
 * Expected: GdkPixbuf*  
 */
static void test_purpose_32()
{
    #define TEXT_DIRECTION GTK_TEXT_DIR_LTR
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define ICON_SIZE GTK_ICON_SIZE_DIALOG
    #define WIDGET gtk_image_menu_item_new ();
    
    GtkStyle* style;
    GtkWidget* widget;
    GdkWindow* window;
    GdkPixbuf* res;
    GdkWindowAttr attributes;
    GtkIconSource* icon_source;
    gint attributes_mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget = WIDGET;
    
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual (widget);
    attributes.colormap = gtk_widget_get_colormap (widget);
    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
    
    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
    
    window = gdk_window_new (NULL, &attributes, attributes_mask);
    gtk_style_attach (style, window);
    
    icon_source = gtk_icon_source_new();
    gtk_icon_source_set_pixbuf (icon_source, gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 5, 10));
    
    res = gtk_style_render_icon (style, icon_source, TEXT_DIRECTION,
                                 STATE_TYPE, ICON_SIZE, widget, NULL);
    
    if (!res)
    {
        TEST_FAIL ("gtk_style_render_icon() returned NULL", NULL);
    }
    
    #undef TEXT_DIRECTION
    #undef STATE_TYPE
    #undef ICON_SIZE
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_hline
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x1, gint x2, gint y
 * Returns: void
 * Assertion: Draws a horizontal line from (x1, y) to (x2, y) in window using the given style and state.
 * Params Values: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x1, gint x2, gint y
 * Expected: void  
 */
static void test_purpose_33()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN)
    #define RECT 0, 0, 1, 1
    #define X1 0
    #define X2 5
    #define Y 0
    #define STATE_TYPE GTK_STATE_NORMAL
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_hline (style, widget->window, STATE_TYPE, &rect, widget, NULL, X1, X2, Y);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X1
    #undef X2
    #undef Y
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_hline
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x1, gint x2, gint y
 * Returns: void
 * Assertion: Draws a horizontal line from (x1, y) to (x2, y) in window using the given style and state.
 * Params Values: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x1, gint x2, gint y
 * Expected: void  
 */
static void test_purpose_34()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X1 1
    #define X2 50
    #define Y 2
    #define STATE_TYPE GTK_STATE_NORMAL
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_hline (style, widget->window, STATE_TYPE, &rect, widget, NULL, X1, X2, Y);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X1
    #undef X2
    #undef Y
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_hline
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x1, gint x2, gint y
 * Returns: void
 * Assertion: Draws a horizontal line from (x1, y) to (x2, y) in window using the given style and state.
 * Params Values: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x1, gint x2, gint y
 * Expected: void  
 */
static void test_purpose_35()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X1 1
    #define X2 50
    #define Y 2
    #define STATE_TYPE GTK_STATE_ACTIVE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_hline (style, widget->window, STATE_TYPE, &rect, widget, NULL, X1, X2, Y);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X1
    #undef X2
    #undef Y
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_hline
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x1, gint x2, gint y
 * Returns: void
 * Assertion: Draws a horizontal line from (x1, y) to (x2, y) in window using the given style and state.
 * Params Values: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x1, gint x2, gint y
 * Expected: void  
 */
static void test_purpose_36()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X1 1
    #define X2 50
    #define Y 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_hline (style, widget->window, STATE_TYPE, &rect, widget, NULL, X1, X2, Y);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X1
    #undef X2
    #undef Y
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_hline
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x1, gint x2, gint y
 * Returns: void
 * Assertion: Draws a horizontal line from (x1, y) to (x2, y) in window using the given style and state.
 * Params Values: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x1, gint x2, gint y
 * Expected: void  
 */
static void test_purpose_37()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X1 1
    #define X2 50
    #define Y 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_hline (style, widget->window, STATE_TYPE, &rect, widget, NULL, X1, X2, Y);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X1
    #undef X2
    #undef Y
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_hline
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x1, gint x2, gint y
 * Returns: void
 * Assertion: Draws a horizontal line from (x1, y) to (x2, y) in window using the given style and state.
 * Params Values: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x1, gint x2, gint y
 * Expected: void  
 */
static void test_purpose_38()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X1 50
    #define X2 50
    #define Y 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_hline (style, widget->window, STATE_TYPE, &rect, widget, NULL, X1, X2, Y);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X1
    #undef X2
    #undef Y
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_hline
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x1, gint x2, gint y
 * Returns: void
 * Assertion: Draws a horizontal line from (x1, y) to (x2, y) in window using the given style and state.
 * Params Values: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x1, gint x2, gint y
 * Expected: void  
 */
static void test_purpose_39()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 100, 100, 100, 100
    #define X1 1
    #define X2 50
    #define Y 2
    #define STATE_TYPE GTK_STATE_NORMAL
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_hline (style, widget->window, STATE_TYPE, &rect, widget, NULL, X1, X2, Y);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X1
    #undef X2
    #undef Y
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_vline
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint y1_, gint y2_, gint x
 * Returns: void
 * Assertion: Draws a vertical line from (x, y1_) to (x, y2_) in window using the given style and state.
 * Params Values: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint y1, gint y2, gint x
 * Expected: void  
 */
static void test_purpose_40()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN)
    #define RECT 0, 0, 1, 1
    #define Y1 0
    #define Y2 5
    #define X 0
    #define STATE_TYPE GTK_STATE_NORMAL
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_vline (style, widget->window, STATE_TYPE, &rect, widget, NULL, Y1, Y2, X);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef Y1
    #undef Y2
    #undef X
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_vline
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint y1_, gint y2_, gint x
 * Returns: void
 * Assertion: Draws a vertical line from (x, y1_) to (x, y2_) in window using the given style and state.
 * Params Values: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint y1, gint y2, gint x
 * Expected: void  
 */
static void test_purpose_41()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define Y1 1
    #define Y2 50
    #define X 2
    #define STATE_TYPE GTK_STATE_NORMAL
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_vline (style, widget->window, STATE_TYPE, &rect, widget, NULL, Y1, Y2, X);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef Y1
    #undef Y2
    #undef X
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_vline
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint y1_, gint y2_, gint x
 * Returns: void
 * Assertion: Draws a vertical line from (x, y1_) to (x, y2_) in window using the given style and state.
 * Params Values: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint y1, gint y2, gint x
 * Expected: void  
 */
static void test_purpose_42()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define Y1 1
    #define Y2 50
    #define X 2
    #define STATE_TYPE GTK_STATE_ACTIVE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_vline (style, widget->window, STATE_TYPE, &rect, widget, NULL, Y1, Y2, X);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef Y1
    #undef Y2
    #undef X
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_vline
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint y1_, gint y2_, gint x
 * Returns: void
 * Assertion: Draws a vertical line from (x, y1_) to (x, y2_) in window using the given style and state.
 * Params Values: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint y1, gint y2, gint x
 * Expected: void  
 */
static void test_purpose_43()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define Y1 1
    #define Y2 50
    #define X 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_vline (style, widget->window, STATE_TYPE, &rect, widget, NULL, Y1, Y2, X);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef Y1
    #undef Y2
    #undef X
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_vline
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint y1_, gint y2_, gint x
 * Returns: void
 * Assertion: Draws a vertical line from (x, y1_) to (x, y2_) in window using the given style and state.
 * Params Values: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint y1, gint y2, gint x
 * Expected: void  
 */
static void test_purpose_44()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define Y1 1
    #define Y2 50
    #define X 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_vline (style, widget->window, STATE_TYPE, &rect, widget, NULL, Y1, Y2, X);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef Y1
    #undef Y2
    #undef X
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_vline
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint y1_, gint y2_, gint x
 * Returns: void
 * Assertion: Draws a vertical line from (x, y1_) to (x, y2_) in window using the given style and state.
 * Params Values: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint y1, gint y2, gint x
 * Expected: void  
 */
static void test_purpose_45()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define Y1 50
    #define Y2 50
    #define X 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_vline (style, widget->window, STATE_TYPE, &rect, widget, NULL, Y1, Y2, X);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef Y1
    #undef Y2
    #undef X
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_vline
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint y1_, gint y2_, gint x
 * Returns: void
 * Assertion: Draws a vertical line from (x, y1_) to (x, y2_) in window using the given style and state.
 * Params Values: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint y1, gint y2, gint x
 * Expected: void  
 */
static void test_purpose_46()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 100, 100, 100, 100
    #define Y1 1
    #define Y2 50
    #define X 2
    #define STATE_TYPE GTK_STATE_NORMAL
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_vline (style, widget->window, STATE_TYPE, &rect, widget, NULL, Y1, Y2, X);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef Y1
    #undef Y2
    #undef X
    #undef STATE_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_copy
 * Params: GtkStyle *style
 * Returns: GtkStyle*
 * Assertion: 
 * Params Values: 
 * Expected:   
 */
static void test_purpose_47()
{
    #define STYLE gtk_style_new ()
    
    GtkStyle* style1;
    GtkStyle* style2;
    int i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style1 = STYLE;
    style2 = gtk_style_copy (style1);
    
    if (!style2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style2))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->fg[i], &style2->fg[i]))
        {
            TEST_FAIL ("foreground color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->bg[i], &style2->bg[i]))
        {
            TEST_FAIL ("background color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->light[i], &style2->light[i]))
        {
            TEST_FAIL ("light color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->dark[i], &style2->dark[i]))
        {
            TEST_FAIL ("dark color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->mid[i], &style2->mid[i]))
        {
            TEST_FAIL ("mid color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->text[i], &style2->text[i]))
        {
            TEST_FAIL ("text color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->base[i], &style2->base[i]))
        {
            TEST_FAIL ("base color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->text_aa[i], &style2->text_aa[i]))
        {
            TEST_FAIL ("text_aa color does not match after copy", NULL); 
        }
    }
    
    if (!gdk_color_equal (&style1->black, &style2->black))
    {
        TEST_FAIL ("black color does not match after copy", NULL); 
    }
    
    if (!gdk_color_equal (&style1->white, &style2->white))
    {
        TEST_FAIL ("white color does not match after copy", NULL); 
    }
    
    if (!pango_font_description_equal (style1->font_desc, style2->font_desc))
    {
        TEST_FAIL ("Pango font description does not match after copy", NULL); 
    }
    
    if (style1->xthickness != style2->xthickness)
    {
        TEST_FAIL ("X thickness does not match after copy", NULL); 
    }
    
    if (style1->ythickness != style2->ythickness)
    {
        TEST_FAIL ("Y thickness does not match after copy", NULL); 
    }
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_copy
 * Params: GtkStyle *style
 * Returns: GtkStyle*
 * Assertion: 
 * Params Values: 
 * Expected:   
 */
static void test_purpose_48()
{
    #define STYLE gtk_widget_get_style (gtk_button_new ())
    
    GtkStyle* style1;
    GtkStyle* style2;
    int i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style1 = STYLE;
    style2 = gtk_style_copy (style1);
    
    if (!style2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style2))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->fg[i], &style2->fg[i]))
        {
            TEST_FAIL ("foreground color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->bg[i], &style2->bg[i]))
        {
            TEST_FAIL ("background color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->light[i], &style2->light[i]))
        {
            TEST_FAIL ("light color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->dark[i], &style2->dark[i]))
        {
            TEST_FAIL ("dark color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->mid[i], &style2->mid[i]))
        {
            TEST_FAIL ("mid color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->text[i], &style2->text[i]))
        {
            TEST_FAIL ("text color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->base[i], &style2->base[i]))
        {
            TEST_FAIL ("base color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->text_aa[i], &style2->text_aa[i]))
        {
            TEST_FAIL ("text_aa color does not match after copy", NULL); 
        }
    }
    
    if (!gdk_color_equal (&style1->black, &style2->black))
    {
        TEST_FAIL ("black color does not match after copy", NULL); 
    }
    
    if (!gdk_color_equal (&style1->white, &style2->white))
    {
        TEST_FAIL ("white color does not match after copy", NULL); 
    }
    
    if (!pango_font_description_equal (style1->font_desc, style2->font_desc))
    {
        TEST_FAIL ("Pango font description does not match after copy", NULL); 
    }
    
    if (style1->xthickness != style2->xthickness)
    {
        TEST_FAIL ("X thickness does not match after copy", NULL); 
    }
    
    if (style1->ythickness != style2->ythickness)
    {
        TEST_FAIL ("Y thickness does not match after copy", NULL); 
    }
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_copy
 * Params: GtkStyle *style
 * Returns: GtkStyle*
 * Assertion: 
 * Params Values: 
 * Expected:   
 */
static void test_purpose_49()
{
    #define STYLE gtk_widget_get_style (gtk_window_new (GTK_WINDOW_TOPLEVEL))
    
    GtkStyle* style1;
    GtkStyle* style2;
    int i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style1 = STYLE;
    style2 = gtk_style_copy (style1);
    
    if (!style2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style2))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->fg[i], &style2->fg[i]))
        {
            TEST_FAIL ("foreground color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->bg[i], &style2->bg[i]))
        {
            TEST_FAIL ("background color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->light[i], &style2->light[i]))
        {
            TEST_FAIL ("light color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->dark[i], &style2->dark[i]))
        {
            TEST_FAIL ("dark color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->mid[i], &style2->mid[i]))
        {
            TEST_FAIL ("mid color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->text[i], &style2->text[i]))
        {
            TEST_FAIL ("text color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->base[i], &style2->base[i]))
        {
            TEST_FAIL ("base color does not match after copy", NULL); 
        }
    }
    
    for (i = 0; i < 5; i++)
    {
        if (!gdk_color_equal (&style1->text_aa[i], &style2->text_aa[i]))
        {
            TEST_FAIL ("text_aa color does not match after copy", NULL); 
        }
    }
    
    if (!gdk_color_equal (&style1->black, &style2->black))
    {
        TEST_FAIL ("black color does not match after copy", NULL); 
    }
    
    if (!gdk_color_equal (&style1->white, &style2->white))
    {
        TEST_FAIL ("white color does not match after copy", NULL); 
    }
    
    if (!pango_font_description_equal (style1->font_desc, style2->font_desc))
    {
        TEST_FAIL ("Pango font description does not match after copy", NULL); 
    }
    
    if (style1->xthickness != style2->xthickness)
    {
        TEST_FAIL ("X thickness does not match after copy", NULL); 
    }
    
    if (style1->ythickness != style2->ythickness)
    {
        TEST_FAIL ("Y thickness does not match after copy", NULL); 
    }
    
    #undef STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_lookup_icon_set
 * Params: GtkStyle *style, const gchar *stock_id
 * Returns: GtkIconSet*
 * Assertion: 
 * Params Values: 
 * Expected:   
 */
static void test_purpose_50()
{
    #define STOCK_ID GTK_STOCK_OPEN
    
    GtkStyle* style;
    GtkIconSet *icon_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    icon_set = NULL;
    
    icon_set = gtk_style_lookup_icon_set (style, STOCK_ID);
    
    if (!icon_set)
    {
        TEST_FAIL ("Can not lookup icon set", NULL); 
    }
    
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_lookup_icon_set
 * Params: GtkStyle *style, const gchar *stock_id
 * Returns: GtkIconSet*
 * Assertion: 
 * Params Values: 
 * Expected:   
 */
static void test_purpose_51()
{
    #define STOCK_ID GTK_STOCK_CLOSE
    
    GtkStyle* style;
    GtkIconSet *icon_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    icon_set = NULL;
    
    icon_set = gtk_style_lookup_icon_set (style, STOCK_ID);
    
    if (!icon_set)
    {
        TEST_FAIL ("Can not lookup icon set", NULL); 
    }
    
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_lookup_icon_set
 * Params: GtkStyle *style, const gchar *stock_id
 * Returns: GtkIconSet*
 * Assertion: 
 * Params Values: 
 * Expected:   
 */
static void test_purpose_52()
{
    #define STOCK_ID GTK_STOCK_CUT
    
    GtkStyle* style;
    GtkIconSet *icon_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    icon_set = NULL;
    
    icon_set = gtk_style_lookup_icon_set (style, STOCK_ID);
    
    if (!icon_set)
    {
        TEST_FAIL ("Can not lookup icon set", NULL); 
    }
    
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_lookup_icon_set
 * Params: GtkStyle *style, const gchar *stock_id
 * Returns: GtkIconSet*
 * Assertion: 
 * Params Values: 
 * Expected:   
 */
static void test_purpose_53()
{
    #define STOCK_ID GTK_STOCK_COPY
    
    GtkStyle* style;
    GtkIconSet *icon_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    icon_set = NULL;
    
    icon_set = gtk_style_lookup_icon_set (style, STOCK_ID);
    
    if (!icon_set)
    {
        TEST_FAIL ("Can not lookup icon set", NULL); 
    }
    
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_style_lookup_icon_set
 * Params: GtkStyle *style, const gchar *stock_id
 * Returns: GtkIconSet*
 * Assertion: 
 * Params Values: 
 * Expected:   
 */
static void test_purpose_54()
{
    #define STOCK_ID GTK_STOCK_ABOUT
    
    GtkStyle* style;
    GtkIconSet *icon_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = gtk_style_new ();
    
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_STYLE (style))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    icon_set = NULL;
    
    icon_set = gtk_style_lookup_icon_set (style, STOCK_ID);
    
    if (!icon_set)
    {
        TEST_FAIL ("Can not lookup icon set", NULL); 
    }
    
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_box
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a box on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the box, y origin of the box, the width of the box, the height of the box.
 * Expected: void  
 */
static void test_purpose_55()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN)
    #define RECT 0, 0, 1, 1
    #define X 0
    #define Y 0
    #define WIDTH 10
    #define HEIGHT 10
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_box (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_box
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a box on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the box, y origin of the box, the width of the box, the height of the box.
 * Expected: void  
 */
static void test_purpose_56()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 30
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_box (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_box
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a box on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the box, y origin of the box, the width of the box, the height of the box.
 * Expected: void  
 */
static void test_purpose_57()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 30
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_ACTIVE
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_box (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_box
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a box on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the box, y origin of the box, the width of the box, the height of the box.
 * Expected: void  
 */
static void test_purpose_58()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 10
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_box (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_box
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a box on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the box, y origin of the box, the width of the box, the height of the box.
 * Expected: void  
 */
static void test_purpose_59()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_box (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_box
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a box on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the box, y origin of the box, the width of the box, the height of the box.
 * Expected: void  
 */
static void test_purpose_60()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 50
    #define Y 50
    #define WIDTH 2
    #define HEIGHT 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_box (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_box
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a box on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the box, y origin of the box, the width of the box, the height of the box.
 * Expected: void  
 */
static void test_purpose_61()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 100, 100, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 20
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_box (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_shadow
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a shadow around the given rectangle in window using the given style and state and shadow type.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle, y origin of the rectangle, the width of the rectangle, the height of the rectangle.
 * Expected: void  
 */
static void test_purpose_62()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN)
    #define RECT 0, 0, 1, 1
    #define X 0
    #define Y 0
    #define WIDTH 10
    #define HEIGHT 10
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_shadow (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_shadow
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a shadow around the given rectangle in window using the given style and state and shadow type.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle, y origin of the rectangle, the width of the rectangle, the height of the rectangle.
 * Expected: void  
 */
static void test_purpose_63()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 30
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_shadow (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_shadow
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a shadow around the given rectangle in window using the given style and state and shadow type.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle, y origin of the rectangle, the width of the rectangle, the height of the rectangle.
 * Expected: void  
 */
static void test_purpose_64()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 30
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_ACTIVE
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_shadow (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_shadow
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a shadow around the given rectangle in window using the given style and state and shadow type.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle, y origin of the rectangle, the width of the rectangle, the height of the rectangle.
 * Expected: void  
 */
static void test_purpose_65()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 10
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_shadow (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_shadow
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a shadow around the given rectangle in window using the given style and state and shadow type.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle, y origin of the rectangle, the width of the rectangle, the height of the rectangle.
 * Expected: void  
 */
static void test_purpose_66()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_shadow (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_shadow
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a shadow around the given rectangle in window using the given style and state and shadow type.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle, y origin of the rectangle, the width of the rectangle, the height of the rectangle.
 * Expected: void  
 */
static void test_purpose_67()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 50
    #define Y 50
    #define WIDTH 2
    #define HEIGHT 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_shadow (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_shadow
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a shadow around the given rectangle in window using the given style and state and shadow type.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle, y origin of the rectangle, the width of the rectangle, the height of the rectangle.
 * Expected: void  
 */
static void test_purpose_68()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 100, 100, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 20
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_shadow (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_focus
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a focus indicator around the given rectangle on window using the given style.
 * Params Values: a GtkStyle, a GdkWindow, a state, clip rectangle, the widget, a style detail, the x origin of the rectangle around which to draw a focus indicator, the y origin of the rectangle around which to draw a focus indicator, the width of the rectangle around which to draw a focus indicator, the height of the rectangle around which to draw a focus indicator.
 * Expected: void  
 */
static void test_purpose_69()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN)
    #define RECT 0, 0, 1, 1
    #define X 0
    #define Y 0
    #define WIDTH 10
    #define HEIGHT 10
    #define STATE_TYPE GTK_STATE_NORMAL
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_focus (style, widget->window, STATE_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_focus
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a focus indicator around the given rectangle on window using the given style.
 * Params Values: a GtkStyle, a GdkWindow, a state, clip rectangle, the widget, a style detail, the x origin of the rectangle around which to draw a focus indicator, the y origin of the rectangle around which to draw a focus indicator, the width of the rectangle around which to draw a focus indicator, the height of the rectangle around which to draw a focus indicator.
 * Expected: void  
 */
static void test_purpose_70()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 30
    #define STATE_TYPE GTK_STATE_NORMAL
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_focus (style, widget->window, STATE_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_focus
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a focus indicator around the given rectangle on window using the given style.
 * Params Values: a GtkStyle, a GdkWindow, a state, clip rectangle, the widget, a style detail, the x origin of the rectangle around which to draw a focus indicator, the y origin of the rectangle around which to draw a focus indicator, the width of the rectangle around which to draw a focus indicator, the height of the rectangle around which to draw a focus indicator.
 * Expected: void  
 */
static void test_purpose_71()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 30
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_ACTIVE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_focus (style, widget->window, STATE_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_focus
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a focus indicator around the given rectangle on window using the given style.
 * Params Values: a GtkStyle, a GdkWindow, a state, clip rectangle, the widget, a style detail, the x origin of the rectangle around which to draw a focus indicator, the y origin of the rectangle around which to draw a focus indicator, the width of the rectangle around which to draw a focus indicator, the height of the rectangle around which to draw a focus indicator.
 * Expected: void  
 */
static void test_purpose_72()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 10
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_focus (style, widget->window, STATE_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_focus
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a focus indicator around the given rectangle on window using the given style.
 * Params Values: a GtkStyle, a GdkWindow, a state, clip rectangle, the widget, a style detail, the x origin of the rectangle around which to draw a focus indicator, the y origin of the rectangle around which to draw a focus indicator, the width of the rectangle around which to draw a focus indicator, the height of the rectangle around which to draw a focus indicator.
 * Expected: void  
 */
static void test_purpose_73()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_focus (style, widget->window, STATE_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_focus
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a focus indicator around the given rectangle on window using the given style.
 * Params Values: a GtkStyle, a GdkWindow, a state, clip rectangle, the widget, a style detail, the x origin of the rectangle around which to draw a focus indicator, the y origin of the rectangle around which to draw a focus indicator, the width of the rectangle around which to draw a focus indicator, the height of the rectangle around which to draw a focus indicator.
 * Expected: void  
 */
static void test_purpose_74()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 50
    #define Y 50
    #define WIDTH 2
    #define HEIGHT 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_focus (style, widget->window, STATE_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_focus
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a focus indicator around the given rectangle on window using the given style.
 * Params Values: a GtkStyle, a GdkWindow, a state, clip rectangle, the widget, a style detail, the x origin of the rectangle around which to draw a focus indicator, the y origin of the rectangle around which to draw a focus indicator, the width of the rectangle around which to draw a focus indicator, the height of the rectangle around which to draw a focus indicator.
 * Expected: void  
 */
static void test_purpose_75()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 100, 100, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 20
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_NORMAL
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_focus (style, widget->window, STATE_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_polygon
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, GdkPoint *points, gint npoints, gboolean fill
 * Returns: void
 * Assertion: Draws a polygon on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, type of shadow to draw, clip rectangle, the widget, a style detail, an array of GdkPoints, length of points, TRUE if the polygon should be filled.
 * Expected: void  
 */
static void test_purpose_76()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN)
    #define RECT 0, 0, 1, 1
    #define POINTS {0, 0}, {0, 10}, {10, 10}
    #define NPOINTS 3
    #define FILL TRUE
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    GdkPoint points[] = {POINTS};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_polygon (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, points, NPOINTS, FILL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef POINTS
    #undef NPOINTS
    #undef FILL
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_polygon
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, GdkPoint *points, gint npoints, gboolean fill
 * Returns: void
 * Assertion: Draws a polygon on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, type of shadow to draw, clip rectangle, the widget, a style detail, an array of GdkPoints, length of points, TRUE if the polygon should be filled.
 * Expected: void  
 */
static void test_purpose_77()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define POINTS {0, 0}, {0, 10}, {10, 10}, {10, 0}
    #define NPOINTS 4
    #define FILL FALSE
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    GdkPoint points[] = {POINTS};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_polygon (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, points, NPOINTS, FILL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef POINTS
    #undef NPOINTS
    #undef FILL
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_polygon
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, GdkPoint *points, gint npoints, gboolean fill
 * Returns: void
 * Assertion: Draws a polygon on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, type of shadow to draw, clip rectangle, the widget, a style detail, an array of GdkPoints, length of points, TRUE if the polygon should be filled.
 * Expected: void  
 */
static void test_purpose_78()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define POINTS {0, 0}, {0, 10}, {10, 10}
    #define NPOINTS 3
    #define FILL TRUE
    #define STATE_TYPE GTK_STATE_ACTIVE
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    GdkPoint points[] = {POINTS};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_polygon (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, points, NPOINTS, FILL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef POINTS
    #undef NPOINTS
    #undef FILL
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_polygon
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, GdkPoint *points, gint npoints, gboolean fill
 * Returns: void
 * Assertion: Draws a polygon on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, type of shadow to draw, clip rectangle, the widget, a style detail, an array of GdkPoints, length of points, TRUE if the polygon should be filled.
 * Expected: void  
 */
static void test_purpose_79()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define POINTS {0, 0}, {0, 10}, {10, 10}, {10, 0}
    #define NPOINTS 4
    #define FILL FALSE
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    GdkPoint points[] = {POINTS};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_polygon (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, points, NPOINTS, FILL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef POINTS
    #undef NPOINTS
    #undef FILL
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_polygon
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, GdkPoint *points, gint npoints, gboolean fill
 * Returns: void
 * Assertion: Draws a polygon on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, type of shadow to draw, clip rectangle, the widget, a style detail, an array of GdkPoints, length of points, TRUE if the polygon should be filled.
 * Expected: void  
 */
static void test_purpose_80()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define POINTS {0, 0}, {0, 10}, {10, 10}
    #define NPOINTS 3
    #define FILL TRUE
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    GdkPoint points[] = {POINTS};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_polygon (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, points, NPOINTS, FILL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef POINTS
    #undef NPOINTS
    #undef FILL
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_polygon
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, GdkPoint *points, gint npoints, gboolean fill
 * Returns: void
 * Assertion: Draws a polygon on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, type of shadow to draw, clip rectangle, the widget, a style detail, an array of GdkPoints, length of points, TRUE if the polygon should be filled.
 * Expected: void  
 */
static void test_purpose_81()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define POINTS {0, 0}, {0, 10}, {10, 10}, {10, 0}
    #define NPOINTS 4
    #define FILL FALSE
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    GdkPoint points[] = {POINTS};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_polygon (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, points, NPOINTS, FILL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef POINTS
    #undef NPOINTS
    #undef FILL
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_polygon
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, GdkPoint *points, gint npoints, gboolean fill
 * Returns: void
 * Assertion: Draws a polygon on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, type of shadow to draw, clip rectangle, the widget, a style detail, an array of GdkPoints, length of points, TRUE if the polygon should be filled.
 * Expected: void  
 */
static void test_purpose_82()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 100, 100, 100, 100
    #define POINTS {0, 0}, {0, 10}, {10, 10}
    #define NPOINTS 3
    #define FILL TRUE
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    GdkPoint points[] = {POINTS};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_polygon (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, points, NPOINTS, FILL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef POINTS
    #undef NPOINTS
    #undef FILL
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_flat_box
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a flat box on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the box, y origin of the box, the width of the box, the height of the box.
 * Expected: void  
 */
static void test_purpose_83()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN)
    #define RECT 0, 0, 1, 1
    #define X 0
    #define Y 0
    #define WIDTH 10
    #define HEIGHT 10
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_flat_box (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_flat_box
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a flat box on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the box, y origin of the box, the width of the box, the height of the box.
 * Expected: void  
 */
static void test_purpose_84()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 30
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_flat_box (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_flat_box
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a flat box on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the box, y origin of the box, the width of the box, the height of the box.
 * Expected: void  
 */
static void test_purpose_85()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 30
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_ACTIVE
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_flat_box (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_flat_box
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a flat box on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the box, y origin of the box, the width of the box, the height of the box.
 * Expected: void  
 */
static void test_purpose_86()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 10
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_flat_box (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_flat_box
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a flat box on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the box, y origin of the box, the width of the box, the height of the box.
 * Expected: void  
 */
static void test_purpose_87()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_flat_box (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_flat_box
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a flat box on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the box, y origin of the box, the width of the box, the height of the box.
 * Expected: void  
 */
static void test_purpose_88()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 50
    #define Y 50
    #define WIDTH 2
    #define HEIGHT 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_flat_box (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_flat_box
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a flat box on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the box, y origin of the box, the width of the box, the height of the box.
 * Expected: void  
 */
static void test_purpose_89()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 100, 100, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 20
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_flat_box (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_option
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a radio button indicator in the given rectangle on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the option in, y origin of the rectangle to draw the option in, the width of the rectangle to draw the option in, the height of the rectangle to draw the option in  
 * Expected: void  
 */
static void test_purpose_90()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN)
    #define RECT 0, 0, 1, 1
    #define X 0
    #define Y 0
    #define WIDTH 10
    #define HEIGHT 10
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_option (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_option
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a radio button indicator in the given rectangle on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the option in, y origin of the rectangle to draw the option in, the width of the rectangle to draw the option in, the height of the rectangle to draw the option in  
 * Expected: void  
 */
static void test_purpose_91()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 30
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_option (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_option
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a radio button indicator in the given rectangle on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the option in, y origin of the rectangle to draw the option in, the width of the rectangle to draw the option in, the height of the rectangle to draw the option in  
 * Expected: void  
 */
static void test_purpose_92()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 30
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_ACTIVE
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_option (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_option
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a radio button indicator in the given rectangle on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the option in, y origin of the rectangle to draw the option in, the width of the rectangle to draw the option in, the height of the rectangle to draw the option in  
 * Expected: void  
 */
static void test_purpose_93()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 10
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_option (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_option
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a radio button indicator in the given rectangle on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the option in, y origin of the rectangle to draw the option in, the width of the rectangle to draw the option in, the height of the rectangle to draw the option in  
 * Expected: void  
 */
static void test_purpose_94()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_option (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_option
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a radio button indicator in the given rectangle on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the option in, y origin of the rectangle to draw the option in, the width of the rectangle to draw the option in, the height of the rectangle to draw the option in  
 * Expected: void  
 */
static void test_purpose_95()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 50
    #define Y 50
    #define WIDTH 2
    #define HEIGHT 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_option (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_option
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a radio button indicator in the given rectangle on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the option in, y origin of the rectangle to draw the option in, the width of the rectangle to draw the option in, the height of the rectangle to draw the option in  
 * Expected: void  
 */
static void test_purpose_96()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 100, 100, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 20
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_option (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_check
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a check button indicator in the given rectangle on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the check in, y origin of the rectangle to draw the check in, the width of the rectangle to draw the check in, the height of the rectangle to draw the check in  
 * Expected: void  
 */
static void test_purpose_97()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN)
    #define RECT 0, 0, 1, 1
    #define X 0
    #define Y 0
    #define WIDTH 10
    #define HEIGHT 10
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_check (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_check
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a check button indicator in the given rectangle on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the check in, y origin of the rectangle to draw the check in, the width of the rectangle to draw the check in, the height of the rectangle to draw the check in  
 * Expected: void  
 */
static void test_purpose_98()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 30
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_check (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_check
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a check button indicator in the given rectangle on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the check in, y origin of the rectangle to draw the check in, the width of the rectangle to draw the check in, the height of the rectangle to draw the check in  
 * Expected: void  
 */
static void test_purpose_99()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 30
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_ACTIVE
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_check (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_check
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a check button indicator in the given rectangle on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the check in, y origin of the rectangle to draw the check in, the width of the rectangle to draw the check in, the height of the rectangle to draw the check in  
 * Expected: void  
 */
static void test_purpose_100()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 10
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_check (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_check
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a check button indicator in the given rectangle on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the check in, y origin of the rectangle to draw the check in, the width of the rectangle to draw the check in, the height of the rectangle to draw the check in  
 * Expected: void  
 */
static void test_purpose_101()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_check (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_check
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a check button indicator in the given rectangle on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the check in, y origin of the rectangle to draw the check in, the width of the rectangle to draw the check in, the height of the rectangle to draw the check in  
 * Expected: void  
 */
static void test_purpose_102()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 50
    #define Y 50
    #define WIDTH 2
    #define HEIGHT 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_check (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_check
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws a check button indicator in the given rectangle on window with the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the check in, y origin of the rectangle to draw the check in, the width of the rectangle to draw the check in, the height of the rectangle to draw the check in  
 * Expected: void  
 */
static void test_purpose_103()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 100, 100, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 20
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_check (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_tab
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws an option menu tab (i.e. the up and down pointing arrows) in the given rectangle on window using the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the tab in, y origin of the rectangle to draw the tab in, the width of the rectangle to draw the tab in, the height of the rectangle to draw the tab in  
 * Expected: void  
 */
static void test_purpose_104()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_combo_box_new ()
    #define RECT 0, 0, 1, 1
    #define X 0
    #define Y 0
    #define WIDTH 10
    #define HEIGHT 10
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_NONE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_tab (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_tab
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws an option menu tab (i.e. the up and down pointing arrows) in the given rectangle on window using the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the tab in, y origin of the rectangle to draw the tab in, the width of the rectangle to draw the tab in, the height of the rectangle to draw the tab in  
 * Expected: void  
 */
static void test_purpose_105()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_combo_box_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 30
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_tab (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_tab
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws an option menu tab (i.e. the up and down pointing arrows) in the given rectangle on window using the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the tab in, y origin of the rectangle to draw the tab in, the width of the rectangle to draw the tab in, the height of the rectangle to draw the tab in  
 * Expected: void  
 */
static void test_purpose_106()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_combo_box_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 30
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_ACTIVE
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_tab (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_tab
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws an option menu tab (i.e. the up and down pointing arrows) in the given rectangle on window using the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the tab in, y origin of the rectangle to draw the tab in, the width of the rectangle to draw the tab in, the height of the rectangle to draw the tab in  
 * Expected: void  
 */
static void test_purpose_107()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_combo_box_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 10
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_tab (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_tab
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws an option menu tab (i.e. the up and down pointing arrows) in the given rectangle on window using the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the tab in, y origin of the rectangle to draw the tab in, the width of the rectangle to draw the tab in, the height of the rectangle to draw the tab in  
 * Expected: void  
 */
static void test_purpose_108()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_combo_box_new ();
    #define RECT 0, 0, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_tab (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_tab
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws an option menu tab (i.e. the up and down pointing arrows) in the given rectangle on window using the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the tab in, y origin of the rectangle to draw the tab in, the width of the rectangle to draw the tab in, the height of the rectangle to draw the tab in  
 * Expected: void  
 */
static void test_purpose_109()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_combo_box_new ();
    #define RECT 0, 0, 100, 100
    #define X 50
    #define Y 50
    #define WIDTH 2
    #define HEIGHT 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_IN
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_tab (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_tab
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws an option menu tab (i.e. the up and down pointing arrows) in the given rectangle on window using the given parameters.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the rectangle to draw the tab in, y origin of the rectangle to draw the tab in, the width of the rectangle to draw the tab in, the height of the rectangle to draw the tab in  
 * Expected: void  
 */
static void test_purpose_110()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_combo_box_new ();
    #define RECT 100, 100, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 20
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_OUT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_tab (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_extension
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height, GtkPositionType gap_side
 * Returns: void
 * Assertion: Draws an extension, i.e. a notebook tab.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the extension, y origin of the extension, the width of the extension, the height of the extension, the side on to which the extension is attached
 * Expected: void  
 */
static void test_purpose_111()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ()
    #define RECT 0, 0, 1, 1
    #define X 0
    #define Y 0
    #define WIDTH 10
    #define HEIGHT 10
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_NONE
    #define GAP_SIDE GTK_POS_LEFT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_extension (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT, GAP_SIDE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    #undef GAP_SIDE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_extension
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height, GtkPositionType gap_side
 * Returns: void
 * Assertion: Draws an extension, i.e. a notebook tab.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the extension, y origin of the extension, the width of the extension, the height of the extension, the side on to which the extension is attached
 * Expected: void  
 */
static void test_purpose_112()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 30
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_IN
    #define GAP_SIDE GTK_POS_RIGHT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_extension (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT, GAP_SIDE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    #undef GAP_SIDE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_extension
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height, GtkPositionType gap_side
 * Returns: void
 * Assertion: Draws an extension, i.e. a notebook tab.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the extension, y origin of the extension, the width of the extension, the height of the extension, the side on to which the extension is attached
 * Expected: void  
 */
static void test_purpose_113()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 30
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_ACTIVE
    #define SHADOW_TYPE GTK_SHADOW_OUT
    #define GAP_SIDE GTK_POS_TOP
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_extension (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT, GAP_SIDE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    #undef GAP_SIDE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_extension
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height, GtkPositionType gap_side
 * Returns: void
 * Assertion: Draws an extension, i.e. a notebook tab.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the extension, y origin of the extension, the width of the extension, the height of the extension, the side on to which the extension is attached
 * Expected: void  
 */
static void test_purpose_114()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 10
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_IN
    #define GAP_SIDE GTK_POS_BOTTOM
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_extension (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT, GAP_SIDE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    #undef GAP_SIDE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_extension
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height, GtkPositionType gap_side
 * Returns: void
 * Assertion: Draws an extension, i.e. a notebook tab.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the extension, y origin of the extension, the width of the extension, the height of the extension, the side on to which the extension is attached
 * Expected: void  
 */
static void test_purpose_115()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_OUT
    #define GAP_SIDE GTK_POS_LEFT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_extension (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT, GAP_SIDE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    #undef GAP_SIDE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_extension
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height, GtkPositionType gap_side
 * Returns: void
 * Assertion: Draws an extension, i.e. a notebook tab.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the extension, y origin of the extension, the width of the extension, the height of the extension, the side on to which the extension is attached
 * Expected: void  
 */
static void test_purpose_116()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 50
    #define Y 50
    #define WIDTH 2
    #define HEIGHT 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_IN
    #define GAP_SIDE GTK_POS_RIGHT
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_extension (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT, GAP_SIDE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    #undef GAP_SIDE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_extension
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, gint width, gint height, GtkPositionType gap_side
 * Returns: void
 * Assertion: Draws an extension, i.e. a notebook tab.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, x origin of the extension, y origin of the extension, the width of the extension, the height of the extension, the side on to which the extension is attached
 * Expected: void  
 */
static void test_purpose_117()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 100, 100, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 20
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_OUT
    #define GAP_SIDE GTK_POS_TOP
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_extension (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, X, Y, WIDTH, HEIGHT, GAP_SIDE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    #undef GAP_SIDE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_expander
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, GtkExpanderStyle expander_style
 * Returns: void
 * Assertion: Draws an expander as used in GtkTreeView.
 * Params Values: a GtkStyle, a GdkWindow, a state, clip rectangle, the widget, a style detail, the x position to draw the expander at, the y position to draw the expander at, the style to draw the expander in.
 * Expected: void  
 */
static void test_purpose_118()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_expander_new ("foo")
    #define RECT 0, 0, 1, 1
    #define X 0
    #define Y 0
    #define STATE_TYPE GTK_STATE_NORMAL
    #define EXPANDER_STYLE GTK_EXPANDER_COLLAPSED
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_expander (style, widget->window, STATE_TYPE, &rect, widget, NULL, X, Y, EXPANDER_STYLE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef STATE_TYPE
    #undef EXPANDER_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_expander
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, GtkExpanderStyle expander_style
 * Returns: void
 * Assertion: Draws an expander as used in GtkTreeView.
 * Params Values: a GtkStyle, a GdkWindow, a state, clip rectangle, the widget, a style detail, the x position to draw the expander at, the y position to draw the expander at, the style to draw the expander in.
 * Expected: void  
 */
static void test_purpose_119()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_expander_new ("foo");
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define STATE_TYPE GTK_STATE_NORMAL
    #define EXPANDER_STYLE GTK_EXPANDER_SEMI_COLLAPSED
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_expander (style, widget->window, STATE_TYPE, &rect, widget, NULL, X, Y, EXPANDER_STYLE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef STATE_TYPE
    #undef EXPANDER_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_expander
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, GtkExpanderStyle expander_style
 * Returns: void
 * Assertion: Draws an expander as used in GtkTreeView.
 * Params Values: a GtkStyle, a GdkWindow, a state, clip rectangle, the widget, a style detail, the x position to draw the expander at, the y position to draw the expander at, the style to draw the expander in.
 * Expected: void  
 */
static void test_purpose_120()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_expander_new ("foo");
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define STATE_TYPE GTK_STATE_ACTIVE
    #define EXPANDER_STYLE GTK_EXPANDER_SEMI_EXPANDED
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_expander (style, widget->window, STATE_TYPE, &rect, widget, NULL, X, Y, EXPANDER_STYLE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef STATE_TYPE
    #undef EXPANDER_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_expander
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, GtkExpanderStyle expander_style
 * Returns: void
 * Assertion: Draws an expander as used in GtkTreeView.
 * Params Values: a GtkStyle, a GdkWindow, a state, clip rectangle, the widget, a style detail, the x position to draw the expander at, the y position to draw the expander at, the style to draw the expander in.
 * Expected: void  
 */
static void test_purpose_121()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_expander_new ("foo");
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define EXPANDER_STYLE GTK_EXPANDER_EXPANDED
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_expander (style, widget->window, STATE_TYPE, &rect, widget, NULL, X, Y, EXPANDER_STYLE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef STATE_TYPE
    #undef EXPANDER_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_expander
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, GtkExpanderStyle expander_style
 * Returns: void
 * Assertion: Draws an expander as used in GtkTreeView.
 * Params Values: a GtkStyle, a GdkWindow, a state, clip rectangle, the widget, a style detail, the x position to draw the expander at, the y position to draw the expander at, the style to draw the expander in.
 * Expected: void  
 */
static void test_purpose_122()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_expander_new ("foo");
    #define RECT 0, 0, 100, 100
    #define X 1
    #define Y 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define EXPANDER_STYLE GTK_EXPANDER_COLLAPSED
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_expander (style, widget->window, STATE_TYPE, &rect, widget, NULL, X, Y, EXPANDER_STYLE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef STATE_TYPE
    #undef EXPANDER_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_expander
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, GtkExpanderStyle expander_style
 * Returns: void
 * Assertion: Draws an expander as used in GtkTreeView.
 * Params Values: a GtkStyle, a GdkWindow, a state, clip rectangle, the widget, a style detail, the x position to draw the expander at, the y position to draw the expander at, the style to draw the expander in.
 * Expected: void  
 */
static void test_purpose_123()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_expander_new ("foo");
    #define RECT 0, 0, 100, 100
    #define X 50
    #define Y 50
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define EXPANDER_STYLE GTK_EXPANDER_SEMI_COLLAPSED
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_expander (style, widget->window, STATE_TYPE, &rect, widget, NULL, X, Y, EXPANDER_STYLE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef STATE_TYPE
    #undef EXPANDER_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_expander
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, GtkExpanderStyle expander_style
 * Returns: void
 * Assertion: Draws an expander as used in GtkTreeView.
 * Params Values: a GtkStyle, a GdkWindow, a state, clip rectangle, the widget, a style detail, the x position to draw the expander at, the y position to draw the expander at, the style to draw the expander in.
 * Expected: void  
 */
static void test_purpose_124()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_expander_new ("foo");
    #define RECT 100, 100, 100, 100
    #define X 1
    #define Y 2
    #define STATE_TYPE GTK_STATE_NORMAL
    #define EXPANDER_STYLE GTK_EXPANDER_SEMI_EXPANDED
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_expander (style, widget->window, STATE_TYPE, &rect, widget, NULL, X, Y, EXPANDER_STYLE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef STATE_TYPE
    #undef EXPANDER_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_arrow
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, GtkArrowType arrow_type, gboolean fill, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws an arrow in the given rectangle on window using the given parameters. arrow_type determines the direction of the arrow.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, the type of arrow to draw, TRUE if the arrow tip should be filled, x origin of the rectangle to draw the arrow in, y origin of the rectangle to draw the arrow in, the width of the rectangle to draw the arrow in, the height of the rectangle to draw the arrow in.
 * Expected: void  
 */
static void test_purpose_125()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN)
    #define RECT 0, 0, 1, 1
    #define X 0
    #define Y 0
    #define WIDTH 10
    #define HEIGHT 10
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_NONE
    #define ARROW_TYPE GTK_ARROW_UP
    #define FILL TRUE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_arrow (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, ARROW_TYPE, FILL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    #undef ARROW_TYPE
    #undef FILL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_arrow
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, GtkArrowType arrow_type, gboolean fill, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws an arrow in the given rectangle on window using the given parameters. arrow_type determines the direction of the arrow.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, the type of arrow to draw, TRUE if the arrow tip should be filled, x origin of the rectangle to draw the arrow in, y origin of the rectangle to draw the arrow in, the width of the rectangle to draw the arrow in, the height of the rectangle to draw the arrow in.
 * Expected: void  
 */
static void test_purpose_126()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 30
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_IN
    #define ARROW_TYPE GTK_ARROW_DOWN
    #define FILL TRUE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_arrow (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, ARROW_TYPE, FILL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    #undef ARROW_TYPE
    #undef FILL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_arrow
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, GtkArrowType arrow_type, gboolean fill, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws an arrow in the given rectangle on window using the given parameters. arrow_type determines the direction of the arrow.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, the type of arrow to draw, TRUE if the arrow tip should be filled, x origin of the rectangle to draw the arrow in, y origin of the rectangle to draw the arrow in, the width of the rectangle to draw the arrow in, the height of the rectangle to draw the arrow in.
 * Expected: void  
 */
static void test_purpose_127()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 30
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_ACTIVE
    #define SHADOW_TYPE GTK_SHADOW_OUT
    #define ARROW_TYPE GTK_ARROW_LEFT
    #define FILL TRUE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_arrow (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, ARROW_TYPE, FILL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    #undef ARROW_TYPE
    #undef FILL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_arrow
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, GtkArrowType arrow_type, gboolean fill, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws an arrow in the given rectangle on window using the given parameters. arrow_type determines the direction of the arrow.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, the type of arrow to draw, TRUE if the arrow tip should be filled, x origin of the rectangle to draw the arrow in, y origin of the rectangle to draw the arrow in, the width of the rectangle to draw the arrow in, the height of the rectangle to draw the arrow in.
 * Expected: void  
 */
static void test_purpose_128()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define WIDTH 10
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_IN
    #define ARROW_TYPE GTK_ARROW_RIGHT
    #define FILL TRUE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_arrow (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, ARROW_TYPE, FILL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    #undef ARROW_TYPE
    #undef FILL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_arrow
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, GtkArrowType arrow_type, gboolean fill, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws an arrow in the given rectangle on window using the given parameters. arrow_type determines the direction of the arrow.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, the type of arrow to draw, TRUE if the arrow tip should be filled, x origin of the rectangle to draw the arrow in, y origin of the rectangle to draw the arrow in, the width of the rectangle to draw the arrow in, the height of the rectangle to draw the arrow in.
 * Expected: void  
 */
static void test_purpose_129()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 50
    #define HEIGHT 50
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_ETCHED_OUT
    #define ARROW_TYPE GTK_ARROW_UP
    #define FILL FALSE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_arrow (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, ARROW_TYPE, FILL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    #undef ARROW_TYPE
    #undef FILL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_arrow
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, GtkArrowType arrow_type, gboolean fill, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws an arrow in the given rectangle on window using the given parameters. arrow_type determines the direction of the arrow.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, the type of arrow to draw, TRUE if the arrow tip should be filled, x origin of the rectangle to draw the arrow in, y origin of the rectangle to draw the arrow in, the width of the rectangle to draw the arrow in, the height of the rectangle to draw the arrow in.
 * Expected: void  
 */
static void test_purpose_130()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 50
    #define Y 50
    #define WIDTH 2
    #define HEIGHT 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define SHADOW_TYPE GTK_SHADOW_IN
    #define ARROW_TYPE GTK_ARROW_DOWN
    #define FILL FALSE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_arrow (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, ARROW_TYPE, FILL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    #undef ARROW_TYPE
    #undef FILL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_arrow
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, GtkShadowType shadow_type, GdkRectangle *area, GtkWidget *widget, const gchar *detail, GtkArrowType arrow_type, gboolean fill, gint x, gint y, gint width, gint height
 * Returns: void
 * Assertion: Draws an arrow in the given rectangle on window using the given parameters. arrow_type determines the direction of the arrow.
 * Params Values: a GtkStyle, a GdkWindow, a state, the type of shadow to draw, clip rectangle, the widget, a style detail, the type of arrow to draw, TRUE if the arrow tip should be filled, x origin of the rectangle to draw the arrow in, y origin of the rectangle to draw the arrow in, the width of the rectangle to draw the arrow in, the height of the rectangle to draw the arrow in.
 * Expected: void  
 */
static void test_purpose_131()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 100, 100, 100, 100
    #define X 1
    #define Y 2
    #define WIDTH 20
    #define HEIGHT 20
    #define STATE_TYPE GTK_STATE_NORMAL
    #define SHADOW_TYPE GTK_SHADOW_OUT
    #define ARROW_TYPE GTK_ARROW_LEFT
    #define FILL FALSE
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_arrow (style, widget->window, STATE_TYPE, SHADOW_TYPE, &rect, widget, NULL, ARROW_TYPE, FILL, X, Y, WIDTH, HEIGHT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef WIDTH
    #undef HEIGHT
    #undef STATE_TYPE
    #undef SHADOW_TYPE
    #undef ARROW_TYPE
    #undef FILL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_layout
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, gboolean use_text, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, PangoLayout *layout
 * Returns: void
 * Assertion: 
 * Params Values: 
 * Expected: void  
 */
static void test_purpose_132()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ()
    #define RECT 0, 0, 1, 1
    #define X 0
    #define Y 0
    #define STATE_TYPE GTK_STATE_NORMAL
    #define USE_TEXT TRUE
    #define LAYOUT gtk_widget_create_pango_layout (widget, NULL)
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_layout (style, widget->window, STATE_TYPE, USE_TEXT, &rect, widget, NULL, X, Y, LAYOUT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef STATE_TYPE
    #undef USE_TEXT
    #undef LAYOUT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_layout
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, gboolean use_text, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, PangoLayout *layout
 * Returns: void
 * Assertion: 
 * Params Values: 
 * Expected: void  
 */
static void test_purpose_133()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define STATE_TYPE GTK_STATE_NORMAL
    #define USE_TEXT TRUE
    #define LAYOUT gtk_widget_create_pango_layout (widget, NULL)
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_layout (style, widget->window, STATE_TYPE, USE_TEXT, &rect, widget, NULL, X, Y, LAYOUT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef STATE_TYPE
    #undef USE_TEXT
    #undef LAYOUT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_layout
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, gboolean use_text, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, PangoLayout *layout
 * Returns: void
 * Assertion: 
 * Params Values: 
 * Expected: void  
 */
static void test_purpose_134()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define STATE_TYPE GTK_STATE_ACTIVE
    #define USE_TEXT TRUE
    #define LAYOUT gtk_widget_create_pango_layout (widget, NULL)
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_layout (style, widget->window, STATE_TYPE, USE_TEXT, &rect, widget, NULL, X, Y, LAYOUT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef STATE_TYPE
    #undef USE_TEXT
    #undef LAYOUT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_layout
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, gboolean use_text, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, PangoLayout *layout
 * Returns: void
 * Assertion: 
 * Params Values: 
 * Expected: void  
 */
static void test_purpose_135()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 10, 10
    #define X 1
    #define Y 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define USE_TEXT TRUE
    #define LAYOUT gtk_widget_create_pango_layout (widget, NULL)
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_layout (style, widget->window, STATE_TYPE, USE_TEXT, &rect, widget, NULL, X, Y, LAYOUT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef STATE_TYPE
    #undef USE_TEXT
    #undef LAYOUT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_layout
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, gboolean use_text, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, PangoLayout *layout
 * Returns: void
 * Assertion: 
 * Params Values: 
 * Expected: void  
 */
static void test_purpose_136()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 1
    #define Y 2
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define USE_TEXT FALSE
    #define LAYOUT gtk_widget_create_pango_layout (widget, NULL)
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_layout (style, widget->window, STATE_TYPE, USE_TEXT, &rect, widget, NULL, X, Y, LAYOUT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef STATE_TYPE
    #undef USE_TEXT
    #undef LAYOUT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_layout
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, gboolean use_text, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, PangoLayout *layout
 * Returns: void
 * Assertion: 
 * Params Values: 
 * Expected: void  
 */
static void test_purpose_137()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 0, 0, 100, 100
    #define X 50
    #define Y 50
    #define STATE_TYPE GTK_STATE_INSENSITIVE
    #define USE_TEXT FALSE
    #define LAYOUT gtk_widget_create_pango_layout (widget, NULL)
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_layout (style, widget->window, STATE_TYPE, USE_TEXT, &rect, widget, NULL, X, Y, LAYOUT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef STATE_TYPE
    #undef USE_TEXT
    #undef LAYOUT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_paint_layout
 * Params: GtkStyle *style, GdkWindow *window, GtkStateType state_type, gboolean use_text, GdkRectangle *area, GtkWidget *widget, const gchar *detail, gint x, gint y, PangoLayout *layout
 * Returns: void
 * Assertion: 
 * Params Values: 
 * Expected: void  
 */
static void test_purpose_138()
{
    #define STYLE gtk_style_new ()
    #define WIDGET gtk_button_new ();
    #define RECT 100, 100, 100, 100
    #define X 1
    #define Y 2
    #define STATE_TYPE GTK_STATE_NORMAL
    #define USE_TEXT FALSE
    #define LAYOUT gtk_widget_create_pango_layout (widget, NULL)
    
    GtkStyle* style;
    GtkWidget* widget;
    GtkWidget* container;
    GdkWindow* window;
    GdkRectangle rect = {RECT};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    style = STYLE;
    if (!style)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    container = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!container)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    gtk_container_add (GTK_CONTAINER (container), widget);
    gtk_widget_realize (widget);
    
    gtk_style_attach (style, widget->window);
    
    gtk_paint_layout (style, widget->window, STATE_TYPE, USE_TEXT, &rect, widget, NULL, X, Y, LAYOUT);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (container);
    
    #undef STYLE
    #undef WIDGET
    #undef RECT
    #undef X
    #undef Y
    #undef STATE_TYPE
    #undef USE_TEXT
    #undef LAYOUT
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for Styles ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {test_purpose_101, 1},
    {test_purpose_102, 1},
    {test_purpose_103, 1},
    {test_purpose_104, 1},
    {test_purpose_105, 1},
    {test_purpose_106, 1},
    {test_purpose_107, 1},
    {test_purpose_108, 1},
    {test_purpose_109, 1},
    {test_purpose_110, 1},
    {test_purpose_111, 1},
    {test_purpose_112, 1},
    {test_purpose_113, 1},
    {test_purpose_114, 1},
    {test_purpose_115, 1},
    {test_purpose_116, 1},
    {test_purpose_117, 1},
    {test_purpose_118, 1},
    {test_purpose_119, 1},
    {test_purpose_120, 1},
    {test_purpose_121, 1},
    {test_purpose_122, 1},
    {test_purpose_123, 1},
    {test_purpose_124, 1},
    {test_purpose_125, 1},
    {test_purpose_126, 1},
    {test_purpose_127, 1},
    {test_purpose_128, 1},
    {test_purpose_129, 1},
    {test_purpose_130, 1},
    {test_purpose_131, 1},
    {test_purpose_132, 1},
    {test_purpose_133, 1},
    {test_purpose_134, 1},
    {test_purpose_135, 1},
    {test_purpose_136, 1},
    {test_purpose_137, 1},
    {test_purpose_138, 1},
    {NULL,0}
};
